@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -29,14 +29,14 @@
 #include "eab-gui-util.h"
 #include "e-addressbook-view.h"
 
-static const char * action_name[] = {
+static const gchar * action_name[] = {
 	N_("New Contact"),
 	N_("New Contact List")
 };
 
 
-static G_CONST_RETURN gchar* ea_minicard_view_get_name (AtkObject *accessible);
-static G_CONST_RETURN gchar* ea_minicard_view_get_description (AtkObject *accessible);
+static G_CONST_RETURN gchar * ea_minicard_view_get_name (AtkObject *accessible);
+static G_CONST_RETURN gchar * ea_minicard_view_get_description (AtkObject *accessible);
 
 static void ea_minicard_view_class_init (EaMinicardViewClass *klass);
 
@@ -58,8 +58,8 @@ static gboolean selection_interface_is_child_selected (AtkSelection *selection,
 static void atk_action_interface_init (AtkActionIface *iface);
 static gboolean atk_action_interface_do_action (AtkAction *iface, gint i);
 static gint atk_action_interface_get_n_action (AtkAction *iface);
-static G_CONST_RETURN gchar* atk_action_interface_get_description (AtkAction *iface, gint i);
-static G_CONST_RETURN gchar* atk_action_interface_get_name (AtkAction *iface, gint i);
+static G_CONST_RETURN gchar * atk_action_interface_get_description (AtkAction *iface, gint i);
+static G_CONST_RETURN gchar * atk_action_interface_get_name (AtkAction *iface, gint i);
 
 static gpointer parent_class = NULL;
 
@@ -135,7 +135,7 @@ ea_minicard_view_class_init (EaMinicardViewClass *klass)
 	class->ref_child = ea_minicard_view_ref_child;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 ea_minicard_view_get_name (AtkObject *accessible)
 {
 	EReflow *reflow;
@@ -160,8 +160,8 @@ ea_minicard_view_get_name (AtkObject *accessible)
 		source_name="";
 
 	string = g_strdup_printf (ngettext ("current address book folder %s has %d card",
-	                          "current address book folder %s has %d cards",
-	                          reflow->count), source_name, reflow->count);
+				  "current address book folder %s has %d cards",
+				  reflow->count), source_name, reflow->count);
 
 	ATK_OBJECT_CLASS (parent_class)->set_name (accessible, string);
 	g_free (string);
@@ -169,7 +169,7 @@ ea_minicard_view_get_name (AtkObject *accessible)
 	return accessible->name;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 ea_minicard_view_get_description (AtkObject *accessible)
 {
 	g_return_val_if_fail (EA_IS_MINICARD_VIEW(accessible), NULL);
@@ -390,7 +390,7 @@ static gboolean atk_action_interface_do_action (AtkAction *action, gint i)
 			eab_show_contact_list_editor (book, contact, TRUE, TRUE);
 			break;
 		default:
-                	return_value = FALSE;
+			return_value = FALSE;
 			break;
 	}
 	g_object_unref (book);
@@ -403,13 +403,13 @@ static gint atk_action_interface_get_n_action (AtkAction *iface)
 	return G_N_ELEMENTS (action_name);
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 atk_action_interface_get_description (AtkAction *iface, gint i)
 {
 	return atk_action_interface_get_name (iface, i);
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 atk_action_interface_get_name (AtkAction *iface, gint i)
 {
 	if( i >= G_N_ELEMENTS (action_name) || i < 0)
