@@ -1,25 +1,23 @@
-/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* vim:expandtab:shiftwidth=8:tabstop=8:
- */
-/* Evolution Accessibility: ea-day-view-main-item.c
- *
- * Copyright (C) 2003 Ximian, Inc.
+/*
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- * Author: Bolian Yin <bolian.yin@sun.com> Sun Microsystem Inc., 2003
+ *
+ * Authors:
+ *		Bolian Yin <bolian.yin@sun.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -34,8 +32,8 @@
 static void ea_day_view_main_item_class_init (EaDayViewMainItemClass *klass);
 
 static void ea_day_view_main_item_finalize (GObject *object);
-static G_CONST_RETURN gchar* ea_day_view_main_item_get_name (AtkObject *accessible);
-static G_CONST_RETURN gchar* ea_day_view_main_item_get_description (AtkObject *accessible);
+static G_CONST_RETURN gchar * ea_day_view_main_item_get_name (AtkObject *accessible);
+static G_CONST_RETURN gchar * ea_day_view_main_item_get_description (AtkObject *accessible);
 
 static gint         ea_day_view_main_item_get_n_children (AtkObject *obj);
 static AtkObject*   ea_day_view_main_item_ref_child (AtkObject *obj,
@@ -63,7 +61,7 @@ static gint table_interface_get_column_at_index (AtkTable *table,
 static gint table_interface_get_row_at_index (AtkTable *table,
 					      gint     index);
 static AtkObject* table_interface_ref_at (AtkTable *table,
-					  gint     row, 
+					  gint     row,
 					  gint     column);
 static gint table_interface_get_n_rows (AtkTable *table);
 static gint table_interface_get_n_columns (AtkTable *table);
@@ -97,10 +95,10 @@ static AtkObject* table_interface_get_column_header (AtkTable *table,
 						     gint in_col);
 static AtkObject* table_interface_get_caption (AtkTable *table);
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 table_interface_get_column_description (AtkTable *table, gint in_col);
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 table_interface_get_row_description (AtkTable *table, gint row);
 
 static AtkObject* table_interface_get_summary (AtkTable *table);
@@ -229,7 +227,7 @@ ea_day_view_main_item_class_init (EaDayViewMainItemClass *klass)
 	class->get_index_in_parent = ea_day_view_main_item_get_index_in_parent;
 }
 
-AtkObject* 
+AtkObject*
 ea_day_view_main_item_new (GObject *obj)
 {
 	AtkObject *accessible;
@@ -284,7 +282,7 @@ ea_day_view_main_item_finalize (GObject *object)
 #endif
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 ea_day_view_main_item_get_name (AtkObject *accessible)
 {
 	AtkObject *parent;
@@ -297,7 +295,7 @@ ea_day_view_main_item_get_name (AtkObject *accessible)
 	return atk_object_get_name (parent);
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 ea_day_view_main_item_get_description (AtkObject *accessible)
 {
 	return _("a table to view and select the current time range");
@@ -447,11 +445,11 @@ ea_day_view_main_item_time_change_cb (EDayView *day_view, gpointer data)
 		atk_state_set_add_state (state_set, ATK_STATE_FOCUSED);
 		g_object_unref (state_set);
 
-	        g_signal_emit_by_name (ea_main_item,
+		g_signal_emit_by_name (ea_main_item,
 			       "active-descendant-changed",
 			       item_cell);
-        	g_signal_emit_by_name (data, "selection_changed");
-                
+		g_signal_emit_by_name (data, "selection_changed");
+
                 atk_focus_tracker_notify (item_cell);
                 g_object_unref (item_cell);
 	}
@@ -545,7 +543,7 @@ ea_day_view_main_item_get_row_label (EaDayViewMainItem *ea_main_item,
 	GObject *g_obj;
 	EDayViewMainItem *main_item;
 	EDayView *day_view;
-	gchar *suffix;
+	const gchar *suffix;
 	gint hour, minute, suffix_width;
 
 	g_return_val_if_fail (ea_main_item, 0);
@@ -553,7 +551,7 @@ ea_day_view_main_item_get_row_label (EaDayViewMainItem *ea_main_item,
 	atk_gobj = ATK_GOBJECT_ACCESSIBLE (ea_main_item);
 	g_obj = atk_gobject_accessible_get_object (atk_gobj);
 	if (!g_obj)
-		return 0 ;
+		return 0;
 
 	main_item = E_DAY_VIEW_MAIN_ITEM (g_obj);
 	day_view = main_item->day_view;
@@ -618,7 +616,7 @@ ea_day_view_main_item_destory_cell_data (EaDayViewMainItem *ea_main_item)
 
 /* Atk Component Interface */
 
-static void 
+static void
 atk_component_interface_init (AtkComponentIface *iface)
 {
 	g_return_if_fail (iface != NULL);
@@ -626,7 +624,7 @@ atk_component_interface_init (AtkComponentIface *iface)
 	iface->get_extents = component_interface_get_extents;
 }
 
-static void 
+static void
 component_interface_get_extents (AtkComponent *component,
 				 gint *x, gint *y, gint *width, gint *height,
 				 AtkCoordType coord_type)
@@ -654,7 +652,7 @@ component_interface_get_extents (AtkComponent *component,
 
 /* atk table interface */
 
-static void 
+static void
 atk_table_interface_init (AtkTableIface *iface)
 {
 	g_return_if_fail (iface != NULL);
@@ -687,9 +685,9 @@ atk_table_interface_init (AtkTableIface *iface)
 	iface->get_column_description = table_interface_get_column_description;
 }
 
-static AtkObject* 
+static AtkObject*
 table_interface_ref_at (AtkTable *table,
-			gint     row, 
+			gint     row,
 			gint     column)
 {
 	gint index;
@@ -700,7 +698,7 @@ table_interface_ref_at (AtkTable *table,
 	return ea_day_view_main_item_ref_child (ATK_OBJECT (ea_main_item), index);
 }
 
-static gint 
+static gint
 table_interface_get_n_rows (AtkTable *table)
 {
 	AtkGObjectAccessible *atk_gobj;
@@ -720,7 +718,7 @@ table_interface_get_n_rows (AtkTable *table)
 	return day_view->rows;
 }
 
-static gint 
+static gint
 table_interface_get_n_columns (AtkTable *table)
 {
 	AtkGObjectAccessible *atk_gobj;
@@ -787,7 +785,7 @@ table_interface_get_column_extent_at (AtkTable      *table,
 	return width;
 }
 
-static gint 
+static gint
 table_interface_get_row_extent_at (AtkTable      *table,
 				   gint          row,
 				   gint          column)
@@ -808,7 +806,7 @@ table_interface_get_row_extent_at (AtkTable      *table,
 	return height;
 }
 
-static gboolean 
+static gboolean
 table_interface_is_row_selected (AtkTable *table,
 				 gint     row)
 {
@@ -838,16 +836,16 @@ table_interface_is_row_selected (AtkTable *table,
 	return FALSE;
 }
 
-static gboolean 
-table_interface_is_selected (AtkTable *table, 
-			     gint     row, 
+static gboolean
+table_interface_is_selected (AtkTable *table,
+			     gint     row,
 			     gint     column)
 {
 	return table_interface_is_row_selected (table, row) &&
 		table_interface_is_column_selected (table, column);
 }
 
-static gboolean 
+static gboolean
 table_interface_is_column_selected (AtkTable *table,
 				    gint     column)
 {
@@ -871,7 +869,7 @@ table_interface_is_column_selected (AtkTable *table,
 	return FALSE;
 }
 
-static gint 
+static gint
 table_interface_get_selected_rows (AtkTable *table,
 				   gint     **rows_selected)
 {
@@ -912,7 +910,7 @@ table_interface_get_selected_rows (AtkTable *table,
 	return n_rows;
 }
 
-static gint 
+static gint
 table_interface_get_selected_columns (AtkTable *table,
 				      gint **columns_selected)
 {
@@ -946,8 +944,8 @@ table_interface_get_selected_columns (AtkTable *table,
 	return n_columns;
 }
 
-static gboolean 
-table_interface_add_row_selection (AtkTable *table, 
+static gboolean
+table_interface_add_row_selection (AtkTable *table,
 				   gint row)
 {
 	AtkGObjectAccessible *atk_gobj;
@@ -979,15 +977,15 @@ table_interface_add_row_selection (AtkTable *table,
 	return TRUE;
 }
 
-static gboolean 
-table_interface_remove_row_selection (AtkTable *table, 
+static gboolean
+table_interface_remove_row_selection (AtkTable *table,
 				      gint row)
 {
 	return FALSE;
 }
 
-static gboolean 
-table_interface_add_column_selection (AtkTable *table, 
+static gboolean
+table_interface_add_column_selection (AtkTable *table,
 				      gint column)
 {
 	AtkGObjectAccessible *atk_gobj;
@@ -1016,24 +1014,24 @@ table_interface_add_column_selection (AtkTable *table,
 	return TRUE;
 }
 
-static gboolean 
-table_interface_remove_column_selection (AtkTable *table, 
+static gboolean
+table_interface_remove_column_selection (AtkTable *table,
 					 gint     column)
 {
 	/* FIXME: NOT IMPLEMENTED */
 	return FALSE;
 }
 
-static AtkObject* 
-table_interface_get_row_header (AtkTable *table, 
+static AtkObject*
+table_interface_get_row_header (AtkTable *table,
 				gint     row)
 {
 	/* FIXME: NOT IMPLEMENTED */
 	return NULL;
 }
 
-static AtkObject* 
-table_interface_get_column_header (AtkTable *table, 
+static AtkObject*
+table_interface_get_column_header (AtkTable *table,
 				   gint     in_col)
 {
 	/* FIXME: NOT IMPLEMENTED */
@@ -1047,7 +1045,7 @@ table_interface_get_caption (AtkTable	*table)
 	return NULL;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 table_interface_get_column_description (AtkTable	  *table,
 					gint       in_col)
 {
@@ -1083,7 +1081,7 @@ table_interface_get_column_description (AtkTable	  *table,
 	return description;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 table_interface_get_row_description (AtkTable    *table,
 				     gint        row)
 {
@@ -1202,7 +1200,7 @@ selection_interface_clear_selection (AtkSelection *selection)
 	return TRUE;
 }
 
-static AtkObject*  
+static AtkObject*
 selection_interface_ref_selection (AtkSelection *selection, gint i)
 {
 	gint count;
