@@ -1,9 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
  * Authors:
- *   Christopher James Lahey <clahey@ximian.com>
+ *		Christopher James Lahey <clahey@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
  */
 
 #include <config.h>
@@ -97,9 +111,9 @@ gal_a11y_e_cell_registry_get_object     (GalA11yECellRegistry     *registry,
 					 ETableItem               *item,
 					 ECellView                *cell_view,
 					 AtkObject                *parent,
-					 int                       model_col,
-					 int                       view_col,
-					 int                       row)
+					 gint                       model_col,
+					 gint                       view_col,
+					 gint                       row)
 {
 	GalA11yECellRegistryFunc func = NULL;
 	GType type;
