@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -102,8 +102,8 @@ toggle_cell_action (GalA11yECell *cell)
 	e_table_item_get_cell_geometry (cell->item, &row, &col,
 					&x, &y, &width, &height);
 
-	event.x = x + width / 2 + (int)(GNOME_CANVAS_ITEM (cell->item)->x1);
-	event.y = y + height / 2 + (int)(GNOME_CANVAS_ITEM (cell->item)->y1);
+	event.x = x + width / 2 + (gint)(GNOME_CANVAS_ITEM (cell->item)->x1);
+	event.y = y + height / 2 + (gint)(GNOME_CANVAS_ITEM (cell->item)->y1);
 
 	event.type = GDK_BUTTON_PRESS;
 	event.window = GTK_LAYOUT(GNOME_CANVAS_ITEM(cell->item)->canvas)->bin_window;
@@ -125,9 +125,9 @@ model_change_cb (ETableModel *etm,
 
 	if (col == cell->model_col && row == cell->row) {
 
-	        value = GPOINTER_TO_INT (
+		value = GPOINTER_TO_INT (
 			e_table_model_value_at (cell->cell_view->e_table_model,
-			 			cell->model_col, cell->row));
+						cell->model_col, cell->row));
 		/* Cheat gnopernicus, or it will ignore the state change signal  */
                 atk_focus_tracker_notify (ATK_OBJECT (cell));
 
@@ -143,9 +143,9 @@ AtkObject*
 gal_a11y_e_cell_toggle_new (ETableItem *item,
 			    ECellView  *cell_view,
 			    AtkObject  *parent,
-			    int         model_col,
-			    int         view_col,
-			    int         row)
+			    gint         model_col,
+			    gint         view_col,
+			    gint         row)
 {
 	AtkObject *a11y;
 	GalA11yECell *cell;
