@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -49,9 +49,9 @@ struct _GalA11yECell {
 	ETableItem *item;
 	ECellView  *cell_view;
 	AtkObject  *parent;
-	int         model_col;
-	int         view_col;
-	int         row;
+	gint         model_col;
+	gint         view_col;
+	gint         row;
 	AtkStateSet *state_set;
 	GList       *action_list;
 	gint         action_idle_handler;
@@ -76,21 +76,21 @@ GType      gal_a11y_e_cell_get_type   (void);
 AtkObject *gal_a11y_e_cell_new        (ETableItem *item,
 				       ECellView  *cell_view,
 				       AtkObject  *parent,
-				       int         model_col,
-				       int         view_col,
-				       int         row);
+				       gint         model_col,
+				       gint         view_col,
+				       gint         row);
 void       gal_a11y_e_cell_construct  (AtkObject  *object,
 				       ETableItem *item,
 				       ECellView  *cell_view,
 				       AtkObject  *parent,
-				       int         model_col,
-				       int         view_col,
-				       int         row);
+				       gint         model_col,
+				       gint         view_col,
+				       gint         row);
 
 void	gal_a11y_e_cell_type_add_action_interface (GType type);
 
 gboolean gal_a11y_e_cell_add_action	(GalA11yECell	*cell,
-				         const gchar     *action_name,
+					 const gchar     *action_name,
 					 const gchar     *action_description,
 					 const gchar     *action_keybinding,
 					 ACTION_FUNC     action_func);
@@ -99,7 +99,7 @@ gboolean gal_a11y_e_cell_remove_action	(GalA11yECell	*cell,
                                          gint           action_id);
 
 gboolean gal_a11y_e_cell_remove_action_by_name (GalA11yECell        *cell,
-                                          	const gchar     *action_name);
+						const gchar     *action_name);
 
 gboolean gal_a11y_e_cell_add_state     (GalA11yECell *cell,
 					AtkStateType state_type,
