@@ -1,8 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Yuedong Du <yuedong.du@sun.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Yuedong Du <yuedong.du@sun.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
  */
 
 #include <config.h>
@@ -21,7 +36,7 @@
 static AtkObjectClass *parent_class;
 static GType parent_type;
 static gint priv_offset;
-#define GET_PRIVATE(object) ((GalA11yETableClickToAddPrivate *) (((char *) object) + priv_offset))
+#define GET_PRIVATE(object) ((GalA11yETableClickToAddPrivate *) (((gchar *) object) + priv_offset))
 #define PARENT_TYPE (parent_type)
 
 struct _GalA11yETableClickToAddPrivate {
@@ -36,7 +51,7 @@ etcta_get_n_actions (AtkAction *action)
 	return 1;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 etcta_get_description (AtkAction *action,
                              gint      i)
 {
@@ -46,7 +61,7 @@ etcta_get_description (AtkAction *action,
 	return NULL;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 etcta_action_get_name (AtkAction *action, gint      i)
 {
 	if (i == 0)
@@ -309,7 +324,7 @@ gal_a11y_e_table_click_to_add_new (GObject *widget)
 
 
 	g_signal_connect_after (G_OBJECT(widget), "event",
-	    			G_CALLBACK (etcta_event), a11y);
+				G_CALLBACK (etcta_event), a11y);
 
 	g_signal_connect (etcta->selection, "cursor_changed",
 			G_CALLBACK (etcta_selection_cursor_changed), a11y);
