@@ -1,25 +1,23 @@
-/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* vim:expandtab:shiftwidth=8:tabstop=8:
- */
-/* Evolution Accessibility: ea-calendar-cell.c
- *
- * Copyright (C) 2003 Ximian, Inc.
+/*
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- * Author: Bolian Yin <bolian.yin@sun.com> Sun Microsystem Inc., 2003
+ *
+ * Authors:
+ *		Bolian Yin <bolian.yin@sun.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -82,7 +80,7 @@ e_calendar_cell_new (ECalendarItem *calitem, gint row, gint column)
 	cell->column = column;
 
 #ifdef ACC_DEBUG
-	g_print ("EvoAcc: e_calendar_cell created %p\n", (void *)cell);
+	g_print ("EvoAcc: e_calendar_cell created %p\n", (gpointer)cell);
 #endif
 
 	return cell;
@@ -93,8 +91,8 @@ e_calendar_cell_new (ECalendarItem *calitem, gint row, gint column)
 static void ea_calendar_cell_class_init (EaCalendarCellClass *klass);
 static void ea_calendar_cell_init (EaCalendarCell *a11y);
 
-static G_CONST_RETURN gchar* ea_calendar_cell_get_name (AtkObject *accessible);
-static G_CONST_RETURN gchar* ea_calendar_cell_get_description (AtkObject *accessible);
+static G_CONST_RETURN gchar * ea_calendar_cell_get_name (AtkObject *accessible);
+static G_CONST_RETURN gchar * ea_calendar_cell_get_description (AtkObject *accessible);
 static AtkObject * ea_calendar_cell_get_parent (AtkObject *accessible);
 static gint ea_calendar_cell_get_index_in_parent (AtkObject *accessible);
 static AtkStateSet *ea_calendar_cell_ref_state_set (AtkObject *accessible);
@@ -211,7 +209,7 @@ static void ea_calendar_cell_finalize (GObject *object)
 }
 #endif
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 ea_calendar_cell_get_name (AtkObject *accessible)
 {
 	GObject *g_obj;
@@ -245,7 +243,7 @@ ea_calendar_cell_get_name (AtkObject *accessible)
 	return accessible->name;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 ea_calendar_cell_get_description (AtkObject *accessible)
 {
 	return ea_calendar_cell_get_name (accessible);
