@@ -1,30 +1,30 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* addressbook.c
- *
- * Copyright (C) 2000, 2001, 2002 Ximian, Inc.
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Chris Lahey <clahey@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Chris Lahey (clahey@ximian.com)
  */
 
 #include <config.h>
 
 #include <string.h>
 
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libebook/e-book.h>
 #include <libedataserver/e-url.h>
@@ -57,10 +57,10 @@ free_load_source_data (LoadSourceData *data)
 /*this function removes of anything present after semicolon
 in uri*/
 
-static gchar*
+static gchar *
 remove_parameters_from_uri (const gchar *uri)
 {
-	char *euri_str;
+	gchar *euri_str;
 	EUri *euri;
 
 	euri = e_uri_new (uri);
@@ -73,6 +73,9 @@ static void
 load_source_auth_cb (EBook *book, EBookStatus status, gpointer closure)
 {
 	LoadSourceData *data = closure;
+	gboolean was_in = g_object_get_data (G_OBJECT (book), "authenticated") != NULL;
+
+	g_object_set_data (G_OBJECT (book), "authenticated", NULL);
 
 	if (data->cancelled) {
 		free_load_source_data (data);
@@ -99,38 +102,42 @@ load_source_auth_cb (EBook *book, EBookStatus status, gpointer closure)
 						"%s", _("Accessing LDAP Server anonymously"));
 				g_signal_connect (dialog, "response", G_CALLBACK(gtk_widget_destroy), NULL);
 				gtk_widget_show (dialog);
-				if (data->cb)
-					data->cb (book, E_BOOK_ERROR_OK, data->closure);
-				free_load_source_data (data);
-				return;
+				status = E_BOOK_ERROR_OK;
+
+				goto done;
 			}
 		} else if (status == E_BOOK_ERROR_INVALID_SERVER_VERSION) {
 			e_error_run (NULL, "addressbook:server-version", NULL);
 			status = E_BOOK_ERROR_OK;
-			if (data->cb)
-				data->cb (book, status, data->closure);
-			free_load_source_data (data);
-			return;
-
+			goto done;
+		} else if (status == E_BOOK_ERROR_UNSUPPORTED_AUTHENTICATION_METHOD) {
+			goto done;
 		} else {
-			const gchar *uri = e_book_get_uri (book);
-			gchar *stripped_uri = remove_parameters_from_uri (uri);
-			const gchar *auth_domain = e_source_get_property (data->source, "auth-domain");
-			const gchar *component_name;
-
-			component_name = auth_domain ? auth_domain : "Addressbook";
-
 			if (status == E_BOOK_ERROR_AUTHENTICATION_FAILED) {
+				const gchar *uri = e_book_get_uri (book);
+				gchar *stripped_uri = remove_parameters_from_uri (uri);
+				const gchar *auth_domain = e_source_get_property (data->source, "auth-domain");
+				const gchar *component_name;
+
+				component_name = auth_domain ? auth_domain : "Addressbook";
+
 				e_passwords_forget_password (component_name, stripped_uri);
+
+				g_free (stripped_uri);
+			} else if (was_in) {
+				/* We already tried to authenticate to the server, and it failed with
+				   other reason than with E_BOOK_ERROR_AUTHENTICATION_FAILED, thus stop
+				   poking with the server and report error to the user. */
+				goto done;
 			}
 
+			g_object_set_data (G_OBJECT (book), "authenticated", GINT_TO_POINTER (1));
 			addressbook_authenticate (book, TRUE, data->source, load_source_auth_cb, closure);
-
-			g_free (stripped_uri);
 			return;
 		}
 	}
 
+done:
 	if (data->cb)
 		data->cb (book, status, data->closure);
 
@@ -160,8 +167,8 @@ static void
 addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *source,
 			  EBookCallback cb, gpointer closure)
 {
-	const char *password = NULL;
-	char *pass_dup = NULL;
+	const gchar *password = NULL;
+	gchar *pass_dup = NULL;
 	const gchar *auth;
 	const gchar *user;
 	gchar *uri = remove_parameters_from_uri(e_book_get_uri (book));
@@ -190,10 +197,10 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *sourc
 		user = "";
 
 	if (!password) {
-		char *prompt;
-		char *password_prompt;
+		gchar *prompt;
+		gchar *password_prompt;
 		gboolean remember;
-		char *failed_auth;
+		const gchar *failed_auth;
 		guint32 flags = E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET|E_PASSWORDS_ONLINE;
 
 		if (previous_failure) {
@@ -211,9 +218,9 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *sourc
 		g_free (password_prompt);
 
 		remember = get_remember_password (source);
-		pass_dup = e_passwords_ask_password (prompt, component_name, uri, prompt,
-						     flags, &remember,
-						     NULL);
+		pass_dup = e_passwords_ask_password (
+			_("Enter password"), component_name,
+			uri, prompt, flags, &remember, NULL);
 		if (remember != get_remember_password (source))
 			set_remember_password (source, remember);
 
