@@ -1,10 +1,29 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ */
+
 #ifndef _EAB_MODEL_H_
 #define _EAB_MODEL_H_
 
 #include <glib.h>
 #include <glib-object.h>
-#include <libebook/e-book-async.h>
+#include <libebook/e-book.h>
 #include <libebook/e-book-view.h>
 
 #define EAB_TYPE_MODEL                  (eab_model_get_type ())
@@ -24,13 +43,15 @@ struct _EABModel {
 	EBookQuery *query;
 	EBookView *book_view;
 
-	EContact **data;
-	int data_count;
-	int allocated_count;
+	gint book_view_idle_id;
 
-	int create_contact_id, remove_contact_id, modify_contact_id;
-	int status_message_id, writable_status_id, sequence_complete_id;
-	int backend_died_id;
+	EContact **data;
+	gint data_count;
+	gint allocated_count;
+
+	gint create_contact_id, remove_contact_id, modify_contact_id;
+	gint status_message_id, writable_status_id, sequence_complete_id;
+	gint backend_died_id;
 
 	guint search_in_progress : 1;
 	guint editable : 1;
@@ -51,7 +72,7 @@ struct _EABModelClass {
 	void (*status_message)     (EABModel *model, const gchar *message);
 	void (*folder_bar_message) (EABModel *model, const gchar *message);
 	void (*contact_added)      (EABModel *model, gint index, gint count);
-	void (*contact_removed)    (EABModel *model, gint index);
+	void (*contacts_removed)    (EABModel *model, gpointer id_list);
 	void (*contact_changed)    (EABModel *model, gint index);
 	void (*model_changed)      (EABModel *model);
 	void (*stop_state_changed) (EABModel *model);
@@ -64,7 +85,7 @@ EABModel          *eab_model_new                       (void);
 
 /* Returns object with ref count of 1. */
 EContact          *eab_model_get_contact               (EABModel *model,
-							int                row);
+							gint                row);
 EBook             *eab_model_get_ebook                 (EABModel *model);
 
 void               eab_model_stop                      (EABModel *model);
@@ -72,9 +93,9 @@ gboolean           eab_model_can_stop                  (EABModel *model);
 
 void               eab_model_force_folder_bar_message  (EABModel *model);
 
-int                eab_model_contact_count             (EABModel *model);
+gint                eab_model_contact_count             (EABModel *model);
 const EContact    *eab_model_contact_at                (EABModel *model,
-							int                index);
+							gint                index);
 gboolean           eab_model_editable                  (EABModel *model);
 
 #endif /* _EAB_MODEL_H_ */
