@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
@@ -20,7 +20,7 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
-#include "eab-marshal.h"
+#include "e-util/e-util.h"
 #include "e-addressbook-reflow-adapter.h"
 #include "e-addressbook-model.h"
 #include "e-addressbook-view.h"
@@ -36,8 +36,8 @@ struct _EAddressbookReflowAdapterPrivate {
 
 	gboolean loading;
 
-	int create_contact_id, remove_contact_id, modify_contact_id, model_changed_id;
-	int search_started_id, search_result_id;
+	gint create_contact_id, remove_contact_id, modify_contact_id, model_changed_id;
+	gint search_started_id, search_result_id;
 };
 
 #define PARENT_TYPE e_reflow_model_get_type()
@@ -50,7 +50,7 @@ enum {
 	PROP_BOOK,
 	PROP_QUERY,
 	PROP_EDITABLE,
-	PROP_MODEL,
+	PROP_MODEL
 };
 
 enum {
@@ -98,10 +98,10 @@ unlink_model(EAddressbookReflowAdapter *adapter)
 }
 
 
-static int
+static gint
 text_height (PangoLayout *layout, const gchar *text)
 {
-	int height;
+	gint height;
 
 	pango_layout_set_text (layout, text, -1);
 
@@ -119,12 +119,12 @@ addressbook_dispose(GObject *object)
 }
 
 static void
-addressbook_set_width (EReflowModel *erm, int width)
+addressbook_set_width (EReflowModel *erm, gint width)
 {
 }
 
 /* This function returns the number of items in our EReflowModel. */
-static int
+static gint
 addressbook_count (EReflowModel *erm)
 {
 	EAddressbookReflowAdapter *adapter = E_ADDRESSBOOK_REFLOW_ADAPTER(erm);
@@ -134,17 +134,17 @@ addressbook_count (EReflowModel *erm)
 }
 
 /* This function returns the height of the minicontact in question */
-static int
-addressbook_height (EReflowModel *erm, int i, GnomeCanvasGroup *parent)
+static gint
+addressbook_height (EReflowModel *erm, gint i, GnomeCanvasGroup *parent)
 {
 	EAddressbookReflowAdapter *adapter = E_ADDRESSBOOK_REFLOW_ADAPTER(erm);
 	EAddressbookReflowAdapterPrivate *priv = adapter->priv;
 	EContactField field;
-	int count = 0;
-	char *string;
+	gint count = 0;
+	gchar *string;
 	EContact *contact = (EContact*)eab_model_contact_at (priv->model, i);
 	PangoLayout *layout = gtk_widget_create_pango_layout (GTK_WIDGET (GNOME_CANVAS_ITEM (parent)->canvas), "");
-	int height;
+	gint height;
 
 	string = e_contact_get(contact, E_CONTACT_FILE_AS);
 	height = text_height (layout, string ? string : "") + 10.0;
@@ -157,8 +157,8 @@ addressbook_height (EReflowModel *erm, int i, GnomeCanvasGroup *parent)
 
 		string = e_contact_get(contact, field);
 		if (string && *string) {
-			int this_height;
-			int field_text_height;
+			gint this_height;
+			gint field_text_height;
 
 			this_height = text_height (layout, e_contact_pretty_name(field));
 
@@ -180,8 +180,8 @@ addressbook_height (EReflowModel *erm, int i, GnomeCanvasGroup *parent)
 	return height;
 }
 
-static int
-addressbook_compare (EReflowModel *erm, int n1, int n2)
+static gint
+addressbook_compare (EReflowModel *erm, gint n1, gint n2)
 {
 	EAddressbookReflowAdapter *adapter = E_ADDRESSBOOK_REFLOW_ADAPTER(erm);
 	EAddressbookReflowAdapterPrivate *priv = adapter->priv;
@@ -195,8 +195,8 @@ addressbook_compare (EReflowModel *erm, int n1, int n2)
 		contact2 = (EContact*)eab_model_contact_at (priv->model, n2);
 
 		if (contact1 && contact2) {
-			const char *file_as1, *file_as2;
-			const char *uid1, *uid2;
+			const gchar *file_as1, *file_as2;
+			const gchar *uid1, *uid2;
 			file_as1 = e_contact_get_const (contact1, E_CONTACT_FILE_AS);
 			file_as2 = e_contact_get_const (contact2, E_CONTACT_FILE_AS);
 			if (file_as1 && file_as2)
@@ -222,7 +222,7 @@ addressbook_compare (EReflowModel *erm, int n1, int n2)
 	}
 }
 
-static int
+static gint
 adapter_drag_begin (EMinicard *card, GdkEvent *event, EAddressbookReflowAdapter *adapter)
 {
 	gint ret_val = 0;
@@ -235,7 +235,7 @@ adapter_drag_begin (EMinicard *card, GdkEvent *event, EAddressbookReflowAdapter
 }
 
 static GnomeCanvasItem *
-addressbook_incarnate (EReflowModel *erm, int i, GnomeCanvasGroup *parent)
+addressbook_incarnate (EReflowModel *erm, gint i, GnomeCanvasGroup *parent)
 {
 	EAddressbookReflowAdapter *adapter = E_ADDRESSBOOK_REFLOW_ADAPTER(erm);
 	EAddressbookReflowAdapterPrivate *priv = adapter->priv;
@@ -259,7 +259,7 @@ addressbook_incarnate (EReflowModel *erm, int i, GnomeCanvasGroup *parent)
 }
 
 static void
-addressbook_reincarnate (EReflowModel *erm, int i, GnomeCanvasItem *item)
+addressbook_reincarnate (EReflowModel *erm, gint i, GnomeCanvasItem *item)
 {
 	EAddressbookReflowAdapter *adapter = E_ADDRESSBOOK_REFLOW_ADAPTER(erm);
 	EAddressbookReflowAdapterPrivate *priv = adapter->priv;
@@ -285,7 +285,7 @@ remove_contacts (EABModel *model,
 		EAddressbookReflowAdapter *adapter)
 {
 	GArray *indices = (GArray *) data;
-	int count = indices->len;
+	gint count = indices->len;
 
 	if (count == 1)
 		e_reflow_model_item_removed (E_REFLOW_MODEL (adapter), g_array_index (indices, gint, 0));
@@ -434,7 +434,7 @@ e_addressbook_reflow_adapter_class_init (GObjectClass *object_class)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EAddressbookReflowAdapterClass, drag_begin),
 			      NULL, NULL,
-			      eab_marshal_INT__POINTER,
+			      e_marshal_INT__POINTER,
 			      G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	model_class->set_width = addressbook_set_width;
@@ -536,7 +536,7 @@ e_addressbook_reflow_adapter_new (EABModel *model)
 
 EContact *
 e_addressbook_reflow_adapter_get_contact (EAddressbookReflowAdapter *adapter,
-					  int index)
+					  gint index)
 {
 	EAddressbookReflowAdapterPrivate *priv = adapter->priv;
 
