@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -119,11 +119,11 @@ struct _EMinicardField {
 #define E_MINICARD_FIELD(field) ((EMinicardField *)(field))
 
 GType       e_minicard_get_type     (void);
-const char *e_minicard_get_card_id  (EMinicard *minicard);
-int         e_minicard_compare      (EMinicard *minicard1,
+const gchar *e_minicard_get_card_id  (EMinicard *minicard);
+gint         e_minicard_compare      (EMinicard *minicard1,
 				     EMinicard *minicard2);
 
-int         e_minicard_selected     (EMinicard *minicard,
+gint         e_minicard_selected     (EMinicard *minicard,
 				     GdkEvent  *event);
 gboolean    e_minicard_activate_editor	(EMinicard *minicard);
 
