@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -45,12 +45,12 @@ struct _EABContactDisplayPrivate {
 	EContact *contact;
 
         GtkWidget *invisible;
-	char *selection_uri;
+	gchar *selection_uri;
 };
 
 static struct {
-	gchar *name;
-	gchar *pretty_name;
+	const gchar *name;
+	const gchar *pretty_name;
 }
 common_location [] =
 {
@@ -78,7 +78,7 @@ common_location [] =
 #define MAX_COMPACT_IMAGE_DIMENSION 48
 
 static void
-eab_uri_popup_link_open(EPopup *ep, EPopupItem *item, void *data)
+eab_uri_popup_link_open(EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EABPopupTargetURI *t = (EABPopupTargetURI *)ep->target;
 
@@ -87,16 +87,16 @@ eab_uri_popup_link_open(EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-eab_uri_popup_email_address_copy(EPopup *ep, EPopupItem *item, void *data)
+eab_uri_popup_email_address_copy(EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EABContactDisplay *display = data;
 	struct _EABContactDisplayPrivate *p = display->priv;
         EABPopupTargetURI *t = (EABPopupTargetURI *)ep->target;
-        const char *url = t->uri;
-        char *html=NULL;
-        int i=0;
+        const gchar *url = t->uri;
+        gchar *html=NULL;
+        gint i=0;
         GList *email_list, *l;
-        int email_num = atoi (url + strlen ("internal-mailto:"));
+        gint email_num = atoi (url + strlen ("internal-mailto:"));
 
 	email_list = e_contact_get (p->contact, E_CONTACT_EMAIL);
 	for (l = email_list; l; l=l->next) {
@@ -105,7 +105,7 @@ eab_uri_popup_email_address_copy(EPopup *ep, EPopupItem *item, void *data)
 	i++;
         }
 
-       	g_free(p->selection_uri);
+	g_free(p->selection_uri);
 	p->selection_uri = g_strdup(html);
 	g_free (html);
 
@@ -114,7 +114,7 @@ eab_uri_popup_email_address_copy(EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-eab_uri_popup_link_copy(EPopup *ep, EPopupItem *pitem, void *data)
+eab_uri_popup_link_copy(EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EABContactDisplay *display = data;
 	struct _EABContactDisplayPrivate *p = display->priv;
@@ -127,14 +127,14 @@ eab_uri_popup_link_copy(EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-eab_uri_popup_address_send(EPopup *ep, EPopupItem *item, void *data)
+eab_uri_popup_address_send(EPopup *ep, EPopupItem *item, gpointer data)
 {
          EABPopupTargetURI *t = (EABPopupTargetURI *)ep->target;
-         const char *url = t->uri;
+         const gchar *url = t->uri;
          EABContactDisplay *display = data;
-  	 struct _EABContactDisplayPrivate *p = display->priv;
+	 struct _EABContactDisplayPrivate *p = display->priv;
 
-	 int mail_num = atoi (url + strlen ("internal-mailto:"));
+	 gint mail_num = atoi (url + strlen ("internal-mailto:"));
 
          if (mail_num == -1)
          return;
@@ -166,15 +166,15 @@ eab_selection_clear_event(GtkWidget *widget, GdkEventSelection *event, EABContac
 }
 
 static EPopupItem eab_uri_popups[] = {
-	{ E_POPUP_ITEM, "05.open", N_("_Open Link in Browser"), eab_uri_popup_link_open, NULL, NULL, EAB_POPUP_URI_NOT_MAILTO },
-        { E_POPUP_ITEM, "10.copy", N_("_Copy Link Location"), eab_uri_popup_link_copy, NULL, "edit-copy", EAB_POPUP_URI_NOT_MAILTO },
-        { E_POPUP_ITEM, "15.send", N_("_Send New Message To..."), eab_uri_popup_address_send, NULL, "mail-message-new", EAB_POPUP_URI_MAILTO},
-	{ E_POPUP_ITEM, "20.copy", N_("Copy _Email Address"), eab_uri_popup_email_address_copy, NULL, "edit-copy", EAB_POPUP_URI_MAILTO},
+	{ E_POPUP_ITEM, (gchar *) "05.open", (gchar *) N_("_Open Link in Browser"), eab_uri_popup_link_open, NULL, NULL, EAB_POPUP_URI_NOT_MAILTO },
+        { E_POPUP_ITEM, (gchar *) "10.copy", (gchar *) N_("_Copy Link Location"), eab_uri_popup_link_copy, NULL, (gchar *) "edit-copy", EAB_POPUP_URI_NOT_MAILTO },
+        { E_POPUP_ITEM, (gchar *) "15.send", (gchar *) N_("_Send New Message To..."), eab_uri_popup_address_send, NULL, (gchar *) "mail-message-new", EAB_POPUP_URI_MAILTO},
+	{ E_POPUP_ITEM, (gchar *) "20.copy", (gchar *) N_("Copy _Email Address"), eab_uri_popup_email_address_copy, NULL, (gchar *) "edit-copy", EAB_POPUP_URI_MAILTO},
         };
 
 
 static void
-eab_uri_popup_free(EPopup *ep, GSList *list, void *data)
+eab_uri_popup_free(EPopup *ep, GSList *list, gpointer data)
 {
 	while (list){
 		GSList *n = list->next;
@@ -185,17 +185,17 @@ eab_uri_popup_free(EPopup *ep, GSList *list, void *data)
 		g_slist_free_1(list);
 
 		list = n;
-         	}
+		}
 }
 
-static int
-eab_uri_popup_event(EABContactDisplay *display, GdkEvent *event, const char *uri)
+static gint
+eab_uri_popup_event(EABContactDisplay *display, GdkEvent *event, const gchar *uri)
 {
 	EABPopup *emp;
-	EABPopupTargetURI *t ;
+	EABPopupTargetURI *t;
 	GtkMenu *menu;
 	GSList *menus = NULL;
-	int i;
+	gint i;
 
 	emp = eab_popup_new("org.gnome.evolution.addressbook.contactdisplay.popup");
 
@@ -220,7 +220,7 @@ eab_uri_popup_event(EABContactDisplay *display, GdkEvent *event, const char *uri
 }
 
 static void
-on_url_requested (GtkHTML *html, const char *url, GtkHTMLStream *handle,
+on_url_requested (GtkHTML *html, const gchar *url, GtkHTMLStream *handle,
 		  EABContactDisplay *display)
 {
 	if (!strcmp (url, "internal-contact-photo:")) {
@@ -230,7 +230,7 @@ on_url_requested (GtkHTML *html, const char *url, GtkHTMLStream *handle,
 		if (!photo)
 			photo = e_contact_get (display->priv->contact, E_CONTACT_LOGO);
 
-		gtk_html_stream_write (handle, (char *)photo->data.inlined.data, photo->data.inlined.length);
+		gtk_html_stream_write (handle, (gchar *)photo->data.inlined.data, photo->data.inlined.length);
 
 		gtk_html_end (html, handle, GTK_HTML_STREAM_OK);
 
@@ -254,11 +254,11 @@ on_url_requested (GtkHTML *html, const char *url, GtkHTMLStream *handle,
 }
 
 static void
-on_link_clicked (GtkHTML *html, const char *uri, EABContactDisplay *display)
+on_link_clicked (GtkHTML *html, const gchar *uri, EABContactDisplay *display)
 {
 #ifdef HANDLE_MAILTO_INTERNALLY
 	if (!strncmp (uri, "internal-mailto:", strlen ("internal-mailto:"))) {
-		int mail_num = atoi (uri + strlen ("internal-mailto:"));
+		gint mail_num = atoi (uri + strlen ("internal-mailto:"));
 
 		if (mail_num == -1)
 			return;
@@ -275,14 +275,14 @@ on_link_clicked (GtkHTML *html, const char *uri, EABContactDisplay *display)
 
 #if 0
 static void
-render_address (GtkHTMLStream *html_stream, EContact *contact, const char *html_label, EContactField adr_field, EContactField label_field)
+render_address (GtkHTMLStream *html_stream, EContact *contact, const gchar *html_label, EContactField adr_field, EContactField label_field)
 {
 	EContactAddress *adr;
-	const char *label;
+	const gchar *label;
 
 	label = e_contact_get_const (contact, label_field);
 	if (label) {
-		char *html = e_text_to_html (label, E_TEXT_TO_HTML_CONVERT_NL);
+		gchar *html = e_text_to_html (label, E_TEXT_TO_HTML_CONVERT_NL);
 
 		gtk_html_stream_printf (html_stream, "<tr><td valign=\"top\" width=\"" IMAGE_COL_WIDTH "\"></td><td valign=\"top\" width=\"100\"><font color=" HEADER_COLOR ">%s:</font><br><a href=\"http://www.mapquest.com/\">%s</a></td><td valign=\"top\">%s</td></tr>", html_label, _("(map)"), html);
 
@@ -312,9 +312,9 @@ This shoul		g_free (html);
 #endif
 
 static void
-render_name_value (GtkHTMLStream *html_stream, const char *label, const char *str, const char *icon, unsigned int html_flags)
+render_name_value (GtkHTMLStream *html_stream, const gchar *label, const gchar *str, const gchar *icon, guint html_flags)
 {
-	char *value = e_text_to_html (str, html_flags);
+	gchar *value = e_text_to_html (str, html_flags);
 
 	if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) {
 		gtk_html_stream_printf (html_stream, "<tr><td align=\"right\" valign=\"top\">%s</td> <td align=\"right\" valign=\"top\" width=\"100\" nowrap><font color=" HEADER_COLOR ">%s:</font></td>", value, label);
@@ -334,9 +334,9 @@ render_name_value (GtkHTMLStream *html_stream, const char *label, const char *st
 }
 
 static void
-render_attribute (GtkHTMLStream *html_stream, EContact *contact, const char *html_label, EContactField field, const char *icon, unsigned int html_flags)
+render_attribute (GtkHTMLStream *html_stream, EContact *contact, const gchar *html_label, EContactField field, const gchar *icon, guint html_flags)
 {
-	const char *str;
+	const gchar *str;
 
 	str = e_contact_get_const (contact, field);
 
@@ -346,15 +346,15 @@ render_attribute (GtkHTMLStream *html_stream, EContact *contact, const char *htm
 }
 
 static void
-accum_address (GString *gstr, EContact *contact, const char *html_label, EContactField adr_field, EContactField label_field)
+accum_address (GString *gstr, EContact *contact, const gchar *html_label, EContactField adr_field, EContactField label_field)
 {
 	EContactAddress *adr;
-	const char *label;
+	const gchar *label;
 	gboolean is_rtl = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL);
 
 	label = e_contact_get_const (contact, label_field);
 	if (label) {
-		char *html = e_text_to_html (label, E_TEXT_TO_HTML_CONVERT_NL);
+		gchar *html = e_text_to_html (label, E_TEXT_TO_HTML_CONVERT_NL);
 
 #ifdef mapping_works
 		if (is_rtl)
@@ -399,16 +399,16 @@ accum_address (GString *gstr, EContact *contact, const char *html_label, EContac
 }
 
 static void
-accum_name_value (GString *gstr, const char *label, const char *str, const char *icon, unsigned int html_flags)
+accum_name_value (GString *gstr, const gchar *label, const gchar *str, const gchar *icon, guint html_flags)
 {
-	char *value = e_text_to_html (str, html_flags);
+	gchar *value = e_text_to_html (str, html_flags);
 
 	if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) {
 		g_string_append_printf (gstr, "<tr><td valign=\"top\" align=\"right\">%s</td> <td align=\"right\" valign=\"top\" width=\"100\" nowrap><font color=" HEADER_COLOR ">%s:</font></td>", value, label);
 		g_string_append_printf (gstr, "<td valign=\"top\" width=\"" IMAGE_COL_WIDTH "\">");
 		if (icon)
 			g_string_append_printf (gstr, "<img width=\"16\" height=\"16\" src=\"evo-icon:%s\"></td></tr>", icon);
-		else 
+		else
 			g_string_append_printf (gstr, "</td></tr>");
 	} else {
 		g_string_append_printf (gstr, "<tr><td valign=\"top\" width=\"" IMAGE_COL_WIDTH "\">");
@@ -422,9 +422,9 @@ accum_name_value (GString *gstr, const char *label, const char *str, const char
 
 
 static void
-accum_attribute (GString *gstr, EContact *contact, const char *html_label, EContactField field, const char *icon, unsigned int html_flags)
+accum_attribute (GString *gstr, EContact *contact, const gchar *html_label, EContactField field, const gchar *icon, guint html_flags)
 {
-	const char *str;
+	const gchar *str;
 
 	str = e_contact_get_const (contact, field);
 
@@ -434,11 +434,11 @@ accum_attribute (GString *gstr, EContact *contact, const char *html_label, ECont
 }
 
 static void
-accum_time_attribute (GString *gstr, EContact *contact, const char *html_label, EContactField field, const char *icon, unsigned int html_flags)
+accum_time_attribute (GString *gstr, EContact *contact, const gchar *html_label, EContactField field, const gchar *icon, guint html_flags)
 {
 	EContactDate *date;
 	GDate *gdate = NULL;
-	char sdate[100];
+	gchar sdate[100];
 
 	date = e_contact_get (contact, field);
 	if (date) {
@@ -453,13 +453,13 @@ accum_time_attribute (GString *gstr, EContact *contact, const char *html_label,
 }
 
 static void
-accum_multival_attribute (GString *gstr, EContact *contact, const char *html_label, EContactField field, const char *icon, unsigned int html_flags)
+accum_multival_attribute (GString *gstr, EContact *contact, const gchar *html_label, EContactField field, const gchar *icon, guint html_flags)
 {
 	GList *val_list, *l;
 
 	val_list = e_contact_get (contact, field);
 	for (l = val_list; l; l = l->next) {
-		const char *str = (const char *) l->data;
+		const gchar *str = (const gchar *) l->data;
 		accum_name_value (gstr, html_label, str, icon, html_flags);
 	}
 	g_list_foreach (val_list, (GFunc) g_free, NULL);
@@ -495,7 +495,7 @@ render_contact_list (GtkHTMLStream *html_stream, EContact *contact)
 }
 
 static void
-start_block (GtkHTMLStream *html_stream, const char *label)
+start_block (GtkHTMLStream *html_stream, const gchar *label)
 {
 	gtk_html_stream_printf (html_stream, "<tr><td height=\"20\" colspan=\"3\"><font color=" HEADER_COLOR "><b>%s</b></font></td></tr>", label);
 }
@@ -506,7 +506,7 @@ end_block (GtkHTMLStream *html_stream)
 	gtk_html_stream_printf (html_stream, "<tr><td height=\"20\">&nbsp;</td></tr>");
 }
 
-static const char *
+static const gchar *
 get_email_location (EVCardAttribute *attr)
 {
 	gint i;
@@ -526,9 +526,10 @@ render_contact (GtkHTMLStream *html_stream, EContact *contact)
 	GList *email_list, *l, *email_attr_list, *al;
 	gboolean is_rtl = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL);
 #ifdef HANDLE_MAILTO_INTERNALLY
-	int email_num = 0;
+	gint email_num = 0;
 #endif
-	char *nl, *nick=NULL;
+	const gchar *nl;
+	gchar *nick=NULL;
 
 	gtk_html_stream_printf (html_stream, "<table border=\"0\">");
 
@@ -541,14 +542,14 @@ render_contact (GtkHTMLStream *html_stream, EContact *contact)
 	email_attr_list = e_contact_get_attributes (contact, E_CONTACT_EMAIL);
 
 	for (l = email_list, al=email_attr_list; l && al; l = l->next, al = al->next) {
-		char *html = NULL, *name = NULL, *mail = NULL;
-		char *attr_str = (char *)get_email_location ((EVCardAttribute *) al->data);
+		gchar *html = NULL, *name = NULL, *mail = NULL;
+		gchar *attr_str = (gchar *)get_email_location ((EVCardAttribute *) al->data);
 
 #ifdef HANDLE_MAILTO_INTERNALLY
 		if (!eab_parse_qp_email (l->data, &name, &mail))
 			mail = e_text_to_html (l->data, 0);
 
-		g_string_append_printf (accum, "%s%s%s<a href=\"internal-mailto:%d\">%s</a>%s <font color=" HEADER_COLOR ">(%s)</font>", 
+		g_string_append_printf (accum, "%s%s%s<a href=\"internal-mailto:%d\">%s</a>%s <font color=" HEADER_COLOR ">(%s)</font>",
 						nl,
 						name ? name : "",
 						name ? " &lt;" : "",
@@ -680,8 +681,8 @@ eab_contact_display_render_normal (EABContactDisplay *display, EContact *contact
 	gtk_html_stream_printf (html_stream, "<body><table width=\"100%%\"><tr><td %s>\n", is_rtl ? " align=\"right\" " : "");
 
 	if (contact) {
-		const char *str;
-		char *html;
+		const gchar *str;
+		gchar *html;
 		EContactPhoto *photo;
 
 		gtk_html_stream_printf (html_stream, "<table cellspacing=\"20\" border=\"0\"><td %s valign=\"top\">", is_rtl ? " align=\"right\" " : "");
@@ -694,7 +695,7 @@ eab_contact_display_render_normal (EABContactDisplay *display, EContact *contact
 			e_contact_photo_free (photo);
 		}
 
- 		gtk_html_stream_printf (html_stream, "</td><td %s valign=\"top\">\n", is_rtl ? " align=\"right\" " : "");
+		gtk_html_stream_printf (html_stream, "</td><td %s valign=\"top\">\n", is_rtl ? " align=\"right\" " : "");
 
 		str = e_contact_get_const (contact, E_CONTACT_FILE_AS);
 		if (!str)
@@ -740,8 +741,8 @@ eab_contact_display_render_compact (EABContactDisplay *display, EContact *contac
 	gtk_html_stream_write (html_stream, "<body>\n", 7);
 
 	if (contact) {
-		const char *str;
-		char *html;
+		const gchar *str;
+		gchar *html;
 		EContactPhoto *photo;
 		guint bg_frame = 0x000000, bg_body = 0xEEEEEE;
 		GtkStyle *style;
@@ -775,7 +776,7 @@ eab_contact_display_render_compact (EABContactDisplay *display, EContact *contac
 		if (!photo)
 			photo = e_contact_get (contact, E_CONTACT_LOGO);
 		if (photo) {
-			int calced_width = MAX_COMPACT_IMAGE_DIMENSION, calced_height = MAX_COMPACT_IMAGE_DIMENSION;
+			gint calced_width = MAX_COMPACT_IMAGE_DIMENSION, calced_height = MAX_COMPACT_IMAGE_DIMENSION;
 			GdkPixbufLoader *loader = gdk_pixbuf_loader_new ();
 			GdkPixbuf *pixbuf;
 
@@ -790,7 +791,7 @@ eab_contact_display_render_compact (EABContactDisplay *display, EContact *contac
 				g_object_ref (pixbuf);
 			g_object_unref (loader);
 			if (pixbuf) {
-				int max_dimension;
+				gint max_dimension;
 
 				calced_width = gdk_pixbuf_get_width (pixbuf);
 				calced_height = gdk_pixbuf_get_height (pixbuf);
@@ -800,8 +801,8 @@ eab_contact_display_render_compact (EABContactDisplay *display, EContact *contac
 					max_dimension = calced_height;
 
 				if (max_dimension > MAX_COMPACT_IMAGE_DIMENSION) {
-					calced_width *= ((float)MAX_COMPACT_IMAGE_DIMENSION / max_dimension);
-					calced_height *= ((float)MAX_COMPACT_IMAGE_DIMENSION / max_dimension);
+					calced_width *= ((gfloat)MAX_COMPACT_IMAGE_DIMENSION / max_dimension);
+					calced_height *= ((gfloat)MAX_COMPACT_IMAGE_DIMENSION / max_dimension);
 				}
 			}
 
@@ -861,7 +862,7 @@ eab_contact_display_render_compact (EABContactDisplay *display, EContact *contac
 				html = eab_parse_qp_email_to_html (str);				\
 													\
 				if (!html)								\
-					html = e_text_to_html (str, 0); 				\
+					html = e_text_to_html (str, 0);				\
 													\
 				gtk_html_stream_printf (html_stream, "%s%s", comma ? ", " : "", html);	\
 				g_free (html);								\
@@ -922,20 +923,20 @@ eab_contact_display_render (EABContactDisplay *display, EContact *contact,
 	}
 }
 
-static int
+static gint
 eab_html_press_event (GtkWidget *widget, GdkEvent *event,EABContactDisplay *display)
 {
-	char *uri;
+	gchar *uri;
 	gboolean res = FALSE;
 
 
 	if (event->button.button!= 3 )
 		return FALSE;
 
-       	uri = gtk_html_get_url_at (GTK_HTML (widget), event->button.x, event->button.y);
+	uri = gtk_html_get_url_at (GTK_HTML (widget), event->button.x, event->button.y);
 	if (uri){
 		eab_uri_popup_event(display,event,uri);
-               	}
+		}
 
          g_free(uri);
 
