@@ -1,24 +1,27 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* Evolution CSV and TAB importer
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+/*
+ * Evolution CSV and TAB importer
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Devashish Sharma <sdevashish@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Authors: Devashish Sharma <sdevashish@novell.com>
  */
+
 #include <config.h>
 #include <stdio.h>
 #include <ctype.h>
@@ -50,7 +53,7 @@ typedef struct {
 
 	guint idle_id;
 
-	int state;
+	gint state;
 	FILE *file;
 	gulong size;
 	gint count;
@@ -60,12 +63,12 @@ typedef struct {
 } CSVImporter;
 
 static gint importer;
-static char delimiter;
+static gchar delimiter;
 
 static void csv_import_done(CSVImporter *gci);
 
 typedef struct {
-	char *csv_attribute;
+	const gchar *csv_attribute;
 	EContactField contact_field;
 #define FLAG_HOME_ADDRESS  0x01
 #define FLAG_WORK_ADDRESS  0x02
@@ -82,7 +85,7 @@ typedef struct {
 #define FLAG_BIRTH_MONTH   0x50
 #define FLAG_DATE_ANNIVERSARY 0x30
 #define FLAG_INVALID       0xff
-	int flags;
+	gint flags;
 }import_fields;
 
 static import_fields csv_fields_outlook[] = {
@@ -260,7 +263,7 @@ static import_fields csv_fields_evolution[] = {
 };
 
 static void
-add_to_notes(EContact *contact, gint i, char *val) {
+add_to_notes(EContact *contact, gint i, gchar *val) {
 	const gchar *old_text;
 	const gchar *field_text = NULL;
 	GString *new_text;
@@ -293,12 +296,12 @@ add_to_notes(EContact *contact, gint i, char *val) {
 
 /* @str: a date string in the format MM-DD-YYYY or MMDDYYYY */
 static EContactDate*
-date_from_string (const char *str)
+date_from_string (const gchar *str)
 {
 	EContactDate* date;
-	int length;
-	char *t;
-	int i = 0;
+	gint length;
+	gchar *t;
+	gint i = 0;
 
 	g_return_val_if_fail (str != NULL, NULL);
 
@@ -332,13 +335,13 @@ date_from_string (const char *str)
 }
 
 static gboolean
-parseLine (CSVImporter *gci, EContact *contact, char *buf) {
+parseLine (CSVImporter *gci, EContact *contact, gchar *buf) {
 
-	char *ptr = buf, *do_free = NULL;
+	gchar *ptr = buf, *do_free = NULL;
 	GString *value;
 	gint i = 0;
-	int flags = 0;
-	int contact_field;
+	gint flags = 0;
+	gint contact_field;
 	EContactAddress *home_address = NULL, *work_address = NULL, *other_address = NULL;
 	EContactDate *bday = NULL;
 	GString *home_street, *work_street, *other_street;
@@ -551,8 +554,8 @@ getNextCSVEntry(CSVImporter *gci, FILE *f) {
 	EContact *contact = NULL;
 	GString  *line;
 	GString *str;
-	char *buf;
-	char c;
+	gchar *buf;
+	gchar c;
 
 	/*
 	if(!fgets(line, sizeof(line),f))
@@ -567,12 +570,12 @@ getNextCSVEntry(CSVImporter *gci, FILE *f) {
 
 	line = g_string_new("");
 	while (1) {
-		c = fgetc (f) ;
+		c = fgetc (f);
 		if (c == EOF)
 			return NULL;
 		if (c == '\n') {
 			g_string_append_c (line, c);
-			break ;
+			break;
 		}
 		if (c == '"') {
 			g_string_append_c (line, c);
@@ -591,12 +594,12 @@ getNextCSVEntry(CSVImporter *gci, FILE *f) {
 		g_string_free (line, TRUE);
 		line = g_string_new("");
 		while (1) {
-			c = fgetc (f) ;
+			c = fgetc (f);
 			if (c == EOF)
 				return NULL;
 			if (c == '\n') {
 				g_string_append_c (line, c);
-				break ;
+				break;
 			}
 			if (c == '"') {
 				g_string_append_c (line, c);
@@ -639,7 +642,7 @@ getNextCSVEntry(CSVImporter *gci, FILE *f) {
 }
 
 static gboolean
-csv_import_contacts(void *d) {
+csv_import_contacts(gpointer d) {
 	CSVImporter *gci = d;
 	EContact *contact = NULL;
 
@@ -701,15 +704,15 @@ csv_getwidget(EImport *ei, EImportTarget *target, EImportImporter *im)
 	return vbox;
 }
 
-static char *supported_extensions[4] = {
+static const gchar *supported_extensions[4] = {
 	".csv", ".tab" , ".txt", NULL
 };
 
 static gboolean
 csv_supported(EImport *ei, EImportTarget *target, EImportImporter *im)
 {
-	char *ext;
-	int i;
+	gchar *ext;
+	gint i;
 	EImportTargetURI *s;
 
 	if (target->type != E_IMPORT_TARGET_URI)
