@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -34,7 +34,6 @@
 #include <bonobo/bonobo-main.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-exec.h>
 #include <libgnome/gnome-sound.h>
 
 #include <libecal/e-cal-time-util.h>
@@ -77,8 +76,8 @@ static GList *tray_icons_list = NULL;
 
 /* Top Tray Image */
 static GtkStatusIcon *tray_icon = NULL;
-static int tray_blink_id = -1;
-static int tray_blink_countdown = 0;
+static gint tray_blink_id = -1;
+static gint tray_blink_countdown = 0;
 static AlarmNotify *an;
 
 /* Structure that stores a client we are monitoring */
@@ -151,7 +150,6 @@ static void popup_notification (time_t trigger, CompQueuedAlarms *cqa,
 static void query_objects_changed_cb (ECal *client, GList *objects, gpointer data);
 static void query_objects_removed_cb (ECal *client, GList *objects, gpointer data);
 
-static void remove_client_alarms (ClientAlarms *ca);
 static void update_cqa (CompQueuedAlarms *cqa, ECalComponent *comp);
 static void update_qa (ECalComponentAlarms *alarms, QueuedAlarm *qa);
 static void tray_list_remove_cqa (CompQueuedAlarms *cqa);
@@ -522,7 +520,7 @@ add_component_alarms (ClientAlarms *ca, ECalComponentAlarms *alarms)
 static void
 load_alarms (ClientAlarms *ca, time_t start, time_t end)
 {
-	char *str_query, *iso_start, *iso_end;
+	gchar *str_query, *iso_start, *iso_end;
 
 	d(printf("%s:%d (load_alarms) \n",__FILE__, __LINE__));
 
@@ -877,7 +875,7 @@ query_objects_removed_cb (ECal *client, GList *objects, gpointer data)
  * compued with respect to the current time.
  */
 static void
-create_snooze (CompQueuedAlarms *cqa, gpointer alarm_id, int snooze_mins)
+create_snooze (CompQueuedAlarms *cqa, gpointer alarm_id, gint snooze_mins)
 {
 	QueuedAlarm *orig_qa;
 	time_t t;
@@ -906,8 +904,8 @@ create_snooze (CompQueuedAlarms *cqa, gpointer alarm_id, int snooze_mins)
 static void
 edit_component (ECal *client, ECalComponent *comp)
 {
-	const char *uid;
-	const char *uri;
+	const gchar *uid;
+	const gchar *uri;
 	ECalSourceType source_type;
 	CORBA_Environment ev;
 	GNOME_Evolution_Calendar_CompEditorFactory factory;
@@ -922,8 +920,8 @@ edit_component (ECal *client, ECalComponent *comp)
 
 	/* Get the factory */
 	CORBA_exception_init (&ev);
-	factory = bonobo_activation_activate_from_id ("OAFIID:GNOME_Evolution_Calendar_CompEditorFactory:" BASE_VERSION,
-						      0, NULL, &ev);
+	factory = bonobo_activation_activate_from_id (
+		(Bonobo_ActivationID) "OAFIID:GNOME_Evolution_Calendar_CompEditorFactory:" BASE_VERSION, 0, NULL, &ev);
 
 	if (BONOBO_EX (&ev)) {
 		e_error_run (NULL, "editor-error", bonobo_exception_get_text (&ev), NULL);
@@ -940,7 +938,7 @@ edit_component (ECal *client, ECalComponent *comp)
 		corba_type = GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_EVENT;
 	}
 
-	GNOME_Evolution_Calendar_CompEditorFactory_editExisting (factory, uri, (char *) uid, corba_type, &ev);
+	GNOME_Evolution_Calendar_CompEditorFactory_editExisting (factory, uri, (gchar *) uid, corba_type, &ev);
 
 	if (BONOBO_EX (&ev))
 		e_error_run (NULL, "editor-error", bonobo_exception_get_text (&ev), NULL);
@@ -952,9 +950,9 @@ edit_component (ECal *client, ECalComponent *comp)
 }
 
 typedef struct {
-	char *summary;
-	char *description;
-	char *location;
+	gchar *summary;
+	gchar *description;
+	gchar *location;
 	gboolean blink_state;
 	gboolean snooze_set;
 	gint blink_id;
@@ -1011,7 +1009,7 @@ free_tray_icon_data (TrayIconData *tray_data)
 static void
 on_dialog_objs_removed_async (struct _query_msg *msg)
 {
-	const char *our_uid;
+	const gchar *our_uid;
 	GList *l;
 	TrayIconData *tray_data;
 	ECal *client;
@@ -1027,7 +1025,7 @@ on_dialog_objs_removed_async (struct _query_msg *msg)
 	g_return_if_fail (our_uid && *our_uid);
 
 	for (l = objects; l != NULL; l = l->next) {
-		const char *uid = l->data;
+		const gchar *uid = l->data;
 
 		if (!uid)
 			continue;
@@ -1199,7 +1197,7 @@ tray_list_remove_data (TrayIconData *data)
 }
 
 static void
-notify_dialog_cb (AlarmNotifyResult result, int snooze_mins, gpointer data)
+notify_dialog_cb (AlarmNotifyResult result, gint snooze_mins, gpointer data)
 {
 	TrayIconData *tray_data = data;
 
@@ -1439,11 +1437,11 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 {
 	QueuedAlarm *qa;
 	ECalComponent *comp;
-	const char *summary, *description, *location;
+	const gchar *summary, *description, *location;
 	TrayIconData *tray_data;
 	ECalComponentText text;
 	GSList *text_list;
-	char *str, *start_str, *end_str, *alarm_str, *time_str;
+	gchar *str, *start_str, *end_str, *alarm_str, *time_str;
 	icaltimezone *current_zone;
 	ECalComponentOrganizer organiser;
 
@@ -1461,7 +1459,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	if (text.value)
 		summary = text.value;
 	else
-	        summary = _("No summary available.");
+		summary = _("No summary available.");
 
 	e_cal_component_get_description_list (comp, &text_list);
 
@@ -1480,7 +1478,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	e_cal_component_get_location (comp, &location);
 
 	if (!location)
-	        location = _("No location information available.");
+		location = _("No location information available.");
 
 	/* create the tray icon */
 	if (tray_icon == NULL) {
@@ -1523,7 +1521,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	tray_list_add_new (tray_data);
 
 	if (g_list_length (tray_icons_list) > 1) {
-		char *tip;
+		gchar *tip;
 
 		tip =  g_strdup_printf (_("You have %d alarms"), g_list_length (tray_icons_list));
 		gtk_status_icon_set_tooltip_text (tray_icon, tip);
@@ -1541,7 +1539,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	g_signal_connect (G_OBJECT (tray_data->query), "objects_removed",
 			  G_CALLBACK (on_dialog_objs_removed_cb), tray_data);
 
-	// FIXME: We should remove this check
+	/* FIXME: We should remove this check */
 	if (!config_data_get_notify_with_tray ()) {
 		tray_blink_id = -1;
 		open_alarm_dialog (tray_data);
@@ -1557,17 +1555,17 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 #ifdef HAVE_LIBNOTIFY
 static void
 popup_notification (time_t trigger, CompQueuedAlarms *cqa,
-	            gpointer alarm_id, gboolean use_description)
+		    gpointer alarm_id, gboolean use_description)
 {
 	QueuedAlarm *qa;
 	ECalComponent *comp;
-	const char *summary, *location;
+	const gchar *summary, *location;
 	ECalComponentText text;
-	char *str, *start_str, *end_str, *alarm_str, *time_str;
+	gchar *str, *start_str, *end_str, *alarm_str, *time_str;
 	icaltimezone *current_zone;
 	ECalComponentOrganizer organiser;
 	NotifyNotification *n;
-	char *body;
+	gchar *body;
 
 	d(printf("%s:%d (popup_notification)\n",__FILE__, __LINE__));
 
@@ -1586,7 +1584,7 @@ popup_notification (time_t trigger, CompQueuedAlarms *cqa,
 	if (text.value)
 		summary = text.value;
 	else
-	        summary = _("No summary available.");
+		summary = _("No summary available.");
 
 	e_cal_component_get_location (comp, &location);
 
@@ -1638,7 +1636,7 @@ audio_notification (time_t trigger, CompQueuedAlarms *cqa,
 	ECalComponent *comp;
 	ECalComponentAlarm *alarm;
 	icalattach *attach;
-	int	flag = 0;
+	gint	flag = 0;
 
 	d(printf("%s:%d (audio_notification)\n",__FILE__, __LINE__));
 
@@ -1654,7 +1652,7 @@ audio_notification (time_t trigger, CompQueuedAlarms *cqa,
 	e_cal_component_alarm_free (alarm);
 
 	if (attach && icalattach_get_is_url (attach)) {
-		const char *url;
+		const gchar *url;
 
 		url = icalattach_get_url (attach);
 
@@ -1704,11 +1702,11 @@ mail_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id)
 
 /* Performs notification of a procedure alarm */
 static gboolean
-procedure_notification_dialog (const char *cmd, const char *url)
+procedure_notification_dialog (const gchar *cmd, const gchar *url)
 {
 	GtkWidget *dialog, *label, *checkbox;
-	char *str;
-	int btn;
+	gchar *str;
+	gint btn;
 
 	d(printf("%s:%d (procedure_notification_dialog)\n",__FILE__, __LINE__));
 
@@ -1757,9 +1755,9 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	ECalComponentAlarm *alarm;
 	ECalComponentText description;
 	icalattach *attach;
-	const char *url;
-	char *cmd;
-	int result;
+	const gchar *url;
+	gchar *cmd;
+	gboolean result = TRUE;
 
 	d(printf("%s:%d (procedure_notification)\n",__FILE__, __LINE__));
 
@@ -1791,19 +1789,18 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	if (description.value)
 		cmd = g_strconcat (url, " ", description.value, NULL);
 	else
-		cmd = (char *) url;
+		cmd = (gchar *) url;
 
-	result = 0;
 	if (procedure_notification_dialog (cmd, url))
-		result = gnome_execute_shell (NULL, cmd);
+		result = g_spawn_command_line_async (cmd, NULL);
 
-	if (cmd != (char *) url)
+	if (cmd != (gchar *) url)
 		g_free (cmd);
 
 	icalattach_unref (attach);
 
 	/* Fall back to display notification if we got an error */
-	if (result < 0)
+	if (result == FALSE)
 		goto fallback;
 
 	return;
@@ -1813,8 +1810,6 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	display_notification (trigger, cqa, alarm_id, FALSE);
 }
 
-
-
 static gboolean
 check_midnight_refresh (gpointer user_data)
 {
@@ -2054,8 +2049,8 @@ remove_comp_by_id (gpointer key, gpointer value, gpointer userdata) {
 
 	d(printf("%s:%d (remove_comp_by_id)\n",__FILE__, __LINE__));
 
-/* 	if (!g_hash_table_size (ca->uid_alarms_hash)) */
-/* 		return; */
+/*	if (!g_hash_table_size (ca->uid_alarms_hash)) */
+/*		return; */
 
 	remove_cqa (ca, (ECalComponentId *)key, (CompQueuedAlarms *) value);
 
@@ -2173,7 +2168,7 @@ update_cqa (CompQueuedAlarms *cqa, ECalComponent *newcomp)
 	/* Update auids in Queued Alarms*/
 	for (qa_list = cqa->queued_alarms; qa_list; qa_list = qa_list->next) {
 		QueuedAlarm *qa = qa_list->data;
-		char *check_auid = (char *) qa->instance->auid;
+		gchar *check_auid = (gchar *) qa->instance->auid;
 		ECalComponentAlarm *alarm;
 
 		alarm = e_cal_component_get_alarm (newcomp, check_auid);
@@ -2211,8 +2206,8 @@ update_qa (ECalComponentAlarms *alarms, QueuedAlarm *qa)
 	d(printf("%s:%d (update_qa)\n",__FILE__, __LINE__));
 	for (instance_list = alarms->alarms; instance_list; instance_list = instance_list->next) {
 		al_inst = instance_list->data;
-		if (al_inst->trigger == qa->orig_trigger) {  /* FIXME if two or more alarm instances (audio, note) 									  for same component have same trigger */
-			g_free ((char *) qa->instance->auid);
+		if (al_inst->trigger == qa->orig_trigger) {  /* FIXME if two or more alarm instances (audio, note)									  for same component have same trigger */
+			g_free ((gchar *) qa->instance->auid);
 			qa->instance->auid = g_strdup (al_inst->auid);
 			break;
 		}
