@@ -1,22 +1,25 @@
-/* Evolution calendar - utility functions
- *
- * Copyright (C) 2000 Ximian, Inc.
- * Copyright (C) 2001 Ximian, Inc.
- *
- * Author: Federico Mena-Quintero <federico@ximian.com>
+/*
+ * Evolution calendar - utility functions
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Federico Mena-Quintero <federico@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,12 +33,12 @@
 #include "util.h"
 
 /* Converts a time_t to a string, relative to the specified timezone */
-char *
+gchar *
 timet_to_str_with_zone (time_t t, icaltimezone *zone)
 {
 	struct icaltimetype itt;
 	struct tm tm;
-	char buf[256];
+	gchar buf[256];
 
 	if (t == -1)
 		return g_strdup (_("invalid time"));
@@ -48,15 +51,15 @@ timet_to_str_with_zone (time_t t, icaltimezone *zone)
 	return g_strdup (buf);
 }
 
-char *
+gchar *
 calculate_time (time_t start, time_t end)
 {
 	time_t difference = end - start;
-	char *str;
-	int   hours, minutes;
-	char *times[4];
-	char *joined;
-	int   i;
+	gchar *str;
+	gint   hours, minutes;
+	gchar *times[4];
+	gchar *joined;
+	gint   i;
 
         i = 0;
 	if (difference >= 3600) {
@@ -73,7 +76,7 @@ calculate_time (time_t start, time_t end)
 	}
 	if (i == 0 || difference != 0) {
 		/* TRANSLATORS: here, "second" is the time division (like "minute"), not the ordinal number (like "third") */
-		times[i++] = g_strdup_printf (ngettext("%d second", "%d seconds", difference), (int)difference);
+		times[i++] = g_strdup_printf (ngettext("%d second", "%d seconds", difference), (gint)difference);
 	}
 
 	times[i] = NULL;
