@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -70,16 +70,16 @@
 #define WEATHER_BASE_URI "weather://"
 #define PERSONAL_RELATIVE_URI "system"
 #define CALENDAR_ERROR_LEVEL_KEY "/apps/evolution/calendar/display/error_level"
-#define CALENDAR_ERROR_TIME_OUT_KEY "/apps/evolution/calendar/display/error_timeout" 
+#define CALENDAR_ERROR_TIME_OUT_KEY "/apps/evolution/calendar/display/error_timeout"
 
 enum DndTargetType {
-	DND_TARGET_TYPE_CALENDAR_LIST,
+	DND_TARGET_TYPE_CALENDAR_LIST
 };
 #define CALENDAR_TYPE "text/calendar"
 #define XCALENDAR_TYPE "text/x-calendar"
 static GtkTargetEntry drag_types[] = {
-	{ CALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST },
-	{ XCALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST }
+	{ (gchar *) CALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST },
+	{ (gchar *) XCALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST }
 };
 static gint num_drag_types = sizeof(drag_types) / sizeof(drag_types[0]);
 #define CALENDAR_COMPONENT_DEFAULT(cc) if (cc == NULL) cc = calendar_component_peek()
@@ -112,15 +112,15 @@ typedef struct
 
 	EActivityHandler *activity_handler;
 
-	float	     vpane_pos;
+	gfloat	     vpane_pos;
 } CalendarComponentView;
 
 struct _CalendarComponentPrivate {
-	char *base_directory;
-	char *config_directory;
+	gchar *base_directory;
+	gchar *config_directory;
 
 	GConfClient *gconf_client;
-	int gconf_notify_id;
+	gint gconf_notify_id;
 
 	ESourceList *source_list;
 	ESourceList *task_source_list;
@@ -142,7 +142,7 @@ extern ECompEditorRegistry *comp_editor_registry;
 static void
 calcomp_vpane_realized (GtkWidget *vpane, CalendarComponentView *view)
 {
-	gtk_paned_set_position (GTK_PANED (vpane), (int)(view->vpane_pos*vpane->allocation.height));
+	gtk_paned_set_position (GTK_PANED (vpane), (gint)(view->vpane_pos*vpane->allocation.height));
 
 }
 
@@ -151,7 +151,7 @@ calcomp_vpane_resized (GtkWidget *vpane, GdkEventButton *e, CalendarComponentVie
 {
 
 	view->vpane_pos = gtk_paned_get_position (GTK_PANED (vpane));
-	calendar_config_set_tag_vpane_pos (view->vpane_pos/(float)vpane->allocation.height);
+	calendar_config_set_tag_vpane_pos (view->vpane_pos/(gfloat)vpane->allocation.height);
 
 	return FALSE;
 }
@@ -164,7 +164,7 @@ ensure_sources (CalendarComponent *component)
 	ESourceGroup *contacts;
 	ESource *personal_source;
 	ESource *birthdays_source;
-	char *base_uri, *base_uri_proto, base_uri_proto_seventh;
+	gchar *base_uri, *base_uri_proto, base_uri_proto_seventh;
 	const gchar *base_dir;
 	gchar *create_source;
 
@@ -231,7 +231,7 @@ ensure_sources (CalendarComponent *component)
 		/* ensure the source name is in current locale, not read from configuration */
 		e_source_set_name (personal_source, _("Personal"));
 	} else {
-		char *primary_calendar = calendar_config_get_primary_calendar();
+		gchar *primary_calendar = calendar_config_get_primary_calendar();
 		GSList *calendars_selected;
 
 		/* Create the default Person addressbook */
@@ -331,7 +331,7 @@ is_in_uids (GSList *uids, ESource *source)
 	GSList *l;
 
 	for (l = uids; l; l = l->next) {
-		const char *uid = l->data;
+		const gchar *uid = l->data;
 
 		if (!strcmp (uid, e_source_peek_uid (source)))
 			return TRUE;
@@ -358,7 +358,7 @@ update_uris_for_selection (CalendarComponentView *component_view)
 		ESource *selected_source = l->data;
 
 		if (gnome_calendar_add_source (component_view->calendar, E_CAL_SOURCE_TYPE_EVENT, selected_source))
-			uids_selected = g_slist_append (uids_selected, (char *) e_source_peek_uid (selected_source));
+			uids_selected = g_slist_append (uids_selected, (gchar *) e_source_peek_uid (selected_source));
 	}
 
 	e_source_selector_free_selection (component_view->source_selection);
@@ -410,7 +410,7 @@ update_selection (CalendarComponentView *component_view)
 
 	/* Make sure the whole selection is there */
 	for (l = uids_selected; l; l = l->next) {
-		char *uid = l->data;
+		gchar *uid = l->data;
 		ESource *source;
 
 		source = e_source_list_peek_source_by_uid (component_view->source_list, uid);
@@ -441,7 +441,7 @@ update_task_memo_selection (CalendarComponentView *component_view, ECalSourceTyp
 
 	/* Remove any that aren't there any more */
 	for (l = source_selection; l; l = l->next) {
-		char *uid = l->data;
+		gchar *uid = l->data;
 		ESource *source;
 
 		source = e_source_list_peek_source_by_uid (component_view->source_list, uid);
@@ -456,12 +456,13 @@ update_task_memo_selection (CalendarComponentView *component_view, ECalSourceTyp
 
 	/* Make sure the whole selection is there */
 	for (l = uids_selected; l; l = l->next) {
-		char *uid = l->data;
+		gchar *uid = l->data;
 		ESource *source;
 
 		source = e_source_list_peek_source_by_uid (source_list, uid);
-		if (source && !gnome_calendar_add_source (component_view->calendar, type, source))
+		if (source && !gnome_calendar_add_source (component_view->calendar, type, source)) {
 			/* FIXME do something */;
+		}
 	}
 
 	if (type == E_CAL_SOURCE_TYPE_TODO)
@@ -474,7 +475,7 @@ static void
 update_primary_selection (CalendarComponentView *component_view)
 {
 	ESource *source = NULL;
-	char *uid;
+	gchar *uid;
 
 	uid = calendar_config_get_primary_calendar ();
 	if (uid) {
@@ -496,7 +497,7 @@ static void
 update_primary_task_memo_selection (CalendarComponentView *component_view, ECalSourceType type)
 {
 	ESource *source = NULL;
-	char *uid;
+	gchar *uid;
 	ESourceList *source_list = NULL;
 
 	if (type == E_CAL_SOURCE_TYPE_TODO) {
@@ -519,7 +520,7 @@ update_primary_task_memo_selection (CalendarComponentView *component_view, ECalS
 
 /* Callbacks.  */
 static void
-copy_calendar_cb (EPopup *ep, EPopupItem *pitem, void *data)
+copy_calendar_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	CalendarComponentView *component_view = data;
 	ESource *selected_source;
@@ -532,12 +533,12 @@ copy_calendar_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-delete_calendar_cb (EPopup *ep, EPopupItem *pitem, void *data)
+delete_calendar_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	CalendarComponentView *component_view = data;
 	ESource *selected_source;
 	ECal *cal;
-	char *uri;
+	gchar *uri;
 
 	selected_source = e_source_selector_peek_primary_selection (E_SOURCE_SELECTOR (component_view->source_selector));
 	if (!selected_source)
@@ -569,13 +570,13 @@ delete_calendar_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-new_calendar_cb (EPopup *ep, EPopupItem *pitem, void *data)
+new_calendar_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	calendar_setup_edit_calendar (GTK_WINDOW (gtk_widget_get_toplevel(ep->target->widget)), NULL, pitem->user_data);
 }
 
 static void
-rename_calendar_cb (EPopup *ep, EPopupItem *pitem, void *data)
+rename_calendar_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	CalendarComponentView *component_view = data;
 	ESourceSelector *selector;
@@ -585,7 +586,7 @@ rename_calendar_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-edit_calendar_cb (EPopup *ep, EPopupItem *pitem, void *data)
+edit_calendar_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	CalendarComponentView *component_view = data;
 	ESource *selected_source;
@@ -597,8 +598,8 @@ edit_calendar_cb (EPopup *ep, EPopupItem *pitem, void *data)
 	calendar_setup_edit_calendar (GTK_WINDOW (gtk_widget_get_toplevel(ep->target->widget)), selected_source, NULL);
 }
 
-static void 
-set_offline_availability (EPopup *ep, EPopupItem *pitem, void *data, const char *value)
+static void
+set_offline_availability (EPopup *ep, EPopupItem *pitem, gpointer data, const gchar *value)
 {
 	CalendarComponentView *component_view = data;
 	ESource *selected_source;
@@ -611,33 +612,33 @@ set_offline_availability (EPopup *ep, EPopupItem *pitem, void *data, const char
 }
 
 static void
-mark_no_offline_cb (EPopup *ep, EPopupItem *pitem, void *data)
+mark_no_offline_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
-	set_offline_availability (ep, pitem, data, "0"); 
+	set_offline_availability (ep, pitem, data, "0");
 }
 
 static void
-mark_offline_cb (EPopup *ep, EPopupItem *pitem, void *data)
+mark_offline_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
-	set_offline_availability (ep, pitem, data, "1"); 
+	set_offline_availability (ep, pitem, data, "1");
 }
 
 static EPopupItem ecc_source_popups[] = {
-	{ E_POPUP_ITEM, "10.new", N_("_New Calendar"), new_calendar_cb, NULL, "x-office-calendar", 0, 0 },
-	{ E_POPUP_ITEM, "15.copy", N_("_Copy..."), copy_calendar_cb, NULL, "edit-copy", 0, E_CAL_POPUP_SOURCE_PRIMARY },
-	{ E_POPUP_ITEM, "18.rename", N_("_Rename..."), rename_calendar_cb, NULL, NULL, 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "10.new", (gchar *) N_("_New Calendar"), new_calendar_cb, NULL, (gchar *) "x-office-calendar", 0, 0 },
+	{ E_POPUP_ITEM, (gchar *) "15.copy", (gchar *) N_("_Copy..."), copy_calendar_cb, NULL, (gchar *) "edit-copy", 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "18.rename", (gchar *) N_("_Rename..."), rename_calendar_cb, NULL, NULL, 0, E_CAL_POPUP_SOURCE_PRIMARY },
 
-	{ E_POPUP_BAR, "20.bar" },
-	{ E_POPUP_ITEM, "20.delete", N_("_Delete"), delete_calendar_cb, NULL, "edit-delete", 0,E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_DELETE },
-	{ E_POPUP_ITEM, "30.mark_calendar_offline", N_("_Make available for offline use"), mark_offline_cb, NULL, "stock_disconnect", E_CAL_POPUP_SOURCE_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_OFFLINE },
-	{ E_POPUP_ITEM, "40.mark_calendar_no_offline", N_("_Do not make available for offline use"), mark_no_offline_cb, NULL, "stock_connect", E_CAL_POPUP_SOURCE_NO_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_NO_OFFLINE },
+	{ E_POPUP_BAR, (gchar *) "20.bar" },
+	{ E_POPUP_ITEM, (gchar *) "20.delete", (gchar *) N_("_Delete"), delete_calendar_cb, NULL, (gchar *) "edit-delete", 0,E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_DELETE },
+	{ E_POPUP_ITEM, (gchar *) "30.mark_calendar_offline", (gchar *) N_("_Make available for offline use"), mark_offline_cb, NULL, (gchar *) "stock_disconnect", E_CAL_POPUP_SOURCE_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_OFFLINE },
+	{ E_POPUP_ITEM, (gchar *) "40.mark_calendar_no_offline", (gchar *) N_("_Do not make available for offline use"), mark_no_offline_cb, NULL, (gchar *) "stock_connect", E_CAL_POPUP_SOURCE_NO_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_NO_OFFLINE },
 
-	{ E_POPUP_BAR, "99.bar" },
-	{ E_POPUP_ITEM, "99.properties", N_("_Properties"), edit_calendar_cb, NULL, "document-properties", 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_BAR, (gchar *) "99.bar" },
+	{ E_POPUP_ITEM, (gchar *) "99.properties", (gchar *) N_("_Properties"), edit_calendar_cb, NULL, (gchar *) "document-properties", 0, E_CAL_POPUP_SOURCE_PRIMARY },
 };
 
 static void
-ecc_source_popup_free(EPopup *ep, GSList *list, void *data)
+ecc_source_popup_free(EPopup *ep, GSList *list, gpointer data)
 {
 	g_slist_free(list);
 }
@@ -648,7 +649,7 @@ popup_event_cb(ESourceSelector *selector, ESource *insource, GdkEventButton *eve
 	ECalPopup *ep;
 	ECalPopupTargetSource *t;
 	GSList *menus = NULL;
-	int i;
+	gint i;
 	GtkMenu *menu;
 
 	/** @HookPoint-ECalPopup: Calendar Source Selector Context Menu
@@ -729,7 +730,7 @@ set_info (CalendarComponentView *component_view)
 	struct icaltimetype start_tt, end_tt;
 	time_t start_time, end_time;
 	struct tm start_tm, end_tm;
-	char buffer[512], end_buffer[256];
+	gchar buffer[512], end_buffer[256];
 	GnomeCalendarViewType view;
 
 	gnome_calendar_get_visible_time_range (component_view->calendar, &start_time, &end_time);
@@ -865,15 +866,15 @@ config_primary_memos_selection_changed_cb (GConfClient *client, guint id, GConfE
 
 /* Evolution::Component CORBA methods.  */
 static void
-impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environment *ev)
+impl_handleURI (PortableServer_Servant servant, const gchar *uri, CORBA_Environment *ev)
 {
 	CalendarComponent *calendar_component = CALENDAR_COMPONENT (bonobo_object_from_servant (servant));
 	CalendarComponentPrivate *priv;
 	GList *l;
 	CalendarComponentView *view = NULL;
-	char *src_uid = NULL;
-	char *uid = NULL;
-	char *rid = NULL;
+	gchar *src_uid = NULL;
+	gchar *uid = NULL;
+	gchar *rid = NULL;
 
 	priv = calendar_component->priv;
 
@@ -885,9 +886,9 @@ impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environme
 
 	if (!strncmp (uri, "calendar:", 9)) {
 		EUri *euri = e_uri_new (uri);
-		const char *p;
-		char *header, *content;
-		size_t len, clen;
+		const gchar *p;
+		gchar *header, *content;
+		gsize len, clen;
 		time_t start = -1, end = -1;
 
 		p = euri->query;
@@ -899,7 +900,7 @@ impl_handleURI (PortableServer_Servant servant, const char *uri, CORBA_Environme
 				if (p[len] != '=')
 					break;
 
-				header = (char *) p;
+				header = (gchar *) p;
 				header[len] = '\0';
 				p += len + 1;
 
@@ -991,10 +992,10 @@ selector_tree_data_dropped (ESourceSelector *selector,
 
 	if (data->data) {
 		icalcomponent *icalcomp = NULL;
-		char *comp_str; /* do not free this! */
+		gchar *comp_str; /* do not free this! */
 
 		/* data->data is "source_uid\ncomponent_string" */
-		comp_str = strchr ((char *)data->data, '\n');
+		comp_str = strchr ((gchar *)data->data, '\n');
 		if (comp_str) {
 			comp_str [0] = 0;
 			comp_str++;
@@ -1002,7 +1003,7 @@ selector_tree_data_dropped (ESourceSelector *selector,
 			icalcomp = icalparser_parse_string (comp_str);
 
 			if (icalcomp) {
-				success = cal_comp_process_source_list_drop (client, icalcomp, action, (char *)data->data, component->priv->source_list);
+				success = cal_comp_process_source_list_drop (client, icalcomp, action, (gchar *)data->data, component->priv->source_list);
 				icalcomponent_free (icalcomp);
 			}
 		}
@@ -1044,7 +1045,7 @@ setup_create_ecal (CalendarComponent *calendar_component, CalendarComponentView
 {
 	CalendarComponentPrivate *priv;
 	ESource *source = NULL;
-	char *uid;
+	gchar *uid;
 	guint not;
 
 	priv = calendar_component->priv;
@@ -1159,7 +1160,7 @@ create_new_event (CalendarComponent *calendar_component, CalendarComponentView *
 }
 
 static void
-create_local_item_cb (EUserCreatableItemsHandler *handler, const char *item_type_name, void *data)
+create_local_item_cb (EUserCreatableItemsHandler *handler, const gchar *item_type_name, gpointer data)
 {
 	CalendarComponent *calendar_component = data;
 	CalendarComponentPrivate *priv;
@@ -1179,7 +1180,7 @@ create_local_item_cb (EUserCreatableItemsHandler *handler, const char *item_type
 
 	if (strcmp (item_type_name, CREATE_EVENT_ID) == 0)
 		create_new_event (calendar_component, component_view, FALSE, FALSE);
- 	else if (strcmp (item_type_name, CREATE_ALLDAY_EVENT_ID) == 0)
+	else if (strcmp (item_type_name, CREATE_ALLDAY_EVENT_ID) == 0)
 		create_new_event (calendar_component, component_view, TRUE, FALSE);
 	else if (strcmp (item_type_name, CREATE_MEETING_ID) == 0)
 		create_new_event (calendar_component, component_view, FALSE, TRUE);
@@ -1433,36 +1434,36 @@ impl__get_userCreatableItems (PortableServer_Servant servant,
 
 	CORBA_sequence_set_release (list, FALSE);
 
-	list->_buffer[0].id = CREATE_EVENT_ID;
-	list->_buffer[0].description = _("New appointment");
-	list->_buffer[0].menuDescription = (char *) C_("New", "_Appointment");
-	list->_buffer[0].tooltip = _("Create a new appointment");
+	list->_buffer[0].id = (gchar *) CREATE_EVENT_ID;
+	list->_buffer[0].description = (gchar *) _("New appointment");
+	list->_buffer[0].menuDescription = (gchar *) C_("New", "_Appointment");
+	list->_buffer[0].tooltip = (gchar *) _("Create a new appointment");
 	list->_buffer[0].menuShortcut = 'a';
-	list->_buffer[0].iconName = "appointment-new";
+	list->_buffer[0].iconName = (gchar *) "appointment-new";
 	list->_buffer[0].type = GNOME_Evolution_CREATABLE_OBJECT;
 
-	list->_buffer[1].id = CREATE_MEETING_ID;
-	list->_buffer[1].description = _("New meeting");
-	list->_buffer[1].menuDescription = (char *) C_("New", "M_eeting");
-	list->_buffer[1].tooltip = _("Create a new meeting request");
+	list->_buffer[1].id = (gchar *) CREATE_MEETING_ID;
+	list->_buffer[1].description = (gchar *) _("New meeting");
+	list->_buffer[1].menuDescription = (gchar *) C_("New", "M_eeting");
+	list->_buffer[1].tooltip = (gchar *) _("Create a new meeting request");
 	list->_buffer[1].menuShortcut = 'e';
-	list->_buffer[1].iconName = "stock_new-meeting";
+	list->_buffer[1].iconName = (gchar *) "stock_new-meeting";
 	list->_buffer[1].type = GNOME_Evolution_CREATABLE_OBJECT;
 
-	list->_buffer[2].id = CREATE_ALLDAY_EVENT_ID;
-	list->_buffer[2].description = _("New all day appointment");
-	list->_buffer[2].menuDescription = (char *) C_("New", "All Day A_ppointment");
-	list->_buffer[2].tooltip = _("Create a new all-day appointment");
+	list->_buffer[2].id = (gchar *) CREATE_ALLDAY_EVENT_ID;
+	list->_buffer[2].description = (gchar *) _("New all day appointment");
+	list->_buffer[2].menuDescription = (gchar *) C_("New", "All Day A_ppointment");
+	list->_buffer[2].tooltip = (gchar *) _("Create a new all-day appointment");
 	list->_buffer[2].menuShortcut = '\0';
-	list->_buffer[2].iconName = "stock_new-24h-appointment";
+	list->_buffer[2].iconName = (gchar *) "stock_new-24h-appointment";
 	list->_buffer[2].type = GNOME_Evolution_CREATABLE_OBJECT;
 
-	list->_buffer[3].id = CREATE_CALENDAR_ID;
-	list->_buffer[3].description = _("New calendar");
-	list->_buffer[3].menuDescription = (char *) C_("New", "Cale_ndar");
-	list->_buffer[3].tooltip = _("Create a new calendar");
+	list->_buffer[3].id = (gchar *) CREATE_CALENDAR_ID;
+	list->_buffer[3].description = (gchar *) _("New calendar");
+	list->_buffer[3].menuDescription = (gchar *) C_("New", "Cale_ndar");
+	list->_buffer[3].tooltip = (gchar *) _("Create a new calendar");
 	list->_buffer[3].menuShortcut = '\0';
-	list->_buffer[3].iconName = "x-office-calendar";
+	list->_buffer[3].iconName = (gchar *) "x-office-calendar";
 	list->_buffer[3].type = GNOME_Evolution_CREATABLE_FOLDER;
 
 	return list;
@@ -1478,7 +1479,7 @@ impl_requestCreateItem (PortableServer_Servant servant,
 
 	if (strcmp (item_type_name, CREATE_EVENT_ID) == 0)
 		result = create_new_event (calendar_component, NULL, FALSE, FALSE);
- 	else if (strcmp (item_type_name, CREATE_ALLDAY_EVENT_ID) == 0)
+	else if (strcmp (item_type_name, CREATE_ALLDAY_EVENT_ID) == 0)
 		result = create_new_event (calendar_component, NULL, TRUE, FALSE);
 	else if (strcmp (item_type_name, CREATE_MEETING_ID) == 0)
 		result = create_new_event (calendar_component, NULL, FALSE, TRUE);
@@ -1609,10 +1610,8 @@ calendar_component_init (CalendarComponent *component)
 	component->priv = priv;
 	ensure_sources (component);
 
-	if (!e_cal_get_sources (&priv->task_source_list, E_CAL_SOURCE_TYPE_TODO, NULL))
-		;
-	if (!e_cal_get_sources (&priv->memo_source_list, E_CAL_SOURCE_TYPE_JOURNAL, NULL))
-		;
+	e_cal_get_sources (&priv->task_source_list, E_CAL_SOURCE_TYPE_TODO, NULL);
+	e_cal_get_sources (&priv->memo_source_list, E_CAL_SOURCE_TYPE_JOURNAL, NULL);
 }
 
 
@@ -1638,13 +1637,13 @@ calendar_component_peek (void)
 	return component;
 }
 
-const char *
+const gchar *
 calendar_component_peek_base_directory (CalendarComponent *component)
 {
 	return component->priv->base_directory;
 }
 
-const char *
+const gchar *
 calendar_component_peek_config_directory (CalendarComponent *component)
 {
 	return component->priv->config_directory;
