@@ -1,25 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
- * Authors :
- *  Damon Chaplin <damon@ximian.com>
- *  Ettore Perazzoli <ettore@ximian.com>
- *  David Trowbridge <trowbrds cs colorado edu>
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *		David Trowbridge <trowbrds cs colorado edu>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -37,20 +36,21 @@
 #include <glib/gi18n.h>
 #include <string.h>
 
-static const int week_start_day_map[] = {
+static const gint week_start_day_map[] = {
 	1, 2, 3, 4, 5, 6, 0, -1
 };
 
-static const int time_division_map[] = {
+static const gint time_division_map[] = {
 	60, 30, 15, 10, 5, -1
 };
 
 /* The following two are kept separate in case we need to re-order each menu individually */
-static const int hide_completed_units_map[] = {
+static const gint hide_completed_units_map[] = {
 	CAL_MINUTES, CAL_HOURS, CAL_DAYS, -1
 };
 
-static const int default_reminder_units_map[] = {
+/* same is used for Birthdays & Anniversaries calendar */
+static const gint default_reminder_units_map[] = {
 	CAL_MINUTES, CAL_HOURS, CAL_DAYS, -1
 };
 
@@ -92,7 +92,7 @@ calendar_prefs_dialog_init (CalendarPrefsDialog *dialog)
 }
 
 static GtkWidget *
-eccp_widget_glade (EConfig *ec, EConfigItem *item, GtkWidget *parent, GtkWidget *old, void *data)
+eccp_widget_glade (EConfig *ec, EConfigItem *item, GtkWidget *parent, GtkWidget *old, gpointer data)
 {
 	CalendarPrefsDialog *prefs = data;
 
@@ -104,7 +104,7 @@ working_days_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 {
 	CalWeekdays working_days = 0;
 	guint32 mask = 1;
-	int day;
+	gint day;
 
 	for (day = 0; day < 7; day++) {
 		if (e_dialog_toggle_get (prefs->working_days[day]))
@@ -119,31 +119,111 @@ static void
 timezone_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 {
 	icaltimezone *zone;
-	icalcomponent *icalcomp, *dl_comp;
 
 	zone = e_timezone_entry_get_timezone (E_TIMEZONE_ENTRY (prefs->timezone));
-	icalcomp = icaltimezone_get_component (zone);
-
-	if (!(dl_comp = icalcomponent_get_first_component (icalcomp, ICAL_XDAYLIGHT_COMPONENT)))
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->daylight_saving, FALSE);
-	else
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->daylight_saving, TRUE);
 
 	calendar_config_set_timezone (icaltimezone_get_location (zone));
 }
 
 static void
-daylight_saving_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
+update_day_second_zone_caption (CalendarPrefsDialog *prefs)
 {
-	gboolean set = gtk_toggle_button_get_active ((GtkToggleButton *) prefs->daylight_saving);
-	calendar_config_set_daylight_saving (set);
-	timezone_changed (widget, prefs);
+	gchar *location;
+	const gchar *caption;
+	icaltimezone *zone;
+
+	g_return_if_fail (prefs != NULL);
+
+	caption = _("None");
+
+	location = calendar_config_get_day_second_zone ();
+	if (location && *location) {
+		zone = icaltimezone_get_builtin_timezone (location);
+		if (zone && icaltimezone_get_display_name (zone)) {
+			caption = icaltimezone_get_display_name (zone);
+		}
+	}
+	g_free (location);
+
+	gtk_button_set_label (GTK_BUTTON (prefs->day_second_zone), caption);
+}
+
+static void
+on_set_day_second_zone (GtkWidget *item, CalendarPrefsDialog *prefs)
+{
+	if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
+		return;
+
+	calendar_config_set_day_second_zone (g_object_get_data (G_OBJECT (item), "timezone"));
+	update_day_second_zone_caption (prefs);
+}
+
+static void
+on_select_day_second_zone (GtkWidget *item, CalendarPrefsDialog *prefs)
+{
+	g_return_if_fail (prefs != NULL);
+
+	calendar_config_select_day_second_zone ();
+	update_day_second_zone_caption (prefs);
+}
+
+static void
+day_second_zone_clicked (GtkWidget *widget, CalendarPrefsDialog *prefs)
+{
+	GtkWidget *menu, *item;
+	GSList *group = NULL, *recent_zones, *s;
+	gchar *location;
+	icaltimezone *zone, *second_zone = NULL;
+
+	menu = gtk_menu_new ();
+
+	location = calendar_config_get_day_second_zone ();
+	if (location && *location)
+		second_zone = icaltimezone_get_builtin_timezone (location);
+	g_free (location);
+
+	group = NULL;
+	item = gtk_radio_menu_item_new_with_label (group, _("None"));
+	group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
+	if (!second_zone)
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), TRUE);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	g_signal_connect (item, "toggled", G_CALLBACK (on_set_day_second_zone), prefs);
+
+	recent_zones = calendar_config_get_day_second_zones ();
+	for (s = recent_zones; s != NULL; s = s->next) {
+		zone = icaltimezone_get_builtin_timezone (s->data);
+		if (!zone)
+			continue;
+
+		item = gtk_radio_menu_item_new_with_label (group, icaltimezone_get_display_name (zone));
+		group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (item));
+		/* both comes from builtin, thus no problem to compare pointers */
+		if (zone == second_zone)
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), TRUE);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+		g_object_set_data_full (G_OBJECT (item), "timezone", g_strdup (s->data), g_free);
+		g_signal_connect (item, "toggled", G_CALLBACK (on_set_day_second_zone), prefs);
+	}
+	calendar_config_free_day_second_zones (recent_zones);
+
+	item = gtk_separator_menu_item_new ();
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+	item = gtk_menu_item_new_with_label (_("Select..."));
+	g_signal_connect (item, "activate", G_CALLBACK (on_select_day_second_zone), prefs);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+	gtk_widget_show_all (menu);
+
+	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
+			0, gtk_get_current_event_time ());
 }
 
 static void
 start_of_day_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 {
-	int start_hour, start_minute, end_hour, end_minute;
+	gint start_hour, start_minute, end_hour, end_minute;
 	EDateEdit *start, *end;
 
 	start = E_DATE_EDIT (prefs->start_of_day);
@@ -168,7 +248,7 @@ start_of_day_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 static void
 end_of_day_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 {
-	int start_hour, start_minute, end_hour, end_minute;
+	gint start_hour, start_minute, end_hour, end_minute;
 	EDateEdit *start, *end;
 
 	start = E_DATE_EDIT (prefs->start_of_day);
@@ -192,7 +272,7 @@ end_of_day_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 static void
 week_start_day_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 {
-	int week_start_day;
+	gint week_start_day;
 
 	week_start_day = e_dialog_combo_box_get (prefs->week_start_day, week_start_day_map);
 	calendar_config_set_week_start_day (week_start_day);
@@ -214,7 +294,7 @@ use_24_hour_toggled (GtkToggleButton *toggle, CalendarPrefsDialog *prefs)
 static void
 time_divisions_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 {
-	int time_divisions;
+	gint time_divisions;
 
 	time_divisions = e_dialog_combo_box_get (prefs->time_divisions, time_division_map);
 	calendar_config_set_time_divisions (time_divisions);
@@ -238,6 +318,18 @@ dnav_show_week_no_toggled (GtkToggleButton *toggle, CalendarPrefsDialog *prefs)
 	calendar_config_set_dnav_show_week_no (gtk_toggle_button_get_active (toggle));
 }
 
+static void
+dview_show_week_no_toggled (GtkToggleButton *toggle, CalendarPrefsDialog *prefs)
+{
+	calendar_config_set_dview_show_week_no (gtk_toggle_button_get_active (toggle));
+}
+
+static void
+month_scroll_by_week_toggled (GtkToggleButton *toggle, CalendarPrefsDialog *prefs)
+{
+	calendar_config_set_month_scroll_by_week (gtk_toggle_button_get_active (toggle));
+}
+
 static void
 hide_completed_tasks_toggled (GtkToggleButton *toggle, CalendarPrefsDialog *prefs)
 {
@@ -313,6 +405,34 @@ default_reminder_units_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
 		e_dialog_combo_box_get (prefs->default_reminder_units, default_reminder_units_map));
 }
 
+static void
+ba_reminder_toggled (GtkToggleButton *toggle, CalendarPrefsDialog *prefs)
+{
+	gboolean enabled = gtk_toggle_button_get_active (toggle);
+
+	calendar_config_set_ba_reminder (&enabled, NULL, NULL);
+}
+
+static void
+ba_reminder_interval_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
+{
+	const gchar *str;
+	gint value;
+
+	str = gtk_entry_get_text (GTK_ENTRY (widget));
+	value = (gint) g_ascii_strtod (str, NULL);
+
+	calendar_config_set_ba_reminder (NULL, &value, NULL);
+}
+
+static void
+ba_reminder_units_changed (GtkWidget *widget, CalendarPrefsDialog *prefs)
+{
+	CalUnits units = e_dialog_combo_box_get (prefs->ba_reminder_units, default_reminder_units_map);
+
+	calendar_config_set_ba_reminder (NULL, NULL, &units);
+}
+
 static void
 alarms_selection_changed (ESourceSelector *selector, CalendarPrefsDialog *prefs)
 {
@@ -365,16 +485,41 @@ template_url_changed (GtkEntry *entry, CalendarPrefsDialog *prefs)
 	calendar_config_set_free_busy_template (gtk_entry_get_text (entry));
 }
 
+static void
+update_system_tz_widgets (CalendarPrefsDialog *prefs)
+{
+	icaltimezone *zone;
+
+	zone = e_cal_util_get_system_timezone ();
+	if (zone) {
+		gchar *tmp = g_strdup_printf ("(%s)", icaltimezone_get_display_name (zone));
+		gtk_label_set_text (GTK_LABEL (prefs->system_tz_label), tmp);
+		g_free (tmp);
+	} else {
+		gtk_label_set_text (GTK_LABEL (prefs->system_tz_label), "(UTC)");
+	}
+
+	gtk_widget_set_sensitive (prefs->timezone, !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (prefs->use_system_tz_check)));
+}
+
+static void
+use_system_tz_changed (GtkWidget *check, CalendarPrefsDialog *prefs)
+{
+	calendar_config_set_use_system_timezone (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)));
+	update_system_tz_widgets (prefs);
+}
+
 static void
 setup_changes (CalendarPrefsDialog *prefs)
 {
-	int i;
+	gint i;
 
 	for (i = 0; i < 7; i ++)
 		g_signal_connect (G_OBJECT (prefs->working_days[i]), "toggled", G_CALLBACK (working_days_changed), prefs);
 
+	g_signal_connect (G_OBJECT (prefs->use_system_tz_check), "toggled", G_CALLBACK (use_system_tz_changed), prefs);
 	g_signal_connect (G_OBJECT (prefs->timezone), "changed", G_CALLBACK (timezone_changed), prefs);
-	g_signal_connect (G_OBJECT (prefs->daylight_saving), "toggled", G_CALLBACK (daylight_saving_changed), prefs);
+	g_signal_connect (G_OBJECT (prefs->day_second_zone), "clicked", G_CALLBACK (day_second_zone_clicked), prefs);
 
 	g_signal_connect (G_OBJECT (prefs->start_of_day), "changed", G_CALLBACK (start_of_day_changed), prefs);
 	g_signal_connect (G_OBJECT (prefs->end_of_day), "changed", G_CALLBACK (end_of_day_changed), prefs);
@@ -388,6 +533,8 @@ setup_changes (CalendarPrefsDialog *prefs)
 	g_signal_connect (G_OBJECT (prefs->show_end_times), "toggled", G_CALLBACK (show_end_times_toggled), prefs);
 	g_signal_connect (G_OBJECT (prefs->compress_weekend), "toggled", G_CALLBACK (compress_weekend_toggled), prefs);
 	g_signal_connect (G_OBJECT (prefs->dnav_show_week_no), "toggled", G_CALLBACK (dnav_show_week_no_toggled), prefs);
+	g_signal_connect (G_OBJECT (prefs->dview_show_week_no), "toggled", G_CALLBACK (dview_show_week_no_toggled), prefs);
+	g_signal_connect (G_OBJECT (prefs->month_scroll_by_week), "toggled", G_CALLBACK (month_scroll_by_week_toggled), prefs);
 
 	g_signal_connect (G_OBJECT (prefs->tasks_hide_completed), "toggled",
 			  G_CALLBACK (hide_completed_tasks_toggled), prefs);
@@ -405,6 +552,11 @@ setup_changes (CalendarPrefsDialog *prefs)
 			  G_CALLBACK (default_reminder_interval_changed), prefs);
 	g_signal_connect (G_OBJECT (prefs->default_reminder_units), "changed", G_CALLBACK (default_reminder_units_changed), prefs);
 
+	g_signal_connect (G_OBJECT (prefs->ba_reminder), "toggled", G_CALLBACK (ba_reminder_toggled), prefs);
+	g_signal_connect (G_OBJECT (prefs->ba_reminder_interval), "changed",
+			  G_CALLBACK (ba_reminder_interval_changed), prefs);
+	g_signal_connect (G_OBJECT (prefs->ba_reminder_units), "changed", G_CALLBACK (ba_reminder_units_changed), prefs);
+
 	g_signal_connect (G_OBJECT (prefs->alarm_list_widget), "selection_changed", G_CALLBACK (alarms_selection_changed), prefs);
 
 
@@ -465,7 +617,7 @@ initialize_selection (ESourceSelector *selector, ESourceList *source_list)
 		GSList *sources;
 		for (sources = e_source_group_peek_sources (group); sources; sources = sources->next) {
 			ESource *source = E_SOURCE (sources->data);
-			const char *completion = e_source_get_property (source, "alarm");
+			const gchar *completion = e_source_get_property (source, "alarm");
 			if (!completion  || !g_ascii_strcasecmp (completion, "true")) {
 				if (!completion)
 					e_source_set_property (E_SOURCE (source), "alarm", "true");
@@ -496,23 +648,23 @@ show_config (CalendarPrefsDialog *prefs)
 	gint mask, day, week_start_day, time_divisions;
 	icaltimezone *zone;
 	gboolean sensitive, set = FALSE;
-	icalcomponent *icalcomp, *dl_comp;
-	char *location;
+	gchar *location;
+	CalUnits units;
+	gint interval;
+
+	/* Use system timezone */
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (prefs->use_system_tz_check), calendar_config_get_use_system_timezone ());
+	gtk_widget_set_sensitive (prefs->system_tz_label, FALSE);
+	update_system_tz_widgets (prefs);
 
 	/* Timezone. */
-	location = calendar_config_get_timezone ();
+	location = calendar_config_get_timezone_stored ();
 	zone = icaltimezone_get_builtin_timezone (location);
 	e_timezone_entry_set_timezone (E_TIMEZONE_ENTRY (prefs->timezone), zone);
 	g_free (location);
 
-	icalcomp = icaltimezone_get_component (zone);
-	if (!(dl_comp = icalcomponent_get_first_component (icalcomp, ICAL_XDAYLIGHT_COMPONENT)))
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->daylight_saving, FALSE);
-	else
-		gtk_widget_set_sensitive ((GtkWidget *) prefs->daylight_saving, TRUE);
-
-	set = calendar_config_get_daylight_saving ();
-	gtk_toggle_button_set_active ((GtkToggleButton *) prefs->daylight_saving, set);
+	/* Day's second zone */
+	update_day_second_zone_caption (prefs);
 
 	/* Working Days. */
 	working_days = calendar_config_get_working_days ();
@@ -556,6 +708,12 @@ show_config (CalendarPrefsDialog *prefs)
 	/* Date Navigator - Show Week Numbers. */
 	e_dialog_toggle_set (prefs->dnav_show_week_no, calendar_config_get_dnav_show_week_no ());
 
+	/* Day/Work Week view - Show Week Number. */
+	e_dialog_toggle_set (prefs->dview_show_week_no, calendar_config_get_dview_show_week_no ());
+
+	/* Month View - Scroll by a week */
+	e_dialog_toggle_set (prefs->month_scroll_by_week, calendar_config_get_month_scroll_by_week ());
+
 	/* Task list */
 	show_task_list_config (prefs);
 
@@ -570,25 +728,32 @@ show_config (CalendarPrefsDialog *prefs)
 	e_dialog_toggle_set (prefs->default_reminder, calendar_config_get_use_default_reminder ());
 	e_dialog_spin_set (prefs->default_reminder_interval, calendar_config_get_default_reminder_interval ());
 	e_dialog_combo_box_set (prefs->default_reminder_units, calendar_config_get_default_reminder_units (), default_reminder_units_map);
+
+	/* Birthdays & Anniversaries reminder */
+	set = calendar_config_get_ba_reminder (&interval, &units);
+
+	e_dialog_toggle_set (prefs->ba_reminder, set);
+	e_dialog_spin_set (prefs->ba_reminder_interval, interval);
+	e_dialog_combo_box_set (prefs->ba_reminder_units, units, default_reminder_units_map);
 }
 
 /* plugin meta-data */
 static ECalConfigItem eccp_items[] = {
-	{ E_CONFIG_BOOK,          "",                             "toplevel-notebook",   eccp_widget_glade },
-	{ E_CONFIG_PAGE,          "00.general",                   "general",             eccp_widget_glade },
-	{ E_CONFIG_SECTION_TABLE, "00.general/00.time",           "time",                eccp_widget_glade },
-	{ E_CONFIG_SECTION_TABLE, "00.general/10.workWeek",       "workWeek",            eccp_widget_glade },
-	{ E_CONFIG_SECTION,       "00.general/20.alerts",         "alerts",              eccp_widget_glade },
-	{ E_CONFIG_PAGE,          "10.display",                   "display",             eccp_widget_glade },
-	{ E_CONFIG_SECTION,       "10.display/00.general",        "displayGeneral",      eccp_widget_glade },
-	{ E_CONFIG_SECTION,       "10.display/10.taskList",       "taskList",            eccp_widget_glade },
-	{ E_CONFIG_PAGE,	  "15.alarms",			  "alarms",		 eccp_widget_glade },
-	{ E_CONFIG_PAGE,          "20.freeBusy",                  "freebusy",            eccp_widget_glade },
-	{ E_CONFIG_SECTION,       "20.freeBusy/00.defaultServer", "defaultFBServer",     eccp_widget_glade },
+	{ E_CONFIG_BOOK,          (gchar *) "",                             (gchar *) "toplevel-notebook", eccp_widget_glade },
+	{ E_CONFIG_PAGE,          (gchar *) "00.general",                   (gchar *) "general",           eccp_widget_glade },
+	{ E_CONFIG_SECTION_TABLE, (gchar *) "00.general/00.time",           (gchar *) "time",              eccp_widget_glade },
+	{ E_CONFIG_SECTION_TABLE, (gchar *) "00.general/10.workWeek",       (gchar *) "workWeek",          eccp_widget_glade },
+	{ E_CONFIG_SECTION,       (gchar *) "00.general/20.alerts",         (gchar *) "alerts",            eccp_widget_glade },
+	{ E_CONFIG_PAGE,          (gchar *) "10.display",                   (gchar *) "display",           eccp_widget_glade },
+	{ E_CONFIG_SECTION,       (gchar *) "10.display/00.general",        (gchar *) "displayGeneral",    eccp_widget_glade },
+	{ E_CONFIG_SECTION,       (gchar *) "10.display/10.taskList",       (gchar *) "taskList",          eccp_widget_glade },
+	{ E_CONFIG_PAGE,          (gchar *) "15.alarms",                    (gchar *) "alarms",            eccp_widget_glade },
+	{ E_CONFIG_PAGE,          (gchar *) "20.freeBusy",                  (gchar *) "freebusy",          eccp_widget_glade },
+	{ E_CONFIG_SECTION,       (gchar *) "20.freeBusy/00.defaultServer", (gchar *) "defaultFBServer",   eccp_widget_glade },
 };
 
 static void
-eccp_free (EConfig *ec, GSList *items, void *data)
+eccp_free (EConfig *ec, GSList *items, gpointer data)
 {
 	g_slist_free (items);
 }
@@ -599,10 +764,10 @@ calendar_prefs_dialog_construct (CalendarPrefsDialog *prefs)
 	GladeXML *gui;
 	ECalConfig *ec;
 	ECalConfigTargetPrefs *target;
-	int i;
+	gint i;
 	GtkWidget *toplevel;
 	GSList *l;
-	const char *working_day_names[] = {
+	const gchar *working_day_names[] = {
 		"sun_button",
 		"mon_button",
 		"tue_button",
@@ -611,7 +776,7 @@ calendar_prefs_dialog_construct (CalendarPrefsDialog *prefs)
 		"fri_button",
 		"sat_button",
 	};
-	char *gladefile;
+	gchar *gladefile;
 
 	gladefile = g_build_filename (EVOLUTION_GLADEDIR,
 				      "cal-prefs-dialog.glade",
@@ -637,8 +802,10 @@ calendar_prefs_dialog_construct (CalendarPrefsDialog *prefs)
 	e_config_add_items ((EConfig *) ec, l, NULL, NULL, eccp_free, prefs);
 
 	/* General tab */
+	prefs->use_system_tz_check = glade_xml_get_widget (gui, "use-system-tz-check");
+	prefs->system_tz_label = glade_xml_get_widget (gui, "system-tz-label");
 	prefs->timezone = glade_xml_get_widget (gui, "timezone");
-	prefs->daylight_saving = glade_xml_get_widget (gui, "daylight_cb");
+	prefs->day_second_zone = glade_xml_get_widget (gui, "day_second_zone");
 	for (i = 0; i < 7; i++)
 		prefs->working_days[i] = glade_xml_get_widget (gui, working_day_names[i]);
 	prefs->week_start_day = glade_xml_get_widget (gui, "week_start_day");
@@ -650,12 +817,17 @@ calendar_prefs_dialog_construct (CalendarPrefsDialog *prefs)
 	prefs->default_reminder = glade_xml_get_widget (gui, "default_reminder");
 	prefs->default_reminder_interval = glade_xml_get_widget (gui, "default_reminder_interval");
 	prefs->default_reminder_units = glade_xml_get_widget (gui, "default_reminder_units");
+	prefs->ba_reminder = glade_xml_get_widget (gui, "ba_reminder");
+	prefs->ba_reminder_interval = glade_xml_get_widget (gui, "ba_reminder_interval");
+	prefs->ba_reminder_units = glade_xml_get_widget (gui, "ba_reminder_units");
 
 	/* Display tab */
 	prefs->time_divisions = glade_xml_get_widget (gui, "time_divisions");
 	prefs->show_end_times = glade_xml_get_widget (gui, "show_end_times");
 	prefs->compress_weekend = glade_xml_get_widget (gui, "compress_weekend");
 	prefs->dnav_show_week_no = glade_xml_get_widget (gui, "dnav_show_week_no");
+	prefs->dview_show_week_no = glade_xml_get_widget (gui, "dview_show_week_no");
+	prefs->month_scroll_by_week = glade_xml_get_widget (gui, "month_scroll_by_week");
 	prefs->tasks_due_today_color = glade_xml_get_widget (gui, "tasks_due_today_color");
 	prefs->tasks_overdue_color = glade_xml_get_widget (gui, "tasks_overdue_color");
 	prefs->tasks_hide_completed = glade_xml_get_widget (gui, "tasks_hide_completed");
