@@ -1,21 +1,25 @@
-/* Evolution calendar - Widget utilities
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * Author: Federico Mena-Quintero <federico@ximian.com>
+/*
+ * Evolution calendar - Widget utilities
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Federico Mena-Quintero <federico@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -108,12 +112,16 @@ comp_editor_free_dates (CompEditorPageDates *dates)
 
 /* dtstart is only passed in if tt is the dtend. */
 static void
-write_label_piece (struct icaltimetype *tt, char *buffer, int size,
-		   char *stext, char *etext, struct icaltimetype *dtstart)
+write_label_piece (struct icaltimetype *tt,
+                   gchar *buffer,
+                   gint size,
+                   gchar *stext,
+                   const gchar *etext,
+                   struct icaltimetype *dtstart)
 {
 	struct tm tmp_tm = { 0 };
 	struct icaltimetype tt_copy = *tt;
-	int len;
+	gint len;
 
 	/* FIXME: May want to convert the time to an appropriate zone. */
 
@@ -158,7 +166,7 @@ write_label_piece (struct icaltimetype *tt, char *buffer, int size,
 void
 comp_editor_date_label (CompEditorPageDates *dates, GtkWidget *label)
 {
-	char buffer[1024];
+	gchar buffer[1024];
 	gboolean start_set = FALSE, end_set = FALSE;
 	gboolean complete_set = FALSE, due_set = FALSE;
 
@@ -282,13 +290,13 @@ comp_editor_get_current_time (GtkObject *object, gpointer data)
  * Return value: The category names stripped of surrounding whitespace
  * and separated with commas.
  **/
-char *
-comp_editor_strip_categories (const char *categories)
+gchar *
+comp_editor_strip_categories (const gchar *categories)
 {
-	char *new_categories;
-	const char *start, *end;
-	const char *p;
-	char *new_p;
+	gchar *new_categories;
+	const gchar *start, *end;
+	const gchar *p;
+	gchar *new_p;
 
 	if (!categories)
 		return NULL;
@@ -306,7 +314,7 @@ comp_editor_strip_categories (const char *categories)
 		if (g_unichar_isspace (c))
 			continue;
 		else if (c == ',') {
-			int len;
+			gint len;
 
 			if (!start)
 				continue;
@@ -329,7 +337,7 @@ comp_editor_strip_categories (const char *categories)
 	}
 
 	if (start) {
-		int len;
+		gint len;
 
 		g_return_val_if_fail (start <= end, NULL);
 
