@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -67,7 +67,7 @@ struct _CompEditorClass {
 	/* Virtual functions */
 	void (*edit_comp) (CompEditor *page, ECalComponent *comp);
 	void (*object_created) (CompEditor *page);
-	gboolean (*send_comp) (CompEditor *page, ECalComponentItipMethod method);
+	gboolean (*send_comp) (CompEditor *page, ECalComponentItipMethod method, gboolean strip_alarms);
 
 	void (*show_categories) (CompEditor *editor, gboolean visible);
 	void (*show_role) (CompEditor *editor, gboolean visible);
@@ -129,7 +129,8 @@ gboolean	comp_editor_save_comp		(CompEditor *editor,
 						 gboolean send);
 void		comp_editor_delete_comp		(CompEditor *editor);
 gboolean	comp_editor_send_comp		(CompEditor *editor,
-						 ECalComponentItipMethod method);
+						 ECalComponentItipMethod method,
+						 gboolean strip_alarms);
 GSList *	comp_editor_get_mime_attach_list(CompEditor *editor);
 gboolean	comp_editor_close		(CompEditor *editor);
 
@@ -146,7 +147,7 @@ GtkAction *	comp_editor_get_action		(CompEditor *editor,
 						 const gchar *action_name);
 GtkActionGroup *
 		comp_editor_get_action_group	(CompEditor *editor,
-                                            	 const gchar *group_name);
+						 const gchar *group_name);
 GtkWidget *	comp_editor_get_managed_widget	(CompEditor *editor,
 						 const gchar *widget_path);
 
