@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -54,18 +54,18 @@ struct _EDelegateDialogClass {
 GType            e_delegate_dialog_get_type          (void);
 
 EDelegateDialog* e_delegate_dialog_construct         (EDelegateDialog *etd,
-						      const char      *name,
-						      const char      *address);
+						      const gchar      *name,
+						      const gchar      *address);
 
-EDelegateDialog* e_delegate_dialog_new               (const char      *name,
-						      const char      *address);
+EDelegateDialog* e_delegate_dialog_new               (const gchar      *name,
+						      const gchar      *address);
 
-char*            e_delegate_dialog_get_delegate      (EDelegateDialog *etd);
+gchar *            e_delegate_dialog_get_delegate      (EDelegateDialog *etd);
 
-char*            e_delegate_dialog_get_delegate_name (EDelegateDialog *etd);
+gchar *            e_delegate_dialog_get_delegate_name (EDelegateDialog *etd);
 
 void             e_delegate_dialog_set_delegate      (EDelegateDialog *etd,
-						      const char      *address);
+						      const gchar      *address);
 
 GtkWidget*       e_delegate_dialog_get_toplevel      (EDelegateDialog *etd);
 
