@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -64,6 +64,34 @@
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), TYPE_EVENT_PAGE, EventPagePrivate))
 
+enum {
+	ALARM_NONE,
+	ALARM_15_MINUTES,
+	ALARM_1_HOUR,
+	ALARM_1_DAY,
+	ALARM_USER_TIME,
+	ALARM_CUSTOM
+};
+
+static const gint alarm_map_with_user_time[] = {
+	ALARM_NONE,
+	ALARM_15_MINUTES,
+	ALARM_1_HOUR,
+	ALARM_1_DAY,
+	ALARM_USER_TIME,
+	ALARM_CUSTOM,
+	-1
+};
+
+static const gint alarm_map_without_user_time[] = {
+	ALARM_NONE,
+	ALARM_15_MINUTES,
+	ALARM_1_HOUR,
+	ALARM_1_DAY,
+	ALARM_CUSTOM,
+	-1
+};
+
 /* Private part of the EventPage structure */
 struct _EventPagePrivate {
 	/* Glade XML data */
@@ -85,7 +113,7 @@ struct _EventPagePrivate {
 	EAccountList *accounts;
 	GList *address_strings;
 	EMeetingAttendee *ia;
-	char *user_add;
+	gchar *user_add;
 	ECalComponent *comp;
 
 	/* For meeting/event */
@@ -148,9 +176,9 @@ struct _EventPagePrivate {
 	gboolean sendoptions_shown;
 
 	ESendOptionsDialog *sod;
-	char *old_summary;
+	gchar *old_summary;
 	CalUnits alarm_units;
-	int alarm_interval;
+	gint alarm_interval;
 
 	/* This is TRUE if both the start & end timezone are the same. If the
 	   start timezone is then changed, we updated the end timezone to the
@@ -159,6 +187,9 @@ struct _EventPagePrivate {
 	gboolean is_meeting;
 
 	GtkWidget *alarm_list_dlg_widget;
+
+	/* either with-user-time or without it */
+	const gint *alarm_map;
 };
 
 static GtkWidget *event_page_get_widget (CompEditorPage *page);
@@ -175,10 +206,10 @@ static void hour_sel_changed ( GtkSpinButton *widget, EventPage *epage);
 static void minute_sel_changed ( GtkSpinButton *widget, EventPage *epage);
 static void hour_minute_changed ( EventPage *epage);
 static void update_end_time_combo ( EventPage *epage);
-static void event_page_select_organizer (EventPage *epage, const char *backend_address);
-static void set_subscriber_info_string (EventPage *epage, const char *backend_address);
+static void event_page_select_organizer (EventPage *epage, const gchar *backend_address);
+static void set_subscriber_info_string (EventPage *epage, const gchar *backend_address);
 
-G_DEFINE_TYPE (EventPage, event_page, TYPE_COMP_EDITOR_PAGE);
+G_DEFINE_TYPE (EventPage, event_page, TYPE_COMP_EDITOR_PAGE)
 
 static void
 event_page_dispose (GObject *object)
@@ -265,27 +296,9 @@ event_page_init (EventPage *epage)
 	epage->priv = EVENT_PAGE_GET_PRIVATE (epage);
 	epage->priv->deleted_attendees = g_ptr_array_new ();
 	epage->priv->alarm_interval = -1;
+	epage->priv->alarm_map = alarm_map_with_user_time;
 }
 
-enum {
-	ALARM_NONE,
-	ALARM_15_MINUTES,
-	ALARM_1_HOUR,
-	ALARM_1_DAY,
-	ALARM_USER_TIME,
-	ALARM_CUSTOM
-};
-
-static const int alarm_map[] = {
-	ALARM_NONE,
-	ALARM_15_MINUTES,
-	ALARM_1_HOUR,
-	ALARM_1_DAY,
-	ALARM_USER_TIME,
-	ALARM_CUSTOM,
-	-1
-};
-
 static void
 set_busy_time_menu (EventPage *epage, gboolean active)
 {
@@ -488,14 +501,14 @@ clear_widgets (EventPage *epage)
 	set_busy_time_menu (epage, TRUE);
 
 	/* Alarm */
-	e_dialog_combo_box_set (priv->alarm_time_combo, ALARM_NONE, alarm_map);
+	e_dialog_combo_box_set (priv->alarm_time_combo, ALARM_NONE, priv->alarm_map);
 
 	/* Categories */
 	e_dialog_editable_set (priv->categories, NULL);
 }
 
 static gboolean
-is_custom_alarm (ECalComponentAlarm *ca, char *old_summary, CalUnits user_units, int user_interval, int *alarm_type)
+is_custom_alarm (ECalComponentAlarm *ca, gchar *old_summary, CalUnits user_units, gint user_interval, gint *alarm_type)
 {
 	ECalComponentAlarmTrigger trigger;
 	ECalComponentAlarmRepeat repeat;
@@ -517,7 +530,7 @@ is_custom_alarm (ECalComponentAlarm *ca, char *old_summary, CalUnits user_units,
 	icalcomp = e_cal_component_alarm_get_icalcomponent (ca);
 	icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
 	while (icalprop) {
-		const char *x_name;
+		const gchar *x_name;
 
 		x_name = icalproperty_get_x_name (icalprop);
 		if (!strcmp (x_name, "X-EVOLUTION-NEEDS-DESCRIPTION"))
@@ -614,7 +627,7 @@ is_custom_alarm (ECalComponentAlarm *ca, char *old_summary, CalUnits user_units,
 }
 
 static gboolean
-is_custom_alarm_uid_list (ECalComponent *comp, GList *alarms, char *old_summary, CalUnits user_units, int user_interval, int *alarm_type)
+is_custom_alarm_uid_list (ECalComponent *comp, GList *alarms, gchar *old_summary, CalUnits user_units, gint user_interval, gint *alarm_type)
 {
 	ECalComponentAlarm *ca;
 	gboolean result;
@@ -630,7 +643,7 @@ is_custom_alarm_uid_list (ECalComponent *comp, GList *alarms, char *old_summary,
 }
 
 static gboolean
-is_custom_alarm_store (EAlarmList *alarm_list_store, char *old_summary,  CalUnits user_units, int user_interval, int *alarm_type)
+is_custom_alarm_store (EAlarmList *alarm_list_store, gchar *old_summary,  CalUnits user_units, gint user_interval, gint *alarm_type)
 {
 	const ECalComponentAlarm *alarm;
 	GtkTreeModel *model;
@@ -687,7 +700,7 @@ event_page_set_view_rsvp (EventPage *epage, gboolean state)
 }
 
 static GtkWidget *
-create_image_event_box (const char *image_text, const char *tip_text)
+create_image_event_box (const gchar *image_text, const gchar *tip_text)
 {
 	GtkWidget *image, *box;
 
@@ -719,7 +732,7 @@ sensitize_widgets (EventPage *epage)
 
 	priv = epage->priv;
 	if (flags & COMP_EDITOR_MEETING)
-	 	sens = flags & COMP_EDITOR_USER_ORG;
+		sens = flags & COMP_EDITOR_USER_ORG;
 
 	if (!e_cal_is_read_only (client, &read_only, NULL))
 		read_only = TRUE;
@@ -728,9 +741,9 @@ sensitize_widgets (EventPage *epage)
 
 	sensitize = !read_only && sens;
 
-	alarm = e_dialog_combo_box_get (priv->alarm_time_combo, alarm_map) != ALARM_NONE;
+	alarm = e_dialog_combo_box_get (priv->alarm_time_combo, priv->alarm_map) != ALARM_NONE;
 	custom = is_custom_alarm_store (priv->alarm_list_store, priv->old_summary, priv->alarm_units, priv->alarm_interval, NULL) ||
-		 e_dialog_combo_box_get (priv->alarm_time_combo, alarm_map)  == ALARM_CUSTOM ? TRUE:FALSE;
+		 e_dialog_combo_box_get (priv->alarm_time_combo, priv->alarm_map)  == ALARM_CUSTOM ? TRUE:FALSE;
 
 	if (alarm && !priv->alarm_icon) {
 		priv->alarm_icon = create_image_event_box ("stock_bell", _("This event has alarms"));
@@ -833,7 +846,8 @@ event_page_set_meeting (EventPage *page, gboolean set)
 	g_return_if_fail (IS_EVENT_PAGE (page));
 
 	page->priv->is_meeting = set;
-        sensitize_widgets (page);
+	if (page->priv->comp)
+		sensitize_widgets (page);
 }
 
 void
@@ -852,7 +866,7 @@ get_current_account (EventPage *epage)
 {
 	EventPagePrivate *priv;
 	EIterator *it;
-	const char *str;
+	const gchar *str;
 
 	priv = epage->priv;
 
@@ -862,7 +876,7 @@ get_current_account (EventPage *epage)
 
 	for (it = e_list_get_iterator((EList *)priv->accounts); e_iterator_is_valid(it); e_iterator_next(it)) {
 		EAccount *a = (EAccount *)e_iterator_get(it);
-		char *full = g_strdup_printf("%s <%s>", a->id->name, a->id->address);
+		gchar *full = g_strdup_printf("%s <%s>", a->id->name, a->id->address);
 
 		if (!g_ascii_strcasecmp (full, str)) {
 			g_free (full);
@@ -891,8 +905,8 @@ event_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 	ECalComponentClassification cl;
 	ECalComponentTransparency transparency;
 	ECalComponentDateTime start_date, end_date;
-	const char *location, *uid = NULL;
-	const char *categories;
+	const gchar *location, *uid = NULL;
+	const gchar *categories;
 	gchar *backend_addr = NULL;
 	GSList *l;
 	gboolean validated = TRUE;
@@ -1070,13 +1084,13 @@ event_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 
 	if (e_cal_component_has_alarms (comp)) {
 		GList *alarms, *list;
-		int alarm_type;
+		gint alarm_type;
 
 		alarms = e_cal_component_get_alarm_uids (comp);
 		if (!is_custom_alarm_uid_list (comp, alarms, priv->old_summary, priv->alarm_units, priv->alarm_interval, &alarm_type))
-			e_dialog_combo_box_set (priv->alarm_time_combo, alarm_type, alarm_map);
+			e_dialog_combo_box_set (priv->alarm_time_combo, alarm_type, priv->alarm_map);
 		else
-			e_dialog_combo_box_set (priv->alarm_time_combo, ALARM_CUSTOM, alarm_map);
+			e_dialog_combo_box_set (priv->alarm_time_combo, ALARM_CUSTOM, priv->alarm_map);
 
 		for (list = alarms; list != NULL; list = list->next) {
 			ECalComponentAlarm *ca;
@@ -1088,7 +1102,7 @@ event_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 
 		cal_obj_uid_list_free (alarms);
 	} else {
-		e_dialog_combo_box_set (priv->alarm_time_combo, ALARM_NONE, alarm_map);
+		e_dialog_combo_box_set (priv->alarm_time_combo, ALARM_NONE, priv->alarm_map);
 	}
 	g_signal_handlers_unblock_matched (priv->alarm_time_combo, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, epage);
 	g_signal_handlers_unblock_matched (priv->alarm_list_store, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, epage);
@@ -1126,7 +1140,7 @@ event_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 	ECalComponentDateTime start_date, end_date;
 	struct icaltimetype start_tt, end_tt;
 	gboolean all_day_event, start_date_set, end_date_set, busy;
-	char *cat, *str;
+	gchar *cat, *str;
 	GtkTextBuffer *text_buffer;
 	GtkTextIter text_iter_start, text_iter_end;
 
@@ -1282,8 +1296,8 @@ event_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 
 	/* Alarm */
 	e_cal_component_remove_all_alarms (comp);
-	if (e_dialog_combo_box_get (priv->alarm_time_combo, alarm_map) != ALARM_NONE) {
-		if (e_dialog_combo_box_get (priv->alarm_time_combo, alarm_map) == ALARM_CUSTOM) {
+	if (e_dialog_combo_box_get (priv->alarm_time_combo, priv->alarm_map) != ALARM_NONE) {
+		if (e_dialog_combo_box_get (priv->alarm_time_combo, priv->alarm_map) == ALARM_CUSTOM) {
 			GtkTreeModel *model;
 			GtkTreeIter iter;
 			gboolean valid_iter;
@@ -1308,7 +1322,7 @@ event_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 				icalcomp = e_cal_component_alarm_get_icalcomponent (alarm);
 				icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
 				while (icalprop) {
-					const char *x_name;
+					const gchar *x_name;
 					ECalComponentText summary;
 
 					x_name = icalproperty_get_x_name (icalprop);
@@ -1335,7 +1349,7 @@ event_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 			ECalComponentAlarm *ca;
 			ECalComponentText summary;
 			ECalComponentAlarmTrigger trigger;
-			int alarm_type;
+			gint alarm_type;
 
 			ca = e_cal_component_alarm_new ();
 
@@ -1350,7 +1364,7 @@ event_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 			trigger.type = E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_START;
 			trigger.u.rel_duration.is_neg = 1;
 
-			alarm_type = e_dialog_combo_box_get (priv->alarm_time_combo, alarm_map);
+			alarm_type = e_dialog_combo_box_get (priv->alarm_time_combo, priv->alarm_map);
 			switch (alarm_type) {
 			case ALARM_15_MINUTES:
 				trigger.u.rel_duration.minutes = 15;
@@ -1442,7 +1456,7 @@ event_page_fill_component (CompEditorPage *page, ECalComponent *comp)
 
 		if (flags & COMP_EDITOR_DELEGATE) {
 			GSList *attendee_list, *l;
-			int i;
+			gint i;
 			const GPtrArray *attendees = e_meeting_store_get_attendees (priv->model);
 
 			e_cal_component_get_attendee_list (priv->comp, &attendee_list);
@@ -1516,7 +1530,7 @@ static void
 time_sel_changed (GtkComboBox *combo, EventPage *epage)
 {
 	EventPagePrivate *priv;
-	int selection = gtk_combo_box_get_active (combo);
+	gint selection = gtk_combo_box_get_active (combo);
 
 	priv = epage->priv;
 
@@ -1549,15 +1563,15 @@ void update_end_time_combo (EventPage *epage)
                              &start_tt.month,
                              &start_tt.day);
         e_date_edit_get_time_of_day (E_DATE_EDIT (priv->start_time),
-       	                             &start_tt.hour,
-               	                     &start_tt.minute);
+				     &start_tt.hour,
+				     &start_tt.minute);
 	e_date_edit_get_date (E_DATE_EDIT (priv->end_time),
                              &end_tt.year,
                              &end_tt.month,
                              &end_tt.day);
 	e_date_edit_get_time_of_day (E_DATE_EDIT (priv->end_time),
-               	                     &end_tt.hour,
-                       	             &end_tt.minute);
+				     &end_tt.hour,
+				     &end_tt.minute);
 
 	end_timet = icaltime_as_timet (end_tt);
 	start_timet = icaltime_as_timet (start_tt);
@@ -1570,20 +1584,20 @@ void update_end_time_combo (EventPage *epage)
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (priv->minute_selector), minutes);
 }
 
-void
-static hour_sel_changed (GtkSpinButton *widget, EventPage *epage)
+static void
+hour_sel_changed (GtkSpinButton *widget, EventPage *epage)
 {
 	hour_minute_changed (epage);
 }
 
-void
-static minute_sel_changed (GtkSpinButton *widget, EventPage *epage)
+static void
+minute_sel_changed (GtkSpinButton *widget, EventPage *epage)
 {
 	hour_minute_changed (epage);
 }
 
-void
-static hour_minute_changed ( EventPage *epage)
+static void
+hour_minute_changed (EventPage *epage)
 {
 	EventPagePrivate *priv;
 	gint for_hours, for_minutes;
@@ -1605,10 +1619,10 @@ static hour_minute_changed ( EventPage *epage)
 	icaltime_adjust (&end_tt, 0, for_hours, for_minutes, 0);
 
 	e_date_edit_set_date_and_time_of_day (E_DATE_EDIT (priv->end_time),
-				  	      end_tt.year,
+					      end_tt.year,
 					      end_tt.month,
 					      end_tt.day,
-			      		      end_tt.hour,
+					      end_tt.hour,
 					      end_tt.minute);
 }
 
@@ -1669,8 +1683,8 @@ existing_attendee (EMeetingAttendee *ia, ECalComponent *comp)
 
 	for (l = attendees; l; l = l->next) {
 		ECalComponentAttendee *attendee = l->data;
-		const char *address;
-		const char *sentby = NULL;
+		const gchar *address;
+		const gchar *sentby = NULL;
 
 		address = itip_strip_mailto (attendee->value);
 		if (attendee->sentby)
@@ -1693,7 +1707,7 @@ remove_attendee (EventPage *epage, EMeetingAttendee *ia)
 	EventPagePrivate *priv = epage->priv;
 	CompEditor *editor;
 	CompEditorFlags flags;
-	int pos = 0;
+	gint pos = 0;
 	gboolean delegate;
 
 	editor = comp_editor_page_get_editor (COMP_EDITOR_PAGE (epage));
@@ -1753,7 +1767,7 @@ remove_clicked_cb (GtkButton *btn, EventPage *epage)
 	GtkTreePath *path = NULL;
 	GtkTreeModel *model = NULL;
 	gboolean valid_iter;
-	char *address;
+	gchar *address;
 
 	priv = epage->priv;
 
@@ -1833,7 +1847,7 @@ attendee_added_cb (EMeetingListView *emlv,
 		e_meeting_store_remove_attendee (priv->model, ia);
 	} else {
 		if (!e_cal_get_static_capability (client, CAL_STATIC_CAPABILITY_DELEGATE_TO_MANY)) {
-			const char *delegator_id = e_meeting_attendee_get_delfrom (ia);
+			const gchar *delegator_id = e_meeting_attendee_get_delfrom (ia);
 			EMeetingAttendee *delegator;
 
 			delegator = e_meeting_store_find_attendee (priv->model, delegator_id, NULL);
@@ -1852,7 +1866,7 @@ attendee_added_cb (EMeetingListView *emlv,
 
 /* Callbacks for list view*/
 static void
-popup_add_cb (EPopup *ep, EPopupItem *pitem, void *data)
+popup_add_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EventPage *epage = data;
 
@@ -1860,7 +1874,7 @@ popup_add_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-popup_delete_cb (EPopup *ep, EPopupItem *pitem, void *data)
+popup_delete_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EventPage *epage = data;
 
@@ -1871,16 +1885,16 @@ enum {
 	ATTENDEE_CAN_DELEGATE = 1<<1,
 	ATTENDEE_CAN_DELETE = 1<<2,
 	ATTENDEE_CAN_ADD = 1<<3,
-	ATTENDEE_LAST = 1<<4,
+	ATTENDEE_LAST = 1<<4
 };
 
 static EPopupItem context_menu_items[] = {
-	{ E_POPUP_ITEM, "10.delete", N_("_Remove"), popup_delete_cb, NULL, GTK_STOCK_REMOVE, ATTENDEE_CAN_DELETE },
-	{ E_POPUP_ITEM, "15.add", N_("_Add "), popup_add_cb, NULL, GTK_STOCK_ADD, ATTENDEE_CAN_ADD },
+	{ E_POPUP_ITEM, (gchar *) "10.delete", (gchar *) N_("_Remove"), popup_delete_cb, NULL, (gchar *) GTK_STOCK_REMOVE, ATTENDEE_CAN_DELETE },
+	{ E_POPUP_ITEM, (gchar *) "15.add", (gchar *) N_("_Add "), popup_add_cb, NULL, (gchar *) GTK_STOCK_ADD, ATTENDEE_CAN_ADD },
 };
 
 static void
-context_popup_free(EPopup *ep, GSList *items, void *data)
+context_popup_free(EPopup *ep, GSList *items, gpointer data)
 {
 	g_slist_free(items);
 }
@@ -1895,11 +1909,11 @@ button_press_event (GtkWidget *widget, GdkEventButton *event, EventPage *epage)
 	EMeetingAttendee *ia;
 	GtkTreePath *path;
 	GtkTreeIter iter;
-	char *address;
+	gchar *address;
 	guint32 disable_mask = ~0;
 	GSList *menus = NULL;
 	ECalPopup *ep;
-	int i;
+	gint i;
 
 	/* only process right-clicks */
 	if (event->button != 3 || event->type != GDK_BUTTON_PRESS)
@@ -1923,8 +1937,8 @@ button_press_event (GtkWidget *widget, GdkEventButton *event, EventPage *epage)
 				gtk_tree_selection_unselect_all (selection);
 				gtk_tree_selection_select_path (selection, path);
 
- 				if (e_meeting_attendee_get_edit_level (ia) == E_MEETING_ATTENDEE_EDIT_FULL)
- 					disable_mask &= ~ATTENDEE_CAN_DELETE;
+				if (e_meeting_attendee_get_edit_level (ia) == E_MEETING_ATTENDEE_EDIT_FULL)
+					disable_mask &= ~ATTENDEE_CAN_DELETE;
 			}
 		}
 	}
@@ -2334,7 +2348,7 @@ check_start_before_end (struct icaltimetype *start_tt,
 			gboolean adjust_end_time)
 {
 	struct icaltimetype end_tt_copy;
-	int cmp;
+	gint cmp;
 
 	/* Convert the end time to the same timezone as the start time. */
 	end_tt_copy = *end_tt;
@@ -2406,7 +2420,7 @@ times_updated (EventPage *epage, gboolean adjust_end_time)
 	if (all_day_event) {
 		/* All Day Events are simple. We just compare the dates and if
 		   start > end we copy one of them to the other. */
-		int cmp = icaltime_compare_date_only (start_tt, end_tt);
+		gint cmp = icaltime_compare_date_only (start_tt, end_tt);
 		if (cmp > 0) {
 			if (adjust_end_time) {
 				end_tt = start_tt;
@@ -2632,7 +2646,7 @@ source_changed_cb (ESourceComboBox *source_combo_box, EventPage *epage)
 }
 
 static void
-set_subscriber_info_string (EventPage *epage, const char *backend_address)
+set_subscriber_info_string (EventPage *epage, const gchar *backend_address)
 {
 	CompEditor *editor;
 	ECal *client;
@@ -2660,12 +2674,12 @@ alarm_changed_cb (GtkWidget *widget, gpointer data)
 	epage = EVENT_PAGE (data);
 	priv = epage->priv;
 
-	if (e_dialog_combo_box_get (priv->alarm_time_combo, alarm_map) != ALARM_NONE) {
+	if (e_dialog_combo_box_get (priv->alarm_time_combo, priv->alarm_map) != ALARM_NONE) {
 		ECalComponentAlarm *ca;
 		ECalComponentAlarmTrigger trigger;
 		icalcomponent *icalcomp;
 		icalproperty *icalprop;
-		int alarm_type;
+		gint alarm_type;
 
 		ca = e_cal_component_alarm_new ();
 
@@ -2675,7 +2689,7 @@ alarm_changed_cb (GtkWidget *widget, gpointer data)
 		trigger.type = E_CAL_COMPONENT_ALARM_TRIGGER_RELATIVE_START;
 		trigger.u.rel_duration.is_neg = 1;
 
-		alarm_type = e_dialog_combo_box_get (priv->alarm_time_combo, alarm_map);
+		alarm_type = e_dialog_combo_box_get (priv->alarm_time_combo, priv->alarm_map);
 		switch (alarm_type) {
 		case ALARM_15_MINUTES:
 			e_alarm_list_clear (priv->alarm_list_store);
@@ -2799,7 +2813,7 @@ init_widgets (EventPage *epage)
 	CompEditor *editor;
 	GtkTextBuffer *text_buffer;
 	icaltimezone *zone;
-	char *combo_label = NULL;
+	gchar *combo_label = NULL;
 	GtkTreeSelection *selection;
 	ECal *client;
 
@@ -2945,10 +2959,13 @@ init_widgets (EventPage *epage)
 	if (combo_label) {
 		gtk_combo_box_append_text (GTK_COMBO_BOX (priv->alarm_time_combo), combo_label);
 		g_free (combo_label);
+		priv->alarm_map = alarm_map_with_user_time;
+	} else {
+		priv->alarm_map = alarm_map_without_user_time;
 	}
 
 	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->alarm_time_combo), _("Customize"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (priv->alarm_time_combo), _("None"));
+	gtk_combo_box_prepend_text (GTK_COMBO_BOX (priv->alarm_time_combo), _("None"));
 
 	g_signal_connect_swapped (
 		priv->alarm_time_combo, "changed",
@@ -2996,7 +3013,7 @@ init_widgets (EventPage *epage)
 
 
 static void
-event_page_select_organizer (EventPage *epage, const char *backend_address)
+event_page_select_organizer (EventPage *epage, const gchar *backend_address)
 {
 	EventPagePrivate *priv = epage->priv;
 	CompEditor *editor;
@@ -3004,10 +3021,10 @@ event_page_select_organizer (EventPage *epage, const char *backend_address)
 	ECal *client;
 	EAccount *def_account;
 	gchar *def_address = NULL;
-	const char *default_address;
+	const gchar *default_address;
 	gboolean subscribed_cal = FALSE;
 	ESource *source = NULL;
-	const char *user_addr = NULL;
+	const gchar *user_addr = NULL;
 
 	def_account = itip_addresses_get_default();
 	if (def_account && def_account->enabled)
@@ -3024,13 +3041,13 @@ event_page_select_organizer (EventPage *epage, const char *backend_address)
 	if (user_addr)
 		subscribed_cal = TRUE;
 	else
- 		user_addr = (backend_address && *backend_address) ? backend_address : NULL;
+		user_addr = (backend_address && *backend_address) ? backend_address : NULL;
 
 	default_address = NULL;
 	if (user_addr)
 		for (l = priv->address_strings; l != NULL; l = l->next)
 			if (g_strrstr ((gchar *) l->data, user_addr) != NULL) {
-				default_address = (const char *) l->data;
+				default_address = (const gchar *) l->data;
 				break;
 			}
 
@@ -3063,7 +3080,7 @@ event_page_construct (EventPage *epage, EMeetingStore *model)
 	EventPagePrivate *priv;
 	EIterator *it;
 	EAccount *a;
-	char *gladefile;
+	gchar *gladefile;
 
 	priv = epage->priv;
 	g_object_ref (model);
@@ -3200,7 +3217,7 @@ static void
 set_attendees (ECalComponent *comp, const GPtrArray *attendees)
 {
 	GSList *comp_attendees = NULL, *l;
-	int i;
+	gint i;
 
 	for (i = 0; i < attendees->len; i++) {
 		EMeetingAttendee *ia = g_ptr_array_index (attendees, i);
@@ -3264,7 +3281,7 @@ event_page_add_attendee (EventPage *epage, EMeetingAttendee *attendee)
 
 	g_return_if_fail (epage != NULL);
 	g_return_if_fail (IS_EVENT_PAGE (epage));
-	
+
 	priv = epage->priv;
 
 	e_meeting_store_add_attendee (priv->model, attendee);
@@ -3283,7 +3300,7 @@ event_page_remove_all_attendees (EventPage *epage)
 
 	g_return_if_fail (epage != NULL);
 	g_return_if_fail (IS_EVENT_PAGE (epage));
-	
+
 	priv = epage->priv;
 
 	e_meeting_store_remove_all_attendees (priv->model);
