@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -52,17 +52,17 @@ G_DEFINE_TYPE (ECalComponentMemoPreview, e_cal_component_memo_preview, GTK_TYPE_
 
 
 static void
-on_link_clicked (GtkHTML *html, const char *url, gpointer data)
+on_link_clicked (GtkHTML *html, const gchar *url, gpointer data)
 {
 	/* FIXME Pass a parent window. */
 	e_show_uri (NULL, url);
 }
 
 static void
-on_url_cb (GtkHTML *html, const char *url, gpointer data)
+on_url_cb (GtkHTML *html, const gchar *url, gpointer data)
 {
 #if 0
-	char *msg;
+	gchar *msg;
 	ECalComponentMemoPreview *preview = data;
 
 	if (url && *url) {
@@ -75,13 +75,13 @@ on_url_cb (GtkHTML *html, const char *url, gpointer data)
 }
 
 /* Converts a time_t to a string, relative to the specified timezone */
-static char *
+static gchar *
 timet_to_str_with_zone (ECalComponentDateTime *dt, ECal *ecal, icaltimezone *default_zone)
 {
 	struct icaltimetype itt;
 	icaltimezone *zone;
         struct tm tm;
-        char buf[256];
+        gchar buf[256];
 
 	if (dt->tzid) {
 		/* If we can't find the zone, we'll guess its "local" */
@@ -138,23 +138,23 @@ write_html (GtkHTMLStream *stream, ECal *ecal, ECalComponent *comp, icaltimezone
 		gtk_html_stream_printf(stream, "<H3>%s: ", _("Categories"));
 
 		for (node = l; node != NULL; node = node->next) {
-			const char *icon_file;
+			const gchar *icon_file;
 
-			icon_file = e_categories_get_icon_file_for ((const char *) node->data);
+			icon_file = e_categories_get_icon_file_for ((const gchar *) node->data);
 			if (icon_file && g_file_test(icon_file, G_FILE_TEST_EXISTS)) {
 				gchar *icon_file_uri = g_filename_to_uri (icon_file, NULL, NULL);
 				gtk_html_stream_printf (stream, "<IMG ALT=\"%s\" SRC=\"%s\">",
-							(const char *) node->data, icon_file_uri);
+							(const gchar *) node->data, icon_file_uri);
 				g_free (icon_file_uri);
 				one_added = TRUE;
 			}
 			else{
 				if(one_added == FALSE){
-					g_string_append_printf (string, "%s", (const char *) node->data);
+					g_string_append_printf (string, "%s", (const gchar *) node->data);
 					one_added = TRUE;
 				}
 				else{
-					g_string_append_printf (string, ", %s", (const char *) node->data);
+					g_string_append_printf (string, ", %s", (const gchar *) node->data);
 				}
 			}
 		}
@@ -196,7 +196,7 @@ write_html (GtkHTMLStream *stream, ECal *ecal, ECalComponent *comp, icaltimezone
 		gtk_html_stream_printf (stream, "<TD><TT>");
 
 		for (node = l; node != NULL; node = node->next) {
-			char *html;
+			gchar *html;
 
 			text = * (ECalComponentText *) node->data;
 			html = camel_text_to_html (text.value ? text.value : "", CAMEL_MIME_FILTER_TOHTML_CONVERT_NL | CAMEL_MIME_FILTER_TOHTML_CONVERT_SPACES | CAMEL_MIME_FILTER_TOHTML_CONVERT_URLS | CAMEL_MIME_FILTER_TOHTML_CONVERT_ADDRESSES, 0);
@@ -213,7 +213,7 @@ write_html (GtkHTMLStream *stream, ECal *ecal, ECalComponent *comp, icaltimezone
 	}
 
 	/* URL */
-	e_cal_component_get_url (comp, (const char **) &str);
+	e_cal_component_get_url (comp, (const gchar **) &str);
 	if (str) {
 		gtk_html_stream_printf (stream, "<TR><TD VALIGN=\"TOP\" ALIGN=\"RIGHT\"><B>%s</B></TD>", _("Web Page:"));
 		gtk_html_stream_printf (stream, "<TD><A HREF=\"%s\">%s</A></TD></TR>", str, str);
