@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -33,7 +33,7 @@
 #define E_TYPE_CAL_COMPONENT_PREVIEW            (e_cal_component_preview_get_type ())
 #define E_CAL_COMPONENT_PREVIEW(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), E_TYPE_CAL_COMPONENT_PREVIEW, ECalComponentPreview))
 #define E_CAL_COMPONENT_PREVIEW_CLASS(klass)    (G_TYPE_CHECK_INSTANCE_CAST_CLASS ((klass), E_TYPE_CAL_COMPONENT_PREVIEW, \
-				                 ECalComponentPreviewClass))
+						 ECalComponentPreviewClass))
 #define E_IS_CAL_COMPONENT_PREVIEW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_CAL_COMPONENT_PREVIEW))
 #define E_IS_CAL_COMPONENT_PREVIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), E_TYPE_CAL_COMPONENT_PREVIEW))
 
@@ -52,7 +52,7 @@ struct _ECalComponentPreviewClass {
 	GtkTableClass parent_class;
 
 	/* Notification signals */
-	void (* selection_changed) (ECalComponentPreview *preview, int n_selected);
+	void (* selection_changed) (ECalComponentPreview *preview, gint n_selected);
 };
 
 
@@ -66,7 +66,7 @@ void e_cal_component_preview_display             (ECalComponentPreview *preview,
 void e_cal_component_preview_clear             (ECalComponentPreview *preview);
 
 /* Callback used when GtkHTML widget requests URL */
-void e_cal_comp_preview_url_requested_cb (GtkHTML *html, const char *url, GtkHTMLStream *html_stream, gpointer data);
+void e_cal_comp_preview_url_requested_cb (GtkHTML *html, const gchar *url, GtkHTMLStream *html_stream, gpointer data);
 
 GtkWidget *e_cal_component_preview_get_html (ECalComponentPreview *preview);
 
