@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  * Authors:
  *		Hans Petter Jansson  <hpj@ximian.com>
@@ -42,7 +42,6 @@
 #include <table/e-cell-combo.h>
 #include <misc/e-popup-menu.h>
 #include <misc/e-cell-date-edit.h>
-#include <libgnome/gnome-exec.h>
 #include <e-util/e-categories-config.h>
 #include <e-util/e-dialog-utils.h>
 #include <e-util/e-util-private.h>
@@ -244,9 +243,9 @@ setup_e_table (ECalListView *cal_list_view)
 	g_object_unref (cell);
 
 	strings = NULL;
-	strings = g_list_append (strings, (char*) _("Public"));
-	strings = g_list_append (strings, (char*) _("Private"));
-	strings = g_list_append (strings, (char*) _("Confidential"));
+	strings = g_list_append (strings, (gchar *) _("Public"));
+	strings = g_list_append (strings, (gchar *) _("Private"));
+	strings = g_list_append (strings, (gchar *) _("Confidential"));
 	e_cell_combo_set_popdown_strings (E_CELL_COMBO (popup_cell),
 					  strings);
 
