@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -44,38 +44,38 @@ static void e_day_view_main_item_set_property (GObject *object,
 					       GParamSpec *pspec);
 static void e_day_view_main_item_update (GnomeCanvasItem *item,
 					 double *affine,
-					 ArtSVP *clip_path, int flags);
+					 ArtSVP *clip_path, gint flags);
 static void e_day_view_main_item_draw (GnomeCanvasItem *item,
 				       GdkDrawable *drawable,
-				       int x, int y,
-				       int width, int height);
+				       gint x, gint y,
+				       gint width, gint height);
 static double e_day_view_main_item_point (GnomeCanvasItem *item,
 					  double x, double y,
-					  int cx, int cy,
+					  gint cx, gint cy,
 					  GnomeCanvasItem **actual_item);
 static gint e_day_view_main_item_event (GnomeCanvasItem *item,
 					GdkEvent *event);
 
 static void e_day_view_main_item_draw_long_events_in_vbars (EDayViewMainItem *dvmitem,
 							    GdkDrawable *drawable,
-							    int x,
-							    int y,
-							    int width,
-							    int height);
+							    gint x,
+							    gint y,
+							    gint width,
+							    gint height);
 static void e_day_view_main_item_draw_events_in_vbars (EDayViewMainItem *dvmitem,
 						       GdkDrawable *drawable,
-						       int x, int y,
-						       int width, int height,
+						       gint x, gint y,
+						       gint width, gint height,
 						       gint day);
 static void e_day_view_main_item_draw_day_events (EDayViewMainItem *dvmitem,
 						  GdkDrawable *drawable,
-						  int x, int y,
-						  int width, int height,
+						  gint x, gint y,
+						  gint width, gint height,
 						  gint day);
 static void e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 						 GdkDrawable *drawable,
-						 int x, int y,
-						 int width, int height,
+						 gint x, gint y,
+						 gint width, gint height,
 						 gint day, gint event_num);
 
 /* The arguments we take */
@@ -111,7 +111,7 @@ e_day_view_main_item_class_init (EDayViewMainItemClass *class)
 			G_PARAM_WRITABLE));
 
 	/* init the accessibility support for e_day_view */
- 	e_day_view_main_item_a11y_init ();
+	e_day_view_main_item_a11y_init ();
 }
 
 
@@ -146,7 +146,7 @@ static void
 e_day_view_main_item_update (GnomeCanvasItem *item,
 			    double *affine,
 			    ArtSVP *clip_path,
-			    int flags)
+			    gint flags)
 {
 	if (GNOME_CANVAS_ITEM_CLASS (e_day_view_main_item_parent_class)->update)
 		(* GNOME_CANVAS_ITEM_CLASS (e_day_view_main_item_parent_class)->update) (item, affine, clip_path, flags);
@@ -164,7 +164,7 @@ e_day_view_main_item_update (GnomeCanvasItem *item,
  */
 static void
 e_day_view_main_item_draw (GnomeCanvasItem *canvas_item, GdkDrawable *drawable,
-			   int x, int y, int width, int height)
+			   gint x, gint y, gint width, gint height)
 {
 	EDayViewMainItem *dvmitem;
 	EDayView *day_view;
@@ -360,7 +360,7 @@ e_day_view_main_item_draw (GnomeCanvasItem *canvas_item, GdkDrawable *drawable,
 	if (e_day_view_get_show_marcus_bains (day_view)) {
 		icaltimezone *zone;
 		struct icaltimetype time_now, day_start;
-		int marcus_bains_y;
+		gint marcus_bains_y;
 		GdkColor mb_color;
 
 		cairo_save (cr);
@@ -402,8 +402,8 @@ e_day_view_main_item_draw (GnomeCanvasItem *canvas_item, GdkDrawable *drawable,
 static void
 e_day_view_main_item_draw_events_in_vbars (EDayViewMainItem *dvmitem,
 					   GdkDrawable *drawable,
-					   int x, int y,
-					   int width, int height,
+					   gint x, gint y,
+					   gint width, gint height,
 					   gint day)
 {
 	EDayView *day_view;
@@ -483,8 +483,8 @@ e_day_view_main_item_draw_events_in_vbars (EDayViewMainItem *dvmitem,
 static void
 e_day_view_main_item_draw_long_events_in_vbars (EDayViewMainItem *dvmitem,
 						GdkDrawable *drawable,
-						int x, int y,
-						int width, int height)
+						gint x, gint y,
+						gint width, gint height)
 {
 	EDayView *day_view;
 	EDayViewEvent *event;
@@ -572,7 +572,7 @@ e_day_view_main_item_draw_long_events_in_vbars (EDayViewMainItem *dvmitem,
 static void
 e_day_view_main_item_draw_day_events (EDayViewMainItem *dvmitem,
 				      GdkDrawable *drawable,
-				      int x, int y, int width, int height,
+				      gint x, gint y, gint width, gint height,
 				      gint day)
 {
 	EDayView *day_view;
@@ -591,7 +591,7 @@ e_day_view_main_item_draw_day_events (EDayViewMainItem *dvmitem,
 static void
 e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 				     GdkDrawable *drawable,
-				     int x, int y, int width, int height,
+				     gint x, gint y, gint width, gint height,
 				     gint day, gint event_num)
 {
 	EDayView *day_view;
@@ -617,13 +617,16 @@ e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 	gdouble cc = 65535.0;
 	gdouble date_fraction;
 	gboolean short_event = FALSE, resize_flag = FALSE;
-	gchar *end_resize_time, *end_resize_suffix;
+	const gchar *end_resize_suffix;
+	gchar *end_regsizeime;
 	gint start_hour, start_display_hour, start_minute, start_suffix_width;
 	gint end_hour, end_display_hour, end_minute, end_suffix_width;
 	gboolean show_span = FALSE, format_time;
 	gint offset, interval;
-	char *text = NULL, *start_suffix, *end_suffix;
-	int scroll_flag = 0;
+	const gchar *start_suffix;
+	const gchar *end_suffix;
+	gchar *text = NULL;
+	gint scroll_flag = 0;
 	gint row_y;
 	GConfClient *gconf;
 
@@ -638,7 +641,7 @@ e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 	gconf = gconf_client_get_default ();
 
 	alpha = gconf_client_get_float (gconf,
-				         "/apps/evolution/calendar/display/events_transparency",
+					 "/apps/evolution/calendar/display/events_transparency",
 					 NULL);
 
 	gradient = gconf_client_get_bool (gconf,
@@ -785,7 +788,7 @@ e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 			/* Black border */
 			cairo_save (cr);
 			x0	   = item_x + E_DAY_VIEW_BAR_WIDTH + 9;
-			y0  	   = item_y + 10;
+			y0	   = item_y + 10;
 			rect_width = MAX (item_w - E_DAY_VIEW_BAR_WIDTH - 7, 0);
 			rect_height = item_h - 7;
 
@@ -967,12 +970,12 @@ e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 
 			if (e_calendar_view_get_use_24_hour_format (E_CALENDAR_VIEW (day_view))) {
 				cairo_translate (cr, item_x + item_w - E_DAY_VIEW_BAR_WIDTH - 32, item_y + item_h - 8);
-				end_resize_time = g_strdup_printf ("%2i:%02i",
+				end_regsizeime = g_strdup_printf ("%2i:%02i",
 					 end_display_hour, end_minute);
 
 			} else {
 				cairo_translate (cr, item_x + item_w - E_DAY_VIEW_BAR_WIDTH - 48, item_y + item_h - 8);
-				end_resize_time = g_strdup_printf ("%2i:%02i%s",
+				end_regsizeime = g_strdup_printf ("%2i:%02i%s",
 						 end_display_hour, end_minute,
 						 end_resize_suffix);
 			}
@@ -982,7 +985,7 @@ e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 			else
 				cairo_set_source_rgb (cr, 1, 1, 1);
 			cairo_set_font_options (cr, font_options);
-			cairo_show_text (cr, end_resize_time);
+			cairo_show_text (cr, end_regsizeime);
 			cairo_close_path (cr);
 			cairo_restore (cr);
 		}
@@ -1016,7 +1019,7 @@ e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 		cairo_restore (cr);
 
 		/* This is for achieving the white stripes in vbar across event color */
-		for (i = 0; i <= (bar_y2 - bar_y1) ; i+=4) {
+		for (i = 0; i <= (bar_y2 - bar_y1); i+=4) {
 			cairo_set_source_rgb (cr, 1, 1, 1);
 			cairo_set_line_width (cr, 0.3);
 			cairo_move_to (cr, item_x + 1, bar_y1 + i);
@@ -1171,11 +1174,11 @@ e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 
 			/* draw categories icons */
 			for (elem = categories_list; elem; elem = elem->next) {
-				char *category;
+				gchar *category;
 				GdkPixmap *pixmap = NULL;
 				GdkBitmap *mask = NULL;
 
-				category = (char *) elem->data;
+				category = (gchar *) elem->data;
 				if (!e_categories_config_get_icon_for (category, &pixmap, &mask))
 					continue;
 
@@ -1214,7 +1217,7 @@ e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
 	{
 		if (event->start_minute % day_view->mins_per_row != 0
 			|| (day_view->show_event_end_times
-		    	&& event->end_minute % day_view->mins_per_row != 0)) {
+			&& event->end_minute % day_view->mins_per_row != 0)) {
 				offset = day_view->first_hour_shown * 60
 				+ day_view->first_minute_shown;
 				show_span = TRUE;
@@ -1312,7 +1315,7 @@ e_day_view_main_item_draw_day_event (EDayViewMainItem *dvmitem,
    This is needed so that we get button/motion events. */
 static double
 e_day_view_main_item_point (GnomeCanvasItem *item, double x, double y,
-			    int cx, int cy,
+			    gint cx, gint cy,
 			    GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
