@@ -13,7 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  * Authors:
  *		Damon Chaplin <damon@ximian.com>
@@ -65,14 +65,14 @@ static void e_day_view_time_item_finalize (GObject *object);
 
 static void e_day_view_time_item_update (GnomeCanvasItem *item,
 					 double *affine,
-					 ArtSVP *clip_path, int flags);
+					 ArtSVP *clip_path, gint flags);
 static void e_day_view_time_item_draw (GnomeCanvasItem *item,
 				       GdkDrawable *drawable,
-				       int x, int y,
-				       int width, int height);
+				       gint x, gint y,
+				       gint width, gint height);
 static double e_day_view_time_item_point (GnomeCanvasItem *item,
 					  double x, double y,
-					  int cx, int cy,
+					  gint cx, gint cy,
 					  GnomeCanvasItem **actual_item);
 static gint e_day_view_time_item_event (GnomeCanvasItem *item,
 					GdkEvent *event);
@@ -131,7 +131,7 @@ e_day_view_time_item_class_init (EDayViewTimeItemClass *class)
 static void
 e_day_view_time_item_init (EDayViewTimeItem *dvtmitem)
 {
-	char *last;
+	gchar *last;
 
 	dvtmitem->dragging_selection = FALSE;
 	dvtmitem->second_zone = NULL;
@@ -185,7 +185,7 @@ static void
 e_day_view_time_item_update (GnomeCanvasItem *item,
 			    double *affine,
 			    ArtSVP *clip_path,
-			    int flags)
+			    gint flags)
 {
 	if (GNOME_CANVAS_ITEM_CLASS (e_day_view_time_item_parent_class)->update)
 		(* GNOME_CANVAS_ITEM_CLASS (e_day_view_time_item_parent_class)->update) (item, affine, clip_path, flags);
@@ -274,17 +274,18 @@ e_day_view_time_item_get_column_width (EDayViewTimeItem *dvtmitem)
 static void
 edvti_draw_zone (GnomeCanvasItem   *canvas_item,
 		GdkDrawable	   *drawable,
-		int		    x,
-		int		    y,
-		int		    width,
-		int		    height,
-		int		    x_offset,
+		gint		    x,
+		gint		    y,
+		gint		    width,
+		gint		    height,
+		gint		    x_offset,
 		icaltimezone       *use_zone)
 {
 	EDayView *day_view;
 	EDayViewTimeItem *dvtmitem;
 	GtkStyle *style;
-	gchar buffer[64], *suffix, *midnight_day = NULL, *midnight_month = NULL;
+	const gchar *suffix;
+	gchar buffer[64], *midnight_day = NULL, *midnight_month = NULL;
 	gint hour, display_hour, minute, row;
 	gint row_y, start_y, large_hour_y_offset, small_font_y_offset;
 	gint long_line_x1, long_line_x2, short_line_x1;
@@ -357,14 +358,14 @@ edvti_draw_zone (GnomeCanvasItem   *canvas_item,
 		/* shift time with a difference between local time and the other timezone */
 		icaltimezone *cal_zone = e_calendar_view_get_timezone (E_CALENDAR_VIEW (day_view));
 		struct icaltimetype tt;
-		int diff;
+		gint diff;
 		struct tm mn;
 
 		tt = icaltime_today ();
 
 		/* diff is number of minutes */
 		diff = (icaltimezone_get_utc_offset (use_zone, &tt, NULL) -
-		        icaltimezone_get_utc_offset (cal_zone, &tt, NULL)
+			icaltimezone_get_utc_offset (cal_zone, &tt, NULL)
 		       ) / 60;
 
 		tt = icaltime_today ();
@@ -415,7 +416,7 @@ edvti_draw_zone (GnomeCanvasItem   *canvas_item,
 	/* Draw the Marcus Bains Line first, so it appears under other elements. */
 	if (e_day_view_get_show_marcus_bains (day_view)) {
 		struct icaltimetype time_now;
-		int marcus_bains_y;
+		gint marcus_bains_y;
 
 		cairo_save (cr);
 		gdk_cairo_set_source_color (cr, &day_view->colors[E_DAY_VIEW_COLOR_MARCUS_BAINS_LINE]);
@@ -608,10 +609,10 @@ edvti_draw_zone (GnomeCanvasItem   *canvas_item,
 static void
 e_day_view_time_item_draw (GnomeCanvasItem *canvas_item,
 			   GdkDrawable	   *drawable,
-			   int		    x,
-			   int		    y,
-			   int		    width,
-			   int		    height)
+			   gint		    x,
+			   gint		    y,
+			   gint		    width,
+			   gint		    height)
 {
 	EDayViewTimeItem *dvtmitem;
 
@@ -644,7 +645,7 @@ e_day_view_time_item_increment_time	(gint	*hour,
 
 static double
 e_day_view_time_item_point (GnomeCanvasItem *item, double x, double y,
-			    int cx, int cy,
+			    gint cx, gint cy,
 			    GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
@@ -690,7 +691,7 @@ static void
 edvti_second_zone_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
 	EDayViewTimeItem *dvtmitem = user_data;
-	char *location;
+	gchar *location;
 
 	g_return_if_fail (user_data != NULL);
 	g_return_if_fail (E_IS_DAY_VIEW_TIME_ITEM (dvtmitem));
@@ -780,7 +781,7 @@ e_day_view_time_item_show_popup_menu (EDayViewTimeItem *dvtmitem,
 		item = gtk_menu_item_new_with_label ("---");
 	gtk_widget_set_sensitive (item, FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	
+
 	item = gtk_separator_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
 
@@ -833,7 +834,7 @@ e_day_view_time_item_on_set_divisions (GtkWidget *item,
 	day_view = dvtmitem->day_view;
 	g_return_if_fail (day_view != NULL);
 
- 	if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
+	if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
 		return;
 
 	divisions = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), "divisions"));
