@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -299,8 +299,8 @@ struct _EDayView
 
 	/* Whether we show the Marcus Bains Line in the main canvas and time canvas. */
 	gboolean show_marcus_bains_line;
-	char *marcus_bains_day_view_color;
-	char *marcus_bains_time_bar_color;
+	gchar *marcus_bains_day_view_color;
+	gchar *marcus_bains_time_bar_color;
 
 	/* Whether we use show event end times in the main canvas. */
 	gboolean show_event_end_times;
@@ -530,8 +530,8 @@ void	   e_day_view_set_working_day		(EDayView	*day_view,
 gboolean   e_day_view_get_show_marcus_bains	(EDayView	*day_view);
 void       e_day_view_set_marcus_bains		(EDayView       *day_view,
 						 gboolean        show_line,
-						 const char 	*dayview_color,
-						 const char     *timebar_color);
+						 const gchar	*dayview_color,
+						 const gchar     *timebar_color);
 
 /* Whether we display event end times in the main canvas. */
 gboolean   e_day_view_get_show_event_end_times	(EDayView	*day_view);
@@ -595,7 +595,7 @@ void	   e_day_view_stop_auto_scroll		(EDayView	*day_view);
 void	   e_day_view_convert_time_to_display	(EDayView	*day_view,
 						 gint		 hour,
 						 gint		*display_hour,
-						 gchar	       **suffix,
+						 const gchar	**suffix,
 						 gint		*suffix_width);
 gint	   e_day_view_get_time_string_width	(EDayView	*day_view);
 
@@ -604,9 +604,9 @@ gint	   e_day_view_event_sort_func		(const void	*arg1,
 						 const void	*arg2);
 
 gboolean e_day_view_find_event_from_item (EDayView *day_view,
- 					  GnomeCanvasItem *item,
- 					  gint *day_return,
- 					  gint *event_num_return);
+					  GnomeCanvasItem *item,
+					  gint *day_return,
+					  gint *event_num_return);
 void e_day_view_update_calendar_selection_time (EDayView *day_view);
 void e_day_view_ensure_rows_visible (EDayView *day_view,
 				     gint start_row,
