@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -669,8 +669,8 @@ compare_times (EMeetingTime *time1,
 }
 
 static gint
-compare_period_starts (const void *arg1,
-		       const void *arg2)
+compare_period_starts (gconstpointer arg1,
+		       gconstpointer arg2)
 {
 	EMeetingFreeBusyPeriod *period1, *period2;
 
@@ -812,7 +812,6 @@ e_meeting_attendee_add_busy_period (EMeetingAttendee *ia,
 
 	g_return_val_if_fail (ia != NULL, FALSE);
 	g_return_val_if_fail (E_IS_MEETING_ATTENDEE (ia), FALSE);
-	g_return_val_if_fail (busy_type >= 0, FALSE);
 	g_return_val_if_fail (busy_type < E_MEETING_FREE_BUSY_LAST, FALSE);
 
 	priv = ia->priv;
@@ -845,6 +844,10 @@ e_meeting_attendee_add_busy_period (EMeetingAttendee *ia,
 	if (compare_times (&period.start, &period.end) > 0)
 		return FALSE;
 
+	/* If the busy_type is FREE, then there is no need to render it in UI */
+	if (busy_type == E_MEETING_FREE_BUSY_FREE)
+		goto done;
+
 	/* If the busy range is not set elsewhere, track it as best we can */
 	if (!priv->start_busy_range_set) {
 		if (!g_date_valid (&priv->busy_periods_start.date)) {
@@ -871,6 +874,7 @@ e_meeting_attendee_add_busy_period (EMeetingAttendee *ia,
 			}
 		}
 	}
+
 	if (!priv->end_busy_range_set) {
 		if (!g_date_valid (&priv->busy_periods_end.date)) {
 			priv->busy_periods_end.date = period.end.date;
@@ -898,12 +902,14 @@ e_meeting_attendee_add_busy_period (EMeetingAttendee *ia,
 	}
 
 	g_array_append_val (priv->busy_periods, period);
-	priv->has_calendar_info = TRUE;
-	priv->busy_periods_sorted = FALSE;
 
 	period_in_days = g_date_get_julian (&period.end.date) - g_date_get_julian (&period.start.date) + 1;
 	priv->longest_period_in_days = MAX (priv->longest_period_in_days, period_in_days);
 
+done:
+	priv->has_calendar_info = TRUE;
+	priv->busy_periods_sorted = FALSE;
+
 	return TRUE;
 }
 
