@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -64,8 +64,8 @@ enum TargetType{
 };
 
 static GtkTargetEntry target_types[] = {
-	{ "text/x-calendar", 0, TARGET_TYPE_VCALENDAR },
-	{ "text/calendar",   0, TARGET_TYPE_VCALENDAR }
+	{ (gchar *) "text/x-calendar", 0, TARGET_TYPE_VCALENDAR },
+	{ (gchar *) "text/calendar",   0, TARGET_TYPE_VCALENDAR }
 };
 
 static guint n_target_types = G_N_ELEMENTS (target_types);
@@ -73,8 +73,6 @@ static guint n_target_types = G_N_ELEMENTS (target_types);
 
 extern ECompEditorRegistry *comp_editor_registry;
 
-static void e_memo_table_class_init		(EMemoTableClass *klass);
-static void e_memo_table_init			(EMemoTable	*memo_table);
 static void e_memo_table_destroy		(GtkObject	*object);
 
 static void e_memo_table_on_double_click	(ETable		*table,
@@ -82,7 +80,7 @@ static void e_memo_table_on_double_click	(ETable		*table,
 						 gint		 col,
 						 GdkEvent	*event,
 						 EMemoTable *memo_table);
-static gint e_memo_table_show_popup_menu    	(ETable *table,
+static gint e_memo_table_show_popup_menu	(ETable *table,
 						 GdkEvent *gdk_event,
 						 EMemoTable *memo_table);
 
@@ -91,7 +89,7 @@ static gint e_memo_table_on_right_click		(ETable		*table,
 						 gint		 col,
 						 GdkEvent       *event,
 						 EMemoTable *memo_table);
-static gboolean e_memo_table_on_popup_menu  	(GtkWidget *widget,
+static gboolean e_memo_table_on_popup_menu	(GtkWidget *widget,
 						 gpointer data);
 
 static gint e_memo_table_on_key_press		(ETable		*table,
@@ -114,7 +112,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 /* The icons to represent the task. */
 #define E_MEMO_MODEL_NUM_ICONS	2
-static const char* icon_names[E_MEMO_MODEL_NUM_ICONS] = {
+static const gchar * icon_names[E_MEMO_MODEL_NUM_ICONS] = {
 	"stock_notes", "stock_insert-note"
 };
 static GdkPixbuf* icon_pixbufs[E_MEMO_MODEL_NUM_ICONS] = { NULL };
@@ -252,7 +250,7 @@ e_memo_table_init (EMemoTable *memo_table)
 
 	if (!icon_pixbufs[0])
 		for (i = 0; i < E_MEMO_MODEL_NUM_ICONS; i++) {
-			icon_pixbufs[i] = e_icon_factory_get_icon (icon_names[i], E_ICON_SIZE_LIST);
+			icon_pixbufs[i] = e_icon_factory_get_icon (icon_names[i], GTK_ICON_SIZE_MENU);
 		}
 
 	cell = e_cell_toggle_new (0, E_MEMO_MODEL_NUM_ICONS, icon_pixbufs);
@@ -373,12 +371,12 @@ e_memo_table_open_selected (EMemoTable *memo_table)
 }
 
 /* Used from e_table_selected_row_foreach(); puts the selected row number in an
- * int pointed to by the closure data.
+ * gint pointed to by the closure data.
  */
 static void
-get_selected_row_cb (int model_row, gpointer data)
+get_selected_row_cb (gint model_row, gpointer data)
 {
-	int *row;
+	gint *row;
 
 	row = data;
 	*row = model_row;
@@ -392,7 +390,7 @@ static ECalModelComponent *
 get_selected_comp (EMemoTable *memo_table)
 {
 	ETable *etable;
-	int row;
+	gint row;
 
 	etable = e_table_scrolled_get_table (E_TABLE_SCROLLED (memo_table->etable));
 	if (e_table_selected_count (etable) != 1)
@@ -414,7 +412,7 @@ struct get_selected_uids_closure {
 
 /* Used from e_table_selected_row_foreach(), builds a list of the selected UIDs */
 static void
-add_uid_cb (int model_row, gpointer data)
+add_uid_cb (gint model_row, gpointer data)
 {
 	struct get_selected_uids_closure *closure;
 	ECalModelComponent *comp_data;
@@ -491,7 +489,7 @@ void
 e_memo_table_delete_selected (EMemoTable *memo_table)
 {
 	ETable *etable;
-	int n_selected;
+	gint n_selected;
 	ECalModelComponent *comp_data;
 	ECalComponent *comp = NULL;
 
@@ -542,7 +540,7 @@ e_memo_table_cut_clipboard (EMemoTable *memo_table)
 
 /* callback for e_table_selected_row_foreach */
 static void
-copy_row_cb (int model_row, gpointer data)
+copy_row_cb (gint model_row, gpointer data)
 {
 	EMemoTable *memo_table;
 	ECalModelComponent *comp_data;
@@ -602,7 +600,7 @@ e_memo_table_copy_clipboard (EMemoTable *memo_table)
 {
 	ETable *etable;
 	GtkClipboard *clipboard;
-	char *comp_str;
+	gchar *comp_str;
 
 	g_return_if_fail (E_IS_MEMO_TABLE (memo_table));
 
@@ -631,7 +629,7 @@ static void
 clipboard_get_calendar_data (EMemoTable *memo_table, const gchar *text)
 {
 	icalcomponent *icalcomp;
-	char *uid;
+	gchar *uid;
 	ECalComponent *comp;
 	ECal *client;
 	icalcomponent_kind kind;
@@ -689,7 +687,7 @@ clipboard_get_calendar_data (EMemoTable *memo_table, const gchar *text)
 		comp = e_cal_component_new ();
 		e_cal_component_set_icalcomponent (comp, icalcomp);
 		uid = e_cal_component_gen_uid ();
-		e_cal_component_set_uid (comp, (const char *) uid);
+		e_cal_component_set_uid (comp, (const gchar *) uid);
 		free (uid);
 
 		e_cal_create_object (client, e_cal_component_get_icalcomponent (comp), NULL, NULL);
@@ -757,7 +755,7 @@ static void
 open_memo (EMemoTable *memo_table, ECalModelComponent *comp_data)
 {
 	CompEditor *medit;
-	const char *uid;
+	const gchar *uid;
 
 	uid = icalcomponent_get_uid (comp_data->icalcomp);
 
@@ -788,7 +786,7 @@ open_memo (EMemoTable *memo_table, ECalModelComponent *comp_data)
 
 /* Opens the task in the specified row */
 static void
-open_memo_by_row (EMemoTable *memo_table, int row)
+open_memo_by_row (EMemoTable *memo_table, gint row)
 {
 	ECalModelComponent *comp_data;
 
@@ -808,7 +806,7 @@ e_memo_table_on_double_click (ETable *table,
 
 
 static void
-e_memo_table_on_open_memo (EPopup *ep, EPopupItem *pitem, void *data)
+e_memo_table_on_open_memo (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EMemoTable *memo_table = E_MEMO_TABLE (data);
 	ECalModelComponent *comp_data;
@@ -819,12 +817,12 @@ e_memo_table_on_open_memo (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-e_memo_table_on_save_as (EPopup *ep, EPopupItem *pitem, void *data)
+e_memo_table_on_save_as (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EMemoTable *memo_table = E_MEMO_TABLE (data);
 	ECalModelComponent *comp_data;
-	char *filename;
-	char *ical_string;
+	gchar *filename;
+	gchar *ical_string;
 
 	comp_data = get_selected_comp (memo_table);
 	if (comp_data == NULL)
@@ -845,7 +843,7 @@ e_memo_table_on_save_as (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-e_memo_table_on_print_memo (EPopup *ep, EPopupItem *pitem, void *data)
+e_memo_table_on_print_memo (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EMemoTable *memo_table = E_MEMO_TABLE (data);
 	ECalModelComponent *comp_data;
@@ -863,7 +861,7 @@ e_memo_table_on_print_memo (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-e_memo_table_on_cut (EPopup *ep, EPopupItem *pitem, void *data)
+e_memo_table_on_cut (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EMemoTable *memo_table = E_MEMO_TABLE (data);
 
@@ -871,7 +869,7 @@ e_memo_table_on_cut (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-e_memo_table_on_copy (EPopup *ep, EPopupItem *pitem, void *data)
+e_memo_table_on_copy (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EMemoTable *memo_table = E_MEMO_TABLE (data);
 
@@ -879,7 +877,7 @@ e_memo_table_on_copy (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-e_memo_table_on_paste (EPopup *ep, EPopupItem *pitem, void *data)
+e_memo_table_on_paste (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EMemoTable *memo_table = E_MEMO_TABLE (data);
 
@@ -887,7 +885,7 @@ e_memo_table_on_paste (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-e_memo_table_on_forward (EPopup *ep, EPopupItem *pitem, void *data)
+e_memo_table_on_forward (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EMemoTable *memo_table = E_MEMO_TABLE (data);
 	ECalModelComponent *comp_data;
@@ -906,7 +904,7 @@ e_memo_table_on_forward (EPopup *ep, EPopupItem *pitem, void *data)
 
 /* Opens the URL of the memo */
 static void
-open_url_cb (EPopup *ep, EPopupItem *pitem, void *data)
+open_url_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EMemoTable *memo_table = E_MEMO_TABLE (data);
 	ECalModelComponent *comp_data;
@@ -926,7 +924,7 @@ open_url_cb (EPopup *ep, EPopupItem *pitem, void *data)
 
 /* Callback for the "delete tasks" menu item */
 static void
-delete_cb (EPopup *ep, EPopupItem *pitem, void *data)
+delete_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	EMemoTable *memo_table = E_MEMO_TABLE (data);
 
@@ -934,29 +932,29 @@ delete_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static EPopupItem memos_popup_items [] = {
-	{ E_POPUP_ITEM, "00.open", N_("_Open"), e_memo_table_on_open_memo, NULL, GTK_STOCK_OPEN, E_CAL_POPUP_SELECT_ONE },
-	{ E_POPUP_ITEM, "05.openweb", N_("Open _Web Page"), open_url_cb, NULL, NULL, E_CAL_POPUP_SELECT_ONE, E_CAL_POPUP_SELECT_HASURL },
-	{ E_POPUP_ITEM, "10.saveas", N_("_Save As..."), e_memo_table_on_save_as, NULL, GTK_STOCK_SAVE_AS, E_CAL_POPUP_SELECT_ONE },
-	{ E_POPUP_ITEM, "20.print", N_("P_rint..."), e_memo_table_on_print_memo, NULL, GTK_STOCK_PRINT, E_CAL_POPUP_SELECT_ONE },
+	{ E_POPUP_ITEM, (gchar *) "00.open", (gchar *) N_("_Open"), e_memo_table_on_open_memo, NULL, (gchar *) GTK_STOCK_OPEN, E_CAL_POPUP_SELECT_ONE },
+	{ E_POPUP_ITEM, (gchar *) "05.openweb", (gchar *) N_("Open _Web Page"), open_url_cb, NULL, NULL, E_CAL_POPUP_SELECT_ONE, E_CAL_POPUP_SELECT_HASURL },
+	{ E_POPUP_ITEM, (gchar *) "10.saveas", (gchar *) N_("_Save As..."), e_memo_table_on_save_as, NULL, (gchar *) GTK_STOCK_SAVE_AS, E_CAL_POPUP_SELECT_ONE },
+	{ E_POPUP_ITEM, (gchar *) "20.print", (gchar *) N_("P_rint..."), e_memo_table_on_print_memo, NULL, (gchar *) GTK_STOCK_PRINT, E_CAL_POPUP_SELECT_ONE },
 
-	{ E_POPUP_BAR, "30.bar" },
+	{ E_POPUP_BAR, (gchar *) "30.bar" },
 
-	{ E_POPUP_ITEM, "40.cut", N_("C_ut"), e_memo_table_on_cut, NULL, GTK_STOCK_CUT, 0, E_CAL_POPUP_SELECT_EDITABLE },
-	{ E_POPUP_ITEM, "50.copy", N_("_Copy"), e_memo_table_on_copy, NULL, GTK_STOCK_COPY, 0, 0 },
-	{ E_POPUP_ITEM, "60.paste", N_("_Paste"), e_memo_table_on_paste, NULL, GTK_STOCK_PASTE, 0, E_CAL_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_ITEM, (gchar *) "40.cut", (gchar *) N_("C_ut"), e_memo_table_on_cut, NULL, (gchar *) GTK_STOCK_CUT, 0, E_CAL_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_ITEM, (gchar *) "50.copy", (gchar *) N_("_Copy"), e_memo_table_on_copy, NULL, (gchar *) GTK_STOCK_COPY, 0, 0 },
+	{ E_POPUP_ITEM, (gchar *) "60.paste", (gchar *) N_("_Paste"), e_memo_table_on_paste, NULL, (gchar *) GTK_STOCK_PASTE, 0, E_CAL_POPUP_SELECT_EDITABLE },
 
-	{ E_POPUP_BAR, "70.bar" },
+	{ E_POPUP_BAR, (gchar *) "70.bar" },
 
-	{ E_POPUP_ITEM, "80.forward", N_("_Forward as iCalendar"), e_memo_table_on_forward, NULL, "mail-forward", E_CAL_POPUP_SELECT_ONE },
+	{ E_POPUP_ITEM, (gchar *) "80.forward", (gchar *) N_("_Forward as iCalendar"), e_memo_table_on_forward, NULL, (gchar *) "mail-forward", E_CAL_POPUP_SELECT_ONE },
 
-	{ E_POPUP_BAR, "90.bar" },
+	{ E_POPUP_BAR, (gchar *) "90.bar" },
 
-	{ E_POPUP_ITEM, "a0.delete", N_("_Delete"), delete_cb, NULL, GTK_STOCK_DELETE, E_CAL_POPUP_SELECT_ONE, E_CAL_POPUP_SELECT_EDITABLE },
-	{ E_POPUP_ITEM, "b0.deletemany", N_("_Delete Selected Memos"), delete_cb, NULL, GTK_STOCK_DELETE, E_CAL_POPUP_SELECT_MANY, E_CAL_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_ITEM, (gchar *) "a0.delete", (gchar *) N_("_Delete"), delete_cb, NULL, (gchar *) GTK_STOCK_DELETE, E_CAL_POPUP_SELECT_ONE, E_CAL_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_ITEM, (gchar *) "b0.deletemany", (gchar *) N_("_Delete Selected Memos"), delete_cb, NULL, (gchar *) GTK_STOCK_DELETE, E_CAL_POPUP_SELECT_MANY, E_CAL_POPUP_SELECT_EDITABLE },
 };
 
 static void
-emt_popup_free(EPopup *ep, GSList *items, void *data)
+emt_popup_free(EPopup *ep, GSList *items, gpointer data)
 {
 	g_slist_free(items);
 }
@@ -971,7 +969,7 @@ e_memo_table_show_popup_menu (ETable *table,
 	GPtrArray *events;
 	ECalPopup *ep;
 	ECalPopupTargetSelect *t;
-	int i;
+	gint i;
 
 	selection = get_selected_objects (memo_table);
 	if (!selection)
@@ -1102,7 +1100,7 @@ e_memo_table_get_current_time (ECellDateEdit *ecde, gpointer data)
 
 #ifdef TRANSLATORS_ONLY
 
-static char *test[] = {
+static gchar *test[] = {
     N_("Click to add a memo")
 };
 
@@ -1130,7 +1128,7 @@ e_memo_table_set_status_message (EMemoTable *memo_table, const gchar *message)
 			memo_table->activity_id = 0;
 		}
         } else if (memo_table->activity_id == 0) {
-                char *client_id = g_strdup_printf ("%p", memo_table);
+                gchar *client_id = g_strdup_printf ("%p", (gpointer) memo_table);
 
                 memo_table->activity_id = e_activity_handler_operation_started (
 			memo_table->activity_handler, client_id, message, TRUE);
