@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -52,7 +52,7 @@ struct _ETasksClass {
 	GtkTableClass parent_class;
 
 	/* Notification signals */
-	void (* selection_changed) (ETasks *tasks, int n_selected);
+	void (* selection_changed) (ETasks *tasks, gint n_selected);
         void (* source_added)      (ETasks *tasks, ESource *source);
         void (* source_removed)    (ETasks *tasks, ESource *source);
 };
@@ -73,9 +73,9 @@ ECal      *e_tasks_get_default_client    (ETasks *tasks);
 
 void       e_tasks_open_task         (ETasks		*tasks);
 void       e_tasks_open_task_id      (ETasks		*tasks,
-				      const char *src_uid,
-				      const char *comp_uid,
-				      const char *comp_rid);
+				      const gchar *src_uid,
+				      const gchar *comp_uid,
+				      const gchar *comp_rid);
 void       e_tasks_new_task          (ETasks            *tasks);
 void       e_tasks_complete_selected (ETasks            *tasks);
 void       e_tasks_delete_selected   (ETasks            *tasks);
