@@ -13,7 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  * Authors:
  *		Damon Chaplin <damon@ximian.com>
@@ -334,8 +334,8 @@ e_week_view_layout_get_day_position	(gint		 day,
 		#define wk(x) ( ( working_days & (days [ ((x) + display_start_day) % 7 ]) ) ? 1 : 0)
 		CalWeekdays days [] = {CAL_MONDAY, CAL_TUESDAY, CAL_WEDNESDAY, CAL_THURSDAY, CAL_FRIDAY, CAL_SATURDAY, CAL_SUNDAY};
 		CalWeekdays working_days;
-		int arr[4] = {1, 1, 1, 1};
-		int edge, i, wd, m, M;
+		gint arr[4] = {1, 1, 1, 1};
+		gint edge, i, wd, m, M;
 		gboolean any = TRUE;
 
 		g_return_if_fail (day < 7);
@@ -432,7 +432,7 @@ e_week_view_layout_get_span_position	(EWeekViewEvent *event,
 	if (span->row >= rows_per_compressed_cell) {
 		if (multi_week_view) {
 			if (compress_weekend) {
-				/* If it ends on a Saturday and is 1 day long
+				/* If it ends on a Saturday and is 1 day glong
 				   we skip it, else we shorten it. If it ends
 				   on a Sunday it must be 1 day long and we
 				   skip it. */
