@@ -1,29 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
-/*
- * Author :
- *  Damon Chaplin <damon@ximian.com>
- *
- * Copyright 1999, Ximian, Inc.
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
- */
-
 /*
  * EWeekViewMainItem - displays the background grid and dates for the Week and
  * Month calendar views.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,13 +38,13 @@ static void e_week_view_main_item_set_property	(GObject	 *object,
 static void e_week_view_main_item_update	(GnomeCanvasItem *item,
 						 double		 *affine,
 						 ArtSVP		 *clip_path,
-						 int		  flags);
+						 gint		  flags);
 static void e_week_view_main_item_draw		(GnomeCanvasItem *item,
 						 GdkDrawable	 *drawable,
-						 int		  x,
-						 int		  y,
-						 int		  width,
-						 int		  height);
+						 gint		  x,
+						 gint		  y,
+						 gint		  width,
+						 gint		  height);
 static void e_week_view_main_item_draw_day	(EWeekViewMainItem *wvmitem,
 						 gint		   day,
 						 GDate		  *date,
@@ -61,8 +56,8 @@ static void e_week_view_main_item_draw_day	(EWeekViewMainItem *wvmitem,
 static double e_week_view_main_item_point	(GnomeCanvasItem *item,
 						 double		  x,
 						 double		  y,
-						 int		  cx,
-						 int		  cy,
+						 gint		  cx,
+						 gint		  cy,
 						 GnomeCanvasItem **actual_item);
 
 /* The arguments we take */
@@ -97,7 +92,7 @@ e_week_view_main_item_class_init (EWeekViewMainItemClass *class)
 			G_PARAM_WRITABLE));
 
 	/* init the accessibility support for e_week_view_main_item */
- 	e_week_view_main_item_a11y_init ();
+	e_week_view_main_item_a11y_init ();
 }
 
 
@@ -132,7 +127,7 @@ static void
 e_week_view_main_item_update (GnomeCanvasItem *item,
 			      double	      *affine,
 			      ArtSVP	      *clip_path,
-			      int	       flags)
+			      gint	       flags)
 {
 	if (GNOME_CANVAS_ITEM_CLASS (e_week_view_main_item_parent_class)->update)
 		(* GNOME_CANVAS_ITEM_CLASS (e_week_view_main_item_parent_class)->update) (item, affine, clip_path, flags);
@@ -151,10 +146,10 @@ e_week_view_main_item_update (GnomeCanvasItem *item,
 static void
 e_week_view_main_item_draw (GnomeCanvasItem  *canvas_item,
 			    GdkDrawable      *drawable,
-			    int		      x,
-			    int		      y,
-			    int		      width,
-			    int		      height)
+			    gint		      x,
+			    gint		      y,
+			    gint		      width,
+			    gint		      height)
 {
 	EWeekViewMainItem *wvmitem;
 	EWeekView *week_view;
@@ -424,7 +419,7 @@ e_week_view_main_item_draw_day (EWeekViewMainItem *wvmitem,
    This is needed so that we get button/motion events. */
 static double
 e_week_view_main_item_point (GnomeCanvasItem *item, double x, double y,
-			     int cx, int cy,
+			     gint cx, gint cy,
 			     GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
