@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -52,7 +52,7 @@ enum E_ITIP_BONOBO_ARGS {
  * BonoboObject.
  */
 
-static char *
+static gchar *
 stream_read (Bonobo_Stream stream)
 {
 	Bonobo_Stream_iobuf *buffer;
@@ -97,7 +97,7 @@ stream_read (Bonobo_Stream stream)
  */
 typedef struct {
 	EItipControl *itip;
-	char *text;
+	gchar *text;
 } idle_data;
 
 static gboolean
@@ -115,7 +115,7 @@ set_data_idle_cb (gpointer data)
 
 static void
 pstream_load (BonoboPersistStream *ps, const Bonobo_Stream stream,
-	      Bonobo_Persist_ContentType type, void *data,
+	      Bonobo_Persist_ContentType type, gpointer data,
 	      CORBA_Environment *ev)
 {
 	EItipControl *itip = data;
@@ -143,7 +143,7 @@ pstream_load (BonoboPersistStream *ps, const Bonobo_Stream stream,
  */
 static void
 pstream_save (BonoboPersistStream *ps, const Bonobo_Stream stream,
-	      Bonobo_Persist_ContentType type, void *data,
+	      Bonobo_Persist_ContentType type, gpointer data,
 	      CORBA_Environment *ev)
 {
 	EItipControl *itip = data;
@@ -164,22 +164,22 @@ pstream_save (BonoboPersistStream *ps, const Bonobo_Stream stream,
 } /* pstream_save */
 
 /* static CORBA_long */
-/* pstream_get_max_size (BonoboPersistStream *ps, void *data, */
-/* 		      CORBA_Environment *ev) */
+/* pstream_get_max_size (BonoboPersistStream *ps, gpointer data, */
+/*		      CORBA_Environment *ev) */
 /* { */
-/* 	EItipControl *itip = data; */
-/* 	gint len; */
+/*	EItipControl *itip = data; */
+/*	gint len; */
 
-/* 	len = e_itip_control_get_data_size (itip); */
+/*	len = e_itip_control_get_data_size (itip); */
 
-/*   	if (len > 0) */
-/* 		return len; */
+/*	if (len > 0) */
+/*		return len; */
 
-/* 	return 0L; */
+/*	return 0L; */
 /* } */
 
 static Bonobo_Persist_ContentTypeList *
-pstream_get_content_types (BonoboPersistStream *ps, void *closure,
+pstream_get_content_types (BonoboPersistStream *ps, gpointer closure,
 			   CORBA_Environment *ev)
 {
 	return bonobo_persist_generate_content_types (2, "text/calendar", "text/x-calendar");
