@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -59,7 +59,7 @@
 #define CREATE_MEMO_LIST_ID          "memo-list"
 
 enum DndTargetType {
-	DND_TARGET_TYPE_CALENDAR_LIST,
+	DND_TARGET_TYPE_CALENDAR_LIST
 };
 #define CALENDAR_TYPE "text/calendar"
 #define XCALENDAR_TYPE "text/x-calendar"
@@ -67,8 +67,8 @@ enum DndTargetType {
 #define PERSONAL_RELATIVE_URI "system"
 
 static GtkTargetEntry drag_types[] = {
-	{ CALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST },
-	{ XCALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST }
+	{ (gchar *) CALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST },
+	{ (gchar *) XCALENDAR_TYPE, 0, DND_TARGET_TYPE_CALENDAR_LIST }
 };
 static gint num_drag_types = sizeof(drag_types) / sizeof(drag_types[0]);
 
@@ -105,8 +105,8 @@ typedef struct _MemosComponentView
 } MemosComponentView;
 
 struct _MemosComponentPrivate {
-	char *base_directory;
-	char *config_directory;
+	gchar *base_directory;
+	gchar *config_directory;
 
 	ESourceList *source_list;
 	GSList *source_selection;
@@ -123,17 +123,12 @@ struct _MemosComponentPrivate {
 static void
 ensure_sources (MemosComponent *component)
 {
-	GSList *groups;
 	ESourceList *source_list;
-	ESourceGroup *group;
 	ESourceGroup *on_this_computer;
-	ESourceGroup *on_the_web;
 	ESource *personal_source;
-	char *base_uri, *base_uri_proto;
+	gchar *base_uri, *base_uri_proto, base_uri_proto_seventh;
 	const gchar *base_dir;
 
-	on_this_computer = NULL;
-	on_the_web = NULL;
 	personal_source = NULL;
 
 	if (!e_cal_get_sources (&source_list, E_CAL_SOURCE_TYPE_JOURNAL, NULL)) {
@@ -145,24 +140,20 @@ ensure_sources (MemosComponent *component)
 	base_uri = g_build_filename (base_dir, "local", NULL);
 
 	base_uri_proto = g_filename_to_uri (base_uri, NULL, NULL);
+	if (strlen (base_uri_proto) > 7) {
+		/* compare only file:// part. If user home dir name changes we do not want to create
+		   one more group  */
+		base_uri_proto_seventh = base_uri_proto[7];
+		base_uri_proto[7] = 0;
+	} else {
+		base_uri_proto_seventh = -1;
+	}
 
-	groups = e_source_list_peek_groups (source_list);
-	if (groups) {
-		/* groups are already there, we need to search for things... */
-		GSList *g;
+	on_this_computer = e_source_list_ensure_group (source_list, _("On This Computer"), base_uri_proto, TRUE);
+	e_source_list_ensure_group (source_list, _("On The Web"), WEB_BASE_URI, FALSE);
 
-		for (g = groups; g; g = g->next) {
-
-			group = E_SOURCE_GROUP (g->data);
-
-			/* compare only file:// part. If user home dir name changes we do not want to create
-			   one more group  */
-
-			if (!on_this_computer && !strncmp (base_uri_proto, e_source_group_peek_base_uri (group), 7))
-				on_this_computer = group;
-			else if (!on_the_web && !strcmp (WEB_BASE_URI, e_source_group_peek_base_uri (group)))
-				on_the_web = group;
-		}
+	if (base_uri_proto_seventh != -1) {
+		base_uri_proto[7] = base_uri_proto_seventh;
 	}
 
 	if (on_this_computer) {
@@ -192,16 +183,6 @@ ensure_sources (MemosComponent *component)
 		       and too late to prevent user seeing "Can not Open ... because of invalid uri" error.*/
 		    e_source_list_sync (source_list,NULL);
 		}
-
-		/* ensure the group name is in current locale, not read from configuration */
-		e_source_group_set_name (on_this_computer, _("On This Computer"));
-	}
-	else {
-		/* create the local source group */
-		group = e_source_group_new (_("On This Computer"), base_uri_proto);
-		e_source_list_add_group (source_list, group, -1);
-
-		on_this_computer = group;
 	}
 
 	if (personal_source) {
@@ -235,18 +216,9 @@ ensure_sources (MemosComponent *component)
 		personal_source = source;
 	}
 
-	if (on_the_web) {
-		/* ensure the group name is in current locale, not read from configuration */
-		e_source_group_set_name (on_the_web, _("On The Web"));
-	} else {
-		/* Create the source group */
-		group = e_source_group_new (_("On The Web"), WEB_BASE_URI);
-		e_source_list_add_group (source_list, group, -1);
-
-		on_the_web = group;
-	}
-
 	component->priv->source_list = source_list;
+
+	g_object_unref (on_this_computer);
 	g_free (base_uri_proto);
 	g_free (base_uri);
 }
@@ -274,7 +246,7 @@ is_in_uids (GSList *uids, ESource *source)
 	GSList *l;
 
 	for (l = uids; l; l = l->next) {
-		const char *uid = l->data;
+		const gchar *uid = l->data;
 
 		if (!strcmp (uid, e_source_peek_uid (source)))
 			return TRUE;
@@ -301,7 +273,7 @@ update_uris_for_selection (MemosComponentView *component_view)
 		ESource *selected_source = l->data;
 
 		e_memos_add_memo_source (component_view->memos, selected_source);
-		uids_selected = g_slist_append (uids_selected, (char *)e_source_peek_uid (selected_source));
+		uids_selected = g_slist_append (uids_selected, (gchar *)e_source_peek_uid (selected_source));
 	}
 
 	e_source_selector_free_selection (component_view->source_selection);
@@ -359,7 +331,7 @@ update_selection (MemosComponentView *component_view)
 
 	/* Make sure the whole selection is there */
 	for (l = uids_selected; l; l = l->next) {
-		char *uid = l->data;
+		gchar *uid = l->data;
 		ESource *source;
 
 		source = e_source_list_peek_source_by_uid (component_view->source_list, uid);
@@ -375,7 +347,7 @@ static void
 update_primary_selection (MemosComponentView *component_view)
 {
 	ESource *source = NULL;
-	char *uid;
+	gchar *uid;
 
 	uid = calendar_config_get_primary_memos ();
 	if (uid) {
@@ -398,7 +370,7 @@ update_primary_selection (MemosComponentView *component_view)
 /* Callbacks.  */
 /* TODO: doesn't work! */
 static void
-copy_memo_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+copy_memo_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	MemosComponentView *component_view = data;
 	ESource *selected_source;
@@ -411,12 +383,12 @@ copy_memo_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-delete_memo_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+delete_memo_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	MemosComponentView *component_view = data;
 	ESource *selected_source;
 	ECal *cal;
-	char *uri;
+	gchar *uri;
 
 	selected_source = e_source_selector_peek_primary_selection (E_SOURCE_SELECTOR (component_view->source_selector));
 	if (!selected_source)
@@ -450,13 +422,13 @@ delete_memo_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-new_memo_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+new_memo_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	calendar_setup_new_memo_list (GTK_WINDOW (gtk_widget_get_toplevel(ep->target->widget)));
 }
 
 static void
-rename_memo_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+rename_memo_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	MemosComponentView *component_view = data;
 	ESourceSelector *selector;
@@ -466,7 +438,7 @@ rename_memo_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
 }
 
 static void
-edit_memo_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
+edit_memo_list_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
 	MemosComponentView *component_view = data;
 	ESource *selected_source;
@@ -478,8 +450,8 @@ edit_memo_list_cb (EPopup *ep, EPopupItem *pitem, void *data)
 	calendar_setup_edit_memo_list (GTK_WINDOW (gtk_widget_get_toplevel(ep->target->widget)), selected_source);
 }
 
-static void 
-set_offline_availability (EPopup *ep, EPopupItem *pitem, void *data, const char *value)
+static void
+set_offline_availability (EPopup *ep, EPopupItem *pitem, gpointer data, const gchar *value)
 {
 	MemosComponentView *component_view = data;
 	ESource *selected_source;
@@ -492,33 +464,33 @@ set_offline_availability (EPopup *ep, EPopupItem *pitem, void *data, const char
 }
 
 static void
-mark_no_offline_cb (EPopup *ep, EPopupItem *pitem, void *data)
+mark_no_offline_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
-	set_offline_availability (ep, pitem, data, "0"); 
+	set_offline_availability (ep, pitem, data, "0");
 }
 
 static void
-mark_offline_cb (EPopup *ep, EPopupItem *pitem, void *data)
+mark_offline_cb (EPopup *ep, EPopupItem *pitem, gpointer data)
 {
-	set_offline_availability (ep, pitem, data, "1"); 
+	set_offline_availability (ep, pitem, data, "1");
 }
 
 static EPopupItem emc_source_popups[] = {
-	{ E_POPUP_ITEM, "10.new", N_("_New Memo List"), new_memo_list_cb, NULL, "stock_notes", 0, 0 },
-	{ E_POPUP_ITEM, "15.copy", N_("_Copy..."), copy_memo_list_cb, NULL, "edit-copy", 0, E_CAL_POPUP_SOURCE_PRIMARY },
-	{ E_POPUP_ITEM, "18.rename", N_("_Rename..."), rename_memo_list_cb, NULL, NULL, 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "10.new", (gchar *) N_("_New Memo List"), new_memo_list_cb, NULL, (gchar *) "stock_notes", 0, 0 },
+	{ E_POPUP_ITEM, (gchar *) "15.copy", (gchar *) N_("_Copy..."), copy_memo_list_cb, NULL, (gchar *) "edit-copy", 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "18.rename", (gchar *) N_("_Rename..."), rename_memo_list_cb, NULL, NULL, 0, E_CAL_POPUP_SOURCE_PRIMARY },
 
-	{ E_POPUP_BAR, "20.bar" },
-	{ E_POPUP_ITEM, "20.delete", N_("_Delete"), delete_memo_list_cb, NULL, "edit-delete", 0, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY },
-	{ E_POPUP_ITEM, "30.mark_memos_offline", N_("_Make available for offline use"), mark_offline_cb, NULL, "stock_disconnect", E_CAL_POPUP_SOURCE_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_OFFLINE },
-	{ E_POPUP_ITEM, "40.mark_memos_no_offline", N_("_Do not make available for offline use"), mark_no_offline_cb, NULL, "stock_connect", E_CAL_POPUP_SOURCE_NO_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_NO_OFFLINE },
+	{ E_POPUP_BAR, (gchar *) "20.bar" },
+	{ E_POPUP_ITEM, (gchar *) "20.delete", (gchar *) N_("_Delete"), delete_memo_list_cb, NULL, (gchar *) "edit-delete", 0, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_ITEM, (gchar *) "30.mark_memos_offline", (gchar *) N_("_Make available for offline use"), mark_offline_cb, NULL, (gchar *) "stock_disconnect", E_CAL_POPUP_SOURCE_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_OFFLINE },
+	{ E_POPUP_ITEM, (gchar *) "40.mark_memos_no_offline", (gchar *) N_("_Do not make available for offline use"), mark_no_offline_cb, NULL, (gchar *) "stock_connect", E_CAL_POPUP_SOURCE_NO_OFFLINE, E_CAL_POPUP_SOURCE_USER|E_CAL_POPUP_SOURCE_PRIMARY|E_CAL_POPUP_SOURCE_NO_OFFLINE },
 
-	{ E_POPUP_BAR, "99.bar" },
-	{ E_POPUP_ITEM, "99.properties", N_("_Properties"), edit_memo_list_cb, NULL, "document-properties", 0, E_CAL_POPUP_SOURCE_PRIMARY },
+	{ E_POPUP_BAR, (gchar *) "99.bar" },
+	{ E_POPUP_ITEM, (gchar *) "99.properties", (gchar *) N_("_Properties"), edit_memo_list_cb, NULL, (gchar *) "document-properties", 0, E_CAL_POPUP_SOURCE_PRIMARY },
 };
 
 static void
-emc_source_popup_free(EPopup *ep, GSList *list, void *data)
+emc_source_popup_free(EPopup *ep, GSList *list, gpointer data)
 {
 	g_slist_free(list);
 }
@@ -529,7 +501,7 @@ popup_event_cb(ESourceSelector *selector, ESource *insource, GdkEventButton *eve
 	ECalPopup *ep;
 	ECalPopupTargetSource *t;
 	GSList *menus = NULL;
-	int i;
+	gint i;
 	GtkMenu *menu;
 
 	/** @HookPoint-ECalPopup: Memos Source Selector Context Menu
@@ -582,7 +554,7 @@ static void
 set_info (MemosComponentView *component_view)
 {
 	GString *message = g_string_new (NULL);
-	int rows, selected_rows;
+	gint rows, selected_rows;
 
 	rows = e_table_model_row_count (component_view->model);
 	selected_rows =  e_table_selected_count (component_view->table);
@@ -609,13 +581,13 @@ model_changed_cb (ETableModel *etm, MemosComponentView *component_view)
 }
 
 static void
-model_rows_inserted_cb (ETableModel *etm, int row, int count, MemosComponentView *component_view)
+model_rows_inserted_cb (ETableModel *etm, gint row, gint count, MemosComponentView *component_view)
 {
 	set_info (component_view);
 }
 
 static void
-model_rows_deleted_cb (ETableModel *etm, int row, int count, MemosComponentView *component_view)
+model_rows_deleted_cb (ETableModel *etm, gint row, gint count, MemosComponentView *component_view)
 {
 	set_info (component_view);
 }
@@ -667,7 +639,7 @@ selector_tree_data_dropped (ESourceSelector *selector,
 	components = cal_comp_selection_get_string_list (data);
 	success = components != NULL;
 	for (p = components; p && success; p = p->next) {
-		char *comp_str; /* do not free this! */
+		gchar *comp_str; /* do not free this! */
 
 		/* p->data is "source_uid\ncomponent_string" */
 		comp_str = strchr (p->data, '\n');
@@ -727,7 +699,7 @@ setup_create_ecal (MemosComponent *component, MemosComponentView *component_view
 {
 	MemosComponentPrivate *priv;
 	ESource *source = NULL;
-	char *uid;
+	gchar *uid;
 	guint not;
 
 	priv = component->priv;
@@ -794,7 +766,7 @@ setup_create_ecal (MemosComponent *component, MemosComponentView *component_view
 	/* Save the primary source for use elsewhere */
 	calendar_config_set_primary_memos (e_source_peek_uid (source));
 
-	return priv->create_ecal ;
+	return priv->create_ecal;
 }
 
 /* Ensures the calendar is selected */
@@ -841,7 +813,7 @@ create_new_memo (MemosComponent *memo_component, gboolean is_assigned, MemosComp
 }
 
 static void
-create_local_item_cb (EUserCreatableItemsHandler *handler, const char *item_type_name, void *data)
+create_local_item_cb (EUserCreatableItemsHandler *handler, const gchar *item_type_name, gpointer data)
 {
 	MemosComponent *memos_component = data;
 	MemosComponentPrivate *priv;
@@ -1067,28 +1039,28 @@ impl__get_userCreatableItems (PortableServer_Servant servant,
 
 	CORBA_sequence_set_release (list, FALSE);
 
-	list->_buffer[0].id = CREATE_MEMO_ID;
-	list->_buffer[0].description = _("New memo");
-	list->_buffer[0].menuDescription = (char *) C_("New", "Mem_o");
-	list->_buffer[0].tooltip = _("Create a new memo");
+	list->_buffer[0].id = (gchar *) CREATE_MEMO_ID;
+	list->_buffer[0].description = (gchar *) _("New memo");
+	list->_buffer[0].menuDescription = (gchar *) C_("New", "Mem_o");
+	list->_buffer[0].tooltip = (gchar *) _("Create a new memo");
 	list->_buffer[0].menuShortcut = 'o';
-	list->_buffer[0].iconName = "stock_insert-note";
+	list->_buffer[0].iconName = (gchar *) "stock_insert-note";
 	list->_buffer[0].type = GNOME_Evolution_CREATABLE_OBJECT;
 
-	list->_buffer[1].id = CREATE_SHARED_MEMO_ID;
-	list->_buffer[1].description = _("New shared memo");
-	list->_buffer[1].menuDescription = (char *) C_("New", "_Shared memo");
-	list->_buffer[1].tooltip = _("Create a shared new memo");
+	list->_buffer[1].id = (gchar *) CREATE_SHARED_MEMO_ID;
+	list->_buffer[1].description = (gchar *) _("New shared memo");
+	list->_buffer[1].menuDescription = (gchar *) C_("New", "_Shared memo");
+	list->_buffer[1].tooltip = (gchar *) _("Create a shared new memo");
 	list->_buffer[1].menuShortcut = 'h';
-	list->_buffer[1].iconName = "stock_insert-note";
+	list->_buffer[1].iconName = (gchar *) "stock_insert-note";
 	list->_buffer[1].type = GNOME_Evolution_CREATABLE_OBJECT;
 
-	list->_buffer[2].id = CREATE_MEMO_LIST_ID;
-	list->_buffer[2].description = _("New memo list");
-	list->_buffer[2].menuDescription = (char *) C_("New", "Memo li_st");
-	list->_buffer[2].tooltip = _("Create a new memo list");
+	list->_buffer[2].id = (gchar *) CREATE_MEMO_LIST_ID;
+	list->_buffer[2].description = (gchar *) _("New memo list");
+	list->_buffer[2].menuDescription = (gchar *) C_("New", "Memo li_st");
+	list->_buffer[2].tooltip = (gchar *) _("Create a new memo list");
 	list->_buffer[2].menuShortcut = '\0';
-	list->_buffer[2].iconName = "stock_notes";
+	list->_buffer[2].iconName = (gchar *) "stock_notes";
 	list->_buffer[2].type = GNOME_Evolution_CREATABLE_FOLDER;
 
 	return list;
@@ -1231,13 +1203,13 @@ memos_component_peek (void)
 	return component;
 }
 
-const char *
+const gchar *
 memos_component_peek_base_directory (MemosComponent *component)
 {
 	return component->priv->base_directory;
 }
 
-const char *
+const gchar *
 memos_component_peek_config_directory (MemosComponent *component)
 {
 	return component->priv->config_directory;
