@@ -13,7 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -160,7 +160,7 @@ tag_calendar_by_client (ECalendar *ecal, ECal *client)
    the server. We need to try to use builtin timezones first, as they may not
    be added to the server yet. */
 static icaltimezone*
-resolve_tzid_cb (const char *tzid, gpointer data)
+resolve_tzid_cb (const gchar *tzid, gpointer data)
 {
 	ECal *client;
 	icaltimezone *zone = NULL;
