@@ -1,24 +1,27 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+
 /*
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU Lesser General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
  */
 
 #include "e-composer-header.h"
-
+#include <glib/gi18n.h>
 #define E_COMPOSER_HEADER_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), E_TYPE_COMPOSER_HEADER, EComposerHeaderPrivate))
@@ -27,6 +30,8 @@ enum {
 	PROP_0,
 	PROP_BUTTON,
 	PROP_LABEL,
+	PROP_ADDACTION,
+	PROP_ADDACTION_TEXT,
 	PROP_SENSITIVE,
 	PROP_VISIBLE
 };
@@ -40,6 +45,12 @@ enum {
 struct _EComposerHeaderPrivate {
 	gchar *label;
 	gboolean button;
+	gchar *addaction_text;
+	gboolean addaction; /*For Add button.*/
+	GtkWidget *action_label;
+
+	guint sensitive : 1;
+	guint visible   : 1;
 };
 
 static gpointer parent_class;
@@ -53,6 +64,19 @@ composer_header_button_clicked_cb (GtkButton *button,
 	g_signal_emit (header, signal_ids[CLICKED], 0);
 }
 
+static void
+composer_header_addaction_clicked_cb (GtkButton *button,
+				      EComposerHeader *header)
+{
+	gboolean show = !e_composer_header_get_visible(header);
+	if (!show)
+		gtk_label_set_markup ((GtkLabel *)header->priv->action_label, g_object_get_data ((GObject *)header->priv->action_label, "show"));
+	else
+		gtk_label_set_markup ((GtkLabel *)header->priv->action_label, g_object_get_data ((GObject *)header->priv->action_label, "hide"));
+
+	e_composer_header_set_visible (header, show);
+}
+
 static GObject *
 composer_header_constructor (GType type,
                              guint n_construct_properties,
@@ -80,6 +104,32 @@ composer_header_constructor (GType type,
 		gtk_label_set_mnemonic_widget (
 			GTK_LABEL (widget), header->input_widget);
 	}
+
+	if (header->priv->addaction) {
+		GtkWidget *box, *tmp;
+		gchar *str;
+
+		header->action_widget = gtk_button_new ();
+		box = gtk_hbox_new (FALSE, 0);
+		tmp = gtk_image_new_from_stock("gtk-add", GTK_ICON_SIZE_BUTTON);
+		gtk_box_pack_start((GtkBox *)box, tmp, FALSE, FALSE, 3);
+		tmp = gtk_label_new (NULL);
+		str = g_strdup_printf ("<span foreground='blue' underline='single' underline_color='blue'  >%s %s</span>", _("Show"), header->priv->addaction_text);
+		g_object_set_data ((GObject *)tmp, "show", str);
+		gtk_label_set_markup((GtkLabel *)tmp, str);
+		str = g_strdup_printf ("<span foreground='blue' underline='single' underline_color='blue'  >%s %s</span>", _("Hide"), header->priv->addaction_text);
+		g_object_set_data ((GObject *)tmp, "hide", str);
+
+		header->priv->action_label = tmp;
+		gtk_box_pack_start((GtkBox *)box, tmp, FALSE, FALSE, 3);
+		gtk_container_add((GtkContainer *)header->action_widget, box);
+		gtk_widget_show_all(header->action_widget);
+		g_signal_connect (
+			header->action_widget, "clicked",
+			G_CALLBACK (composer_header_addaction_clicked_cb),
+			header);
+	}
+
 	header->title_widget = g_object_ref_sink (widget);
 
 	g_free (header->priv->label);
@@ -103,6 +153,14 @@ composer_header_set_property (GObject *object,
 			priv->button = g_value_get_boolean (value);
 			return;
 
+		case PROP_ADDACTION:	/* construct only */
+			priv->addaction = g_value_get_boolean (value);
+			return;
+
+		case PROP_ADDACTION_TEXT:/* construct only */
+			priv->addaction_text = g_value_dup_string (value);
+			return;
+
 		case PROP_LABEL:	/* construct only */
 			priv->label = g_value_dup_string (value);
 			return;
@@ -123,6 +181,15 @@ composer_header_set_property (GObject *object,
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 }
 
+void
+e_composer_header_set_property (GObject *object,
+                              guint property_id,
+                              const GValue *value,
+                              GParamSpec *pspec)
+{
+	composer_header_set_property (object, property_id, value, pspec);
+}
+
 static void
 composer_header_get_property (GObject *object,
                               guint property_id,
@@ -138,6 +205,15 @@ composer_header_get_property (GObject *object,
 			g_value_set_boolean (value, priv->button);
 			return;
 
+		case PROP_ADDACTION:	/* construct only */
+			g_value_set_boolean (value, priv->button);
+			return;
+
+		case PROP_ADDACTION_TEXT:	/* construct only */
+			g_value_take_string (
+				value, priv->addaction_text);
+			return;
+
 		case PROP_LABEL:	/* construct only */
 			g_value_take_string (
 				value, e_composer_header_get_label (
@@ -204,6 +280,28 @@ composer_header_class_init (EComposerHeaderClass *class)
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT_ONLY));
 
+	g_object_class_install_property (
+		object_class,
+		PROP_ADDACTION,
+		g_param_spec_boolean (
+			"addaction",
+			NULL,
+			NULL,
+			FALSE,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT_ONLY));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_ADDACTION_TEXT,
+		g_param_spec_string (
+			"addaction_text",
+			NULL,
+			NULL,
+			NULL,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT_ONLY));
+
 	g_object_class_install_property (
 		object_class,
 		PROP_LABEL,
@@ -301,15 +399,9 @@ e_composer_header_get_label (EComposerHeader *header)
 gboolean
 e_composer_header_get_sensitive (EComposerHeader *header)
 {
-	gboolean sensitive;
-
 	g_return_val_if_fail (E_IS_COMPOSER_HEADER (header), FALSE);
 
-	sensitive = GTK_WIDGET_SENSITIVE (header->title_widget);
-	if (GTK_WIDGET_SENSITIVE (header->input_widget) != sensitive)
-		g_warning ("%s: Sensitivity is out of sync", G_STRFUNC);
-
-	return sensitive;
+	return header->priv->sensitive;
 }
 
 void
@@ -318,8 +410,7 @@ e_composer_header_set_sensitive (EComposerHeader *header,
 {
 	g_return_if_fail (E_IS_COMPOSER_HEADER (header));
 
-	gtk_widget_set_sensitive (header->title_widget, sensitive);
-	gtk_widget_set_sensitive (header->input_widget, sensitive);
+	header->priv->sensitive = sensitive;
 
 	g_object_notify (G_OBJECT (header), "sensitive");
 }
@@ -327,15 +418,9 @@ e_composer_header_set_sensitive (EComposerHeader *header,
 gboolean
 e_composer_header_get_visible (EComposerHeader *header)
 {
-	gboolean visible;
-
 	g_return_val_if_fail (E_IS_COMPOSER_HEADER (header), FALSE);
 
-	visible = GTK_WIDGET_VISIBLE (header->title_widget);
-	if (GTK_WIDGET_VISIBLE (header->input_widget) != visible)
-		g_warning ("%s: Visibility is out of sync", G_STRFUNC);
-
-	return visible;
+	return header->priv->visible;
 }
 
 void
@@ -344,13 +429,7 @@ e_composer_header_set_visible (EComposerHeader *header,
 {
 	g_return_if_fail (E_IS_COMPOSER_HEADER (header));
 
-	if (visible) {
-		gtk_widget_show (header->title_widget);
-		gtk_widget_show (header->input_widget);
-	} else {
-		gtk_widget_hide (header->title_widget);
-		gtk_widget_hide (header->input_widget);
-	}
+	header->priv->visible = visible;
 
 	g_object_notify (G_OBJECT (header), "visible");
 }
