@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -45,27 +45,27 @@ enum {
 };
 
 typedef struct _e_bconf_map {
-	char *from;
-	char *to;
-	int type;
+	const gchar *from;
+	const gchar *to;
+	gint type;
 	struct _e_bconf_map *child;
 } e_bconf_map_t;
 
 
-char *e_bconf_hex_decode (const char *val);
-char *e_bconf_url_decode (const char *val);
+gchar *e_bconf_hex_decode (const gchar *val);
+gchar *e_bconf_url_decode (const gchar *val);
 
-xmlNodePtr e_bconf_get_path (xmlDocPtr doc, const char *path);
-xmlNodePtr e_bconf_get_entry (xmlNodePtr root, const char *name);
+xmlNodePtr e_bconf_get_path (xmlDocPtr doc, const gchar *path);
+xmlNodePtr e_bconf_get_entry (xmlNodePtr root, const gchar *name);
 
-char *e_bconf_get_value (xmlNodePtr root, const char *name);
-char *e_bconf_get_bool (xmlNodePtr root, const char *name);
-char *e_bconf_get_long (xmlNodePtr root, const char *name);
-char *e_bconf_get_string (xmlNodePtr root, const char *name);
+gchar *e_bconf_get_value (xmlNodePtr root, const gchar *name);
+gchar *e_bconf_get_bool (xmlNodePtr root, const gchar *name);
+gchar *e_bconf_get_long (xmlNodePtr root, const gchar *name);
+gchar *e_bconf_get_string (xmlNodePtr root, const gchar *name);
 
-int e_bconf_import_xml_blob (GConfClient *gconf, xmlDocPtr config_xmldb, e_bconf_map_t *map,
-			     const char *bconf_path, const char *gconf_path,
-			     const char *name, const char *idparam);
+gint e_bconf_import_xml_blob (GConfClient *gconf, xmlDocPtr config_xmldb, e_bconf_map_t *map,
+			     const gchar *bconf_path, const gchar *gconf_path,
+			     const gchar *name, const gchar *idparam);
 
 
 enum {
@@ -83,17 +83,17 @@ enum {
 };
 
 typedef struct {
-	char *from;
-	char *to;
-	int type;
+	const gchar *from;
+	const gchar *to;
+	gint type;
 } e_gconf_map_t;
 
 typedef struct {
-	char *root;
+	const gchar *root;
 	e_gconf_map_t *map;
 } e_gconf_map_list_t;
 
-int e_bconf_import (GConfClient *gconf, xmlDocPtr config_xmldb, e_gconf_map_list_t *remap_list);
+gint e_bconf_import (GConfClient *gconf, xmlDocPtr config_xmldb, e_gconf_map_list_t *remap_list);
 
 #ifdef __cplusplus
 }
