@@ -1,22 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
  *
- *  Authors: Michel Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michel Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -41,14 +42,14 @@ typedef struct _EProfileEventClass EProfileEventClass;
 
 /* Current target description */
 enum _e_profile_event_target_t {
-	E_PROFILE_EVENT_TARGET,
+	E_PROFILE_EVENT_TARGET
 };
 
 /* Flags that qualify a target (UNIMPLEMENTED) */
 enum {
 	E_PROFILE_EVENT_START = 1<< 0,
 	E_PROFILE_EVENT_END = 1<< 1,
-	E_PROFILE_EVENT_CANCEL = 1<< 2,
+	E_PROFILE_EVENT_CANCEL = 1<< 2
 };
 
 typedef struct _EProfileEventTarget EProfileEventTarget;
@@ -57,8 +58,8 @@ struct _EProfileEventTarget {
 	EEventTarget target;
 
 	struct timeval tv;
-	char *id;		/* id of event */
-	char *uid;		/* uid of event (folder/message, etc) */
+	gchar *id;		/* id of event */
+	gchar *uid;		/* uid of event (folder/message, etc) */
 };
 
 typedef struct _EEventItem EProfileEventItem;
@@ -78,11 +79,11 @@ GType e_profile_event_get_type(void);
 
 EProfileEvent *e_profile_event_peek(void);
 
-EProfileEventTarget *e_profile_event_target_new(EProfileEvent *emp, const char *id, const char *uid, guint32 flags);
+EProfileEventTarget *e_profile_event_target_new(EProfileEvent *emp, const gchar *id, const gchar *uid, guint32 flags);
 
 /* we don't want ANY rubbish code lying around if we have profiling off */
 #ifdef ENABLE_PROFILING
-void e_profile_event_emit(const char *id, const char *uid, guint32 flags);
+void e_profile_event_emit(const gchar *id, const gchar *uid, guint32 flags);
 #else
 #define e_profile_event_emit(a, b, c)
 #endif
