@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-sorter-array.c
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -35,26 +34,26 @@
 
 G_DEFINE_TYPE (ESorterArray, e_sorter_array, E_SORTER_TYPE)
 
-static void    	esa_sort               (ESorterArray *esa);
-static void    	esa_backsort           (ESorterArray *esa);
+static void	esa_sort               (ESorterArray *esa);
+static void	esa_backsort           (ESorterArray *esa);
 
-static gint    	esa_model_to_sorted           (ESorter *sorter, int row);
-static gint    	esa_sorted_to_model           (ESorter *sorter, int row);
-static void    	esa_get_model_to_sorted_array (ESorter *sorter, int **array, int *count);
-static void    	esa_get_sorted_to_model_array (ESorter *sorter, int **array, int *count);
+static gint	esa_model_to_sorted           (ESorter *sorter, gint row);
+static gint	esa_sorted_to_model           (ESorter *sorter, gint row);
+static void	esa_get_model_to_sorted_array (ESorter *sorter, gint **array, gint *count);
+static void	esa_get_sorted_to_model_array (ESorter *sorter, gint **array, gint *count);
 static gboolean esa_needs_sorting             (ESorter *esa);
 
 #define ESA_NEEDS_SORTING(esa) (((ESorterArray *) (esa))->compare != NULL)
 
-static int
-esort_callback(const void *data1, const void *data2, gpointer user_data)
+static gint
+esort_callback(gconstpointer data1, gconstpointer data2, gpointer user_data)
 {
 	ESorterArray *esa = user_data;
-	int ret_val;
-	int int1, int2;
+	gint ret_val;
+	gint int1, int2;
 
-	int1 = *(int *)data1;
-	int2 = *(int *)data2;
+	int1 = *(gint *)data1;
+	int2 = *(gint *)data2;
 
 	ret_val = esa->compare (int1, int2, esa->closure);
 	if (ret_val != 0)
@@ -70,8 +69,8 @@ esort_callback(const void *data1, const void *data2, gpointer user_data)
 static void
 esa_sort(ESorterArray *esa)
 {
-	int rows;
-	int i;
+	gint rows;
+	gint i;
 
 	if (esa->sorted)
 		return;
@@ -84,14 +83,14 @@ esa_sort(ESorterArray *esa)
 
 	if (esa->compare)
 		g_qsort_with_data (
-			esa->sorted, rows, sizeof(int),
+			esa->sorted, rows, sizeof(gint),
 			esort_callback, esa);
 }
 
 static void
 esa_backsort(ESorterArray *esa)
 {
-	int i, rows;
+	gint i, rows;
 
 	if (esa->backsorted)
 		return;
@@ -109,7 +108,7 @@ esa_backsort(ESorterArray *esa)
 
 
 static gint
-esa_model_to_sorted (ESorter *es, int row)
+esa_model_to_sorted (ESorter *es, gint row)
 {
 	ESorterArray *esa = E_SORTER_ARRAY(es);
 
@@ -126,7 +125,7 @@ esa_model_to_sorted (ESorter *es, int row)
 }
 
 static gint
-esa_sorted_to_model (ESorter *es, int row)
+esa_sorted_to_model (ESorter *es, gint row)
 {
 	ESorterArray *esa = (ESorterArray *) es;
 
@@ -143,7 +142,7 @@ esa_sorted_to_model (ESorter *es, int row)
 }
 
 static void
-esa_get_model_to_sorted_array (ESorter *es, int **array, int *count)
+esa_get_model_to_sorted_array (ESorter *es, gint **array, gint *count)
 {
 	ESorterArray *esa = E_SORTER_ARRAY(es);
 	if (array || count) {
@@ -157,7 +156,7 @@ esa_get_model_to_sorted_array (ESorter *es, int **array, int *count)
 }
 
 static void
-esa_get_sorted_to_model_array (ESorter *es, int **array, int *count)
+esa_get_sorted_to_model_array (ESorter *es, gint **array, gint *count)
 {
 	ESorterArray *esa = E_SORTER_ARRAY(es);
 	if (array || count) {
@@ -188,26 +187,26 @@ e_sorter_array_clean(ESorterArray *esa)
 }
 
 void
-e_sorter_array_set_count  (ESorterArray *esa, int count)
+e_sorter_array_set_count  (ESorterArray *esa, gint count)
 {
 	e_sorter_array_clean (esa);
 	esa->rows = count;
 }
 
 void
-e_sorter_array_append  (ESorterArray *esa, int count)
+e_sorter_array_append  (ESorterArray *esa, gint count)
 {
-	int i;
+	gint i;
 	g_free(esa->backsorted);
 	esa->backsorted = NULL;
 
 	if (esa->sorted) {
 		esa->sorted = g_renew(int, esa->sorted, esa->rows + count);
 		for (i = 0; i < count; i++) {
-			int value = esa->rows;
-			size_t pos;
-			e_bsearch (&value, esa->sorted, esa->rows, sizeof (int), esort_callback, esa, &pos, NULL);
-			memmove (esa->sorted + pos + 1, esa->sorted + pos, sizeof (int) * (esa->rows - pos));
+			gint value = esa->rows;
+			gsize pos;
+			e_bsearch (&value, esa->sorted, esa->rows, sizeof (gint), esort_callback, esa, &pos, NULL);
+			memmove (esa->sorted + pos + 1, esa->sorted + pos, sizeof (gint) * (esa->rows - pos));
 			esa->sorted[pos] = value;
 			esa->rows ++;
 		}
@@ -239,11 +238,11 @@ e_sorter_array_class_init (ESorterArrayClass *klass)
 {
 	ESorterClass *sorter_class = E_SORTER_CLASS(klass);
 
-	sorter_class->model_to_sorted           = esa_model_to_sorted           ;
-	sorter_class->sorted_to_model           = esa_sorted_to_model           ;
-	sorter_class->get_model_to_sorted_array = esa_get_model_to_sorted_array ;
-	sorter_class->get_sorted_to_model_array = esa_get_sorted_to_model_array ;
-	sorter_class->needs_sorting             = esa_needs_sorting             ;
+	sorter_class->model_to_sorted           = esa_model_to_sorted;
+	sorter_class->sorted_to_model           = esa_sorted_to_model;
+	sorter_class->get_model_to_sorted_array = esa_get_model_to_sorted_array;
+	sorter_class->get_sorted_to_model_array = esa_get_sorted_to_model_array;
+	sorter_class->needs_sorting             = esa_needs_sorting;
 }
 
 static void
