@@ -1,24 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-sorter.h
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #ifndef _E_SORTER_H_
@@ -44,16 +44,16 @@ typedef struct {
 typedef struct {
 	GObjectClass parent_class;
 	gint      (*model_to_sorted)            (ESorter    *sorter,
-						 int         row);
+						 gint         row);
 	gint      (*sorted_to_model)            (ESorter    *sorter,
-						 int         row);
+						 gint         row);
 
 	void      (*get_model_to_sorted_array)  (ESorter    *sorter,
-						 int       **array,
-						 int        *count);
+						 gint       **array,
+						 gint        *count);
 	void      (*get_sorted_to_model_array)  (ESorter    *sorter,
-						 int       **array,
-						 int        *count);
+						 gint       **array,
+						 gint        *count);
 
 	gboolean  (*needs_sorting)              (ESorter    *sorter);
 } ESorterClass;
@@ -62,16 +62,16 @@ GType     e_sorter_get_type                   (void);
 ESorter  *e_sorter_new                        (void);
 
 gint      e_sorter_model_to_sorted            (ESorter  *sorter,
-					       int       row);
+					       gint       row);
 gint      e_sorter_sorted_to_model            (ESorter  *sorter,
-					       int       row);
+					       gint       row);
 
 void      e_sorter_get_model_to_sorted_array  (ESorter  *sorter,
-					       int     **array,
-					       int      *count);
+					       gint     **array,
+					       gint      *count);
 void      e_sorter_get_sorted_to_model_array  (ESorter  *sorter,
-					       int     **array,
-					       int      *count);
+					       gint     **array,
+					       gint      *count);
 
 gboolean  e_sorter_needs_sorting              (ESorter  *sorter);
 
