@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -40,6 +40,8 @@
 #include <glib/gstdio.h>
 #include <libgnome/gnome-init.h>
 
+#include <camel/camel-url.h>
+
 #ifdef G_OS_WIN32
 #include <windows.h>
 #endif
@@ -108,6 +110,7 @@ e_show_uri (GtkWindow *parent,
 	GtkWidget *dialog;
 	GdkScreen *screen = NULL;
 	GError *error = NULL;
+	gchar *decoded_uri;
 	guint32 timestamp;
 
 	g_return_if_fail (uri != NULL);
@@ -117,8 +120,11 @@ e_show_uri (GtkWindow *parent,
 	if (parent != NULL)
 		screen = gtk_widget_get_screen (GTK_WIDGET (parent));
 
-	if (gtk_show_uri (screen, uri, timestamp, &error))
-		return;
+	decoded_uri = g_strdup (uri);
+	camel_url_decode (decoded_uri);
+
+	if (gtk_show_uri (screen, decoded_uri, timestamp, &error))
+		goto exit;
 
 	dialog = gtk_message_dialog_new_with_markup (
 		parent, GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -133,6 +139,9 @@ e_show_uri (GtkWindow *parent,
 
 	gtk_widget_destroy (dialog);
 	g_error_free (error);
+
+exit:
+	g_free (decoded_uri);
 }
 
 /**
@@ -185,6 +194,183 @@ exit:
 	g_string_free (uri, TRUE);
 }
 
+/**
+ * e_lookup_action:
+ * @ui_manager: a #GtkUIManager
+ * @action_name: the name of an action
+ *
+ * Returns the first #GtkAction named @action_name by traversing the
+ * list of action groups in @ui_manager.  If no such action exists, the
+ * function emits a critical warning before returning %NULL, since this
+ * probably indicates a programming error and most code is not prepared
+ * to deal with lookup failures.
+ *
+ * Returns: the first #GtkAction named @action_name
+ **/
+GtkAction *
+e_lookup_action (GtkUIManager *ui_manager,
+                 const gchar *action_name)
+{
+	GtkAction *action = NULL;
+	GList *iter;
+
+	g_return_val_if_fail (GTK_IS_UI_MANAGER (ui_manager), NULL);
+	g_return_val_if_fail (action_name != NULL, NULL);
+
+	iter = gtk_ui_manager_get_action_groups (ui_manager);
+
+	while (iter != NULL) {
+		GtkActionGroup *action_group = iter->data;
+
+		action = gtk_action_group_get_action (
+			action_group, action_name);
+		if (action != NULL)
+			return action;
+
+		iter = g_list_next (iter);
+	}
+
+	g_critical ("%s: action `%s' not found", G_STRFUNC, action_name);
+
+	return NULL;
+}
+
+/**
+ * e_lookup_action_group:
+ * @ui_manager: a #GtkUIManager
+ * @group_name: the name of an action group
+ *
+ * Returns the #GtkActionGroup in @ui_manager named @group_name.  If no
+ * such action group exists, the function emits a critical warnings before
+ * returning %NULL, since this probably indicates a programming error and
+ * most code is not prepared to deal with lookup failures.
+ *
+ * Returns: the #GtkActionGroup named @group_name
+ **/
+GtkActionGroup *
+e_lookup_action_group (GtkUIManager *ui_manager,
+                       const gchar *group_name)
+{
+	GList *iter;
+
+	g_return_val_if_fail (GTK_IS_UI_MANAGER (ui_manager), NULL);
+	g_return_val_if_fail (group_name != NULL, NULL);
+
+	iter = gtk_ui_manager_get_action_groups (ui_manager);
+
+	while (iter != NULL) {
+		GtkActionGroup *action_group = iter->data;
+		const gchar *name;
+
+		name = gtk_action_group_get_name (action_group);
+		if (strcmp (name, group_name) == 0)
+			return action_group;
+
+		iter = g_list_next (iter);
+	}
+
+	g_critical ("%s: action group `%s' not found", G_STRFUNC, group_name);
+
+	return NULL;
+}
+
+/**
+ * e_load_ui_definition:
+ * @ui_manager: a #GtkUIManager
+ * @basename: basename of the UI definition file
+ *
+ * Loads a UI definition into @ui_manager from Evolution's UI directory.
+ * Failure here is fatal, since the application can't function without
+ * its UI definitions.
+ *
+ * Returns: The merge ID for the merged UI.  The merge ID can be used to
+ *          unmerge the UI with gtk_ui_manager_remove_ui().
+ **/
+guint
+e_load_ui_definition (GtkUIManager *ui_manager,
+                      const gchar *basename)
+{
+	gchar *filename;
+	guint merge_id;
+	GError *error = NULL;
+
+	g_return_val_if_fail (GTK_IS_UI_MANAGER (ui_manager), 0);
+	g_return_val_if_fail (basename != NULL, 0);
+
+	filename = g_build_filename (EVOLUTION_UIDIR, basename, NULL);
+	merge_id = gtk_ui_manager_add_ui_from_file (
+		ui_manager, filename, &error);
+	g_free (filename);
+
+	if (error != NULL) {
+		g_error ("%s: %s", basename, error->message);
+		g_assert_not_reached ();
+	}
+
+	return merge_id;
+}
+
+/**
+ * e_action_compare_by_label:
+ * @action1: a #GtkAction
+ * @action2: a #GtkAction
+ *
+ * Compares the labels for @action1 and @action2 using g_utf8_collate().
+ *
+ * Returns: &lt; 0 if @action1 compares before @action2, 0 if they
+ *          compare equal, &gt; 0 if @action1 compares after @action2
+ **/
+gint
+e_action_compare_by_label (GtkAction *action1,
+                           GtkAction *action2)
+{
+	gchar *label1;
+	gchar *label2;
+	gint result;
+
+	/* XXX This is horribly inefficient but will generally only be
+	 *     used on short lists of actions during UI construction. */
+
+	if (action1 == action2)
+		return 0;
+
+	g_object_get (action1, "label", &label1, NULL);
+	g_object_get (action2, "label", &label2, NULL);
+
+	result = g_utf8_collate (label1, label2);
+
+	g_free (label1);
+	g_free (label2);
+
+	return result;
+}
+
+/**
+ * e_action_group_remove_all_actions:
+ * @action_group: a #GtkActionGroup
+ *
+ * Removes all actions from the action group.
+ **/
+void
+e_action_group_remove_all_actions (GtkActionGroup *action_group)
+{
+	GList *list, *iter;
+
+	/* XXX I've proposed this function for inclusion in GTK+.
+         *     GtkActionGroup stores actions in an internal hash
+         *     table and can do this more efficiently by calling
+         *     g_hash_table_remove_all().
+         *
+         *     http://bugzilla.gnome.org/show_bug.cgi?id=550485 */
+
+	g_return_if_fail (GTK_IS_ACTION_GROUP (action_group));
+
+	list = gtk_action_group_list_actions (action_group);
+	for (iter = list; iter != NULL; iter = iter->next)
+		gtk_action_group_remove_action (action_group, iter->data);
+	g_list_free (list);
+}
+
 /**
  * e_str_without_underscores:
  * @s: the string to strip underscores from.
@@ -192,12 +378,12 @@ exit:
  * Strips underscores from a string in the same way @gtk_label_new_with_mnemonis does.
  * The returned string should be freed.
  */
-char *
-e_str_without_underscores (const char *s)
+gchar *
+e_str_without_underscores (const gchar *s)
 {
-	char *new_string;
-	const char *sp;
-	char *dp;
+	gchar *new_string;
+	const gchar *sp;
+	gchar *dp;
 
 	new_string = g_malloc (strlen (s) + 1);
 
@@ -335,10 +521,6 @@ e_write_file_uri (const gchar *filename, const gchar *data)
 	return res;
 }
 
-/* Include build marshalers */
-
-#include "e-util-marshal.h"
-
 static gint
 epow10 (gint number)
 {
@@ -952,64 +1134,85 @@ e_strdup_append_strings (gchar *first_string, ...)
 	return buffer;
 }
 
+/* font options cache */
+static gchar *fo_antialiasing = NULL, *fo_hinting = NULL, *fo_subpixel_order = NULL;
+static GStaticMutex fo_lock = G_STATIC_MUTEX_INIT;
+
+static void
+fo_option_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
+{
+	#define update_value(key,variable)	\
+		g_free (variable);		\
+		variable = gconf_client_get_string (client, "/desktop/gnome/font_rendering/" key, NULL);
+
+	g_static_mutex_lock (&fo_lock);
+	update_value ("antialiasing", fo_antialiasing);
+	update_value ("hinting", fo_hinting);
+	update_value ("rgba_order", fo_subpixel_order);
+	g_static_mutex_unlock (&fo_lock);
+
+	#undef update_value
+}
+
 cairo_font_options_t *
 get_font_options (void)
 {
-	gchar *antialiasing, *hinting, *subpixel_order;
-	GConfClient *gconf = gconf_client_get_default ();
+	static GConfClient *fo_gconf = NULL;
 	cairo_font_options_t *font_options = cairo_font_options_create ();
 
+	if (fo_gconf == NULL) {
+		fo_gconf = gconf_client_get_default ();
+
+		gconf_client_add_dir (fo_gconf, "/desktop/gnome/font_rendering", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+		gconf_client_notify_add (fo_gconf, "/desktop/gnome/font_rendering/antialiasing", fo_option_changed, NULL, NULL, NULL);
+		gconf_client_notify_add (fo_gconf, "/desktop/gnome/font_rendering/hinting", fo_option_changed, NULL, NULL, NULL);
+		gconf_client_notify_add (fo_gconf, "/desktop/gnome/font_rendering/rgba_order", fo_option_changed, NULL, NULL, NULL);
+
+		fo_option_changed (fo_gconf, 0, NULL, NULL);
+	}
+
+	g_static_mutex_lock (&fo_lock);
+
 	/* Antialiasing */
-	antialiasing = gconf_client_get_string (gconf,
-			"/desktop/gnome/font_rendering/antialiasing", NULL);
-	if (antialiasing == NULL)
+	if (fo_antialiasing == NULL)
 		cairo_font_options_set_antialias (font_options, CAIRO_ANTIALIAS_DEFAULT);
-	else {
-		if (strcmp (antialiasing, "grayscale") == 0)
-			cairo_font_options_set_antialias (font_options, CAIRO_ANTIALIAS_GRAY);
-		else if (strcmp (antialiasing, "rgba") == 0)
-			cairo_font_options_set_antialias (font_options, CAIRO_ANTIALIAS_SUBPIXEL);
-		else if (strcmp (antialiasing, "none") == 0)
-			cairo_font_options_set_antialias (font_options, CAIRO_ANTIALIAS_NONE);
-		else
-			cairo_font_options_set_antialias (font_options, CAIRO_ANTIALIAS_DEFAULT);
-	}
-	hinting = gconf_client_get_string (gconf,
-			"/desktop/gnome/font_rendering/hinting", NULL);
-	if (hinting == NULL)
+	else if (strcmp (fo_antialiasing, "grayscale") == 0)
+		cairo_font_options_set_antialias (font_options, CAIRO_ANTIALIAS_GRAY);
+	else if (strcmp (fo_antialiasing, "rgba") == 0)
+		cairo_font_options_set_antialias (font_options, CAIRO_ANTIALIAS_SUBPIXEL);
+	else if (strcmp (fo_antialiasing, "none") == 0)
+		cairo_font_options_set_antialias (font_options, CAIRO_ANTIALIAS_NONE);
+	else
+		cairo_font_options_set_antialias (font_options, CAIRO_ANTIALIAS_DEFAULT);
+
+	if (fo_hinting == NULL)
 		cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_DEFAULT);
-	else {
-		if (strcmp (hinting, "full") == 0)
-			cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_FULL);
-		else if (strcmp (hinting, "medium") == 0)
-			cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_MEDIUM);
-		else if (strcmp (hinting, "slight") == 0)
-			cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_SLIGHT);
-		else if (strcmp (hinting, "none") == 0)
-			cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_NONE);
-		else
-			cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_DEFAULT);
-	}
-	subpixel_order = gconf_client_get_string (gconf,
-			"/desktop/gnome/font_rendering/rgba_order", NULL);
-	if (subpixel_order == NULL)
+	else if (strcmp (fo_hinting, "full") == 0)
+		cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_FULL);
+	else if (strcmp (fo_hinting, "medium") == 0)
+		cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_MEDIUM);
+	else if (strcmp (fo_hinting, "slight") == 0)
+		cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_SLIGHT);
+	else if (strcmp (fo_hinting, "none") == 0)
+		cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_NONE);
+	else
+		cairo_font_options_set_hint_style (font_options, CAIRO_HINT_STYLE_DEFAULT);
+
+	if (fo_subpixel_order == NULL)
 		cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_DEFAULT);
-	else {
-		if (strcmp (subpixel_order, "rgb") == 0)
-			cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_RGB);
-		else if (strcmp (subpixel_order, "bgr") == 0)
-			cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_BGR);
-		else if (strcmp (subpixel_order, "vrgb") == 0)
-			cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_VRGB);
-		else if (strcmp (subpixel_order, "vbgr") == 0)
-			cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_VBGR);
-		else
-			cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_DEFAULT);
-	}
-	g_free (antialiasing);
-	g_free (hinting);
-	g_free (subpixel_order);
-	g_object_unref (gconf);
+	else if (strcmp (fo_subpixel_order, "rgb") == 0)
+		cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_RGB);
+	else if (strcmp (fo_subpixel_order, "bgr") == 0)
+		cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_BGR);
+	else if (strcmp (fo_subpixel_order, "vrgb") == 0)
+		cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_VRGB);
+	else if (strcmp (fo_subpixel_order, "vbgr") == 0)
+		cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_VBGR);
+	else
+		cairo_font_options_set_subpixel_order (font_options, CAIRO_SUBPIXEL_ORDER_DEFAULT);
+
+	g_static_mutex_unlock (&fo_lock);
+
 	return font_options;
 }
 
@@ -1091,10 +1294,10 @@ get_lock_filename (void)
 gboolean
 e_file_lock_create ()
 {
-	const char *fname = get_lock_filename ();
+	const gchar *fname = get_lock_filename ();
 	gboolean status = FALSE;
 
-	int fd = g_creat (fname, S_IRUSR|S_IWUSR);
+	gint fd = g_creat (fname, S_IRUSR|S_IWUSR);
 	if (fd == -1){
 		g_warning ("Lock file '%s' creation failed, error %d\n", fname, errno);
 	} else {
@@ -1108,17 +1311,17 @@ e_file_lock_create ()
 void
 e_file_lock_destroy ()
 {
-	const char *fname = get_lock_filename ();
+	const gchar *fname = get_lock_filename ();
 
 	if (g_unlink (fname) == -1){
 		g_warning ("Lock destroy: failed to unlink file '%s'!",fname);
 	}
 }
 
-gboolean 
+gboolean
 e_file_lock_exists ()
 {
-	const char *fname = get_lock_filename ();
+	const gchar *fname = get_lock_filename ();
 
 	return g_file_test (fname, G_FILE_TEST_EXISTS);
 }
@@ -1131,10 +1334,10 @@ e_file_lock_exists ()
  *
  * Guesses mime_type for the given filename.
  **/
-char *
-e_util_guess_mime_type (const char *filename, gboolean localfile)
+gchar *
+e_util_guess_mime_type (const gchar *filename, gboolean localfile)
 {
-	char *mime_type = NULL;
+	gchar *mime_type = NULL;
 
 	g_return_val_if_fail (filename != NULL, NULL);
 
@@ -1152,7 +1355,7 @@ e_util_guess_mime_type (const char *filename, gboolean localfile)
 			fi = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE, G_FILE_QUERY_INFO_NONE, NULL, NULL);
 			if (fi) {
 				mime_type = g_content_type_get_mime_type (g_file_info_get_content_type (fi));
-	
+
 				g_object_unref (fi);
 			}
 
@@ -1182,11 +1385,11 @@ e_util_guess_mime_type (const char *filename, gboolean localfile)
  *
  * Converts local file name to URI.
  **/
-char *
-e_util_filename_to_uri (const char *filename)
+gchar *
+e_util_filename_to_uri (const gchar *filename)
 {
 	GFile *file;
-	char *uri = NULL;
+	gchar *uri = NULL;
 
 	g_return_val_if_fail (filename != NULL, NULL);
 
@@ -1207,11 +1410,11 @@ e_util_filename_to_uri (const char *filename)
  *
  * Converts URI to local file name. NULL indicates no such local file name exists.
  **/
-char *
-e_util_uri_to_filename (const char *uri)
+gchar *
+e_util_uri_to_filename (const gchar *uri)
 {
 	GFile *file;
-	char *filename = NULL;
+	gchar *filename = NULL;
 
 	g_return_val_if_fail (uri != NULL, NULL);
 
@@ -1238,7 +1441,7 @@ e_util_uri_to_filename (const char *uri)
  * Mount point should be already mounted when calling this function.
  **/
 gboolean
-e_util_read_file (const char *filename, gboolean filename_is_uri, char **buffer, gsize *read, GError **error)
+e_util_read_file (const gchar *filename, gboolean filename_is_uri, gchar **buffer, gsize *read, GError **error)
 {
 	GFile *file;
 	GFileInfo *info;
@@ -1263,10 +1466,10 @@ e_util_read_file (const char *filename, gboolean filename_is_uri, char **buffer,
 
 	if (!err && info) {
 		guint64 sz;
-		char *buff;
+		gchar *buff;
 
 		sz = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
-		buff = g_malloc (sizeof (char) * sz);
+		buff = g_malloc (sizeof (gchar) * sz);
 
 		if (buff) {
 			GInputStream *stream;
@@ -1278,7 +1481,7 @@ e_util_read_file (const char *filename, gboolean filename_is_uri, char **buffer,
 
 				if (err)
 					res = FALSE;
-				
+
 				if (res)
 					*buffer = buff;
 				else
@@ -1313,7 +1516,7 @@ e_util_get_category_filter_options (void)
 
 	clist = e_categories_get_list ();
 	for (l = clist; l; l = l->next) {
-		const char *cname = l->data;
+		const gchar *cname = l->data;
 		struct _filter_option *fo = g_new0 (struct _filter_option, 1);
 
 		fo->title = g_strdup (cname);
@@ -1325,3 +1528,33 @@ e_util_get_category_filter_options (void)
 
 	return g_slist_reverse (res);
 }
+
+static gpointer
+e_camel_object_copy (gpointer camel_object)
+{
+	if (CAMEL_IS_OBJECT (camel_object))
+		camel_object_ref (camel_object);
+
+	return camel_object;
+}
+
+static void
+e_camel_object_free (gpointer camel_object)
+{
+	if (CAMEL_IS_OBJECT (camel_object))
+		camel_object_unref (camel_object);
+}
+
+GType
+e_camel_object_get_type (void)
+{
+	static GType type = 0;
+
+	if (G_UNLIKELY (type == 0))
+		type = g_boxed_type_register_static (
+			"ECamelObject",
+			(GBoxedCopyFunc) e_camel_object_copy,
+			(GBoxedFreeFunc) e_camel_object_free);
+
+	return type;
+}
