@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -80,7 +80,7 @@ filter_code_class_init (FilterCodeClass *klass)
 static void
 filter_code_init (FilterCode *fc)
 {
-	((FilterInput *) fc)->type = (char *)xmlStrdup ((const unsigned char *)"code");
+	((FilterInput *) fc)->type = (gchar *)xmlStrdup ((const guchar *)"code");
 }
 
 static void
@@ -98,9 +98,16 @@ filter_code_finalise (GObject *obj)
  * Return value: A new #FilterCode object.
  **/
 FilterCode *
-filter_code_new (void)
+filter_code_new (gboolean raw_code)
 {
-	return (FilterCode *) g_object_new (FILTER_TYPE_CODE, NULL, NULL);
+	FilterCode *fc = (FilterCode *) g_object_new (FILTER_TYPE_CODE, NULL, NULL);
+
+	if (fc && raw_code) {
+		xmlFree (((FilterInput *) fc)->type);
+		((FilterInput *) fc)->type = (gchar *)xmlStrdup ((const guchar *)"rawcode");
+	}
+
+	return fc;
 }
 
 /* here, the string IS the code */
@@ -109,14 +116,19 @@ build_code (FilterElement *fe, GString *out, struct _FilterPart *ff)
 {
 	GList *l;
 	FilterInput *fi = (FilterInput *)fe;
+	gboolean is_rawcode = fi && fi->type && g_str_equal (fi->type, "rawcode");
+
+	if (!is_rawcode)
+		g_string_append(out, "(match-all ");
 
-	g_string_append(out, "(match-all ");
 	l = fi->values;
 	while (l) {
-		g_string_append(out, (char *)l->data);
+		g_string_append(out, (gchar *)l->data);
 		l = g_list_next(l);
 	}
-	g_string_append(out, ")");
+
+	if (!is_rawcode)
+		g_string_append (out, ")");
 }
 
 /* and we have no value */
