@@ -1,26 +1,26 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2002 Ximian Inc.
- *
- *  Authors: Not Zed <notzed@lostzed.mmc.com.au>
- *           Jeffrey Stedfast <fejj@ximian.com>
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Not Zed <notzed@lostzed.mmc.com.au>
+ *      Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -35,14 +35,15 @@
 #include "e-util/e-util-private.h"
 #include "rule-editor.h"
 
-static int enable_undo = 0;
+static gint enable_undo = 0;
 
 #define d(x)
 
-static void set_source (RuleEditor *re, const char *source);
+static void set_source (RuleEditor *re, const gchar *source);
 static void set_sensitive (RuleEditor *re);
 static FilterRule *create_rule (RuleEditor *re);
 
+static gboolean update_selected_rule (RuleEditor *re);
 static void cursor_changed (GtkTreeView *treeview, RuleEditor *re);
 
 static void rule_editor_class_init (RuleEditorClass *klass);
@@ -163,18 +164,19 @@ rule_editor_destroy (GtkObject *obj)
  * Return value: A new #RuleEditor object.
  **/
 RuleEditor *
-rule_editor_new (RuleContext *rc, const char *source, const char *label)
+rule_editor_new (RuleContext *rc, const gchar *source, const gchar *label)
 {
 	RuleEditor *re = (RuleEditor *) g_object_new (RULE_TYPE_EDITOR, NULL);
 	GladeXML *gui;
-	char *filter_glade = g_build_filename (EVOLUTION_GLADEDIR,
+	gchar *filter_glade = g_build_filename (EVOLUTION_GLADEDIR,
 					       "filter.glade",
 					       NULL);
 
 	gui = glade_xml_new (filter_glade, "rule_editor", NULL);
 	g_free (filter_glade);
 	rule_editor_construct (re, rc, gui, source, label);
-        gtk_widget_hide(glade_xml_get_widget (gui, "filter_source"));
+	gtk_widget_hide(glade_xml_get_widget (gui, "label17"));
+	gtk_widget_hide(glade_xml_get_widget (gui, "filter_source"));
 	g_object_unref (gui);
 
 	return re;
@@ -189,7 +191,7 @@ rule_editor_set_sensitive (RuleEditor *re)
 
 /* used internally by implementations */
 void
-rule_editor_set_source (RuleEditor *re, const char *source)
+rule_editor_set_source (RuleEditor *re, const gchar *source)
 {
 	RULE_EDITOR_GET_CLASS (re)->set_source (re, source);
 }
@@ -229,7 +231,7 @@ editor_destroy (RuleEditor *re, GObject *deadbeef)
 }
 
 static void
-rule_editor_add_undo (RuleEditor *re, int type, FilterRule *rule, int rank, int newrank)
+rule_editor_add_undo (RuleEditor *re, gint type, FilterRule *rule, gint rank, gint newrank)
 {
         RuleEditorUndo *undo;
 
@@ -297,7 +299,7 @@ rule_editor_play_undo (RuleEditor *re)
 }
 
 static void
-editor_response (GtkWidget *dialog, int button, RuleEditor *re)
+editor_response (GtkWidget *dialog, gint button, RuleEditor *re)
 {
 	if (button == GTK_RESPONSE_CANCEL) {
 		if (enable_undo)
@@ -318,7 +320,7 @@ editor_response (GtkWidget *dialog, int button, RuleEditor *re)
 }
 
 static void
-add_editor_response (GtkWidget *dialog, int button, RuleEditor *re)
+add_editor_response (GtkWidget *dialog, gint button, RuleEditor *re)
 {
 	GtkTreeSelection *selection;
 	GtkTreePath *path;
@@ -397,12 +399,12 @@ rule_add (GtkWidget *widget, RuleEditor *re)
 }
 
 static void
-edit_editor_response (GtkWidget *dialog, int button, RuleEditor *re)
+edit_editor_response (GtkWidget *dialog, gint button, RuleEditor *re)
 {
 	FilterRule *rule;
 	GtkTreePath *path;
 	GtkTreeIter iter;
-	int pos;
+	gint pos;
 
 	if (button == GTK_RESPONSE_OK) {
 		if (!filter_rule_validate (re->edit)) {
@@ -442,6 +444,8 @@ rule_edit (GtkWidget *widget, RuleEditor *re)
 {
 	GtkWidget *rules;
 
+	update_selected_rule(re);
+
 	if (re->current == NULL || re->edit != NULL)
 		return;
 
@@ -481,7 +485,9 @@ rule_delete (GtkWidget *widget, RuleEditor *re)
 	GtkTreeSelection *selection;
 	GtkTreePath *path;
 	GtkTreeIter iter;
-	int pos, len;
+	gint pos, len;
+
+	update_selected_rule(re);
 
 	d(printf ("delete rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
@@ -530,7 +536,7 @@ rule_delete (GtkWidget *widget, RuleEditor *re)
 }
 
 static void
-rule_move (RuleEditor *re, int from, int to)
+rule_move (RuleEditor *re, gint from, gint to)
 {
 	GtkTreeSelection *selection;
 	GtkTreePath *path;
@@ -574,7 +580,9 @@ rule_move (RuleEditor *re, int from, int to)
 static void
 rule_top (GtkWidget *widget, RuleEditor *re)
 {
-	int pos;
+	gint pos;
+
+	update_selected_rule(re);
 
 	d(printf ("top rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
@@ -585,7 +593,9 @@ rule_top (GtkWidget *widget, RuleEditor *re)
 static void
 rule_up (GtkWidget *widget, RuleEditor *re)
 {
-	int pos;
+	gint pos;
+
+	update_selected_rule(re);
 
 	d(printf ("up rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
@@ -596,7 +606,9 @@ rule_up (GtkWidget *widget, RuleEditor *re)
 static void
 rule_down (GtkWidget *widget, RuleEditor *re)
 {
-	int pos;
+	gint pos;
+
+	update_selected_rule(re);
 
 	d(printf ("down rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
@@ -607,10 +619,12 @@ rule_down (GtkWidget *widget, RuleEditor *re)
 static void
 rule_bottom (GtkWidget *widget, RuleEditor *re)
 {
-	int pos;
-	int index = -1, count = 0;
+	gint pos;
+	gint index = -1, count = 0;
 	FilterRule *rule = NULL;
 
+	update_selected_rule(re);
+
 	d(printf ("bottom rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
 	/* There's probably a better/faster way to get the count of the list here */
@@ -625,7 +639,7 @@ rule_bottom (GtkWidget *widget, RuleEditor *re)
 }
 
 static struct {
-	char *name;
+	const gchar *name;
 	GCallback func;
 } edit_buttons[] = {
 	{ "rule_add",    G_CALLBACK (rule_add)    },
@@ -641,7 +655,7 @@ static void
 set_sensitive (RuleEditor *re)
 {
 	FilterRule *rule = NULL;
-	int index = -1, count = 0;
+	gint index = -1, count = 0;
 
 	while ((rule = rule_context_next_rule (re->context, rule, re->source))) {
 		if (rule == re->current)
@@ -669,8 +683,8 @@ dialog_rule_changed (FilterRule *fr, GtkWidget *dialog)
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, fr && fr->parts);
 }
 
-static void
-cursor_changed (GtkTreeView *treeview, RuleEditor *re)
+static gboolean
+update_selected_rule (RuleEditor *re)
 {
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
@@ -679,7 +693,16 @@ cursor_changed (GtkTreeView *treeview, RuleEditor *re)
 	selection = gtk_tree_view_get_selection (re->list);
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 		gtk_tree_model_get (GTK_TREE_MODEL (re->model), &iter, 1, &re->current, -1);
+		return TRUE;
+	}
 
+	return FALSE;
+}
+
+static void
+cursor_changed (GtkTreeView *treeview, RuleEditor *re)
+{
+	if (update_selected_rule(re)) {
 		g_return_if_fail (re->current);
 
 		rule_editor_set_sensitive (re);
@@ -702,7 +725,7 @@ double_click (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *colum
 }
 
 static void
-set_source (RuleEditor *re, const char *source)
+set_source (RuleEditor *re, const gchar *source)
 {
 	FilterRule *rule = NULL;
 	GtkTreeIter iter;
@@ -723,7 +746,7 @@ set_source (RuleEditor *re, const char *source)
 }
 
 static void
-rule_able_toggled (GtkCellRendererToggle *renderer, char *arg1, gpointer user_data)
+rule_able_toggled (GtkCellRendererToggle *renderer, gchar *arg1, gpointer user_data)
 {
 	GtkWidget *table = user_data;
 	GtkTreeSelection *selection;
@@ -749,11 +772,11 @@ rule_able_toggled (GtkCellRendererToggle *renderer, char *arg1, gpointer user_da
 	gtk_tree_path_free (path);
 }
 
-GtkWidget *rule_editor_treeview_new (char *widget_name, char *string1, char *string2,
-				     int int1, int int2);
+GtkWidget *rule_editor_treeview_new (gchar *widget_name, gchar *string1, gchar *string2,
+				     gint int1, gint int2);
 
 GtkWidget *
-rule_editor_treeview_new (char *widget_name, char *string1, char *string2, int int1, int int2)
+rule_editor_treeview_new (gchar *widget_name, gchar *string1, gchar *string2, gint int1, gint int2)
 {
 	GtkWidget *table, *scrolled;
 	GtkTreeSelection *selection;
@@ -803,11 +826,11 @@ rule_editor_treeview_new (char *widget_name, char *string1, char *string2, int i
 }
 
 void
-rule_editor_construct (RuleEditor *re, RuleContext *context, GladeXML *gui, const char *source, const char *label)
+rule_editor_construct (RuleEditor *re, RuleContext *context, GladeXML *gui, const gchar *source, const gchar *label)
 {
 	GtkWidget *w;
-	int i;
-	char *tmp;
+	gint i;
+	gchar *tmp;
 
 	re->context = context;
 	g_object_ref (context);
