@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -52,19 +52,19 @@ struct _ESearchingTokenizerClass {
 
 GType e_searching_tokenizer_get_type (void);
 
-HTMLTokenizer *e_searching_tokenizer_new (void);
+ESearchingTokenizer *e_searching_tokenizer_new (void);
 
 /* For now, just a simple API */
 
-void e_searching_tokenizer_set_primary_search_string    (ESearchingTokenizer *, const char *);
-void e_searching_tokenizer_add_primary_search_string    (ESearchingTokenizer *, const char *);
+void e_searching_tokenizer_set_primary_search_string    (ESearchingTokenizer *, const gchar *);
+void e_searching_tokenizer_add_primary_search_string    (ESearchingTokenizer *, const gchar *);
 void e_searching_tokenizer_set_primary_case_sensitivity (ESearchingTokenizer *, gboolean is_case_sensitive);
 
-void e_searching_tokenizer_set_secondary_search_string    (ESearchingTokenizer *, const char *);
-void e_searching_tokenizer_add_secondary_search_string (ESearchingTokenizer *st, const char *search_str);
+void e_searching_tokenizer_set_secondary_search_string    (ESearchingTokenizer *, const gchar *);
+void e_searching_tokenizer_add_secondary_search_string (ESearchingTokenizer *st, const gchar *search_str);
 void e_searching_tokenizer_set_secondary_case_sensitivity (ESearchingTokenizer *, gboolean is_case_sensitive);
 
 
-int e_searching_tokenizer_match_count          (ESearchingTokenizer *);
+gint e_searching_tokenizer_match_count          (ESearchingTokenizer *);
 
 #endif /* __E_SEARCHING_TOKENIZER_H__ */
