@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Michael Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -29,8 +29,6 @@
 
 #include <gtk/gtk.h>
 
-#include <libgnome/gnome-url.h>
-
 #include "em-config.h"
 #include "libedataserver/e-msgport.h"
 #include "em-utils.h"
@@ -126,7 +124,7 @@ emp_target_free(EConfig *ep, EConfigTarget *t)
 }
 
 static void
-emp_account_changed(struct _EAccount *ea, int id, EMConfig *emc)
+emp_account_changed(struct _EAccount *ea, gint id, EMConfig *emc)
 {
 	e_config_target_changed((EConfig *)emc, E_CONFIG_TARGET_CHANGED_STATE);
 }
@@ -182,7 +180,7 @@ em_config_get_type(void)
 	return type;
 }
 
-EMConfig *em_config_new(int type, const char *menuid)
+EMConfig *em_config_new(gint type, const gchar *menuid)
 {
 	EMConfig *emp = g_object_new(em_config_get_type(), NULL);
 
@@ -192,7 +190,7 @@ EMConfig *em_config_new(int type, const char *menuid)
 }
 
 EMConfigTargetFolder *
-em_config_target_new_folder(EMConfig *emp, struct _CamelFolder *folder, const char *uri)
+em_config_target_new_folder(EMConfig *emp, struct _CamelFolder *folder, const gchar *uri)
 {
 	EMConfigTargetFolder *t = e_config_target_new(&emp->config, EM_CONFIG_TARGET_FOLDER, sizeof(*t));
 
@@ -255,7 +253,7 @@ em_config_target_new_account(EMConfig *emp, struct _EAccount *account)
 
 */
 
-static void *emph_parent_class;
+static gpointer emph_parent_class;
 #define emph ((EMConfigHook *)eph)
 
 static const EConfigHookTargetMask emph_no_masks[] = {
@@ -280,7 +278,7 @@ emph_finalise(GObject *o)
 static void
 emph_class_init(EPluginHookClass *klass)
 {
-	int i;
+	gint i;
 
 	((GObjectClass *)klass)->finalize = emph_finalise;
 	((EPluginHookClass *)klass)->id = "org.gnome.evolution.mail.config:1.0";
