@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -79,6 +79,7 @@
 #include "e-util/e-error.h"
 #include "e-util/e-util-private.h"
 #include "e-util/e-util-labels.h"
+#include "e-mail-search-bar.h"
 #include "em-utils.h"
 #include "em-composer-utils.h"
 #include "em-format-html-display.h"
@@ -106,6 +107,7 @@ CamelStore *vfolder_store; /* the 1 static vfolder store */
 struct _EMFolderBrowserPrivate {
 	GtkWidget *preview;	/* container for message display */
 	GtkWidget *scroll;
+	GtkWidget *search_bar;
 
 	GtkWidget *subscribe_editor;
 
@@ -119,7 +121,7 @@ struct _EMFolderBrowserPrivate {
 	guint vpane_resize_id;
 	guint list_built_id;	/* hook onto list-built for delayed 'select first unread' stuff */
 
-	char *select_uid;
+	gchar *select_uid;
 	guint folder_changed_id;
 
 	guint show_wide:1;
@@ -134,23 +136,23 @@ struct _EMFolderBrowserPrivate {
 
 typedef struct EMFBSearchBarItem {
 	ESearchBarItem search;
-	char *image;
+	const gchar *image;
 } EMFBSearchBarItem;
 
-static void emfb_activate(EMFolderView *emfv, BonoboUIComponent *uic, int state);
-static void emfb_set_folder(EMFolderView *emfv, CamelFolder *folder, const char *uri);
-static void emfb_set_search_folder(EMFolderView *emfv, CamelFolder *folder, const char *uri);
+static void emfb_activate(EMFolderView *emfv, BonoboUIComponent *uic, gint state);
+static void emfb_set_folder(EMFolderView *emfv, CamelFolder *folder, const gchar *uri);
+static void emfb_set_search_folder(EMFolderView *emfv, CamelFolder *folder, const gchar *uri);
 
 /* FilterBar stuff ... */
-static void emfb_search_config_search(EFilterBar *efb, FilterRule *rule, int id, const char *query, void *data);
-static void emfb_search_menu_activated(ESearchBar *esb, int id, EMFolderBrowser *emfb);
+static void emfb_search_config_search(EFilterBar *efb, FilterRule *rule, gint id, const gchar *query, gpointer data);
+static void emfb_search_menu_activated(ESearchBar *esb, gint id, EMFolderBrowser *emfb);
 static void emfb_search_search_activated(ESearchBar *esb, EMFolderBrowser *emfb);
 static void emfb_search_search_cleared(ESearchBar *esb);
 
-static int emfb_list_key_press(ETree *tree, int row, ETreePath path, int col, GdkEvent *ev, EMFolderBrowser *emfb);
-static void emfb_list_message_selected (MessageList *ml, const char *uid, EMFolderBrowser *emfb);
+static gint emfb_list_key_press(ETree *tree, gint row, ETreePath path, gint col, GdkEvent *ev, EMFolderBrowser *emfb);
+static void emfb_list_message_selected (MessageList *ml, const gchar *uid, EMFolderBrowser *emfb);
 
-static void emfb_expand_all_threads(BonoboUIComponent *uid, void *data, const char *path);
+static void emfb_expand_all_threads(BonoboUIComponent *uid, gpointer data, const gchar *path);
 
 static const EMFolderViewEnable emfb_enable_map[] = {
 	{ "EditInvertSelection", EM_POPUP_SELECT_FOLDER },
@@ -164,7 +166,6 @@ static const EMFolderViewEnable emfb_enable_map[] = {
 	{ "FolderRename", EM_POPUP_SELECT_FOLDER },
 	{ "FolderRefresh", EM_POPUP_SELECT_FOLDER },
 	{ "ChangeFolderProperties", EM_POPUP_SELECT_FOLDER },
-	{ "MailPost", EM_POPUP_SELECT_FOLDER },
 	{ "MessageMarkAllAsRead", EM_POPUP_SELECT_FOLDER },
 	{ "ViewHideSelected", EM_POPUP_SELECT_MANY },
 	{ "ViewThreadsCollapseAll", EM_FOLDER_VIEW_SELECT_THREADED},
@@ -181,7 +182,7 @@ enum {
 static guint folder_browser_signals [LAST_SIGNAL] = {0, };
 
 enum {
-	ESB_SAVE,
+	ESB_SAVE
 };
 
 static ESearchBarItem emfb_search_items[] = {
@@ -190,7 +191,7 @@ static ESearchBarItem emfb_search_items[] = {
 	E_FILTERBAR_SAVE,
 	E_FILTERBAR_EDIT,
 	{ NULL, 0, 0 },
-	{ N_("C_reate Search Folder From Search..."), ESB_SAVE, 0},
+	{ (gchar *) N_("C_reate Search Folder From Search..."), ESB_SAVE, 0},
 	{ NULL, -1, 0 }
 };
 
@@ -215,24 +216,22 @@ enum {
 
 /* Options for View */
 static EMFBSearchBarItem emfb_view_items[] = {
-	{{ N_("All Messages"), VIEW_ALL_MESSAGES, 0 }, NULL},
-	{{ N_("Unread Messages"), VIEW_UNREAD_MESSAGES, 0 }, "mail-unread"},
+	{{ (gchar *) N_("All Messages"), VIEW_ALL_MESSAGES, 0 }, NULL},
+	{{ (gchar *) N_("Unread Messages"), VIEW_UNREAD_MESSAGES, 0 }, "mail-unread"},
 	{{ NULL, 0, 0 }, NULL},
-	{{ N_("No Label"),VIEW_NO_LABEL, 0 }, NULL},
+	{{ (gchar *) N_("No Label"),VIEW_NO_LABEL, 0 }, NULL},
 	{{ NULL, -1, 0 }, NULL}
 };
 
 /* TODO: Following options should be  customizable */
 static EMFBSearchBarItem temp_view_items[] = {
 	{{ NULL, 0, 0 }, NULL},
-	{{ N_("Read Messages"), VIEW_READ_MESSAGES, 0 }, "mail-read"},
-	{{ N_("Recent Messages"), VIEW_RECENT_MESSAGES, 0 }, NULL},
-	{{ N_("Last 5 Days' Messages"), VIEW_LAST_FIVE_DAYS, 0 }, NULL},
-	{{ N_("Messages with Attachments"), VIEW_WITH_ATTACHMENTS, 0 }, "mail-attachment"},
-	{{ N_("Important Messages"), VIEW_MESSAGES_MARKED_AS_IMPORTANT, 0}, "emblem-important"},
-	{{ N_("Messages Not Junk"), VIEW_NOT_JUNK, 0 }, "mail-mark-notjunk"},
-/* 	{ NULL, 0, NULL }, */
-/* 	{ N_("Customize"), NOT_IMPLEMENTED, NULL }, */
+	{{ (gchar *) N_("Read Messages"), VIEW_READ_MESSAGES, 0 }, "mail-read"},
+	{{ (gchar *) N_("Recent Messages"), VIEW_RECENT_MESSAGES, 0 }, NULL},
+	{{ (gchar *) N_("Last 5 Days' Messages"), VIEW_LAST_FIVE_DAYS, 0 }, NULL},
+	{{ (gchar *) N_("Messages with Attachments"), VIEW_WITH_ATTACHMENTS, 0 }, "mail-attachment"},
+	{{ (gchar *) N_("Important Messages"), VIEW_MESSAGES_MARKED_AS_IMPORTANT, 0}, "emblem-important"},
+	{{ (gchar *) N_("Messages Not Junk"), VIEW_NOT_JUNK, 0 }, "mail-mark-notjunk"},
 	{{ NULL, -1, 0 }, NULL}
 };
 
@@ -240,7 +239,6 @@ static ESearchBarItem emfb_search_scope_items[] = {
 	E_FILTERBAR_CURRENT_FOLDER,
 	E_FILTERBAR_CURRENT_ACCOUNT,
 	E_FILTERBAR_ALL_ACCOUNTS,
-	E_FILTERBAR_CURRENT_MESSAGE,
 	{ NULL, -1, 0 }
 };
 
@@ -296,11 +294,11 @@ generate_viewoption_menu (GtkWidget *emfv)
 
 	for (i = 0; emfb_view_items[i].search.id != -1; ++i) {
 		if (emfb_view_items[i].search.text) {
-			char *str;
+			gchar *str;
 
 			str = e_str_without_underscores (_(emfb_view_items[i].search.text));
 			menu_item = gtk_image_menu_item_new_with_label (str);
- 			if (emfb_view_items[i].image) {
+			if (emfb_view_items[i].image) {
 				GtkWidget *image;
 
 				image = gtk_image_new_from_icon_name (
@@ -327,7 +325,7 @@ generate_viewoption_menu (GtkWidget *emfv)
 	for (l = mail_config_get_labels (), i = 0; l; l = l->next, i++) {
 		EUtilLabel *label = l->data;
 		if (label->name && *(label->name)) {
-			char *str;
+			gchar *str;
 			GdkPixmap *pixmap;
 			GdkColor colour;
 			GdkGC *gc;
@@ -361,7 +359,7 @@ generate_viewoption_menu (GtkWidget *emfv)
 
 	for (i = 0; temp_view_items[i].search.id != -1; ++i) {
 		if (temp_view_items[i].search.text) {
-			char *str;
+			gchar *str;
 			str = e_str_without_underscores (_(temp_view_items[i].search.text));
 			menu_item = gtk_image_menu_item_new_with_label (str);
 			if (temp_view_items[i].image) {
@@ -425,7 +423,7 @@ emfb_realize (GtkWidget *widget)
 {
 	GtkWidget *menu;
 	EMFolderBrowser *emfb = (EMFolderBrowser *)widget;
-	int id;
+	gint id;
 
 	menu = generate_viewoption_menu (widget);
 	id = e_search_bar_get_viewitem_id (E_SEARCH_BAR (emfb->search));
@@ -486,6 +484,7 @@ emfb_init(GObject *o)
 	EMFolderBrowser *emfb = (EMFolderBrowser *)o;
 	RuleContext *search_context = mail_component_peek_search_context (mail_component_peek ());
 	struct _EMFolderBrowserPrivate *p;
+	GtkWidget *html;
 
 	EMEvent *eme;
 	EMEventTargetFolderBrowser *target;
@@ -513,11 +512,11 @@ emfb_init(GObject *o)
 							       "evolution-mail-message.xml",
 							       NULL));
 
-	emfb->view.enable_map = g_slist_prepend(emfb->view.enable_map, (void *)emfb_enable_map);
+	emfb->view.enable_map = g_slist_prepend(emfb->view.enable_map, (gpointer)emfb_enable_map);
 
 	if (search_context) {
-		const char *systemrules = g_object_get_data (G_OBJECT (search_context), "system");
-		const char *userrules = g_object_get_data (G_OBJECT (search_context), "user");
+		const gchar *systemrules = g_object_get_data (G_OBJECT (search_context), "system");
+		const gchar *userrules = g_object_get_data (G_OBJECT (search_context), "user");
 		EFilterBar *efb;
 		GConfClient *gconf;
 
@@ -525,10 +524,9 @@ emfb_init(GObject *o)
 		efb = (EFilterBar *)emfb->search;
 		efb->account_search_vf = NULL;
 		efb->all_account_search_vf = NULL;
- 		efb->account_search_cancel = NULL;
+		efb->account_search_cancel = NULL;
 		e_search_bar_set_menu ((ESearchBar *)emfb->search, emfb_search_items);
 		e_search_bar_set_scopeoption ((ESearchBar *)emfb->search, emfb_search_scope_items);
-		e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, FALSE);
 		emfb->priv->scope_restricted = TRUE;
 		g_signal_connect(emfb, "realize", G_CALLBACK(emfb_realize), NULL);
 		gtk_widget_show((GtkWidget *)emfb->search);
@@ -562,14 +560,21 @@ emfb_init(GObject *o)
 	gtk_scrolled_window_set_shadow_type((GtkScrolledWindow *)p->scroll, GTK_SHADOW_IN);
 	gtk_widget_show(p->scroll);
 
-	p->preview = gtk_vbox_new (FALSE, 6);
-	gtk_container_add((GtkContainer *)p->scroll, (GtkWidget *)emfb->view.preview->formathtml.html);
-	gtk_widget_show((GtkWidget *)emfb->view.preview->formathtml.html);
+	html = GTK_WIDGET (emfb->view.preview->formathtml.html);
+
+	p->preview = gtk_vbox_new (FALSE, 1);
+	p->search_bar = e_mail_search_bar_new (GTK_HTML (html));
+	gtk_container_add((GtkContainer *)p->scroll, html);
+	gtk_widget_show(html);
 	gtk_box_pack_start ((GtkBox *)p->preview, p->scroll, TRUE, TRUE, 0);
-	gtk_box_pack_start ((GtkBox *)p->preview, em_format_html_get_search_dialog (emfb->view.preview), FALSE, FALSE, 0);
+	gtk_box_pack_start ((GtkBox *)p->preview, p->search_bar, FALSE, FALSE, 0);
 	gtk_paned_pack2 (GTK_PANED (emfb->vpane), p->preview, TRUE, FALSE);
 	gtk_widget_show(p->preview);
 
+	g_signal_connect_swapped (
+		p->search_bar, "changed",
+		G_CALLBACK (em_format_redraw), emfb->view.preview);
+
 	/** @HookPoint-EMFolderBrower: Folder Browser
 	 * @Id: emfb.created
 	 * @Class: org.gnome.evolution.mail.events:1.0
@@ -638,6 +643,14 @@ emfb_destroy(GtkObject *o)
 	((GtkObjectClass *)emfb_parent)->destroy(o);
 }
 
+static void
+emfb_show_search_bar (EMFolderView *folder_view)
+{
+	EMFolderBrowser *browser = (EMFolderBrowser *) folder_view;
+
+	gtk_widget_show (browser->priv->search_bar);
+}
+
 static void
 emfb_class_init(GObjectClass *klass)
 {
@@ -667,6 +680,7 @@ emfb_class_init(GObjectClass *klass)
 	((GtkObjectClass *)klass)->destroy = emfb_destroy;
 	((EMFolderViewClass *)klass)->set_folder = emfb_set_folder;
 	((EMFolderViewClass *)klass)->activate = emfb_activate;
+	((EMFolderViewClass *)klass)->show_search_bar = emfb_show_search_bar;
 }
 
 GType
@@ -712,7 +726,6 @@ void em_folder_browser_show_preview(EMFolderBrowser *emfb, gboolean state)
 	if ((emfb->view.preview_active ^ state) == 0
 	    || emfb->view.list == NULL) {
 		if (state && emfb->priv->scope_restricted && emfb->view.list->cursor_uid && *(emfb->view.list->cursor_uid)) {
-			e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, TRUE);
 			emfb->priv->scope_restricted = FALSE;
 		}
 
@@ -723,7 +736,7 @@ void em_folder_browser_show_preview(EMFolderBrowser *emfb, gboolean state)
 
 	if (state) {
 		GConfClient *gconf = mail_config_get_gconf_client ();
-		int paned_size /*, y*/;
+		gint paned_size /*, y*/;
 
 		paned_size = gconf_client_get_int(gconf, emfb->priv->show_wide ? "/apps/evolution/mail/display/hpaned_size":"/apps/evolution/mail/display/paned_size", NULL);
 
@@ -732,9 +745,8 @@ void em_folder_browser_show_preview(EMFolderBrowser *emfb, gboolean state)
 		gtk_widget_show (GTK_WIDGET (emfb->priv->preview));
 
 		if (emfb->view.list->cursor_uid) {
-			char *uid = g_alloca(strlen(emfb->view.list->cursor_uid)+1);
+			gchar *uid = g_alloca(strlen(emfb->view.list->cursor_uid)+1);
 
-			e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, TRUE);
 			emfb->priv->scope_restricted = FALSE;
 			strcpy(uid, emfb->view.list->cursor_uid);
 			em_folder_view_set_message(&emfb->view, uid, FALSE);
@@ -750,7 +762,6 @@ void em_folder_browser_show_preview(EMFolderBrowser *emfb, gboolean state)
 		emfb->view.displayed_uid = NULL;
 
 		gtk_widget_hide(emfb->priv->preview);
-		e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, FALSE);
 		emfb->priv->scope_restricted = TRUE;
 		/*
 		mail_display_set_message (emfb->mail_display, NULL, NULL, NULL);
@@ -768,7 +779,7 @@ gboolean em_folder_browser_get_wide (EMFolderBrowser *emfb)
 void em_folder_browser_show_wide(EMFolderBrowser *emfb, gboolean state)
 {
 	GtkWidget *w;
-	int paned_size;
+	gint paned_size;
 
 	if ((emfb->priv->show_wide &&  state)
 	    || emfb->view.list == NULL) {
@@ -807,7 +818,7 @@ void em_folder_browser_show_wide(EMFolderBrowser *emfb, gboolean state)
 /* FIXME: Ugh! */
 
 static void
-emfb_search_menu_activated(ESearchBar *esb, int id, EMFolderBrowser *emfb)
+emfb_search_menu_activated(ESearchBar *esb, gint id, EMFolderBrowser *emfb)
 {
 	EFilterBar *efb = (EFilterBar *)esb;
 
@@ -818,7 +829,7 @@ emfb_search_menu_activated(ESearchBar *esb, int id, EMFolderBrowser *emfb)
 		d(printf("Save vfolder\n"));
 		if (efb->current_query) {
 			FilterRule *rule;
-			char *name, *text;
+			gchar *name, *text;
 
 			/* ensures vfolder is running */
 			vfolder_load_storage ();
@@ -839,12 +850,14 @@ emfb_search_menu_activated(ESearchBar *esb, int id, EMFolderBrowser *emfb)
 }
 
 static void
-emfb_search_config_search(EFilterBar *efb, FilterRule *rule, int id, const char *query, void *data)
+emfb_search_config_search(EFilterBar *efb, FilterRule *rule, gint id, const gchar *query, gpointer data)
 {
 	EMFolderBrowser *emfb = data;
+	EMailSearchBar *search_bar;
+	ESearchingTokenizer *tokenizer;
 	GList *partl;
 	struct _camel_search_words *words;
-	int i;
+	gint i;
 	GSList *strings = NULL;
 
 	/* we scan the parts of a rule, and set all the types we know about to the query string */
@@ -861,7 +874,7 @@ emfb_search_config_search(EFilterBar *efb, FilterRule *rule, int id, const char
 			if (input)
 				filter_input_set_value(input, query);
 
-			words = camel_search_words_split((unsigned char *)query);
+			words = camel_search_words_split((guchar *)query);
 			for (i=0;i<words->len;i++)
 				strings = g_slist_prepend(strings, g_strdup(words->words[i]->word));
 			camel_search_words_free (words);
@@ -878,24 +891,35 @@ emfb_search_config_search(EFilterBar *efb, FilterRule *rule, int id, const char
 		partl = partl->next;
 	}
 
-	em_format_html_display_set_search(emfb->view.preview,
-					  EM_FORMAT_HTML_DISPLAY_SEARCH_SECONDARY|EM_FORMAT_HTML_DISPLAY_SEARCH_ICASE,
-					  strings);
-	while (strings) {
-		GSList *n = strings->next;
-		g_free(strings->data);
-		g_slist_free_1(strings);
-		strings = n;
+	search_bar = E_MAIL_SEARCH_BAR (emfb->priv->search_bar);
+
+	/* XXX This is a hack, but this code is on its way out anyway.
+	 *     Function is called once before the search bar is created. */
+	if (!E_IS_MAIL_SEARCH_BAR (search_bar))
+		return;
+
+	tokenizer = e_mail_search_bar_get_tokenizer (search_bar);
+
+	e_searching_tokenizer_set_secondary_case_sensitivity (tokenizer, FALSE);
+	e_searching_tokenizer_set_secondary_search_string (tokenizer, NULL);
+
+	while (strings != NULL) {
+		e_searching_tokenizer_add_secondary_search_string (
+			tokenizer, strings->data);
+		g_free (strings->data);
+		strings = g_slist_delete_link (strings, strings);
 	}
+
+	e_mail_search_bar_changed (search_bar);
 }
 
-static char *
-get_view_query (ESearchBar *esb, CamelFolder *folder, const char *folder_uri)
+static const gchar *
+get_view_query (ESearchBar *esb, CamelFolder *folder, const gchar *folder_uri)
 {
-	char *view_sexp = NULL;
+	const gchar *view_sexp = NULL;
 	gint id;
 	GtkWidget *menu_item;
-	char *tag;
+	gchar *tag;
 	gboolean duplicate = TRUE;
 
 	/* Get the current selected view */
@@ -958,10 +982,10 @@ get_view_query (ESearchBar *esb, CamelFolder *folder, const char *folder_uri)
 		g_string_append (s, ")");
 
 		duplicate = FALSE;
-	        view_sexp = g_string_free (s, FALSE);
+		view_sexp = g_string_free (s, FALSE);
 		} break;
         case VIEW_LABEL:
-		tag = (char *)g_object_get_data (G_OBJECT (menu_item), "LabelTag");
+		tag = (gchar *)g_object_get_data (G_OBJECT (menu_item), "LabelTag");
 		view_sexp = g_strdup_printf ("(match-all (or (= (user-tag \"label\") \"%s\") (user-flag \"$Label%s\") (user-flag \"%s\")))", tag, tag, tag);
 		duplicate = FALSE;
 		break;
@@ -989,7 +1013,7 @@ struct _setup_msg {
 
 	CamelFolder *folder;
 	CamelOperation *cancel;
-	char *query;
+	gchar *query;
 	GList *sources_uri;
 	GList *sources_folder;
 };
@@ -1015,12 +1039,12 @@ vfolder_setup_exec(struct _setup_msg *m)
 
 	l = m->sources_uri;
 	while (l) {
-		d(printf(" Adding uri: %s\n", (char *)l->data));
+		d(printf(" Adding uri: %s\n", (gchar *)l->data));
 		folder = mail_tool_uri_to_folder (l->data, 0, &m->base.ex);
 		if (folder) {
 			list = g_list_append(list, folder);
 		} else {
-			g_warning("Could not open vfolder source: %s", (char *)l->data);
+			g_warning("Could not open vfolder source: %s", (gchar *)l->data);
 			camel_exception_clear(&m->base.ex);
 		}
 		l = l->next;
@@ -1081,11 +1105,11 @@ static MailMsgInfo vfolder_setup_info = {
 };
 
 /* sources_uri should be camel uri's */
-static int
-vfolder_setup(CamelFolder *folder, const char *query, GList *sources_uri, GList *sources_folder, CamelOperation *cancel)
+static gint
+vfolder_setup(CamelFolder *folder, const gchar *query, GList *sources_uri, GList *sources_folder, CamelOperation *cancel)
 {
 	struct _setup_msg *m;
-	int id;
+	gint id;
 
 	m = mail_msg_new(&vfolder_setup_info);
 	m->folder = folder;
@@ -1094,9 +1118,9 @@ vfolder_setup(CamelFolder *folder, const char *query, GList *sources_uri, GList
 	m->sources_uri = sources_uri;
 	m->sources_folder = sources_folder;
 
- 	if (cancel) {
- 		m->cancel = cancel;
- 	}
+	if (cancel) {
+		m->cancel = cancel;
+	}
 
 	id = m->base.seq;
 	mail_msg_slow_ordered_push (m);
@@ -1109,14 +1133,15 @@ emfb_search_search_activated(ESearchBar *esb, EMFolderBrowser *emfb)
 {
 	EMFolderView *emfv = (EMFolderView *) emfb;
 	EFilterBar *efb = (EFilterBar *)esb;
-	char *search_state = NULL, *view_sexp, *folder_uri=NULL;
-	char *word = NULL, *storeuri = NULL, *search_word = NULL;
+	const gchar *view_sexp;
+	gchar *search_state = NULL, *folder_uri=NULL;
+	gchar *word = NULL, *storeuri = NULL, *search_word = NULL;
 	gint id, i;
 	CamelFolder *folder;
 	CamelStore *store;
 	GPtrArray *folders;
-	GList *folder_list_account = NULL ;
-	GList *l, *folder_list = NULL ;
+	GList *folder_list_account = NULL;
+	GList *l, *folder_list = NULL;
 	CamelException *ex;
 	ex = camel_exception_new ();
 
@@ -1126,18 +1151,6 @@ emfb_search_search_activated(ESearchBar *esb, EMFolderBrowser *emfb)
 	id = e_search_bar_get_search_scope (esb);
 
 	switch (id) {
-	    case E_FILTERBAR_CURRENT_MESSAGE_ID:
-		    word = e_search_bar_get_text (esb);
-		    if ( word && *word ) {
-			    gtk_widget_set_sensitive (esb->option_button, FALSE);
-			    em_format_html_display_search_with (emfb->view.preview, word);
-		    } else {
-			    em_format_html_display_search_close (emfb->view.preview);
-		    }
-		    g_free (word);
-		    return;
-		    break;
-
 	    case E_FILTERBAR_CURRENT_FOLDER_ID:
 		    g_object_get (esb, "query", &search_word, NULL);
 		    break;
@@ -1247,11 +1260,11 @@ emfb_search_search_activated(ESearchBar *esb, EMFolderBrowser *emfb)
 			    /* Add the local folders */
 			    l = mail_vfolder_get_sources_local ();
 			    while (l) {
-				    folder = mail_tool_uri_to_folder ((const char *)l->data, 0,ex);
+				    folder = mail_tool_uri_to_folder ((const gchar *)l->data, 0,ex);
 				    if (folder)
 					    folder_list = g_list_append(folder_list, folder);
 				    else {
-					    g_warning("Could not open vfolder source: %s", (char *)l->data);
+					    g_warning("Could not open vfolder source: %s", (gchar *)l->data);
 					    camel_exception_clear(ex);
 				    }
 				    l = l->next;
@@ -1260,11 +1273,11 @@ emfb_search_search_activated(ESearchBar *esb, EMFolderBrowser *emfb)
 			    /* Add the remote source folder */
 			    l = mail_vfolder_get_sources_remote ();
 			    while (l) {
-				    folder = mail_tool_uri_to_folder ((const char *)l->data, 0,ex);
+				    folder = mail_tool_uri_to_folder ((const gchar *)l->data, 0,ex);
 				    if (folder)
 					    folder_list = g_list_append(folder_list, folder);
 				    else {
-					    g_warning("Could not open vfolder source: %s", (char *)l->data);
+					    g_warning("Could not open vfolder source: %s", (gchar *)l->data);
 					    camel_exception_clear(ex);
 				    }
 				    l = l->next;
@@ -1310,7 +1323,6 @@ emfb_search_search_activated(ESearchBar *esb, EMFolderBrowser *emfb)
 
 	g_free (word);
 	g_free (search_word);
-	g_free (view_sexp);
 
 	camel_exception_free (ex);
 }
@@ -1324,8 +1336,8 @@ emfb_search_search_cleared(ESearchBar *esb)
 
 /* ********************************************************************** */
 
-static int
-emfb_list_key_press(ETree *tree, int row, ETreePath path, int col, GdkEvent *ev, EMFolderBrowser *emfb)
+static gint
+emfb_list_key_press(ETree *tree, gint row, ETreePath path, gint col, GdkEvent *ev, EMFolderBrowser *emfb)
 {
 	gboolean state, folder_choose = TRUE;
 	if ((ev->key.state & GDK_CONTROL_MASK) != 0)
@@ -1363,7 +1375,7 @@ emfb_list_key_press(ETree *tree, int row, ETreePath path, int col, GdkEvent *ev,
 	}
 
 	if (!folder_choose && !emfb->view.preview->caret_mode && mail_config_get_enable_magic_spacebar ()) {
-		//check for unread messages. if yes .. rewindback to the folder
+		/* check for unread messages. if yes .. rewindback to the folder */
 		EMFolderTree *emft = g_object_get_data((GObject*)emfb, "foldertree");
 		switch (ev->key.keyval) {
 		    case GDK_space:
@@ -1379,7 +1391,7 @@ emfb_list_key_press(ETree *tree, int row, ETreePath path, int col, GdkEvent *ev,
 }
 
 static void
-emfb_list_message_selected (MessageList *ml, const char *uid, EMFolderBrowser *emfb)
+emfb_list_message_selected (MessageList *ml, const gchar *uid, EMFolderBrowser *emfb)
 {
 	EMFolderView *emfv = (EMFolderView *) emfb;
 
@@ -1387,10 +1399,8 @@ emfb_list_message_selected (MessageList *ml, const char *uid, EMFolderBrowser *e
 		return;
 
 	if (uid && *uid && emfb->priv->scope_restricted && emfb->view.preview_active) {
-		e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, TRUE);
 		emfb->priv->scope_restricted = FALSE;
 	} else if ( !(uid && *uid) && !emfb->priv->scope_restricted) {
-		e_search_bar_scope_enable ((ESearchBar *)emfb->search, E_FILTERBAR_CURRENT_MESSAGE_ID, FALSE);
 		emfb->priv->scope_restricted = TRUE;
 	}
 
@@ -1403,7 +1413,7 @@ emfb_list_message_selected (MessageList *ml, const char *uid, EMFolderBrowser *e
 /* ********************************************************************** */
 
 static void
-emfb_edit_cut(BonoboUIComponent *uid, void *data, const char *path)
+emfb_edit_cut(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1418,7 +1428,7 @@ emfb_edit_cut(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_edit_copy(BonoboUIComponent *uid, void *data, const char *path)
+emfb_edit_copy(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1431,7 +1441,7 @@ emfb_edit_copy(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_edit_paste(BonoboUIComponent *uid, void *data, const char *path)
+emfb_edit_paste(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1442,7 +1452,7 @@ emfb_edit_paste(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_edit_invert_selection(BonoboUIComponent *uid, void *data, const char *path)
+emfb_edit_invert_selection(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderView *emfv = data;
 
@@ -1458,7 +1468,7 @@ emfb_select_all_daemon (MessageList *ml)
 }
 
 static void
-emfb_edit_select_all(BonoboUIComponent *uid, void *data, const char *path)
+emfb_edit_select_all(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 		EMFolderView *emfv = data;
 
@@ -1466,8 +1476,8 @@ emfb_edit_select_all(BonoboUIComponent *uid, void *data, const char *path)
 
 				emfb_expand_all_threads (uid, data, path);
 
-				/* The time out below is added so that the execution thread to 
-				   expand all conversations threads would've completed. 
+				/* The time out below is added so that the execution thread to
+				   expand all conversations threads would've completed.
 
 				   The timeout 505 is just to ensure that the value is a small delta
 				   more than the timeout value in expand_all_threads thread. */
@@ -1481,7 +1491,7 @@ emfb_edit_select_all(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_edit_select_thread(BonoboUIComponent *uid, void *data, const char *path)
+emfb_edit_select_thread(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderView *emfv = data;
 
@@ -1489,7 +1499,7 @@ emfb_edit_select_thread(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_edit_select_subthread(BonoboUIComponent *uid, void *data, const char *path)
+emfb_edit_select_subthread(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderView *emfv = data;
 
@@ -1497,7 +1507,7 @@ emfb_edit_select_subthread(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_folder_properties(BonoboUIComponent *uid, void *data, const char *path)
+emfb_folder_properties(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1507,7 +1517,7 @@ emfb_folder_properties(BonoboUIComponent *uid, void *data, const char *path)
 
 /* VIEWTHREADED*/
 static void
-emfb_expand_all_threads(BonoboUIComponent *uid, void *data, const char *path)
+emfb_expand_all_threads(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderView *emfv = data;
 
@@ -1516,7 +1526,7 @@ emfb_expand_all_threads(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_collapse_all_threads(BonoboUIComponent *uid, void *data, const char *path)
+emfb_collapse_all_threads(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderView *emfv = data;
 
@@ -1524,7 +1534,7 @@ emfb_collapse_all_threads(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_folder_copy(BonoboUIComponent *uid, void *data, const char *path)
+emfb_folder_copy(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 	CamelFolderInfo *fi = NULL;
@@ -1547,7 +1557,7 @@ emfb_folder_copy(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_folder_move(BonoboUIComponent *uid, void *data, const char *path)
+emfb_folder_move(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 	CamelFolderInfo *fi = NULL;
@@ -1570,7 +1580,7 @@ emfb_folder_move(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_folder_delete(BonoboUIComponent *uid, void *data, const char *path)
+emfb_folder_delete(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1580,19 +1590,23 @@ emfb_folder_delete(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_folder_refresh(BonoboUIComponent *uid, void *data, const char *path)
+emfb_folder_refresh(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
         EMFolderBrowser *emfb = data;
 	EMFolderTree *tree = g_object_get_data (G_OBJECT (emfb), "foldertree");
         CamelFolder *folder;
 
-        if ((folder = em_folder_tree_get_selected_folder (tree)) != NULL)
+        if ((folder = em_folder_tree_get_selected_folder (tree)) != NULL) {
+		EMEvent *e = em_event_peek();
+		EMEventTargetFolder *t = em_event_target_new_folder(e, folder->full_name, 0);
+		e_event_emit((EEvent *)e, "folder.refresh", (EEventTarget *)t);
                 mail_refresh_folder(folder, NULL, NULL);
+	}
 }
 
 
 static void
-emfb_folder_rename(BonoboUIComponent *uid, void *data, const char *path)
+emfb_folder_rename(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1602,7 +1616,7 @@ emfb_folder_rename(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_folder_create(BonoboUIComponent *uid, void *data, const char *path)
+emfb_folder_create(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 	CamelFolderInfo *fi = NULL;
@@ -1623,7 +1637,7 @@ emfb_folder_create(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_folder_expunge(BonoboUIComponent *uid, void *data, const char *path)
+emfb_folder_expunge(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1632,12 +1646,12 @@ emfb_folder_expunge(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_mark_all_read(BonoboUIComponent *uid, void *data, const char *path)
+emfb_mark_all_read(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	/* FIXME: make a 'mark messages' function? */
 	EMFolderView *emfv = data;
 	GPtrArray *uids;
-	int i;
+	gint i;
 
 	if (emfv->folder == NULL)
 		return;
@@ -1652,7 +1666,7 @@ emfb_mark_all_read(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_view_hide_read(BonoboUIComponent *uid, void *data, const char *path)
+emfb_view_hide_read(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderView *emfv = data;
 
@@ -1660,7 +1674,7 @@ emfb_view_hide_read(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_view_hide_selected(BonoboUIComponent *uid, void *data, const char *path)
+emfb_view_hide_selected(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderView *emfv = data;
 	GPtrArray *uids;
@@ -1678,7 +1692,7 @@ emfb_view_hide_selected(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_view_show_all(BonoboUIComponent *uid, void *data, const char *path)
+emfb_view_show_all(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderView *emfv = data;
 
@@ -1688,20 +1702,13 @@ emfb_view_show_all(BonoboUIComponent *uid, void *data, const char *path)
 /* ********************************************************************** */
 
 static void
-emfb_mail_stop(BonoboUIComponent *uid, void *data, const char *path)
+emfb_mail_stop(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	mail_cancel_all();
 }
 
 static void
-emfb_mail_post(BonoboUIComponent *uid, void *data, const char *path)
-{
-	EMFolderView *emfv = data;
-	em_utils_post_to_folder (emfv->folder);
-}
-
-static void
-emfb_tools_filters(BonoboUIComponent *uid, void *data, const char *path)
+emfb_tools_filters(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1715,7 +1722,7 @@ emfb_subscribe_editor_destroy(GtkWidget *w, EMFolderBrowser *emfb)
 }
 
 static void
-emfb_tools_subscriptions(BonoboUIComponent *uid, void *data, const char *path)
+emfb_tools_subscriptions(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1730,7 +1737,7 @@ emfb_tools_subscriptions(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_focus_search(BonoboUIComponent *uid, void *data, const char *path)
+emfb_focus_search(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	EMFolderBrowser *emfb = data;
 
@@ -1738,13 +1745,13 @@ emfb_focus_search(BonoboUIComponent *uid, void *data, const char *path)
 }
 
 static void
-emfb_help_debug (BonoboUIComponent *uid, void *data, const char *path)
+emfb_help_debug (BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	mail_component_show_logger ((GtkWidget *) data);
 }
 
 static void
-emfb_tools_vfolders(BonoboUIComponent *uid, void *data, const char *path)
+emfb_tools_vfolders(BonoboUIComponent *uid, gpointer data, const gchar *path)
 {
 	/* FIXME: rename/refactor this */
 	vfolder_edit();
@@ -1779,7 +1786,6 @@ static BonoboUIVerb emfb_verbs[] = {
 	BONOBO_UI_UNSAFE_VERB ("FolderCreate", emfb_folder_create),
 	BONOBO_UI_UNSAFE_VERB ("HelpDebug", emfb_help_debug),
 
-	BONOBO_UI_UNSAFE_VERB ("MailPost", emfb_mail_post),
 	BONOBO_UI_UNSAFE_VERB ("MailStop", emfb_mail_stop),
 	BONOBO_UI_UNSAFE_VERB ("ToolsFilters", emfb_tools_filters),
 	BONOBO_UI_UNSAFE_VERB ("ToolsSubscriptions", emfb_tools_subscriptions),
@@ -1792,18 +1798,18 @@ static BonoboUIVerb emfb_verbs[] = {
 };
 
 static EPixmap emfb_pixmaps[] = {
-	E_PIXMAP ("/commands/FolderCreate", "folder-new", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/ChangeFolderProperties", "document-properties", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/FolderCopy", "folder-copy", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/FolderMove", "folder-move", E_ICON_SIZE_MENU),
-	E_PIXMAP ("/commands/MessageMarkAllAsRead", "mail-read", E_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderCreate", "folder-new", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/ChangeFolderProperties", "document-properties", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderCopy", "folder-copy", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/FolderMove", "folder-move", GTK_ICON_SIZE_MENU),
+	E_PIXMAP ("/commands/MessageMarkAllAsRead", "mail-read", GTK_ICON_SIZE_MENU),
 
 	E_PIXMAP_END
 };
 
 
 static void
-emfb_hide_deleted(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_EventType type, const char *state, void *data)
+emfb_hide_deleted(BonoboUIComponent *uic, const gchar *path, Bonobo_UIComponent_EventType type, const gchar *state, gpointer data)
 {
 	GConfClient *gconf;
 	EMFolderView *emfv = data;
@@ -1817,7 +1823,7 @@ emfb_hide_deleted(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_E
 }
 
 static void
-emfb_view_threaded(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_EventType type, const char *state, void *data)
+emfb_view_threaded(BonoboUIComponent *uic, const gchar *path, Bonobo_UIComponent_EventType type, const gchar *state, gpointer data)
 {
 	GConfClient *gconf;
 	EMFolderView *emfv = data;
@@ -1838,7 +1844,7 @@ emfb_view_threaded(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_
 }
 
 static void
-emfb_view_preview(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_EventType type, const char *state, void *data)
+emfb_view_preview(BonoboUIComponent *uic, const gchar *path, Bonobo_UIComponent_EventType type, const gchar *state, gpointer data)
 {
 	GConfClient *gconf;
 	EMFolderView *emfv = data;
@@ -1857,7 +1863,7 @@ emfb_view_preview(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_E
 }
 
 static void
-emfb_show_next(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_EventType type, const char *state, void *data)
+emfb_show_next(BonoboUIComponent *uic, const gchar *path, Bonobo_UIComponent_EventType type, const gchar *state, gpointer data)
 {
 	GConfClient *gconf;
 	EMFolderBrowser *emfb = data;
@@ -1872,7 +1878,7 @@ emfb_show_next(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_Even
 }
 
 static void
-emfb_show_below(BonoboUIComponent *uic, const char *path, Bonobo_UIComponent_EventType type, const char *state, void *data)
+emfb_show_below(BonoboUIComponent *uic, const gchar *path, Bonobo_UIComponent_EventType type, const gchar *state, gpointer data)
 {
 	GConfClient *gconf;
 	EMFolderBrowser *emfb = data;
@@ -1891,7 +1897,7 @@ emfb_list_scrolled (MessageList *ml, EMFolderBrowser *emfb)
 {
 	EMFolderView *emfv = (EMFolderView *) emfb;
 	double position;
-	char *state;
+	gchar *state;
 
 	position = message_list_get_scrollbar_position (ml);
 	state = g_strdup_printf ("%f", position);
@@ -1907,7 +1913,7 @@ scroll_idle_cb (EMFolderBrowser *emfb)
 {
 	EMFolderView *emfv = (EMFolderView *) emfb;
 	double position;
-	char *state;
+	gchar *state;
 
 	if ((state = camel_object_meta_get (emfv->folder, "evolution:list_scroll_position"))) {
 		position = strtod (state, NULL);
@@ -1926,15 +1932,19 @@ scroll_idle_cb (EMFolderBrowser *emfb)
 }
 
 static void
-emfb_gui_folder_changed(CamelFolder *folder, void *dummy, EMFolderBrowser *emfb)
+emfb_gui_folder_changed(CamelFolder *folder, gpointer dummy, EMFolderBrowser *emfb)
 {
 	if (emfb->priv->select_uid) {
 		CamelMessageInfo *mi;
 
 		mi = camel_folder_get_message_info(emfb->view.folder, emfb->priv->select_uid);
 		if (mi) {
+			/* because some sub-functions might free the pointer before it's done here */
+			gchar *uid = g_strdup (emfb->priv->select_uid);
+
 			camel_folder_free_message_info(emfb->view.folder, mi);
-			em_folder_view_set_message(&emfb->view, emfb->priv->select_uid, FALSE);
+			em_folder_view_set_message (&emfb->view, uid, FALSE);
+			g_free (uid);
 			g_free (emfb->priv->select_uid);
 			emfb->priv->select_uid = NULL;
 		}
@@ -2006,10 +2016,10 @@ emfb_list_built (MessageList *ml, EMFolderBrowser *emfb)
 }
 
 static void
-emfb_set_search_folder(EMFolderView *emfv, CamelFolder *folder, const char *uri)
+emfb_set_search_folder(EMFolderView *emfv, CamelFolder *folder, const gchar *uri)
 {
 	EMFolderBrowser *emfb = (EMFolderBrowser *) emfv;
-	char *state;
+	const gchar *state;
 
 	message_list_freeze(emfv->list);
 
@@ -2043,7 +2053,7 @@ emfb_set_search_folder(EMFolderView *emfv, CamelFolder *folder, const char *uri)
 
 
 static void
-emfb_set_folder(EMFolderView *emfv, CamelFolder *folder, const char *uri)
+emfb_set_folder(EMFolderView *emfv, CamelFolder *folder, const gchar *uri)
 {
 	EMFolderBrowser *emfb = (EMFolderBrowser *) emfv;
 	struct _EMFolderBrowserPrivate *p = emfb->priv;
@@ -2076,8 +2086,8 @@ emfb_set_folder(EMFolderView *emfv, CamelFolder *folder, const char *uri)
 	   before the folder is open and need to override the
 	   defaults */
 	if (folder) {
-		char *sstate;
-		int state;
+		gchar *sstate;
+		gint state;
 		gboolean safe;
 		GConfClient *gconf = mail_config_get_gconf_client();
 
@@ -2176,12 +2186,12 @@ emfb_set_folder(EMFolderView *emfv, CamelFolder *folder, const char *uri)
 }
 
 static void
-emfb_activate(EMFolderView *emfv, BonoboUIComponent *uic, int act)
+emfb_activate(EMFolderView *emfv, BonoboUIComponent *uic, gint act)
 {
 	if (act) {
 		GConfClient *gconf;
 		gboolean state;
-		char *sstate;
+		gchar *sstate;
 		EMFolderBrowser *emfb = (EMFolderBrowser *) emfv;
 
 		gconf = mail_config_get_gconf_client ();
@@ -2194,8 +2204,8 @@ emfb_activate(EMFolderView *emfv, BonoboUIComponent *uic, int act)
 
 		/* FIXME: finish */
 		/* (Pre)view pane size (do this first because it affects the
-	           preview settings - see folder_browser_set_message_preview()
-	           internals for details) */
+		   preview settings - see folder_browser_set_message_preview()
+		   internals for details) */
 		g_signal_handler_block(emfb->vpane, emfb->priv->vpane_resize_id);
 		gtk_paned_set_position((GtkPaned *)emfb->vpane, gconf_client_get_int (gconf, emfb->priv->show_wide ? "/apps/evolution/mail/display/hpaned_size": "/apps/evolution/mail/display/paned_size", NULL));
 		g_signal_handler_unblock(emfb->vpane, emfb->priv->vpane_resize_id);
@@ -2214,7 +2224,7 @@ emfb_activate(EMFolderView *emfv, BonoboUIComponent *uic, int act)
 		bonobo_ui_component_add_listener(uic, "ViewPreview", emfb_view_preview, emfv);
 
 		/* Stop button */
-		state = mail_msg_active((unsigned int)-1);
+		state = mail_msg_active((guint)-1);
 		bonobo_ui_component_set_prop(uic, "/commands/MailStop", "sensitive", state?"1":"0", NULL);
 
 		/* HideDeleted */
