@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -37,6 +37,7 @@
 #include <libedataserver/e-xml-utils.h>
 #include <libedataserver/e-data-server-util.h>
 
+#include <e-util/e-util.h>
 #include <e-util/e-mktemp.h>
 
 #include <glib/gi18n.h>
@@ -53,27 +54,17 @@
 #include "mail-folder-cache.h"
 
 #include "em-utils.h"
+#include "em-folder-utils.h"
+#include "em-event.h"
 
 #include <camel/camel-folder.h>
 #include <camel/camel-vee-store.h>
 
-#include "em-marshal.h"
 #include "em-folder-tree-model.h"
 
 #define u(x)			/* unread count debug */
 #define d(x)
 
-static GType col_types[] = {
-	G_TYPE_STRING,   /* display name */
-	G_TYPE_POINTER,  /* store object */
-	G_TYPE_STRING,   /* path */
-	G_TYPE_STRING,   /* uri */
-	G_TYPE_UINT,     /* unread count */
-	G_TYPE_UINT,     /* flags */
-	G_TYPE_BOOLEAN,  /* is a store node */
-	G_TYPE_BOOLEAN,  /* has not-yet-loaded subfolders */
-};
-
 /* GObject virtual method overrides */
 static void em_folder_tree_model_class_init (EMFolderTreeModelClass *klass);
 static void em_folder_tree_model_init (EMFolderTreeModel *model);
@@ -93,6 +84,8 @@ enum {
 	LAST_SIGNAL
 };
 
+extern CamelStore *vfolder_store;
+
 static guint signals[LAST_SIGNAL] = { 0, };
 static GtkTreeStoreClass *parent_class = NULL;
 
@@ -152,7 +145,7 @@ em_folder_tree_model_class_init (EMFolderTreeModelClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EMFolderTreeModelClass, loading_row),
 			      NULL, NULL,
-			      em_marshal_VOID__POINTER_POINTER,
+			      e_marshal_VOID__POINTER_POINTER,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_POINTER,
 			      G_TYPE_POINTER);
@@ -163,7 +156,7 @@ em_folder_tree_model_class_init (EMFolderTreeModelClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EMFolderTreeModelClass, loaded_row),
 			      NULL, NULL,
-			      em_marshal_VOID__POINTER_POINTER,
+			      e_marshal_VOID__POINTER_POINTER,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_POINTER,
 			      G_TYPE_POINTER);
@@ -174,21 +167,20 @@ em_folder_tree_model_class_init (EMFolderTreeModelClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EMFolderTreeModelClass, folder_added),
 			      NULL, NULL,
-			      em_marshal_VOID__STRING_STRING,
+			      e_marshal_VOID__STRING_STRING,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_STRING,
 			      G_TYPE_STRING);
 }
 
-static int
+static gint
 sort_cb (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data)
 {
-	extern CamelStore *vfolder_store;
-	char *aname, *bname;
+	gchar *aname, *bname;
 	CamelStore *store;
 	gboolean is_store;
 	guint32 aflags, bflags;
-	int rv = -2;
+	gint rv = -2;
 
 	gtk_tree_model_get (model, a, COL_BOOL_IS_STORE, &is_store,
 			    COL_POINTER_CAMEL_STORE, &store,
@@ -295,7 +287,7 @@ em_folder_tree_model_init (EMFolderTreeModel *model)
 	model->account_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
 	model->account_changed_id = g_signal_connect (model->accounts, "account-changed", G_CALLBACK (account_changed), model);
 	model->account_removed_id = g_signal_connect (model->accounts, "account-removed", G_CALLBACK (account_removed), model);
-	//g_signal_connect (model, "row-changed", G_CALLBACK (emft_model_unread_count_changed), NULL);
+	/* g_signal_connect (model, "row-changed", G_CALLBACK (emft_model_unread_count_changed), NULL); */
 }
 
 static void
@@ -332,7 +324,7 @@ tree_sortable_iface_init (GtkTreeSortableIface *iface)
 
 
 static void
-em_folder_tree_model_load_state (EMFolderTreeModel *model, const char *filename)
+em_folder_tree_model_load_state (EMFolderTreeModel *model, const gchar *filename)
 {
 	xmlNodePtr root, node;
 
@@ -341,7 +333,7 @@ em_folder_tree_model_load_state (EMFolderTreeModel *model, const char *filename)
 
 	if ((model->state = e_xml_parse_file (filename)) != NULL) {
 		node = xmlDocGetRootElement (model->state);
-		if (!node || strcmp ((char *)node->name, "tree-state") != 0) {
+		if (!node || strcmp ((gchar *)node->name, "tree-state") != 0) {
 			/* it is not expected XML file, thus free it and use the default */
 			xmlFreeDoc (model->state);
 		} else
@@ -349,25 +341,39 @@ em_folder_tree_model_load_state (EMFolderTreeModel *model, const char *filename)
 	}
 
 	/* setup some defaults - expand "Local Folders" and "Search Folders" */
-	model->state = xmlNewDoc ((const unsigned char *)"1.0");
-	root = xmlNewDocNode (model->state, NULL, (const unsigned char *)"tree-state", NULL);
+	model->state = xmlNewDoc ((const guchar *)"1.0");
+	root = xmlNewDocNode (model->state, NULL, (const guchar *)"tree-state", NULL);
 	xmlDocSetRootElement (model->state, root);
 
-	node = xmlNewChild (root, NULL, (const unsigned char *)"node", NULL);
-	xmlSetProp (node, (const unsigned char *)"name", (const unsigned char *)"local");
-	xmlSetProp (node, (const unsigned char *)"expand", (const unsigned char *)"true");
+	node = xmlNewChild (root, NULL, (const guchar *)"node", NULL);
+	xmlSetProp (node, (const guchar *)"name", (const guchar *)"local");
+	xmlSetProp (node, (const guchar *)"expand", (const guchar *)"true");
 
-	node = xmlNewChild (root, NULL, (const unsigned char *)"node", NULL);
-	xmlSetProp (node, (const unsigned char *)"name", (const unsigned char *)"vfolder");
-	xmlSetProp (node, (const unsigned char *)"expand", (const unsigned char *)"true");
+	node = xmlNewChild (root, NULL, (const guchar *)"node", NULL);
+	xmlSetProp (node, (const guchar *)"name", (const guchar *)"vfolder");
+	xmlSetProp (node, (const guchar *)"expand", (const guchar *)"true");
 }
 
 
 EMFolderTreeModel *
-em_folder_tree_model_new (const char *evolution_dir)
+em_folder_tree_model_new (const gchar *evolution_dir)
 {
 	EMFolderTreeModel *model;
-	char *filename;
+	gchar *filename;
+
+	GType col_types[] = {
+		G_TYPE_STRING,   /* display name */
+		G_TYPE_POINTER,  /* store object */
+		G_TYPE_STRING,   /* full name */
+		G_TYPE_STRING,   /* icon name */
+		G_TYPE_STRING,   /* uri */
+		G_TYPE_UINT,     /* unread count */
+		G_TYPE_UINT,     /* flags */
+		G_TYPE_BOOLEAN,  /* is a store node */
+		G_TYPE_BOOLEAN,  /* is a folder node */
+		G_TYPE_BOOLEAN,  /* has not-yet-loaded subfolders */
+		G_TYPE_UINT      /* last known unread count */
+	};
 
 	model = g_object_new (EM_TYPE_FOLDER_TREE_MODEL, NULL);
 	gtk_tree_store_set_column_types ((GtkTreeStore *) model, NUM_COLUMNS, col_types);
@@ -391,7 +397,7 @@ account_changed (EAccountList *accounts, EAccount *account, gpointer user_data)
 	CamelProvider *provider;
 	CamelStore *store;
 	CamelException ex;
-	char *uri;
+	gchar *uri;
 
 	if (!(si = g_hash_table_lookup (model->account_hash, account)))
 		return;
@@ -436,17 +442,26 @@ account_removed (EAccountList *accounts, EAccount *account, gpointer user_data)
 void
 em_folder_tree_model_set_folder_info (EMFolderTreeModel *model, GtkTreeIter *iter,
 				      struct _EMFolderTreeModelStoreInfo *si,
-				      CamelFolderInfo *fi, int fully_loaded)
+				      CamelFolderInfo *fi, gint fully_loaded)
 {
 	GtkTreeRowReference *uri_row, *path_row;
-	unsigned int unread;
+	GtkTreeStore *tree_store;
+	guint unread;
 	GtkTreePath *path;
 	GtkTreeIter sub;
-	gboolean load = FALSE;
+	gboolean load = FALSE, is_drafts = FALSE, is_templates = FALSE;
 	struct _CamelFolder *folder;
 	gboolean emitted = FALSE;
-	const char *name;
-	guint32 flags;
+	const gchar *name;
+	const gchar *icon_name;
+	guint32 flags, add_flags = 0;
+	EMEventTargetCustomIcon *target;
+
+	/* make sure we don't already know about it? */
+	if (g_hash_table_lookup (si->full_hash, fi->full_name))
+		return;
+
+	tree_store = GTK_TREE_STORE (model);
 
 	if (!fully_loaded)
 		load = fi->child == NULL && !(fi->flags & (CAMEL_FOLDER_NOCHILDREN | CAMEL_FOLDER_NOINFERIORS));
@@ -465,10 +480,10 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model, GtkTreeIter *ite
 	unread = fi->unread;
 	if (mail_note_get_folder_from_uri(fi->uri, &folder) && folder) {
 		if (folder == mail_component_get_folder(NULL, MAIL_COMPONENT_FOLDER_OUTBOX)) {
-			int total;
+			gint total;
 
 			if ((total = camel_folder_get_message_count (folder)) > 0) {
-				int deleted = camel_folder_get_deleted_message_count (folder);
+				gint deleted = camel_folder_get_deleted_message_count (folder);
 
 				if (deleted != -1)
 					total -= deleted;
@@ -477,10 +492,10 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model, GtkTreeIter *ite
 			unread = total > 0 ? total : 0;
 		}
 		if (folder == mail_component_get_folder(NULL, MAIL_COMPONENT_FOLDER_DRAFTS)) {
-			int total;
+			gint total;
 
 			if ((total = camel_folder_get_message_count (folder)) > 0) {
-				int deleted = camel_folder_get_deleted_message_count (folder);
+				gint deleted = camel_folder_get_deleted_message_count (folder);
 
 				if (deleted != -1)
 					total -= deleted;
@@ -498,6 +513,10 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model, GtkTreeIter *ite
 	if (si->store == mail_component_peek_local_store(NULL)) {
 		if (!strcmp(fi->full_name, "Drafts")) {
 			name = _("Drafts");
+			is_drafts = TRUE;
+		} else if (!strcmp(fi->full_name, "Templates")) {
+			name = _("Templates");
+			is_templates = TRUE;
 		} else if (!strcmp(fi->full_name, "Inbox")) {
 			flags = (flags & ~CAMEL_FOLDER_TYPE_MASK) | CAMEL_FOLDER_TYPE_INBOX;
 			name = _("Inbox");
@@ -510,31 +529,70 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model, GtkTreeIter *ite
 		}
 	}
 
-	gtk_tree_store_set ((GtkTreeStore *) model, iter,
-			    COL_STRING_DISPLAY_NAME, name,
-			    COL_POINTER_CAMEL_STORE, si->store,
-			    COL_STRING_FULL_NAME, fi->full_name,
-			    COL_STRING_URI, fi->uri,
-			    COL_UINT_FLAGS, flags,
-			    COL_BOOL_IS_STORE, FALSE,
-			    COL_BOOL_LOAD_SUBDIRS, load,
-			    -1);
+	if (si->account && (flags & CAMEL_FOLDER_TYPE_MASK) == 0) {
+		if (!is_drafts && si->account->drafts_folder_uri) {
+			gchar *curi = em_uri_to_camel (si->account->drafts_folder_uri);
+			is_drafts = camel_store_folder_uri_equal (si->store, fi->uri, curi);
+			g_free (curi);
+		}
+
+		if (si->account->sent_folder_uri) {
+			gchar *curi = em_uri_to_camel (si->account->sent_folder_uri);
+			if (camel_store_folder_uri_equal (si->store, fi->uri, curi)) {
+				add_flags = CAMEL_FOLDER_TYPE_SENT;
+			}
+			g_free(curi);
+		}
+	}
+
+	/* Choose an icon name for the folder. */
+	icon_name = em_folder_utils_get_icon_name (flags | add_flags);
+
+	if (g_str_equal (icon_name, "folder")) {
+		if (is_drafts)
+			icon_name = "accessories-text-editor";
+		else if (is_templates)
+			icon_name = "text-x-generic-template";
+	}
+
+	gtk_tree_store_set (
+		tree_store, iter,
+		COL_STRING_DISPLAY_NAME, name,
+		COL_POINTER_CAMEL_STORE, si->store,
+		COL_STRING_FULL_NAME, fi->full_name,
+		COL_STRING_ICON_NAME, icon_name,
+		COL_STRING_URI, fi->uri,
+		COL_UINT_FLAGS, flags,
+		COL_BOOL_IS_STORE, FALSE,
+		COL_BOOL_IS_FOLDER, TRUE,
+		COL_BOOL_LOAD_SUBDIRS, load,
+		COL_UINT_UNREAD_LAST_SEL, 0,
+		-1);
+
+	target = em_event_target_new_custom_icon (em_event_peek(), tree_store, iter, fi->full_name, EM_EVENT_CUSTOM_ICON);
+	e_event_emit ((EEvent *)em_event_peek (), "folder.customicon", (EEventTarget *) target);
 
 	if (unread != ~0)
-		gtk_tree_store_set ((GtkTreeStore *) model, iter, COL_UINT_UNREAD, unread, -1);
+		gtk_tree_store_set (
+			tree_store, iter, COL_UINT_UNREAD, unread,
+			COL_UINT_UNREAD_LAST_SEL, unread, -1);
 
 	if (load) {
 		/* create a placeholder node for our subfolders... */
-		gtk_tree_store_append ((GtkTreeStore *) model, &sub, iter);
-		gtk_tree_store_set ((GtkTreeStore *) model, &sub,
-				    COL_STRING_DISPLAY_NAME, _("Loading..."),
-				    COL_POINTER_CAMEL_STORE, NULL,
-				    COL_STRING_FULL_NAME, NULL,
-				    COL_BOOL_LOAD_SUBDIRS, FALSE,
-				    COL_BOOL_IS_STORE, FALSE,
-				    COL_STRING_URI, NULL,
-				    COL_UINT_UNREAD, 0,
-				    -1);
+		gtk_tree_store_append (tree_store, &sub, iter);
+		gtk_tree_store_set (
+			tree_store, &sub,
+			COL_STRING_DISPLAY_NAME, _("Loading..."),
+			COL_POINTER_CAMEL_STORE, NULL,
+			COL_STRING_FULL_NAME, NULL,
+			COL_STRING_ICON_NAME, NULL,
+			COL_BOOL_LOAD_SUBDIRS, FALSE,
+			COL_BOOL_IS_STORE, FALSE,
+			COL_BOOL_IS_FOLDER, FALSE,
+			COL_STRING_URI, NULL,
+			COL_UINT_UNREAD, 0,
+			COL_UINT_UNREAD_LAST_SEL, 0,
+			-1);
 
 		path = gtk_tree_model_get_path ((GtkTreeModel *) model, iter);
 		g_signal_emit (model, signals[LOADING_ROW], 0, path, iter);
@@ -546,7 +604,7 @@ em_folder_tree_model_set_folder_info (EMFolderTreeModel *model, GtkTreeIter *ite
 		fi = fi->child;
 
 		do {
-			gtk_tree_store_append ((GtkTreeStore *) model, &sub, iter);
+			gtk_tree_store_append (tree_store, &sub, iter);
 
 			if (!emitted) {
 				path = gtk_tree_model_get_path ((GtkTreeModel *) model, iter);
@@ -576,7 +634,7 @@ folder_subscribed (CamelStore *store, CamelFolderInfo *fi, EMFolderTreeModel *mo
 	GtkTreeIter parent, iter;
 	GtkTreePath *path;
 	gboolean load;
-	char *dirname, *p;
+	gchar *dirname, *p;
 
 	if (!(si = g_hash_table_lookup (model->store_hash, store)))
 		goto done;
@@ -630,7 +688,7 @@ folder_subscribed (CamelStore *store, CamelFolderInfo *fi, EMFolderTreeModel *mo
 }
 
 static void
-folder_subscribed_cb (CamelStore *store, void *event_data, EMFolderTreeModel *model)
+folder_subscribed_cb (CamelStore *store, gpointer event_data, EMFolderTreeModel *model)
 {
 	CamelFolderInfo *fi;
 
@@ -668,7 +726,7 @@ folder_unsubscribed (CamelStore *store, CamelFolderInfo *fi, EMFolderTreeModel *
 }
 
 static void
-folder_unsubscribed_cb (CamelStore *store, void *event_data, EMFolderTreeModel *model)
+folder_unsubscribed_cb (CamelStore *store, gpointer event_data, EMFolderTreeModel *model)
 {
 	CamelFolderInfo *fi;
 
@@ -678,7 +736,7 @@ folder_unsubscribed_cb (CamelStore *store, void *event_data, EMFolderTreeModel *
 }
 
 static void
-folder_created_cb (CamelStore *store, void *event_data, EMFolderTreeModel *model)
+folder_created_cb (CamelStore *store, gpointer event_data, EMFolderTreeModel *model)
 {
 	CamelFolderInfo *fi;
 
@@ -692,7 +750,7 @@ folder_created_cb (CamelStore *store, void *event_data, EMFolderTreeModel *model
 }
 
 static void
-folder_deleted_cb (CamelStore *store, void *event_data, EMFolderTreeModel *model)
+folder_deleted_cb (CamelStore *store, gpointer event_data, EMFolderTreeModel *model)
 {
 	CamelFolderInfo *fi;
 
@@ -712,7 +770,7 @@ folder_renamed (CamelStore *store, CamelRenameInfo *info, EMFolderTreeModel *mod
 	GtkTreeRowReference *row;
 	GtkTreeIter root, iter;
 	GtkTreePath *path;
-	char *parent, *p;
+	gchar *parent, *p;
 
 	if (!(si = g_hash_table_lookup (model->store_hash, store)))
 		goto done;
@@ -770,7 +828,7 @@ folder_renamed (CamelStore *store, CamelRenameInfo *info, EMFolderTreeModel *mod
 }
 
 static void
-folder_renamed_cb (CamelStore *store, void *event_data, EMFolderTreeModel *model)
+folder_renamed_cb (CamelStore *store, gpointer event_data, EMFolderTreeModel *model)
 {
 	CamelRenameInfo *rinfo, *info = event_data;
 
@@ -784,14 +842,14 @@ folder_renamed_cb (CamelStore *store, void *event_data, EMFolderTreeModel *model
 }
 
 void
-em_folder_tree_model_add_store (EMFolderTreeModel *model, CamelStore *store, const char *display_name)
+em_folder_tree_model_add_store (EMFolderTreeModel *model, CamelStore *store, const gchar *display_name)
 {
 	struct _EMFolderTreeModelStoreInfo *si;
 	GtkTreeRowReference *row;
 	GtkTreeIter root, iter;
 	GtkTreePath *path;
 	EAccount *account;
-	char *uri;
+	gchar *uri;
 
 	g_return_if_fail (EM_IS_FOLDER_TREE_MODEL (model));
 	g_return_if_fail (CAMEL_IS_STORE (store));
@@ -841,6 +899,7 @@ em_folder_tree_model_add_store (EMFolderTreeModel *model, CamelStore *store, con
 			    COL_BOOL_IS_STORE, FALSE,
 			    COL_STRING_URI, NULL,
 			    COL_UINT_UNREAD, 0,
+			    COL_UINT_UNREAD_LAST_SEL, 0,
 			    -1);
 
 	g_free (uri);
@@ -858,7 +917,7 @@ em_folder_tree_model_add_store (EMFolderTreeModel *model, CamelStore *store, con
 }
 
 static void
-em_folder_tree_model_remove_uri (EMFolderTreeModel *model, const char *uri)
+em_folder_tree_model_remove_uri (EMFolderTreeModel *model, const gchar *uri)
 {
 	g_return_if_fail (EM_IS_FOLDER_TREE_MODEL (model));
 	g_return_if_fail (uri != NULL);
@@ -878,15 +937,16 @@ em_folder_tree_model_remove_store_info (EMFolderTreeModel *model, CamelStore *st
 	if (!(si = g_hash_table_lookup (model->store_hash, store)))
 		return;
 
-	g_hash_table_remove (model->store_hash, si->store);
 	g_hash_table_remove (model->account_hash, si->account);
+	/* store_hash owns and frees the si structure, thus free it after done with it */
+	g_hash_table_remove (model->store_hash, si->store);
 }
 
 
 void
 em_folder_tree_model_remove_folders (EMFolderTreeModel *model, struct _EMFolderTreeModelStoreInfo *si, GtkTreeIter *toplevel)
 {
-	char *uri, *full_name;
+	gchar *uri, *full_name;
 	gboolean is_store, go;
 	GtkTreeIter iter;
 
@@ -943,15 +1003,15 @@ em_folder_tree_model_remove_store (EMFolderTreeModel *model, CamelStore *store)
 
 
 static xmlNodePtr
-find_xml_node (xmlNodePtr root, const char *name)
+find_xml_node (xmlNodePtr root, const gchar *name)
 {
 	xmlNodePtr node;
-	char *nname;
+	gchar *nname;
 
 	node = root->children;
 	while (node != NULL) {
-		if (!strcmp ((char *)node->name, "node")) {
-			nname = (char *)xmlGetProp (node, (const unsigned char *)"name");
+		if (!strcmp ((gchar *)node->name, "node")) {
+			nname = (gchar *)xmlGetProp (node, (const guchar *)"name");
 			if (nname && !strcmp (nname, name)) {
 				xmlFree (nname);
 				return node;
@@ -967,18 +1027,18 @@ find_xml_node (xmlNodePtr root, const char *name)
 }
 
 gboolean
-em_folder_tree_model_get_expanded (EMFolderTreeModel *model, const char *key)
+em_folder_tree_model_get_expanded (EMFolderTreeModel *model, const gchar *key)
 {
 	xmlNodePtr node;
-	const char *name;
-	char *buf, *p;
+	const gchar *name;
+	gchar *buf, *p;
 
 	/* This code needs to be rewritten.
 	   First it doesn't belong on the model
 	   Second, it shouldn't use an xml tree to store a bit table in memory! */
 
 	node = model->state ? model->state->children : NULL;
-	if (!node || strcmp ((char *)node->name, "tree-state") != 0)
+	if (!node || strcmp ((gchar *)node->name, "tree-state") != 0)
 		return FALSE;
 
 	name = buf = g_alloca (strlen (key) + 1);
@@ -994,8 +1054,8 @@ em_folder_tree_model_get_expanded (EMFolderTreeModel *model, const char *key)
 		if ((node = find_xml_node (node, name))) {
 			gboolean expanded;
 
-			buf = (char *)xmlGetProp (node, (const unsigned char *)"expand");
-			expanded = buf && !strcmp ((char *)buf, "true");
+			buf = (gchar *)xmlGetProp (node, (const guchar *)"expand");
+			expanded = buf && !strcmp ((gchar *)buf, "true");
 			xmlFree (buf);
 
 			if (!expanded || p == NULL)
@@ -1010,17 +1070,17 @@ em_folder_tree_model_get_expanded (EMFolderTreeModel *model, const char *key)
 
 
 void
-em_folder_tree_model_set_expanded (EMFolderTreeModel *model, const char *key, gboolean expanded)
+em_folder_tree_model_set_expanded (EMFolderTreeModel *model, const gchar *key, gboolean expanded)
 {
 	xmlNodePtr node, parent;
-	const char *name;
-	char *buf, *p;
+	const gchar *name;
+	gchar *buf, *p;
 
 	if (model->state == NULL)
-		model->state = xmlNewDoc ((const unsigned char *)"1.0");
+		model->state = xmlNewDoc ((const guchar *)"1.0");
 
 	if (!model->state->children) {
-		node = xmlNewDocNode (model->state, NULL, (const unsigned char *)"tree-state", NULL);
+		node = xmlNewDocNode (model->state, NULL, (const guchar *)"tree-state", NULL);
 		xmlDocSetRootElement (model->state, node);
 	} else {
 		node = model->state->children;
@@ -1044,11 +1104,11 @@ em_folder_tree_model_set_expanded (EMFolderTreeModel *model, const char *key, gb
 			}
 
 			/* node (or parent node) doesn't exist, need to add it */
-			node = xmlNewChild (parent, NULL, (const unsigned char *)"node", NULL);
-			xmlSetProp (node, (const unsigned char *)"name", (unsigned char *)name);
+			node = xmlNewChild (parent, NULL, (const guchar *)"node", NULL);
+			xmlSetProp (node, (const guchar *)"name", (guchar *)name);
 		}
 
-		xmlSetProp (node, (const unsigned char *)"expand", (const unsigned char *)(expanded || p ? "true" : "false"));
+		xmlSetProp (node, (const guchar *)"expand", (const guchar *)(expanded || p ? "true" : "false"));
 
 		name = p ? p + 1 : NULL;
 	} while (name);
@@ -1061,7 +1121,7 @@ em_folder_tree_model_set_expanded (EMFolderTreeModel *model, const char *key, gb
  * @return Key of the uri or NULL, if failed. Returned value should be clear by g_free.
  **/
 static gchar *
-emftm_uri_to_key (const char *uri)
+emftm_uri_to_key (const gchar *uri)
 {
 	CamelException ex = { 0 };
 	CamelStore *store;
@@ -1079,7 +1139,7 @@ emftm_uri_to_key (const char *uri)
 	if (store == NULL || url == NULL) {
 		key = NULL;
 	} else {
-		const char *path;
+		const gchar *path;
 		EAccount *account;
 
 		if (((CamelService *)store)->provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH)
@@ -1112,7 +1172,7 @@ emftm_uri_to_key (const char *uri)
  * Same as @ref em_folder_tree_model_get_expanded, but here we use uri, not key for node.
  **/
 gboolean
-em_folder_tree_model_get_expanded_uri (EMFolderTreeModel *model, const char *uri)
+em_folder_tree_model_get_expanded_uri (EMFolderTreeModel *model, const gchar *uri)
 {
 	gchar *key;
 	gboolean expanded;
@@ -1133,7 +1193,7 @@ em_folder_tree_model_get_expanded_uri (EMFolderTreeModel *model, const char *uri
  * Same as @ref em_folder_tree_model_set_expanded, but here we use uri, not key for node.
  **/
 void
-em_folder_tree_model_set_expanded_uri (EMFolderTreeModel *model, const char *uri, gboolean expanded)
+em_folder_tree_model_set_expanded_uri (EMFolderTreeModel *model, const gchar *uri, gboolean expanded)
 {
 	gchar *key;
 
@@ -1150,7 +1210,7 @@ em_folder_tree_model_set_expanded_uri (EMFolderTreeModel *model, const char *uri
 void
 em_folder_tree_model_save_state (EMFolderTreeModel *model)
 {
-	char *dirname;
+	gchar *dirname;
 
 	if (model->state == NULL)
 		return;
@@ -1168,17 +1228,17 @@ em_folder_tree_model_save_state (EMFolderTreeModel *model)
 
 
 static void
-expand_foreach_r (EMFolderTreeModel *model, xmlNodePtr parent, const char *dirname, EMFTModelExpandFunc func, void *user_data)
+expand_foreach_r (EMFolderTreeModel *model, xmlNodePtr parent, const gchar *dirname, EMFTModelExpandFunc func, gpointer user_data)
 {
 	xmlNodePtr node = parent->children;
-	char *path, *name, *expand;
+	gchar *path, *name, *expand;
 
 	while (node != NULL) {
-		if (!strcmp ((char *)node->name, "node")) {
-			name = (char *)xmlGetProp (node, (const unsigned char *)"name");
-			expand = (char *)xmlGetProp (node, (const unsigned char *)"expand");
+		if (!strcmp ((gchar *)node->name, "node")) {
+			name = (gchar *)xmlGetProp (node, (const guchar *)"name");
+			expand = (gchar *)xmlGetProp (node, (const guchar *)"expand");
 
-			if (expand && name && !strcmp ((char *)expand, "true")) {
+			if (expand && name && !strcmp ((gchar *)expand, "true")) {
 				if (dirname)
 					path = g_strdup_printf ("%s/%s", dirname, name);
 				else
@@ -1199,19 +1259,19 @@ expand_foreach_r (EMFolderTreeModel *model, xmlNodePtr parent, const char *dirna
 }
 
 void
-em_folder_tree_model_expand_foreach (EMFolderTreeModel *model, EMFTModelExpandFunc func, void *user_data)
+em_folder_tree_model_expand_foreach (EMFolderTreeModel *model, EMFTModelExpandFunc func, gpointer user_data)
 {
 	xmlNodePtr root;
 
 	root = model->state ? model->state->children : NULL;
-	if (!root || !root->children || strcmp ((char *)root->name, "tree-state") != 0)
+	if (!root || !root->children || strcmp ((gchar *)root->name, "tree-state") != 0)
 		return;
 
 	expand_foreach_r (model, root, NULL, func, user_data);
 }
 
 gboolean
-em_folder_tree_model_is_type_inbox (EMFolderTreeModel *model, CamelStore *store, const char *full)
+em_folder_tree_model_is_type_inbox (EMFolderTreeModel *model, CamelStore *store, const gchar *full)
 {
 	struct _EMFolderTreeModelStoreInfo *si;
 	GtkTreeRowReference *row;
@@ -1251,14 +1311,14 @@ em_folder_tree_model_is_type_inbox (EMFolderTreeModel *model, CamelStore *store,
 	return FALSE;
 }
 
-char *
-em_folder_tree_model_get_folder_name (EMFolderTreeModel *model, CamelStore *store, const char *full)
+gchar *
+em_folder_tree_model_get_folder_name (EMFolderTreeModel *model, CamelStore *store, const gchar *full)
 {
 	struct _EMFolderTreeModelStoreInfo *si;
 	GtkTreeRowReference *row;
 	GtkTreePath *tree_path;
 	GtkTreeIter iter;
-	char *name = NULL;
+	gchar *name = NULL;
 
 	g_return_val_if_fail (EM_IS_FOLDER_TREE_MODEL (model), FALSE);
 	g_return_val_if_fail (CAMEL_IS_STORE (store), FALSE);
@@ -1288,12 +1348,14 @@ em_folder_tree_model_get_folder_name (EMFolderTreeModel *model, CamelStore *stor
 }
 
 void
-em_folder_tree_model_set_unread_count (EMFolderTreeModel *model, CamelStore *store, const char *full, int unread)
+em_folder_tree_model_set_unread_count (EMFolderTreeModel *model, CamelStore *store, const gchar *full, gint unread)
 {
 	struct _EMFolderTreeModelStoreInfo *si;
 	GtkTreeRowReference *row;
 	GtkTreePath *tree_path;
 	GtkTreeIter iter;
+	guint old_unread = 0;
+	gchar *uri, *sel_uri;
 
 	g_return_if_fail (EM_IS_FOLDER_TREE_MODEL (model));
 	g_return_if_fail (CAMEL_IS_STORE (store));
@@ -1322,26 +1384,39 @@ em_folder_tree_model_set_unread_count (EMFolderTreeModel *model, CamelStore *sto
 
 	gtk_tree_path_free (tree_path);
 
-	gtk_tree_store_set ((GtkTreeStore *) model, &iter, COL_UINT_UNREAD, unread, -1);
+	sel_uri = em_folder_tree_model_get_selected (model);
+	gtk_tree_model_get (
+		GTK_TREE_MODEL (model), &iter,
+		COL_UINT_UNREAD_LAST_SEL, &old_unread,
+		COL_STRING_URI, &uri, -1);
+	if (!(g_strcmp0 (sel_uri, uri) != 0 && unread > old_unread))
+		old_unread = unread;
+	gtk_tree_store_set (
+		GTK_TREE_STORE (model), &iter,
+		COL_UINT_UNREAD, unread,
+		COL_UINT_UNREAD_LAST_SEL, old_unread, -1);
+
+	g_free (uri);
+	g_free (sel_uri);
 
 	/* May be this is from where we should propagate unread count to parents etc. */
 	emft_model_unread_count_changed (GTK_TREE_MODEL (model), &iter);
 }
 
 
-char *
+gchar *
 em_folder_tree_model_get_selected (EMFolderTreeModel *model)
 {
 	xmlNodePtr node;
-	char *buf, *uri;
+	gchar *buf, *uri;
 
 	node = model->state ? model->state->children : NULL;
-	if (!node || strcmp ((char *)node->name, "tree-state") != 0)
+	if (!node || strcmp ((gchar *)node->name, "tree-state") != 0)
 		return NULL;
 
 	node = node->children;
 	while (node != NULL) {
-		if (!strcmp ((char *)node->name, "selected"))
+		if (!strcmp ((gchar *)node->name, "selected"))
 			break;
 		node = node->next;
 	}
@@ -1349,7 +1424,7 @@ em_folder_tree_model_get_selected (EMFolderTreeModel *model)
 	if (node == NULL)
 		return NULL;
 
-	buf = (char *)xmlGetProp (node, (unsigned char *)"uri");
+	buf = (gchar *)xmlGetProp (node, (guchar *)"uri");
 	uri = g_strdup (buf);
 	xmlFree (buf);
 
@@ -1362,15 +1437,15 @@ em_folder_tree_model_get_selected (EMFolderTreeModel *model)
 
 
 void
-em_folder_tree_model_set_selected (EMFolderTreeModel *model, const char *uri)
+em_folder_tree_model_set_selected (EMFolderTreeModel *model, const gchar *uri)
 {
 	xmlNodePtr root, node;
 
 	if (model->state == NULL)
-		model->state = xmlNewDoc ((unsigned char *)"1.0");
+		model->state = xmlNewDoc ((guchar *)"1.0");
 
 	if (!model->state->children) {
-		root = xmlNewDocNode (model->state, NULL, (const unsigned char *)"tree-state", NULL);
+		root = xmlNewDocNode (model->state, NULL, (const guchar *)"tree-state", NULL);
 		xmlDocSetRootElement (model->state, root);
 	} else {
 		root = model->state->children;
@@ -1378,13 +1453,13 @@ em_folder_tree_model_set_selected (EMFolderTreeModel *model, const char *uri)
 
 	node = root->children;
 	while (node != NULL) {
-		if (!strcmp ((char *)node->name, "selected"))
+		if (!strcmp ((gchar *)node->name, "selected"))
 			break;
 		node = node->next;
 	}
 
 	if (node == NULL)
-		node = xmlNewChild (root, NULL, (const unsigned char *)"selected", NULL);
+		node = xmlNewChild (root, NULL, (const guchar *)"selected", NULL);
 
-	xmlSetProp (node, (const unsigned char *)"uri", (unsigned char *)uri);
+	xmlSetProp (node, (const guchar *)"uri", (guchar *)uri);
 }
