@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -38,9 +38,9 @@ static void em_html_stream_class_init (EMHTMLStreamClass *klass);
 static void em_html_stream_init (CamelObject *object);
 static void em_html_stream_finalize (CamelObject *object);
 
-static ssize_t emhs_sync_write(CamelStream *stream, const char *buffer, size_t n);
-static int emhs_sync_close(CamelStream *stream);
-static int emhs_sync_flush(CamelStream *stream);
+static gssize emhs_sync_write(CamelStream *stream, const gchar *buffer, gsize n);
+static gint emhs_sync_close(CamelStream *stream);
+static gint emhs_sync_flush(CamelStream *stream);
 
 static EMSyncStreamClass *parent_class = NULL;
 
@@ -103,8 +103,8 @@ em_html_stream_finalize (CamelObject *object)
 	}
 }
 
-static ssize_t
-emhs_sync_write(CamelStream *stream, const char *buffer, size_t n)
+static gssize
+emhs_sync_write(CamelStream *stream, const gchar *buffer, gsize n)
 {
 	EMHTMLStream *emhs = EM_HTML_STREAM (stream);
 
@@ -116,10 +116,10 @@ emhs_sync_write(CamelStream *stream, const char *buffer, size_t n)
 
 	gtk_html_stream_write(emhs->html_stream, buffer, n);
 
-	return (ssize_t) n;
+	return (gssize) n;
 }
 
-static int
+static gint
 emhs_sync_flush(CamelStream *stream)
 {
 	EMHTMLStream *emhs = (EMHTMLStream *)stream;
@@ -132,7 +132,7 @@ emhs_sync_flush(CamelStream *stream)
 	return 0;
 }
 
-static int
+static gint
 emhs_sync_close(CamelStream *stream)
 {
 	EMHTMLStream *emhs = (EMHTMLStream *)stream;
