@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -29,7 +29,6 @@
 #include <string.h>
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gdk-pixbuf/gdk-pixbuf-loader.h>
 #include <gtk/gtk.h>
 #include "em-icon-stream.h"
 #include "e-util/e-icon-factory.h"
@@ -51,15 +50,15 @@ static void em_icon_stream_class_init (EMIconStreamClass *klass);
 static void em_icon_stream_init (CamelObject *object);
 static void em_icon_stream_finalize (CamelObject *object);
 
-static ssize_t emis_sync_write(CamelStream *stream, const char *buffer, size_t n);
-static int emis_sync_close(CamelStream *stream);
-static int emis_sync_flush(CamelStream *stream);
+static gssize emis_sync_write(CamelStream *stream, const gchar *buffer, gsize n);
+static gint emis_sync_close(CamelStream *stream);
+static gint emis_sync_flush(CamelStream *stream);
 
 static EMSyncStreamClass *parent_class = NULL;
 static EMCache *emis_cache;
 
 static void
-emis_cache_free(void *data)
+emis_cache_free(gpointer data)
 {
 	struct _emis_cache_node *node = data;
 
@@ -133,33 +132,33 @@ em_icon_stream_finalize(CamelObject *object)
 	emis_cleanup(emis);
 }
 
-static ssize_t
-emis_sync_write(CamelStream *stream, const char *buffer, size_t n)
+static gssize
+emis_sync_write(CamelStream *stream, const gchar *buffer, gsize n)
 {
 	EMIconStream *emis = EM_ICON_STREAM (stream);
 
 	if (emis->loader == NULL)
 		return -1;
 
-	if (!gdk_pixbuf_loader_write(emis->loader, (const unsigned char *)buffer, n, NULL)) {
+	if (!gdk_pixbuf_loader_write(emis->loader, (const guchar *)buffer, n, NULL)) {
 		emis_cleanup(emis);
 		return -1;
 	}
 
-	return (ssize_t) n;
+	return (gssize) n;
 }
 
-static int
+static gint
 emis_sync_flush(CamelStream *stream)
 {
 	return 0;
 }
 
 static GdkPixbuf *
-emis_fit(GdkPixbuf *pixbuf, int maxwidth, int maxheight, int *scale)
+emis_fit(GdkPixbuf *pixbuf, gint maxwidth, gint maxheight, gint *scale)
 {
 	GdkPixbuf *mini = NULL;
-	int width, height;
+	gint width, height;
 
 	width = gdk_pixbuf_get_width(pixbuf);
 	height = gdk_pixbuf_get_height(pixbuf);
@@ -191,14 +190,14 @@ emis_fit(GdkPixbuf *pixbuf, int maxwidth, int maxheight, int *scale)
 	return mini;
 }
 
-static int
+static gint
 emis_sync_close(CamelStream *stream)
 {
 	EMIconStream *emis = (EMIconStream *)stream;
 	GdkPixbuf *pixbuf, *mini;
 	struct _emis_cache_node *node;
-	char *scalekey;
-	int scale;
+	gchar *scalekey;
+	gint scale;
 
 	if (emis->loader == NULL)
 		return -1;
@@ -245,7 +244,7 @@ emis_image_destroy(struct _GtkImage *image, EMIconStream *emis)
 }
 
 CamelStream *
-em_icon_stream_new(GtkImage *image, const char *key, unsigned int maxwidth, unsigned int maxheight, int keep)
+em_icon_stream_new(GtkImage *image, const gchar *key, guint maxwidth, guint maxheight, gint keep)
 {
 	EMIconStream *new;
 
@@ -262,11 +261,11 @@ em_icon_stream_new(GtkImage *image, const char *key, unsigned int maxwidth, unsi
 }
 
 GdkPixbuf *
-em_icon_stream_get_image(const char *tkey, unsigned int maxwidth, unsigned int maxheight)
+em_icon_stream_get_image(const gchar *tkey, guint maxwidth, guint maxheight)
 {
 	struct _emis_cache_node *node;
 	GdkPixbuf *pb = NULL;
-	const char *key;
+	const gchar *key;
 
 	key = tkey ? tkey : "";
 
@@ -275,7 +274,7 @@ em_icon_stream_get_image(const char *tkey, unsigned int maxwidth, unsigned int m
 
 	node = (struct _emis_cache_node *)em_cache_lookup(emis_cache, key);
 	if (node) {
-		int width, height;
+		gint width, height;
 
 		pb = node->pixbuf;
 		g_object_ref(pb);
@@ -286,8 +285,8 @@ em_icon_stream_get_image(const char *tkey, unsigned int maxwidth, unsigned int m
 
 		if ((maxwidth && width > maxwidth)
 		    || (maxheight && height > maxheight)) {
-			unsigned int scale;
-			char *realkey;
+			guint scale;
+			gchar *realkey;
 
 			if (maxheight == 0 || width >= height)
 				scale = width * EMIS_SCALE / maxwidth;
@@ -318,12 +317,12 @@ em_icon_stream_get_image(const char *tkey, unsigned int maxwidth, unsigned int m
 	return pb;
 }
 
-int
-em_icon_stream_is_resized(const char *tkey, unsigned int maxwidth, unsigned int maxheight)
+gint
+em_icon_stream_is_resized(const gchar *tkey, guint maxwidth, guint maxheight)
 {
-	int res = FALSE;
+	gint res = FALSE;
 	struct _emis_cache_node *node;
-	const char *key;
+	const gchar *key;
 
 	key = tkey ? tkey : "";
 
