@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Vivek Jain <jvivek@novell.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2005 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Vivek Jain <jvivek@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -29,7 +29,6 @@
 #include <glib.h>
 #include "em-junk-hook.h"
 #include "mail-session.h"
-#include <e-util/e-icon-factory.h>
 #include "e-util/e-error.h"
 #include "em-utils.h"
 #include <camel/camel-junk-plugin.h>
@@ -38,7 +37,7 @@
 static GHashTable *emjh_types;
 static GObjectClass *parent_class = NULL;
 
-static void *emjh_parent_class;
+static gpointer emjh_parent_class;
 static GObjectClass *emj_parent;
 #define emjh ((EMJunkHook *)eph)
 
@@ -56,7 +55,7 @@ static const EPluginHookTargetKey emjh_flag_map[] = {
   <hook class="org.gnome.evolution.mail.junk:1.0">
   <group id="EMJunk">
      <item check_junk="sa_check_junk"
-     	   report_junk="sa_report_junk"
+	   report_junk="sa_report_junk"
 	   report_non_junk="sa_report_non_junk"
 	   commit_reports = "sa_commit_reports"/>
   </group>
@@ -64,7 +63,7 @@ static const EPluginHookTargetKey emjh_flag_map[] = {
 
 */
 
-static void manage_error (const char *msg, GError *error);
+static void manage_error (const gchar *msg, GError *error);
 
 GQuark
 em_junk_error_quark (void)
@@ -72,7 +71,7 @@ em_junk_error_quark (void)
 	return g_quark_from_static_string ("em-junk-error-quark");
 }
 
-static const char *
+static const gchar *
 em_junk_get_name (CamelJunkPlugin *csp);
 
 static void
@@ -83,7 +82,7 @@ em_junk_init(CamelJunkPlugin *csp)
 	((EPluginClass *)G_OBJECT_GET_CLASS(item->hook->hook.plugin))->enable(item->hook->hook.plugin, 1);
 }
 
-static const char *
+static const gchar *
 em_junk_get_name (CamelJunkPlugin *csp)
 {
 	struct _EMJunkHookItem *item = (EMJunkHookItem *)csp;
@@ -91,7 +90,7 @@ em_junk_get_name (CamelJunkPlugin *csp)
 	if (item->hook && item->hook->hook.plugin->enabled) {
 		return (item->hook->hook.plugin->name);
 	} else
-		return 	_("None");
+		return	_("None");
 
 }
 
@@ -249,7 +248,7 @@ emjh_construct_group(EPluginHook *eph, xmlNodePtr root)
 
 	/* We'll processs only  the first item from xml file*/
 	while (node) {
-		if (0 == strcmp((char *)node->name, "item")) {
+		if (0 == strcmp((gchar *)node->name, "item")) {
 			struct _EMJunkHookItem *item;
 
 			item = emjh_construct_item(eph, group, node);
@@ -268,7 +267,7 @@ error:
 	return NULL;
 }
 
-static int
+static gint
 emjh_construct(EPluginHook *eph, EPlugin *ep, xmlNodePtr root)
 {
 	xmlNodePtr node;
@@ -285,7 +284,7 @@ emjh_construct(EPluginHook *eph, EPlugin *ep, xmlNodePtr root)
 
 	node = root->children;
 	while (node) {
-		if (strcmp((char *)node->name, "group") == 0) {
+		if (strcmp((gchar *)node->name, "group") == 0) {
 			struct _EMJunkHookGroup *group;
 
 			group = emjh_construct_group(eph, node);
@@ -301,23 +300,57 @@ emjh_construct(EPluginHook *eph, EPlugin *ep, xmlNodePtr root)
 	return 0;
 }
 
+struct manage_error_idle_data
+{
+	const gchar *msg;
+	GError *error;
+};
+
 static void
-manage_error (const char *msg, GError *error)
+free_mei (gpointer data)
+{
+	struct manage_error_idle_data *mei = (struct manage_error_idle_data*) data;
+
+	if (!mei)
+		return;
+
+	g_error_free (mei->error);
+	g_free (mei);
+}
+
+static gboolean
+manage_error_idle (gpointer data)
 {
 	GtkWidget *w;
+	struct manage_error_idle_data *mei = (struct manage_error_idle_data *) data;
+
+	if (!mei)
+		return FALSE;
+
+	w = e_error_new (NULL, mei->msg, mei->error->message, NULL);
+	em_utils_show_error_silent (w);
+
+	return FALSE;
+}
+
+static void
+manage_error (const gchar *msg, GError *error)
+{
+	struct manage_error_idle_data *mei;
 
 	if (!error)
 		return;
 
-	w = e_error_new (NULL, msg, error->message, NULL);
-	em_utils_show_error_silent (w);
+	mei = g_new0 (struct manage_error_idle_data, 1);
+	mei->msg = msg; /* it's a static string, should be safe to use it as this */
+	mei->error = error;
 
-	g_error_free (error);
+	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, manage_error_idle, mei, free_mei);
 }
 
 /*XXX: don't think we need here*/
 static void
-emjh_enable(EPluginHook *eph, int state)
+emjh_enable(EPluginHook *eph, gint state)
 {
 	GSList *g;
 
@@ -403,5 +436,5 @@ em_junk_hook_register_type(GType type)
 	d(printf("registering junk plugin type '%s'\n", g_type_name(type)));
 
 	klass = g_type_class_ref(type);
-	g_hash_table_insert(emjh_types, (void *)g_type_name(type), klass);
+	g_hash_table_insert(emjh_types, (gpointer)g_type_name(type), klass);
 }
