@@ -1,26 +1,25 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Veerapuram Varadhan  <vvaradhan@novell.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2007 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ * Authors:
+ *		Veerapuram Varadhan  <vvaradhan@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
-
 #ifndef __EM_NETWORK_PREFS_H__
 #define __EM_NETWORK_PREFS_H__
 
@@ -55,23 +54,26 @@ typedef enum {
 
 struct _EMNetworkPrefs {
 	GtkVBox parent_object;
-	
+
 	struct _GConfClient *gconf;
-	
+
 	struct _GladeXML *gui;
-	
+
 	/* Default Behavior */
 	struct _GtkToggleButton *sys_proxy;
 	struct _GtkToggleButton *no_proxy;
 	struct _GtkToggleButton *manual_proxy;
+#if 0
 	struct _GtkToggleButton *auto_proxy;
+#endif
 	struct _GtkToggleButton *use_auth;
 
 	struct _GtkEntry *http_host;
 	struct _GtkEntry *https_host;
-	struct _GtkEntry *socks_host;
 	struct _GtkEntry *ignore_hosts;
+#if 0
 	struct _GtkEntry *auto_proxy_url;
+#endif
 	struct _GtkEntry *auth_user;
 	struct _GtkEntry *auth_pwd;
 
@@ -79,22 +81,25 @@ struct _EMNetworkPrefs {
 	struct _GtkLabel *lbl_http_port;
 	struct _GtkLabel *lbl_https_host;
 	struct _GtkLabel *lbl_https_port;
-	struct _GtkLabel *lbl_socks_host;
-	struct _GtkLabel *lbl_socks_port;	
 	struct _GtkLabel *lbl_ignore_hosts;
 	struct _GtkLabel *lbl_auth_user;
 	struct _GtkLabel *lbl_auth_pwd;
 
 	struct _GtkSpinButton *http_port;
 	struct _GtkSpinButton *https_port;
-	struct _GtkSpinButton *socks_port;	
+#if 0
+	struct _GtkLabel *lbl_socks_host;
+	struct _GtkEntry *socks_host;
+	struct _GtkLabel *lbl_socks_port;
+	struct _GtkSpinButton *socks_port;
+#endif
 };
 
 struct _EMNetworkPrefsClass {
 	GtkVBoxClass parent_class;
-	
+
 	/* signals */
-	
+
 };
 
 GType em_network_prefs_get_type (void);
