@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -55,7 +55,7 @@
 #include <e-util/e-util.h>
 #include "e-attachment.h"
 
-static void emp_standard_menu_factory(EPopup *emp, void *data);
+static void emp_standard_menu_factory(EPopup *emp, gpointer data);
 
 static GObjectClass *emp_parent;
 
@@ -135,7 +135,7 @@ em_popup_get_type(void)
 	return type;
 }
 
-EMPopup *em_popup_new(const char *menuid)
+EMPopup *em_popup_new(const gchar *menuid)
 {
 	EMPopup *emp = g_object_new(em_popup_get_type(), NULL);
 
@@ -155,14 +155,14 @@ EMPopup *em_popup_new(const char *menuid)
  * Return value:
  **/
 EMPopupTargetSelect *
-em_popup_target_new_select(EMPopup *emp, struct _CamelFolder *folder, const char *folder_uri, GPtrArray *uids)
+em_popup_target_new_select(EMPopup *emp, struct _CamelFolder *folder, const gchar *folder_uri, GPtrArray *uids)
 {
 	EMPopupTargetSelect *t = e_popup_target_new(&emp->popup, EM_POPUP_TARGET_SELECT, sizeof(*t));
 	CamelStore *store = CAMEL_STORE (folder->parent_store);
 	guint32 mask = ~0;
 	gboolean draft_or_outbox;
-	int i;
-	const char *tmp;
+	gint i;
+	const gchar *tmp;
 
 	t->uids = uids;
 	t->folder = folder;
@@ -251,7 +251,7 @@ em_popup_target_new_select(EMPopup *emp, struct _CamelFolder *folder, const char
 }
 
 EMPopupTargetURI *
-em_popup_target_new_uri(EMPopup *emp, const char *uri)
+em_popup_target_new_uri(EMPopup *emp, const gchar *uri)
 {
 	EMPopupTargetURI *t = e_popup_target_new(&emp->popup, EM_POPUP_TARGET_URI, sizeof(*t));
 	guint32 mask = ~0;
@@ -261,10 +261,6 @@ em_popup_target_new_uri(EMPopup *emp, const char *uri)
 	if (g_ascii_strncasecmp(uri, "http:", 5) == 0
 	    || g_ascii_strncasecmp(uri, "https:", 6) == 0)
 		mask &= ~EM_POPUP_URI_HTTP;
-	else if (g_ascii_strncasecmp(uri, "sip:", 3) == 0
-	    || g_ascii_strncasecmp(uri, "h323:", 5) == 0
-	    || g_ascii_strncasecmp(uri, "callto:", 7) == 0)
-		mask &= ~EM_POPUP_URI_CALLTO;
 
 	if (g_ascii_strncasecmp(uri, "mailto:", 7) == 0)
 		mask &= ~EM_POPUP_URI_MAILTO;
@@ -277,7 +273,7 @@ em_popup_target_new_uri(EMPopup *emp, const char *uri)
 }
 
 EMPopupTargetPart *
-em_popup_target_new_part(EMPopup *emp, struct _CamelMimePart *part, const char *mime_type)
+em_popup_target_new_part(EMPopup *emp, struct _CamelMimePart *part, const gchar *mime_type)
 {
 	EMPopupTargetPart *t = e_popup_target_new(&emp->popup, EM_POPUP_TARGET_PART, sizeof(*t));
 	guint32 mask = ~0;
@@ -304,7 +300,7 @@ em_popup_target_new_part(EMPopup *emp, struct _CamelMimePart *part, const char *
 
 /* TODO: This should be based on the CamelFolderInfo, but ... em-folder-tree doesn't keep it? */
 EMPopupTargetFolder *
-em_popup_target_new_folder (EMPopup *emp, const char *uri, guint32 info_flags, guint32 popup_flags)
+em_popup_target_new_folder (EMPopup *emp, const gchar *uri, guint32 info_flags, guint32 popup_flags)
 {
 	EMPopupTargetFolder *t = e_popup_target_new(&emp->popup, EM_POPUP_TARGET_FOLDER, sizeof(*t));
 	guint32 mask = ~0;
@@ -322,7 +318,7 @@ em_popup_target_new_folder (EMPopup *emp, const char *uri, guint32 info_flags, g
 		goto done;
 
 	if (!(popup_flags & EM_POPUP_FOLDER_STORE)) {
-		const char *path;
+		const gchar *path;
 
 		if (popup_flags & EM_POPUP_FOLDER_DELETE)
 			mask &= ~EM_POPUP_FOLDER_DELETE;
@@ -358,7 +354,7 @@ done:
 /* ********************************************************************** */
 
 static void
-emp_part_popup_saveas(EPopup *ep, EPopupItem *item, void *data)
+emp_part_popup_saveas(EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EPopupTarget *t = ep->target;
 	CamelMimePart *part = NULL;
@@ -369,12 +365,12 @@ emp_part_popup_saveas(EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-emp_part_popup_set_background(EPopup *ep, EPopupItem *item, void *data)
+emp_part_popup_set_background(EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EPopupTarget *t = ep->target;
 	GConfClient *gconf;
-	char *str, *filename, *path, *extension;
-	unsigned int i=1;
+	gchar *str, *filename, *path, *extension;
+	guint i=1;
 	CamelMimePart *part = NULL;
 
 	part = ((EMPopupTargetPart *) t)->part;
@@ -403,7 +399,7 @@ emp_part_popup_set_background(EPopup *ep, EPopupItem *item, void *data)
 
 	/* if file exists, stick a (number) on the end */
 	while (g_file_test(path, G_FILE_TEST_EXISTS)) {
-		char *name;
+		gchar *name;
 		name = g_strdup_printf(extension?"%s (%d).%s":"%s (%d)", filename, i++, extension);
 		g_free(path);
 		path = g_build_filename(g_get_home_dir(), ".gnome2", "wallpapers", name, NULL);
@@ -442,7 +438,7 @@ emp_part_popup_set_background(EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-emp_part_popup_reply_sender(EPopup *ep, EPopupItem *item, void *data)
+emp_part_popup_reply_sender(EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EPopupTarget *t = ep->target;
 	CamelMimeMessage *message;
@@ -455,7 +451,7 @@ emp_part_popup_reply_sender(EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-emp_part_popup_reply_list (EPopup *ep, EPopupItem *item, void *data)
+emp_part_popup_reply_list (EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EPopupTarget *t = ep->target;
 	CamelMimeMessage *message;
@@ -468,7 +464,7 @@ emp_part_popup_reply_list (EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-emp_part_popup_reply_all (EPopup *ep, EPopupItem *item, void *data)
+emp_part_popup_reply_all (EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EPopupTarget *t = ep->target;
 	CamelMimeMessage *message;
@@ -481,7 +477,7 @@ emp_part_popup_reply_all (EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-emp_part_popup_forward (EPopup *ep, EPopupItem *item, void *data)
+emp_part_popup_forward (EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EPopupTarget *t = ep->target;
 	CamelMimeMessage *message;
@@ -495,22 +491,22 @@ emp_part_popup_forward (EPopup *ep, EPopupItem *item, void *data)
 }
 
 static EMPopupItem emp_standard_object_popups[] = {
-	{ E_POPUP_ITEM, "00.part.00", N_("_Save As..."), emp_part_popup_saveas, NULL, "document-save-as", 0 },
-	{ E_POPUP_ITEM, "00.part.10", N_("Set as _Background"), emp_part_popup_set_background, NULL, NULL, EM_POPUP_PART_IMAGE },
-	{ E_POPUP_BAR, "10.part", NULL, NULL, NULL, NULL, EM_POPUP_PART_MESSAGE },
-	{ E_POPUP_ITEM, "10.part.00", N_("_Reply to sender"), emp_part_popup_reply_sender, NULL, "mail-reply-sender" , EM_POPUP_PART_MESSAGE },
-	{ E_POPUP_ITEM, "10.part.01", N_("Reply to _List"), emp_part_popup_reply_list, NULL, NULL, EM_POPUP_PART_MESSAGE},
-	{ E_POPUP_ITEM, "10.part.03", N_("Reply to _All"), emp_part_popup_reply_all, NULL, "mail-reply-all", EM_POPUP_PART_MESSAGE},
-	{ E_POPUP_BAR, "20.part", NULL, NULL, NULL, NULL, EM_POPUP_PART_MESSAGE },
-	{ E_POPUP_ITEM, "20.part.00", N_("_Forward"), emp_part_popup_forward, NULL, "mail-forward", EM_POPUP_PART_MESSAGE },
+	{ E_POPUP_ITEM, (gchar *) "00.part.00", (gchar *) N_("_Save As..."), emp_part_popup_saveas, NULL, (gchar *) "document-save-as", 0 },
+	{ E_POPUP_ITEM, (gchar *) "00.part.10", (gchar *) N_("Set as _Background"), emp_part_popup_set_background, NULL, NULL, EM_POPUP_PART_IMAGE },
+	{ E_POPUP_BAR, (gchar *) "10.part", NULL, NULL, NULL, NULL, EM_POPUP_PART_MESSAGE },
+	{ E_POPUP_ITEM, (gchar *) "10.part.00", (gchar *) N_("_Reply to sender"), emp_part_popup_reply_sender, NULL, (gchar *) "mail-reply-sender" , EM_POPUP_PART_MESSAGE },
+	{ E_POPUP_ITEM, (gchar *) "10.part.01", (gchar *) N_("Reply to _List"), emp_part_popup_reply_list, NULL, NULL, EM_POPUP_PART_MESSAGE},
+	{ E_POPUP_ITEM, (gchar *) "10.part.03", (gchar *) N_("Reply to _All"), emp_part_popup_reply_all, NULL, (gchar *) "mail-reply-all", EM_POPUP_PART_MESSAGE},
+	{ E_POPUP_BAR, (gchar *) "20.part", NULL, NULL, NULL, NULL, EM_POPUP_PART_MESSAGE },
+	{ E_POPUP_ITEM, (gchar *) "20.part.00", (gchar *) N_("_Forward"), emp_part_popup_forward, NULL, (gchar *) "mail-forward", EM_POPUP_PART_MESSAGE },
 };
 
-static const EPopupItem emp_standard_part_apps_bar = { E_POPUP_BAR, "99.object" };
+static const EPopupItem emp_standard_part_apps_bar = { E_POPUP_BAR, (gchar *) "99.object" };
 
 /* ********************************************************************** */
 
 static void
-emp_uri_popup_link_open(EPopup *ep, EPopupItem *item, void *data)
+emp_uri_popup_link_open(EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EMPopupTargetURI *t = (EMPopupTargetURI *)ep->target;
 
@@ -519,7 +515,7 @@ emp_uri_popup_link_open(EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-emp_uri_popup_address_send(EPopup *ep, EPopupItem *item, void *data)
+emp_uri_popup_address_send(EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EMPopupTargetURI *t = (EMPopupTargetURI *)ep->target;
 
@@ -528,7 +524,7 @@ emp_uri_popup_address_send(EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-emp_uri_popup_address_add(EPopup *ep, EPopupItem *item, void *data)
+emp_uri_popup_address_add(EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EMPopupTargetURI *t = (EMPopupTargetURI *)ep->target;
 	CamelURL *url;
@@ -546,9 +542,9 @@ emp_uri_popup_address_add(EPopup *ep, EPopupItem *item, void *data)
 }
 
 static EPopupItem emp_standard_uri_popups[] = {
-	{ E_POPUP_ITEM, "00.uri.00", N_("_Open Link in Browser"), emp_uri_popup_link_open, NULL, NULL, EM_POPUP_URI_HTTP },
-	{ E_POPUP_ITEM, "00.uri.10", N_("_Send New Message To..."), emp_uri_popup_address_send, NULL, "mail-message-new", EM_POPUP_URI_MAILTO },
-	{ E_POPUP_ITEM, "00.uri.20", N_("_Add to Address Book"), emp_uri_popup_address_add, NULL, "contact-new", EM_POPUP_URI_MAILTO },
+	{ E_POPUP_ITEM, (gchar *) "00.uri.00", (gchar *) N_("_Open Link in Browser"), emp_uri_popup_link_open, NULL, NULL, EM_POPUP_URI_HTTP },
+	{ E_POPUP_ITEM, (gchar *) "00.uri.10", (gchar *) N_("_Send New Message To..."), emp_uri_popup_address_send, NULL, (gchar *) "mail-message-new", EM_POPUP_URI_MAILTO },
+	{ E_POPUP_ITEM, (gchar *) "00.uri.20", (gchar *) N_("_Add to Address Book"), emp_uri_popup_address_add, NULL, (gchar *) "contact-new", EM_POPUP_URI_MAILTO },
 };
 
 /* ********************************************************************** */
@@ -556,9 +552,9 @@ static EPopupItem emp_standard_uri_popups[] = {
 #define LEN(x) (sizeof(x)/sizeof(x[0]))
 
 static void
-emp_apps_open_in(EPopup *ep, EPopupItem *item, void *data)
+emp_apps_open_in(EPopup *ep, EPopupItem *item, gpointer data)
 {
-	char *path;
+	gchar *path;
 	EPopupTarget *target = ep->target;
 	CamelMimePart *part;
 
@@ -577,7 +573,7 @@ emp_apps_open_in(EPopup *ep, EPopupItem *item, void *data)
 			g_app_info_launch (app, uris, NULL, &error);
 			g_object_unref (file);
 		} else {
-			char *uri;
+			gchar *uri;
 
 			uri = e_util_filename_to_uri (path);
 			uris = g_list_append (uris, uri);
@@ -597,7 +593,7 @@ emp_apps_open_in(EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-emp_apps_popup_free(EPopup *ep, GSList *free_list, void *data)
+emp_apps_popup_free(EPopup *ep, GSList *free_list, gpointer data)
 {
 	while (free_list) {
 		GSList *n = free_list->next;
@@ -616,19 +612,19 @@ emp_apps_popup_free(EPopup *ep, GSList *free_list, void *data)
 }
 
 static void
-emp_standard_items_free(EPopup *ep, GSList *items, void *data)
+emp_standard_items_free(EPopup *ep, GSList *items, gpointer data)
 {
 	g_slist_free(items);
 }
 
 static void
-emp_add_vcard (EPopup *ep, EPopupItem *item, void *data)
+emp_add_vcard (EPopup *ep, EPopupItem *item, gpointer data)
 {
 	EPopupTarget *target = ep->target;
 	CamelMimePart *part;
 	CamelDataWrapper *content;
 	CamelStreamMem *mem;
-	
+
 
 	part = ((EMPopupTargetPart *) target)->part;
 
@@ -653,14 +649,14 @@ emp_add_vcard (EPopup *ep, EPopupItem *item, void *data)
 }
 
 static void
-emp_standard_menu_factory(EPopup *emp, void *data)
+emp_standard_menu_factory(EPopup *emp, gpointer data)
 {
-	int i, len;
+	gint i, len;
 	EPopupItem *items;
 	GSList *menus = NULL;
 	GList *apps = NULL;
-	char *mime_type = NULL;
-	const char *filename = NULL;
+	gchar *mime_type = NULL;
+	const gchar *filename = NULL;
 
 	switch (emp->target->type) {
 #if 0
@@ -718,7 +714,7 @@ emp_standard_menu_factory(EPopup *emp, void *data)
 			GSList *open_menus = NULL;
 			GList *l;
 
-			menus = g_slist_prepend(menus, (void *)&emp_standard_part_apps_bar);
+			menus = g_slist_prepend(menus, (gpointer)&emp_standard_part_apps_bar);
 
 			for (l = apps, i = 0; l; l = l->next, i++) {
 				GAppInfo *app = l->data;
@@ -747,11 +743,11 @@ emp_standard_menu_factory(EPopup *emp, void *data)
 
 			item = g_malloc0 (sizeof (*item));
 			item->type = E_POPUP_ITEM;
-			item->path = "00.00.vcf.00"; /* make it first item */
+			item->path = (gchar *) "00.00.vcf.00"; /* make it first item */
 			item->label = _("_Add to Address Book");
 			item->activate = emp_add_vcard;
 			item->user_data = NULL;
-			item->image = "contact-new";
+			item->image = (gchar *) "contact-new";
 
 			e_popup_add_items (emp, g_slist_append (NULL, item), NULL, NULL, NULL);
 		}
@@ -796,7 +792,7 @@ emp_standard_menu_factory(EPopup *emp, void *data)
 
 */
 
-static void *emph_parent_class;
+static gpointer emph_parent_class;
 #define emph ((EMPopupHook *)eph)
 
 static const EPopupHookTargetMask emph_select_masks[] = {
@@ -824,7 +820,6 @@ static const EPopupHookTargetMask emph_uri_masks[] = {
 	{ "http", EM_POPUP_URI_HTTP },
 	{ "mailto", EM_POPUP_URI_MAILTO },
 	{ "notmailto", EM_POPUP_URI_NOT_MAILTO },
-	{ "callto", EM_POPUP_URI_CALLTO },
 	{ NULL }
 };
 
@@ -864,7 +859,7 @@ emph_finalise(GObject *o)
 static void
 emph_class_init(EPluginHookClass *klass)
 {
-	int i;
+	gint i;
 
 	((GObjectClass *)klass)->finalize = emph_finalise;
 	((EPluginHookClass *)klass)->id = "org.gnome.evolution.mail.popup:1.0";
