@@ -1,22 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
  *
- *  Authors: Michel Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2003 Ximian, Inc. (www.ximian.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michel Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -42,7 +43,6 @@ typedef struct _EMPopupClass EMPopupClass;
  * @EM_POPUP_TARGET_URI: A URI.
  * @EM_POPUP_TARGET_PART: A CamelMimePart message part.
  * @EM_POPUP_TARGET_FOLDER: A folder URI.
- * @EM_POPUP_TARGET_ATTACHMENTS: A list of attachments.
  *
  * Defines the value of the targetid for all EMPopup target types.
  **/
@@ -50,8 +50,7 @@ enum _em_popup_target_t {
 	EM_POPUP_TARGET_SELECT,
 	EM_POPUP_TARGET_URI,
 	EM_POPUP_TARGET_PART,
-	EM_POPUP_TARGET_FOLDER,
-	EM_POPUP_TARGET_ATTACHMENTS,
+	EM_POPUP_TARGET_FOLDER
 };
 
 /**
@@ -105,7 +104,7 @@ enum _em_popup_target_select_t {
 	EM_POPUP_SELECT_FOLDER             = 1<<15,     /* do we have any folder at all? */
 	EM_POPUP_SELECT_JUNK               = 1<<16,
 	EM_POPUP_SELECT_NOT_JUNK           = 1<<17,
-	EM_POPUP_SELECT_LAST               = 1<<18,
+	EM_POPUP_SELECT_LAST               = 1<<18
 };
 
 /**
@@ -114,14 +113,12 @@ enum _em_popup_target_select_t {
  * @EM_POPUP_URI_HTTP: This is a HTTP or HTTPS url.
  * @EM_POPUP_URI_MAILTO: This is a MAILTO url.
  * @EM_POPUP_URI_NOT_MAILTO: This is not a MAILTO url.
- * @EM_POPUP_URI_CALLTO: This is a CALLTO url.
  *
  **/
 enum _em_popup_target_uri_t {
 	EM_POPUP_URI_HTTP = 1<<0,
 	EM_POPUP_URI_MAILTO = 1<<1,
-	EM_POPUP_URI_NOT_MAILTO = 1<<2,
-	EM_POPUP_URI_CALLTO = 1<<3,
+	EM_POPUP_URI_NOT_MAILTO = 1<<2
 };
 
 /**
@@ -133,7 +130,7 @@ enum _em_popup_target_uri_t {
  **/
 enum _em_popup_target_part_t {
 	EM_POPUP_PART_MESSAGE = 1<<0,
-	EM_POPUP_PART_IMAGE = 1<<1,
+	EM_POPUP_PART_IMAGE = 1<<1
 };
 
 /**
@@ -154,29 +151,13 @@ enum _em_popup_target_folder_t {
 	EM_POPUP_FOLDER_DELETE = 1<<3, /* folder can be deleted/renamed */
 	EM_POPUP_FOLDER_SELECT = 1<<4, /* folder can be selected/opened */
 	EM_POPUP_FOLDER_OUTBOX = 1<<5, /* Outbox folder */
-	EM_POPUP_FOLDER_NONSTATIC = 1<<6, /* Except static folders like Outbox.*/
-};
-
-/**
- * enum _em_popup_target_attachments_t - EMPopupTargetAttachments qualifiers.
- *
- * @EM_POPUP_ATTACHMENTS_ONE: There is one and only one attachment selected.
- * @EM_POPUP_ATTACHMENTS_MANY: There is one or more attachments selected.
- *
- **/
-enum _em_popup_target_attachments_t {
-	EM_POPUP_ATTACHMENTS_ONE = 1<<0, /* only 1 selected */
-	EM_POPUP_ATTACHMENTS_MANY = 1<<1, /* one or more selected */
-	EM_POPUP_ATTACHMENTS_MULTIPLE = 1<<2, /* More than 1 selected */
-	EM_POPUP_ATTACHMENTS_IMAGE = 1<<3, /* Image selected */
-	EM_POPUP_ATTACHMENTS_MESSAGE = 1<<4 /* Message selected */
+	EM_POPUP_FOLDER_NONSTATIC = 1<<6 /* Except static folders like Outbox.*/
 };
 
 typedef struct _EMPopupTargetSelect EMPopupTargetSelect;
 typedef struct _EMPopupTargetURI EMPopupTargetURI;
 typedef struct _EMPopupTargetPart EMPopupTargetPart;
 typedef struct _EMPopupTargetFolder EMPopupTargetFolder;
-typedef struct _EMPopupTargetAttachments EMPopupTargetAttachments;
 
 /**
  * struct _EMPopupTargetURI - An inline URI.
@@ -188,7 +169,7 @@ typedef struct _EMPopupTargetAttachments EMPopupTargetAttachments;
  **/
 struct _EMPopupTargetURI {
 	EPopupTarget target;
-	char *uri;
+	gchar *uri;
 };
 
 /**
@@ -206,7 +187,7 @@ struct _EMPopupTargetURI {
 struct _EMPopupTargetSelect {
 	EPopupTarget target;
 	struct _CamelFolder *folder;
-	char *uri;
+	gchar *uri;
 	GPtrArray *uids;
 };
 
@@ -223,7 +204,7 @@ struct _EMPopupTargetSelect {
  **/
 struct _EMPopupTargetPart {
 	EPopupTarget target;
-	char *mime_type;
+	gchar *mime_type;
 	struct _CamelMimePart *part;
 };
 
@@ -237,21 +218,7 @@ struct _EMPopupTargetPart {
  **/
 struct _EMPopupTargetFolder {
 	EPopupTarget target;
-	char *uri;
-};
-
-/**
- * struct _EMPopupTargetAttachments - A list of composer attachments.
- *
- * @target: Superclass.
- * @attachments: A GSList list of EMsgComposer attachments.
- *
- * This target is used to represent a selected list of attachments in
- * the message composer attachment area.
- **/
-struct _EMPopupTargetAttachments {
-	EPopupTarget target;
-	GSList *attachments;
+	gchar *uri;
 };
 
 typedef struct _EPopupItem EMPopupItem;
@@ -269,13 +236,12 @@ struct _EMPopupClass {
 
 GType em_popup_get_type(void);
 
-EMPopup *em_popup_new(const char *menuid);
+EMPopup *em_popup_new(const gchar *menuid);
 
-EMPopupTargetURI *em_popup_target_new_uri(EMPopup *emp, const char *uri);
-EMPopupTargetSelect *em_popup_target_new_select(EMPopup *emp, struct _CamelFolder *folder, const char *folder_uri, GPtrArray *uids);
-EMPopupTargetPart *em_popup_target_new_part(EMPopup *emp, struct _CamelMimePart *part, const char *mime_type);
-EMPopupTargetFolder *em_popup_target_new_folder(EMPopup *emp, const char *uri, guint32 info_flags, guint32 popup_flags);
-EMPopupTargetAttachments *em_popup_target_new_attachments(EMPopup *emp, GSList *attachments);
+EMPopupTargetURI *em_popup_target_new_uri(EMPopup *emp, const gchar *uri);
+EMPopupTargetSelect *em_popup_target_new_select(EMPopup *emp, struct _CamelFolder *folder, const gchar *folder_uri, GPtrArray *uids);
+EMPopupTargetPart *em_popup_target_new_part(EMPopup *emp, struct _CamelMimePart *part, const gchar *mime_type);
+EMPopupTargetFolder *em_popup_target_new_folder(EMPopup *emp, const gchar *uri, guint32 info_flags, guint32 popup_flags);
 
 /* ********************************************************************** */
 
