@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -35,18 +35,18 @@ enum {
 	AUTO_SUBJECT = 1,
 	AUTO_FROM = 2,
 	AUTO_TO = 4,
-	AUTO_MLIST = 8,
+	AUTO_MLIST = 8
 };
 
-struct _FilterRule *em_vfolder_rule_from_message(struct _EMVFolderContext *context, struct _CamelMimeMessage *msg, int flags, const char *source);
-struct _FilterRule *filter_rule_from_message(struct _EMFilterContext *context, struct _CamelMimeMessage *msg, int flags);
-struct _FilterRule *em_vfolder_rule_from_address(struct _EMVFolderContext *context, struct _CamelInternetAddress *addr, int flags, const char *source);
+struct _FilterRule *em_vfolder_rule_from_message(struct _EMVFolderContext *context, struct _CamelMimeMessage *msg, gint flags, const gchar *source);
+struct _FilterRule *filter_rule_from_message(struct _EMFilterContext *context, struct _CamelMimeMessage *msg, gint flags);
+struct _FilterRule *em_vfolder_rule_from_address(struct _EMVFolderContext *context, struct _CamelInternetAddress *addr, gint flags, const gchar *source);
 
 /* easiest place to put this */
-void  filter_gui_add_from_message(struct _CamelMimeMessage *msg, const char *source, int flags);
+void  filter_gui_add_from_message(struct _CamelMimeMessage *msg, const gchar *source, gint flags);
 
 /* Also easiest place for these, we should really share a global rule context for this stuff ... */
-void mail_filter_rename_uri(struct _CamelStore *store, const char *olduri, const char *newuri);
-void mail_filter_delete_uri(struct _CamelStore *store, const char *uri);
+void mail_filter_rename_uri(struct _CamelStore *store, const gchar *olduri, const gchar *newuri);
+void mail_filter_delete_uri(struct _CamelStore *store, const gchar *uri);
 
 #endif
