@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -46,10 +46,10 @@ extern "C" {
 #endif /* __cplusplus */
 
 typedef struct _MailConfigSignature {
-	int id;
-	char *name;
-	char *filename;
-	char *script;
+	gint id;
+	gchar *name;
+	gchar *filename;
+	gchar *script;
 	gboolean html;
 } MailConfigSignature;
 
@@ -101,29 +101,29 @@ gboolean mail_config_is_corrupt               (void);
 
 GSList *mail_config_get_labels (void);
 
-const char **mail_config_get_allowable_mime_types (void);
+const gchar **mail_config_get_allowable_mime_types (void);
 
 void mail_config_service_set_save_passwd (struct _EAccountService *service, gboolean save_passwd);
 
 /* accounts */
 gboolean mail_config_find_account (struct _EAccount *account);
 struct _EAccount *mail_config_get_default_account (void);
-struct _EAccount *mail_config_get_account_by_name (const char *account_name);
-struct _EAccount *mail_config_get_account_by_uid (const char *uid);
-struct _EAccount *mail_config_get_account_by_source_url (const char *url);
-struct _EAccount *mail_config_get_account_by_transport_url (const char *url);
+struct _EAccount *mail_config_get_account_by_name (const gchar *account_name);
+struct _EAccount *mail_config_get_account_by_uid (const gchar *uid);
+struct _EAccount *mail_config_get_account_by_source_url (const gchar *url);
+struct _EAccount *mail_config_get_account_by_transport_url (const gchar *url);
 
 struct _EAccountList *mail_config_get_accounts (void);
 void mail_config_add_account (struct _EAccount *account);
 void mail_config_remove_account (struct _EAccount *account);
 void mail_config_set_default_account (struct _EAccount *account);
-int mail_config_get_address_count (void);
-int mail_config_get_message_limit (void);
+gint mail_config_get_address_count (void);
+gint mail_config_get_message_limit (void);
 gboolean mail_config_get_enable_magic_spacebar (void);
 
 void mail_config_remove_account_proxies (struct _EAccount *account);
 void mail_config_prune_proxies (void);
-int mail_config_has_proxies (struct _EAccount *account);
+gint mail_config_has_proxies (struct _EAccount *account);
 
 struct _EAccountIdentity *mail_config_get_default_identity (void);
 struct _EAccountService  *mail_config_get_default_transport (void);
@@ -131,9 +131,9 @@ struct _EAccountService  *mail_config_get_default_transport (void);
 void mail_config_save_accounts (void);
 
 /* signatures */
-struct _ESignature *mail_config_signature_new (const char *filename, gboolean script, gboolean html);
-struct _ESignature *mail_config_get_signature_by_uid (const char *uid);
-struct _ESignature *mail_config_get_signature_by_name (const char *name);
+struct _ESignature *mail_config_signature_new (const gchar *filename, gboolean script, gboolean html);
+struct _ESignature *mail_config_get_signature_by_uid (const gchar *uid);
+struct _ESignature *mail_config_get_signature_by_name (const gchar *name);
 
 struct _ESignatureList *mail_config_get_signatures (void);
 void mail_config_add_signature (struct _ESignature *signature);
@@ -141,16 +141,16 @@ void mail_config_remove_signature (struct _ESignature *signature);
 
 void mail_config_save_signatures (void);
 
-char *mail_config_signature_run_script (const char *script);
+gchar *mail_config_signature_run_script (const gchar *script);
 
 
 /* uri's got changed by the store, etc */
-void mail_config_uri_renamed (GCompareFunc uri_cmp, const char *old, const char *new);
-void mail_config_uri_deleted (GCompareFunc uri_cmp, const char *uri);
+void mail_config_uri_renamed (GCompareFunc uri_cmp, const gchar *old, const gchar *new);
+void mail_config_uri_deleted (GCompareFunc uri_cmp, const gchar *uri);
 
 /* static utility functions */
-char *mail_config_folder_to_cachename (struct _CamelFolder *folder, const char *prefix);
-char *mail_config_folder_to_safe_url (struct _CamelFolder *folder);
+gchar *mail_config_folder_to_cachename (struct _CamelFolder *folder, const gchar *prefix);
+gchar *mail_config_folder_to_safe_url (struct _CamelFolder *folder);
 guint mail_config_get_error_timeout  (void);
 guint mail_config_get_error_level  (void);
 
