@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -67,17 +67,17 @@
 /* this stuff is used to keep track of which folders filters have accessed, and
    what not. the thaw/refreeze thing doesn't really seem to work though */
 struct _folder_info {
-	char *uri;
+	gchar *uri;
 	CamelFolder *folder;
 	time_t update;
-	int count;		/* how many times updated, to slow it down as we go, if we have lots */
+	gint count;		/* how many times updated, to slow it down as we go, if we have lots */
 };
 
 struct _send_data {
 	GList *infos;
 
 	GtkDialog *gd;
-	int cancelled;
+	gint cancelled;
 
 	CamelFolder *inbox;	/* since we're never asked to update this one, do it ourselves */
 	time_t inbox_update;
@@ -93,7 +93,7 @@ typedef enum {
 	SEND_SEND,		/* sender */
 	SEND_UPDATE,		/* imap-like 'just update folder info' */
 	SEND_INVALID
-} send_info_t ;
+} send_info_t;
 
 typedef enum {
 	SEND_ACTIVE,
@@ -104,24 +104,24 @@ typedef enum {
 struct _send_info {
 	send_info_t type;		/* 0 = fetch, 1 = send */
 	CamelOperation *cancel;
-	char *uri;
+	gchar *uri;
 	gboolean keep_on_server;
 	send_state_t state;
 	GtkWidget *progress_bar;
 	GtkWidget *cancel_button;
 	GtkWidget *status_label;
 
-	int again;		/* need to run send again */
+	gint again;		/* need to run send again */
 
-	int timeout_id;
-	char *what;
-	int pc;
+	gint timeout_id;
+	gchar *what;
+	gint pc;
 
 	/*time_t update;*/
 	struct _send_data *data;
 };
 
-static CamelFolder *receive_get_folder(CamelFilterDriver *d, const char *uri, void *data, CamelException *ex);
+static CamelFolder *receive_get_folder(CamelFilterDriver *d, const gchar *uri, gpointer data, CamelException *ex);
 
 static struct _send_data *send_data = NULL;
 static GtkWidget *send_recv_dialog = NULL;
@@ -207,13 +207,13 @@ free_send_data(void)
 }
 
 static void
-cancel_send_info(void *key, struct _send_info *info, void *data)
+cancel_send_info(gpointer key, struct _send_info *info, gpointer data)
 {
 	receive_cancel (GTK_BUTTON (info->cancel_button), info);
 }
 
 static void
-hide_send_info(void *key, struct _send_info *info, void *data)
+hide_send_info(gpointer key, struct _send_info *info, gpointer data)
 {
 	info->cancel_button = NULL;
 	info->progress_bar = NULL;
@@ -234,7 +234,7 @@ dialog_destroy_cb (struct _send_data *data, GObject *deadbeef)
 }
 
 static void
-dialog_response(GtkDialog *gd, int button, struct _send_data *data)
+dialog_response(GtkDialog *gd, gint button, struct _send_data *data)
 {
 	switch(button) {
 	case GTK_RESPONSE_CANCEL:
@@ -254,8 +254,8 @@ dialog_response(GtkDialog *gd, int button, struct _send_data *data)
 	}
 }
 
-static int
-operation_status_timeout(void *data)
+static gint
+operation_status_timeout(gpointer data)
 {
 	struct _send_info *info = data;
 
@@ -274,7 +274,7 @@ operation_status_timeout(void *data)
 }
 
 static void
-set_send_status(struct _send_info *info, const char *desc, int pc)
+set_send_status(struct _send_info *info, const gchar *desc, gint pc)
 {
 	/* FIXME: LOCK */
 	g_free(info->what);
@@ -284,7 +284,7 @@ set_send_status(struct _send_info *info, const char *desc, int pc)
 
 /* for camel operation status */
 static void
-operation_status(CamelOperation *op, const char *what, int pc, void *data)
+operation_status(CamelOperation *op, const gchar *what, gint pc, gpointer data)
 {
 	struct _send_info *info = data;
 
@@ -301,11 +301,11 @@ operation_status(CamelOperation *op, const char *what, int pc, void *data)
 	set_send_status(info, what, pc);
 }
 
-static char *
-format_url(const char *internal_url, const char *account_name)
+static gchar *
+format_url(const gchar *internal_url, const gchar *account_name)
 {
 	CamelURL *url;
-       	char *pretty_url;
+	gchar *pretty_url;
 
 	url = camel_url_new(internal_url, NULL);
 	if (account_name) {
@@ -330,7 +330,7 @@ format_url(const char *internal_url, const char *account_name)
 }
 
 static send_info_t
-get_receive_type(const char *url)
+get_receive_type(const gchar *url)
 {
 	CamelProvider *provider;
 	CamelException ex;
@@ -360,11 +360,11 @@ get_receive_type(const char *url)
 }
 
 static struct _send_data *
-build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destination)
+build_dialog (EAccountList *accounts, CamelFolder *outbox, const gchar *destination)
 {
 	GtkDialog *gd;
 	GtkWidget *table;
-	int row, num_sources;
+	gint row, num_sources;
 	GList *list = NULL;
 	struct _send_data *data;
         GtkWidget *send_icon;
@@ -375,7 +375,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 	GtkWidget *progress_bar;
 	GtkWidget *cancel_button;
 	struct _send_info *info;
-	char *pretty_url;
+	gchar *pretty_url;
 	EAccount *account;
 	EIterator *iter;
 	EMEventTargetSendReceive *target;
@@ -416,7 +416,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 	g_object_unref (iter);
 
 	/* Check to see if we have to send any mails --- if we don't, don't display the SMTP row in the table */
-	if (outbox && destination 
+	if (outbox && destination
 	 && (camel_folder_get_message_count(outbox) - camel_folder_get_deleted_message_count(outbox)) == 0)
 		num_sources--;
 
@@ -487,7 +487,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 
 		recv_icon = gtk_image_new_from_icon_name (
 			"mail-inbox", GTK_ICON_SIZE_LARGE_TOOLBAR);
-	       	pretty_url = format_url (source->url, account->name);
+		pretty_url = format_url (source->url, account->name);
 		label = gtk_label_new (NULL);
 		gtk_label_set_ellipsize (
 			GTK_LABEL (label), PANGO_ELLIPSIZE_END);
@@ -508,7 +508,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 		gtk_misc_set_alignment (GTK_MISC (label), 0, .5);
 		gtk_misc_set_alignment (GTK_MISC (status_label), 0, .5);
 
-	        gtk_table_attach (
+		gtk_table_attach (
 			GTK_TABLE (table), recv_icon,
 			0, 1, row, row+2, 0, 0, 0, 0);
 		gtk_table_attach (
@@ -545,7 +545,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 	e_event_emit ((EEvent *)em_event_peek (), "mail.sendreceive", (EEventTarget *) target);
 
 	/* Skip displaying the SMTP row if we've got no outbox, destination or unsent mails */
-	if (outbox && destination 
+	if (outbox && destination
 	 && (camel_folder_get_message_count(outbox) - camel_folder_get_deleted_message_count(outbox)) != 0) {
 		info = g_hash_table_lookup (data->active, SEND_URI_KEY);
 		if (info == NULL) {
@@ -559,7 +559,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 			info->state = SEND_ACTIVE;
 			info->timeout_id = g_timeout_add (STATUS_TIMEOUT, operation_status_timeout, info);
 
-			g_hash_table_insert (data->active, SEND_URI_KEY, info);
+			g_hash_table_insert (data->active, (gpointer) SEND_URI_KEY, info);
 			list = g_list_prepend (list, info);
 		} else if (info->timeout_id == 0)
 			info->timeout_id = g_timeout_add (STATUS_TIMEOUT, operation_status_timeout, info);
@@ -623,7 +623,7 @@ build_dialog (EAccountList *accounts, CamelFolder *outbox, const char *destinati
 }
 
 static void
-update_folders(char *uri, struct _folder_info *info, void *data)
+update_folders(gchar *uri, struct _folder_info *info, gpointer data)
 {
 	time_t now = *((time_t *)data);
 
@@ -641,7 +641,7 @@ update_folders(char *uri, struct _folder_info *info, void *data)
 }
 
 static void
-receive_status (CamelFilterDriver *driver, enum camel_filter_status_t status, int pc, const char *desc, void *data)
+receive_status (CamelFilterDriver *driver, enum camel_filter_status_t status, gint pc, const gchar *desc, gpointer data)
 {
 	struct _send_info *info = data;
 	time_t now = time(NULL);
@@ -673,7 +673,7 @@ receive_status (CamelFilterDriver *driver, enum camel_filter_status_t status, in
 
 /* when receive/send is complete */
 static void
-receive_done (char *uri, void *data)
+receive_done (const gchar *uri, gpointer data)
 {
 	struct _send_info *info = data;
 
@@ -731,7 +731,7 @@ receive_done (char *uri, void *data)
    This can also be used to hook into which folders are being updated, and occasionally
    let them refresh */
 static CamelFolder *
-receive_get_folder(CamelFilterDriver *d, const char *uri, void *data, CamelException *ex)
+receive_get_folder(CamelFilterDriver *d, const gchar *uri, gpointer data, CamelException *ex)
 {
 	struct _send_info *info = data;
 	CamelFolder *folder;
@@ -782,15 +782,8 @@ get_folders (CamelStore *store, GPtrArray *folders, CamelFolderInfo *info)
 	camel_exception_init (&ex);
 
 	while (info) {
-		if (camel_store_can_refresh_folder (store, info, &ex)) {
-			CamelURL *url = camel_url_new (info->uri, NULL);
-
-			if (url && (!camel_url_get_param (url, "noselect") || !g_str_equal (camel_url_get_param (url, "noselect"), "yes")))
-				g_ptr_array_add (folders, g_strdup (info->uri));
-
-			if (url)
-				camel_url_free (url);
-		}
+		if (camel_store_can_refresh_folder (store, info, &ex))
+			g_ptr_array_add (folders, g_strdup (info->uri));
 		camel_exception_clear (&ex);
 
 		get_folders (store, folders, info->child);
@@ -816,7 +809,7 @@ refresh_folders_desc (struct _refresh_folders_msg *m)
 static void
 refresh_folders_exec (struct _refresh_folders_msg *m)
 {
-	int i;
+	gint i;
 	CamelFolder *folder;
 	CamelException ex = CAMEL_EXCEPTION_INITIALISER;
 
@@ -849,7 +842,7 @@ refresh_folders_done (struct _refresh_folders_msg *m)
 static void
 refresh_folders_free (struct _refresh_folders_msg *m)
 {
-	int i;
+	gint i;
 
 	for (i=0;i<m->folders->len;i++)
 		g_free(m->folders->pdata[i]);
@@ -868,7 +861,7 @@ static MailMsgInfo refresh_folders_info = {
 };
 
 static gboolean
-receive_update_got_folderinfo(CamelStore *store, CamelFolderInfo *info, void *data)
+receive_update_got_folderinfo(CamelStore *store, CamelFolderInfo *info, gpointer data)
 {
 	if (info) {
 		GPtrArray *folders = g_ptr_array_new();
@@ -894,7 +887,7 @@ receive_update_got_folderinfo(CamelStore *store, CamelFolderInfo *info, void *da
 }
 
 static void
-receive_update_got_store (char *uri, CamelStore *store, void *data)
+receive_update_got_store (gchar *uri, CamelStore *store, gpointer data)
 {
 	struct _send_info *info = data;
 
@@ -969,14 +962,14 @@ mail_send_receive (void)
 
 struct _auto_data {
 	EAccount *account;
-	int period;		/* in seconds */
-	int timeout_id;
+	gint period;		/* in seconds */
+	gint timeout_id;
 };
 
 static GHashTable *auto_active;
 
 static gboolean
-auto_timeout(void *data)
+auto_timeout(gpointer data)
 {
 	struct _auto_data *info = data;
 
@@ -995,7 +988,7 @@ auto_timeout(void *data)
 }
 
 static void
-auto_account_removed(EAccountList *eal, EAccount *ea, void *dummy)
+auto_account_removed(EAccountList *eal, EAccount *ea, gpointer dummy)
 {
 	struct _auto_data *info = g_object_get_data((GObject *)ea, "mail-autoreceive");
 
@@ -1018,7 +1011,7 @@ auto_account_finalised(struct _auto_data *info)
 static void
 auto_account_commit(struct _auto_data *info)
 {
-	int period, check;
+	gint period, check;
 
 	check = info->account->enabled
 		&& e_account_get_bool(info->account, E_ACCOUNT_SOURCE_AUTO_CHECK)
@@ -1034,11 +1027,11 @@ auto_account_commit(struct _auto_data *info)
 	}
 	info->period = period;
 	if (check && info->timeout_id == 0)
-		info->timeout_id = g_timeout_add(info->period*1000, auto_timeout, info);
+		info->timeout_id = g_timeout_add_seconds(info->period, auto_timeout, info);
 }
 
 static void
-auto_account_added(EAccountList *eal, EAccount *ea, void *dummy)
+auto_account_added(EAccountList *eal, EAccount *ea, gpointer dummy)
 {
 	struct _auto_data *info;
 
@@ -1049,7 +1042,7 @@ auto_account_added(EAccountList *eal, EAccount *ea, void *dummy)
 }
 
 static void
-auto_account_changed(EAccountList *eal, EAccount *ea, void *dummy)
+auto_account_changed(EAccountList *eal, EAccount *ea, gpointer dummy)
 {
 	struct _auto_data *info = g_object_get_data((GObject *)ea, "mail-autoreceive");
 
@@ -1059,7 +1052,7 @@ auto_account_changed(EAccountList *eal, EAccount *ea, void *dummy)
 }
 
 static void
-auto_online(CamelObject *o, void *ed, void *d)
+auto_online(CamelObject *o, gpointer ed, gpointer d)
 {
 	EIterator *iter;
 	EAccountList *accounts;
@@ -1203,7 +1196,7 @@ mail_send (void)
 	info->status_label = NULL;
 	info->uri = g_strdup (transport->url);
 	info->keep_on_server = FALSE;
-	info->cancel = NULL; 
+	info->cancel = NULL;
 	info->cancel_button = NULL;
 	info->data = data;
 	info->state = SEND_ACTIVE;
@@ -1211,7 +1204,7 @@ mail_send (void)
 
 	d(printf("Adding new info %p\n", info));
 
-	g_hash_table_insert (data->active, SEND_URI_KEY, info);
+	g_hash_table_insert (data->active, (gpointer) SEND_URI_KEY, info);
 
 	/* todo, store the folder in info? */
 	outbox_folder = mail_component_get_folder(NULL, MAIL_COMPONENT_FOLDER_OUTBOX);
