@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -33,7 +33,6 @@
 
 #include <gconf/gconf-client.h>
 
-#include <libgnome/gnome-config.h>
 #include <libgnome/gnome-sound.h>
 
 #include <libedataserverui/e-passwords.h>
@@ -47,6 +46,7 @@
 #include "e-util/e-util-private.h"
 #include "e-account-combo-box.h"
 
+#include "em-composer-utils.h"
 #include "em-filter-context.h"
 #include "em-filter-rule.h"
 #include "em-utils.h"
@@ -60,7 +60,7 @@
 #define d(x)
 
 CamelSession *session;
-static int session_check_junk_notify_id = -1;
+static gint session_check_junk_notify_id = -1;
 
 #define MAIL_SESSION_TYPE     (mail_session_get_type ())
 #define MAIL_SESSION(obj)     (CAMEL_CHECK_CAST((obj), MAIL_SESSION_TYPE, MailSession))
@@ -84,15 +84,16 @@ typedef struct _MailSessionClass {
 
 static CamelSessionClass *ms_parent_class;
 
-static char *get_password(CamelSession *session, CamelService *service, const char *domain, const char *prompt, const char *item, guint32 flags, CamelException *ex);
-static void forget_password(CamelSession *session, CamelService *service, const char *domain, const char *item, CamelException *ex);
-static gboolean alert_user(CamelSession *session, CamelSessionAlertType type, const char *prompt, gboolean cancel);
-static CamelFilterDriver *get_filter_driver(CamelSession *session, const char *type, CamelException *ex);
-static gboolean lookup_addressbook(CamelSession *session, const char *name);
+static gchar *get_password(CamelSession *session, CamelService *service, const gchar *domain, const gchar *prompt, const gchar *item, guint32 flags, CamelException *ex);
+static void forget_password(CamelSession *session, CamelService *service, const gchar *domain, const gchar *item, CamelException *ex);
+static gboolean alert_user(CamelSession *session, CamelSessionAlertType type, const gchar *prompt, gboolean cancel);
+static CamelFilterDriver *get_filter_driver(CamelSession *session, const gchar *type, CamelException *ex);
+static gboolean lookup_addressbook(CamelSession *session, const gchar *name);
 
-static void ms_thread_status(CamelSession *session, CamelSessionThreadMsg *msg, const char *text, int pc);
-static void *ms_thread_msg_new(CamelSession *session, CamelSessionThreadOps *ops, unsigned int size);
+static void ms_thread_status(CamelSession *session, CamelSessionThreadMsg *msg, const gchar *text, gint pc);
+static gpointer ms_thread_msg_new(CamelSession *session, CamelSessionThreadOps *ops, guint size);
 static void ms_thread_msg_free(CamelSession *session, CamelSessionThreadMsg *m);
+static void ms_forward_to (CamelSession *session, CamelFolder *folder, CamelMimeMessage *message, const gchar *address, CamelException *ex);
 
 static void
 init (MailSession *session)
@@ -124,6 +125,7 @@ class_init (MailSessionClass *mail_session_class)
 	camel_session_class->thread_msg_new = ms_thread_msg_new;
 	camel_session_class->thread_msg_free = ms_thread_msg_free;
 	camel_session_class->thread_status = ms_thread_status;
+	camel_session_class->forward_to = ms_forward_to;
 }
 
 static CamelType
@@ -148,10 +150,10 @@ mail_session_get_type (void)
 }
 
 
-static char *
-make_key (CamelService *service, const char *item)
+static gchar *
+make_key (CamelService *service, const gchar *item)
 {
-	char *key;
+	gchar *key;
 
 	if (service)
 		key = camel_url_to_string (service->url, CAMEL_URL_HIDE_PASSWORD | CAMEL_URL_HIDE_PARAMS);
@@ -163,15 +165,15 @@ make_key (CamelService *service, const char *item)
 
 /* ********************************************************************** */
 
-static char *
-get_password (CamelSession *session, CamelService *service, const char *domain,
-	      const char *prompt, const char *item, guint32 flags, CamelException *ex)
+static gchar *
+get_password (CamelSession *session, CamelService *service, const gchar *domain,
+	      const gchar *prompt, const gchar *item, guint32 flags, CamelException *ex)
 {
-	char *url;
-	char *ret = NULL;
+	gchar *url;
+	gchar *ret = NULL;
 	EAccount *account = NULL;
 
-        url = service?camel_url_to_string(service->url, CAMEL_URL_HIDE_ALL):NULL;
+	url = service?camel_url_to_string(service->url, CAMEL_URL_HIDE_ALL):NULL;
 
 	if (!strcmp(item, "popb4smtp_uri")) {
 		/* not 100% mt safe, but should be ok */
@@ -181,7 +183,7 @@ get_password (CamelSession *session, CamelService *service, const char *domain,
 		else
 			ret = g_strdup(url);
 	} else {
-		char *key = make_key(service, item);
+		gchar *key = make_key(service, item);
 		EAccountService *config_service = NULL;
 
 		if (domain == NULL)
@@ -202,7 +204,7 @@ get_password (CamelSession *session, CamelService *service, const char *domain,
 
 			if (!config_service || (config_service && !config_service->get_password_canceled)) {
 				guint32 eflags;
-				char *title;
+				gchar *title;
 
 				if (flags & CAMEL_SESSION_PASSPHRASE) {
 					if (account)
@@ -261,9 +263,9 @@ get_password (CamelSession *session, CamelService *service, const char *domain,
 }
 
 static void
-forget_password (CamelSession *session, CamelService *service, const char *domain, const char *item, CamelException *ex)
+forget_password (CamelSession *session, CamelService *service, const gchar *domain, const gchar *item, CamelException *ex)
 {
-	char *key = make_key (service, item);
+	gchar *key = make_key (service, item);
 
 	e_passwords_forget_password (domain?domain:"Mail", key);
 	g_free (key);
@@ -278,18 +280,18 @@ struct _user_message_msg {
 	MailMsg base;
 
 	CamelSessionAlertType type;
-	char *prompt;
+	gchar *prompt;
 	EFlag *done;
 
-	unsigned int allow_cancel:1;
-	unsigned int result:1;
-	unsigned int ismain:1;
+	guint allow_cancel:1;
+	guint result:1;
+	guint ismain:1;
 };
 
 static void user_message_exec (struct _user_message_msg *m);
 
 static void
-user_message_response_free (GtkDialog *dialog, int button, struct _user_message_msg *m)
+user_message_response_free (GtkDialog *dialog, gint button, struct _user_message_msg *m)
 {
 	gtk_widget_destroy ((GtkWidget *) dialog);
 
@@ -305,7 +307,7 @@ user_message_response_free (GtkDialog *dialog, int button, struct _user_message_
 
 /* clicked, send back the reply */
 static void
-user_message_response (GtkDialog *dialog, int button, struct _user_message_msg *m)
+user_message_response (GtkDialog *dialog, gint button, struct _user_message_msg *m)
 {
 	/* if !allow_cancel, then we've already replied */
 	if (m->allow_cancel) {
@@ -396,7 +398,7 @@ static MailMsgInfo user_message_info = {
 };
 
 static gboolean
-lookup_addressbook(CamelSession *session, const char *name)
+lookup_addressbook(CamelSession *session, const gchar *name)
 {
 	CamelInternetAddress *addr;
 	gboolean ret;
@@ -413,7 +415,7 @@ lookup_addressbook(CamelSession *session, const char *name)
 }
 
 static gboolean
-alert_user(CamelSession *session, CamelSessionAlertType type, const char *prompt, gboolean cancel)
+alert_user(CamelSession *session, CamelSessionAlertType type, const gchar *prompt, gboolean cancel)
 {
 	MailSession *mail_session = MAIL_SESSION (session);
 	struct _user_message_msg *m;
@@ -450,13 +452,13 @@ alert_user(CamelSession *session, CamelSessionAlertType type, const char *prompt
 }
 
 static CamelFolder *
-get_folder (CamelFilterDriver *d, const char *uri, void *data, CamelException *ex)
+get_folder (CamelFilterDriver *d, const gchar *uri, gpointer data, CamelException *ex)
 {
 	return mail_tool_uri_to_folder(uri, 0, ex);
 }
 
 static void
-main_play_sound (CamelFilterDriver *driver, char *filename, gpointer user_data)
+main_play_sound (CamelFilterDriver *driver, gchar *filename, gpointer user_data)
 {
 	if (filename && *filename)
 		gnome_sound_play (filename);
@@ -468,7 +470,7 @@ main_play_sound (CamelFilterDriver *driver, char *filename, gpointer user_data)
 }
 
 static void
-session_play_sound (CamelFilterDriver *driver, const char *filename, gpointer user_data)
+session_play_sound (CamelFilterDriver *driver, const gchar *filename, gpointer user_data)
 {
 	MailSession *ms = (MailSession *) session;
 
@@ -497,11 +499,11 @@ session_system_beep (CamelFilterDriver *driver, gpointer user_data)
 }
 
 static CamelFilterDriver *
-main_get_filter_driver (CamelSession *session, const char *type, CamelException *ex)
+main_get_filter_driver (CamelSession *session, const gchar *type, CamelException *ex)
 {
 	CamelFilterDriver *driver;
 	FilterRule *rule = NULL;
-	char *user, *system;
+	gchar *user, *system;
 	GConfClient *gconf;
 	RuleContext *fc;
 
@@ -521,7 +523,7 @@ main_get_filter_driver (CamelSession *session, const char *type, CamelException
 		MailSession *ms = (MailSession *) session;
 
 		if (ms->filter_logfile == NULL) {
-			char *filename;
+			gchar *filename;
 
 			filename = gconf_client_get_string (gconf, "/apps/evolution/mail/filters/logfile", NULL);
 			if (filename) {
@@ -541,7 +543,7 @@ main_get_filter_driver (CamelSession *session, const char *type, CamelException
 	if ((!strcmp (type, FILTER_SOURCE_INCOMING) || !strcmp (type, FILTER_SOURCE_JUNKTEST))
 	    && camel_session_check_junk (session)) {
 		/* implicit junk check as 1st rule */
-		camel_filter_driver_add_rule (driver, "Junk check", "(junk-test)", "(begin (set-system-flag \"junk\")(set-system-flag \"seen\"))");
+		camel_filter_driver_add_rule (driver, "Junk check", "(junk-test)", "(begin (set-system-flag \"junk\"))");
 	}
 
 	if (strcmp (type, FILTER_SOURCE_JUNKTEST) != 0) {
@@ -577,7 +579,7 @@ main_get_filter_driver (CamelSession *session, const char *type, CamelException
 }
 
 static CamelFilterDriver *
-get_filter_driver (CamelSession *session, const char *type, CamelException *ex)
+get_filter_driver (CamelSession *session, const gchar *type, CamelException *ex)
 {
 	return (CamelFilterDriver *) mail_call_main (MAIL_CALL_p_ppp, (MailMainFunc) main_get_filter_driver,
 						     session, type, ex);
@@ -588,7 +590,7 @@ get_filter_driver (CamelSession *session, const char *type, CamelException *ex)
 
 static MailMsgInfo ms_thread_info_dummy = { sizeof (MailMsg) };
 
-static void *ms_thread_msg_new(CamelSession *session, CamelSessionThreadOps *ops, unsigned int size)
+static gpointer ms_thread_msg_new(CamelSession *session, CamelSessionThreadOps *ops, guint size)
 {
 	CamelSessionThreadMsg *msg = ms_parent_class->thread_msg_new(session, ops, size);
 
@@ -612,18 +614,28 @@ static void ms_thread_msg_free(CamelSession *session, CamelSessionThreadMsg *m)
 	ms_parent_class->thread_msg_free(session, m);
 }
 
-static void ms_thread_status(CamelSession *session, CamelSessionThreadMsg *msg, const char *text, int pc)
+static void ms_thread_status(CamelSession *session, CamelSessionThreadMsg *msg, const gchar *text, gint pc)
 {
 	/* This should never be called since we bypass it in alloc! */
 	printf("Thread status '%s' %d%%\n", text, pc);
 }
 
-char *
-mail_session_get_password (const char *url_string)
+static void
+ms_forward_to (CamelSession *session, CamelFolder *folder, CamelMimeMessage *message, const gchar *address, CamelException *ex)
+{
+	g_return_if_fail (session != NULL);
+	g_return_if_fail (message != NULL);
+	g_return_if_fail (address != NULL);
+
+	em_utils_forward_message_raw (folder, message, address, ex);
+}
+
+gchar *
+mail_session_get_password (const gchar *url_string)
 {
 	CamelURL *url;
-	char *simple_url;
-	char *passwd;
+	gchar *simple_url;
+	gchar *passwd;
 
 	url = camel_url_new (url_string, NULL);
 	simple_url = camel_url_to_string (url, CAMEL_URL_HIDE_PASSWORD | CAMEL_URL_HIDE_PARAMS);
@@ -637,11 +649,11 @@ mail_session_get_password (const char *url_string)
 }
 
 void
-mail_session_add_password (const char *url_string,
-			   const char *passwd)
+mail_session_add_password (const gchar *url_string,
+			   const gchar *passwd)
 {
 	CamelURL *url;
-	char *simple_url;
+	gchar *simple_url;
 
 	url = camel_url_new (url_string, NULL);
 	simple_url = camel_url_to_string (url, CAMEL_URL_HIDE_PASSWORD | CAMEL_URL_HIDE_PARAMS);
@@ -653,10 +665,10 @@ mail_session_add_password (const char *url_string,
 }
 
 void
-mail_session_remember_password (const char *url_string)
+mail_session_remember_password (const gchar *url_string)
 {
 	CamelURL *url;
-	char *simple_url;
+	gchar *simple_url;
 
 	url = camel_url_new (url_string, NULL);
 	simple_url = camel_url_to_string (url, CAMEL_URL_HIDE_PASSWORD | CAMEL_URL_HIDE_PARAMS);
@@ -668,7 +680,7 @@ mail_session_remember_password (const char *url_string)
 }
 
 void
-mail_session_forget_password (const char *key)
+mail_session_forget_password (const gchar *key)
 {
 	e_passwords_forget_password ("Mail", key);
 }
@@ -690,9 +702,9 @@ mail_session_check_junk_notify (GConfClient *gconf, guint id, GConfEntry *entry,
 }
 
 void
-mail_session_init (const char *base_directory)
+mail_session_init (const gchar *base_directory)
 {
-	char *camel_dir;
+	gchar *camel_dir;
 	GConfClient *gconf;
 
 	if (camel_init (base_directory, TRUE) != 0)
@@ -761,8 +773,8 @@ mail_session_set_interactive (gboolean interactive)
 }
 
 void
-mail_session_forget_passwords (BonoboUIComponent *uih, void *user_data,
-			       const char *path)
+mail_session_forget_passwords (BonoboUIComponent *uih, gpointer user_data,
+			       const gchar *path)
 {
 	e_passwords_forget_passwords ();
 }
@@ -777,11 +789,11 @@ mail_session_flush_filter_log (void)
 }
 
 void
-mail_session_add_junk_plugin (const char *plugin_name, CamelJunkPlugin *junk_plugin)
+mail_session_add_junk_plugin (const gchar *plugin_name, CamelJunkPlugin *junk_plugin)
 {
 	MailSession *ms = (MailSession *) session;
 	GConfClient *gconf;
-	char *def_plugin;
+	gchar *def_plugin;
 
 	gconf = mail_config_get_gconf_client ();
 	def_plugin = gconf_client_get_string (gconf, "/apps/evolution/mail/junk/default_plugin", NULL);
@@ -806,7 +818,7 @@ mail_session_get_junk_plugins (void)
 }
 
 void
-mail_session_set_junk_headers (const char **name, const char **value, int len)
+mail_session_set_junk_headers (const gchar **name, const gchar **value, gint len)
 {
 	if (!session)
 		return;
