@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -25,7 +25,6 @@
 #include "config.h"
 #endif
 
-#include <sys/wait.h>
 #include <signal.h>
 #include <unistd.h>
 #include <errno.h>
@@ -34,12 +33,21 @@
 #define G_LOG_DOMAIN "bf-junk-filter"
 
 #include <glib.h>
+
+#ifndef G_OS_WIN32
+#  include <sys/wait.h>
+#else
+#  include <windows.h>
+#endif
+
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <e-util/e-plugin.h>
 #include "mail/em-config.h"
 #include <mail/em-junk-hook.h>
 #include <camel/camel-data-wrapper.h>
+#include <camel/camel-mime-message.h>
+#include <camel/camel-mime-parser.h>
 #include <camel/camel-stream-fs.h>
 #include <camel/camel-debug.h>
 #include <gconf/gconf-client.h>
@@ -65,21 +73,53 @@ GtkWidget * org_gnome_bogo_convert_unicode (struct _EPlugin *epl, struct _EConfi
 
 /* plugin fonction prototypes */
 gboolean em_junk_bf_check_junk (EPlugin *ep, EMJunkHookTarget *target);
-void *em_junk_bf_validate_binary (EPlugin *ep, EMJunkHookTarget *target);
+gpointer em_junk_bf_validate_binary (EPlugin *ep, EMJunkHookTarget *target);
 void em_junk_bf_report_junk (EPlugin *ep, EMJunkHookTarget *target);
 void em_junk_bf_report_non_junk (EPlugin *ep, EMJunkHookTarget *target);
 void em_junk_bf_commit_reports (EPlugin *ep, EMJunkHookTarget *target);
+static gint pipe_to_bogofilter (CamelMimeMessage *msg, const gchar **argv, GError **error);
 
 /* eplugin stuff */
-int e_plugin_lib_enable (EPluginLib *ep, int enable);
+gint e_plugin_lib_enable (EPluginLib *ep, gint enable);
 
 #define EM_JUNK_BF_GCONF_DIR_LENGTH (G_N_ELEMENTS (em_junk_bf_gconf_dir) - 1)
 
 
 static gboolean em_junk_bf_unicode = TRUE;
 
+static void
+init_db ()
+{
+	CamelStream *stream = camel_stream_fs_new_with_name (WELCOME_MESSAGE, O_RDONLY, 0);
+	CamelMimeParser *parser = camel_mime_parser_new ();
+	CamelMimeMessage *msg = camel_mime_message_new ();
+	const gchar *argv[] = {
+		em_junk_bf_binary,
+		"-n",
+		NULL,
+		NULL
+	};
+
+	camel_mime_parser_init_with_stream (parser, stream);
+	camel_mime_parser_scan_from (parser, FALSE);
+	camel_object_unref (stream);
+
+	camel_mime_part_construct_from_parser ((CamelMimePart *) msg, parser);
+	camel_object_unref (parser);
+
+	d(fprintf (stderr, "Initing the bogofilter DB with Welcome message\n"));
+
+	if (em_junk_bf_unicode) {
+		argv[2] = "--unicode=yes";
+	}
+
+	pipe_to_bogofilter (msg, argv, NULL);
+	camel_object_unref (msg);
+
+}
+
 static gint
-pipe_to_bogofilter (CamelMimeMessage *msg, gchar **argv, GError **error)
+pipe_to_bogofilter (CamelMimeMessage *msg, const gchar **argv, GError **error)
 {
 	GPid child_pid;
 	gint bf_in;
@@ -88,9 +128,11 @@ pipe_to_bogofilter (CamelMimeMessage *msg, gchar **argv, GError **error)
 	gint status;
 	gint waitres;
 	gint res;
+	static gboolean only_once = FALSE;
 
+retry:
 	if (camel_debug_start ("junk")) {
-		int i;
+		gint i;
 
 		printf ("pipe_to_bogofilter ");
 		for (i = 0; argv[i]; i++)
@@ -100,21 +142,21 @@ pipe_to_bogofilter (CamelMimeMessage *msg, gchar **argv, GError **error)
 	}
 
 	if (!g_spawn_async_with_pipes (NULL,
-	                               argv,
-	                               NULL,
-	                               G_SPAWN_DO_NOT_REAP_CHILD |
-	                                   G_SPAWN_STDOUT_TO_DEV_NULL,
-	                               NULL,
-	                               NULL,
-	                               &child_pid,
-	                               &bf_in,
-	                               NULL,
-	                               NULL,
-	                               &err))
+				       (gchar **) argv,
+				       NULL,
+				       G_SPAWN_DO_NOT_REAP_CHILD |
+					   G_SPAWN_STDOUT_TO_DEV_NULL,
+				       NULL,
+				       NULL,
+				       &child_pid,
+				       &bf_in,
+				       NULL,
+				       NULL,
+				       &err))
 	{
 		g_warning ("error occurred while spawning %s: %s",
-		           argv[0],
-		           err->message);
+			   argv[0],
+			   err->message);
 		/* For Translators: The first %s stands for the executable full path with a file name, the second is the error message itself. */
 		g_set_error (error, EM_JUNK_ERROR, err->code, _("Error occurred while spawning %s: %s."), argv[0], err->message);
 
@@ -127,6 +169,7 @@ pipe_to_bogofilter (CamelMimeMessage *msg, gchar **argv, GError **error)
 	camel_stream_close (stream);
 	camel_object_unref (stream);
 
+#ifndef G_OS_WIN32
 	waitres = waitpid (child_pid, &status, 0);
 	if (waitres < 0 && errno == EINTR) {
 		/* child process is hanging... */
@@ -141,21 +184,34 @@ pipe_to_bogofilter (CamelMimeMessage *msg, gchar **argv, GError **error)
 			sleep (1);
 			waitres = waitpid (child_pid, &status, WNOHANG);
 			g_set_error (error, EM_JUNK_ERROR, -2, _("Bogofilter child process does not respond, killing..."));
-		} else 
+		} else
 			g_set_error (error, EM_JUNK_ERROR, -3, _("Wait for Bogofilter child process interrupted, terminating..."));
 	}
 
-	g_spawn_close_pid (child_pid);
-
 	if (waitres >= 0 && WIFEXITED (status)) {
 		res = WEXITSTATUS (status);
 	} else {
 		res = BOGOFILTER_ERROR;
 	}
+#else
+	WaitForSingleObject (child_pid, INFINITE);
+	GetExitCodeProcess (child_pid, &res);
+#endif
 
-	if (res < 0 || res > 2)
+	g_spawn_close_pid (child_pid);
+
+	if (res < 0 || res > 2) {
+		if (!only_once) {
+			/* Create wordlist.db */
+			only_once = TRUE;
+			init_db();
+
+			goto retry;
+		}
 		g_set_error (error, EM_JUNK_ERROR, res, _("Pipe to Bogofilter failed, error code: %d."), res);
 
+	}
+
 	return res;
 }
 
@@ -165,7 +221,7 @@ em_junk_bf_setting_notify (GConfClient *gconf,
                            GConfEntry  *entry,
                            void        *data)
 {
-	const char *key;
+	const gchar *key;
 	GConfValue *value;
 
 	value = gconf_entry_get_value (entry);
@@ -191,9 +247,9 @@ gboolean
 em_junk_bf_check_junk (EPlugin *ep, EMJunkHookTarget *target)
 {
 	CamelMimeMessage *msg = target->m;
-	int rv;
+	gint rv;
 
-	gchar *argv[] = {
+	const gchar *argv[] = {
 		em_junk_bf_binary,
 		NULL,
 		NULL
@@ -217,7 +273,7 @@ em_junk_bf_report_junk (EPlugin *ep, EMJunkHookTarget *target)
 {
 	CamelMimeMessage *msg = target->m;
 
-	gchar *argv[] = {
+	const gchar *argv[] = {
 		em_junk_bf_binary,
 		"-s",
 		NULL,
@@ -238,7 +294,7 @@ em_junk_bf_report_non_junk (EPlugin *ep, EMJunkHookTarget *target)
 {
 	CamelMimeMessage *msg = target->m;
 
-	gchar *argv[] = {
+	const gchar *argv[] = {
 		em_junk_bf_binary,
 		"-n",
 		NULL,
@@ -259,14 +315,14 @@ em_junk_bf_commit_reports (EPlugin *ep, EMJunkHookTarget *target)
 {
 }
 
-void *
+gpointer
 em_junk_bf_validate_binary (EPlugin *ep, EMJunkHookTarget *target)
 {
-	return g_file_test (em_junk_bf_binary, G_FILE_TEST_EXISTS) ? "1" : NULL;
+	return g_file_test (em_junk_bf_binary, G_FILE_TEST_EXISTS) ? (gpointer) "1" : NULL;
 }
 
-int
-e_plugin_lib_enable (EPluginLib *ep, int enable)
+gint
+e_plugin_lib_enable (EPluginLib *ep, gint enable)
 {
 	GConfClient *gconf;
 
@@ -277,12 +333,12 @@ e_plugin_lib_enable (EPluginLib *ep, int enable)
 	gconf = gconf_client_get_default();
 
 	gconf_client_add_dir (gconf,
-	                      em_junk_bf_gconf_dir,
-	                      GCONF_CLIENT_PRELOAD_ONELEVEL,
-	                      NULL);
+			      em_junk_bf_gconf_dir,
+			      GCONF_CLIENT_PRELOAD_ONELEVEL,
+			      NULL);
 
 	gconf_client_notify_add (gconf,
-	                         em_junk_bf_gconf_dir,
+				 em_junk_bf_gconf_dir,
 				 em_junk_bf_setting_notify,
 				 NULL, NULL, NULL);
 
@@ -301,7 +357,7 @@ convert_unicode_cb (GtkWidget *widget, gpointer data)
 	gboolean active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 	GConfClient *gconf = gconf_client_get_default();
 
-   	gconf_client_set_bool (gconf, data, active, NULL);
+	gconf_client_set_bool (gconf, data, active, NULL);
 
 	g_object_unref (gconf);
 }
@@ -309,7 +365,7 @@ convert_unicode_cb (GtkWidget *widget, gpointer data)
 GtkWidget *
 org_gnome_bogo_convert_unicode (struct _EPlugin *epl, struct _EConfigHookItemFactoryData *data)
 {
-   	GtkWidget *check;
+	GtkWidget *check;
 	guint i = ((GtkTable *)data->parent)->nrows;
 
 	if (data->old)
@@ -318,7 +374,7 @@ org_gnome_bogo_convert_unicode (struct _EPlugin *epl, struct _EConfigHookItemFac
 	check = gtk_check_button_new_with_mnemonic (_("Convert message text to _Unicode"));
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), em_junk_bf_unicode);
-	g_signal_connect (GTK_TOGGLE_BUTTON (check), "toggled", G_CALLBACK (convert_unicode_cb), "/apps/evolution/mail/junk/bogofilter/unicode");
+	g_signal_connect (GTK_TOGGLE_BUTTON (check), "toggled", G_CALLBACK (convert_unicode_cb), (gpointer) "/apps/evolution/mail/junk/bogofilter/unicode");
 	gtk_table_attach((GtkTable *)data->parent, check, 0, 1, i, i+1, 0, 0, 0, 0);
 	gtk_widget_show (check);
 	return (GtkWidget *)check;
