@@ -14,7 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
@@ -53,16 +53,16 @@ struct _ExchangeConfigListenerPrivate {
 	GConfClient *gconf;
 	guint idle_id;
 
-	char *configured_uri, *configured_name;
+	gchar *configured_uri, *configured_name;
 	EAccount *configured_account;
 
 	ExchangeAccount *exchange_account;
 };
 
 typedef struct {
-	const char *name;
-	const char *uri;
-	int type;
+	const gchar *name;
+	const gchar *uri;
+	gint type;
 }FolderInfo;
 
 enum {
@@ -89,14 +89,14 @@ static void account_changed (EAccountList *account_listener,
 			     EAccount     *account);
 static void account_removed (EAccountList *account_listener,
 			     EAccount     *account);
-#if LDEAD
+#ifdef LDEAD
 static void exchange_add_autocompletion_folders (GConfClient *gc_client,
 						 ExchangeAccount *account);
 #endif
 static gboolean exchange_camel_urls_is_equal (const gchar *url1,
 					      const gchar *url2);
 static void remove_selected_non_offline_esources (ExchangeAccount *account,
-						  const char *gconf_key);
+						  const gchar *gconf_key);
 static void
 class_init (GObjectClass *object_class)
 {
@@ -182,9 +182,9 @@ E2K_MAKE_TYPE (exchange_config_listener, ExchangeConfigListener, class_init, ini
 #define EVOLUTION_URI_PREFIX_LEN (sizeof (EVOLUTION_URI_PREFIX) - 1)
 
 static EFolder *
-standard_folder (ExchangeAccount *account, const char *folder_type)
+standard_folder (ExchangeAccount *account, const gchar *folder_type)
 {
-	const char *uri;
+	const gchar *uri;
 
 	uri = exchange_account_get_standard_uri (account, folder_type);
 	if (!uri)
@@ -193,21 +193,21 @@ standard_folder (ExchangeAccount *account, const char *folder_type)
 }
 
 static void
-set_special_mail_folder (ExchangeAccount *account, const char *folder_type,
-			 char **folder_uri)
+set_special_mail_folder (ExchangeAccount *account, const gchar *folder_type,
+			 gchar **folder_uri)
 {
 	EFolder *folder;
-	const char *physical_uri;
-	char *url_string, *path;
+	const gchar *physical_uri;
+	gchar *url_string, *path;
 	CamelURL *camel_url;
-	int uri_len;
+	gint uri_len;
 
 	folder = standard_folder (account, folder_type);
 	if (!folder)
 		return;
 	physical_uri = e_folder_get_physical_uri (folder);
 
-	/* remove ; form the uri */
+	/* remove; form the uri */
 	camel_url = camel_url_new (physical_uri, NULL);
 	url_string = camel_url_to_string (camel_url, CAMEL_URL_HIDE_ALL);
 	camel_url_free (camel_url);
@@ -229,7 +229,7 @@ add_defaults_for_account (ExchangeConfigListener *config_listener,
 	EAccount *eaccount;
 	gboolean save = FALSE;
 
-#if LDEAD
+#ifdef LDEAD
 	exchange_add_autocompletion_folders (config_listener->priv->gconf, account);
 #endif
 
@@ -237,12 +237,12 @@ add_defaults_for_account (ExchangeConfigListener *config_listener,
 	eaccount = config_listener->priv->configured_account;
 	if (!e_account_get_string (eaccount, E_ACCOUNT_DRAFTS_FOLDER_URI)) {
 		set_special_mail_folder (account, "drafts",
-				 	 &eaccount->drafts_folder_uri);
+					 &eaccount->drafts_folder_uri);
 		save = TRUE;
 	}
 	if (!e_account_get_string (eaccount, E_ACCOUNT_SENT_FOLDER_URI)) {
 		set_special_mail_folder (account, "sentitems",
-				 	 &eaccount->sent_folder_uri);
+					 &eaccount->sent_folder_uri);
 		save = TRUE;
 	}
 	if (save) {
@@ -271,12 +271,12 @@ add_account_esources (ExchangeAccount *account,
 	ESourceGroup *cal_source_group = NULL;
 	ESourceGroup *tasks_source_group = NULL;
 	ESourceGroup *contacts_source_group = NULL;
-	char *relative_uri = NULL, *username = NULL;
+	gchar *relative_uri = NULL, *username = NULL;
 #if 0
 	GSList *ids;
 #endif
 	GConfClient *client;
-	int mode;
+	gint mode;
 	ESourceList *cal_source_list, *tasks_source_list, *contacts_source_list;
 	FolderInfo *folder=NULL;
 	gboolean offline_mode = FALSE;
@@ -302,16 +302,16 @@ add_account_esources (ExchangeAccount *account,
 	cal_source_group = e_source_group_new (account->account_name,
 					       EXCHANGE_URI_PREFIX);
 	tasks_source_group = e_source_group_new (account->account_name,
-					   	 EXCHANGE_URI_PREFIX);
+						 EXCHANGE_URI_PREFIX);
 	contacts_source_group = e_source_group_new (account->account_name,
-					   	    EXCHANGE_URI_PREFIX);
+						    EXCHANGE_URI_PREFIX);
 
 	if (!e_source_list_add_group (contacts_source_list, contacts_source_group, -1) ||
 	    !e_source_list_add_group (cal_source_list, cal_source_group, -1) ||
 	    !e_source_list_add_group (tasks_source_list, tasks_source_group, -1)) {
 		goto done;
 	}
-	for ( ; folders != NULL ; folders = g_slist_next (folders)) {
+	for (; folders != NULL; folders = g_slist_next (folders)) {
 		/* Create source for each folder and add to the group */
 
 		folder = folders->data;
@@ -409,11 +409,11 @@ add_new_sources (ExchangeAccount *account)
 
 	exchange_folders = exchange_account_get_folders (account);
         if (exchange_folders && exchange_folders->len > 0) {
-		int i;
-		const char *folder_type;
-		const char *folder_name;
-		const char *folder_uri;
-		int type;
+		gint i;
+		const gchar *folder_type;
+		const gchar *folder_name;
+		const gchar *folder_uri;
+		gint type;
 		EFolder *folder;
 		ExchangeHierarchy *hier;
 		gboolean create_esource = FALSE;
@@ -462,8 +462,8 @@ add_sources (ExchangeAccount *account)
 
 	exchange_folders = exchange_account_get_folders (account);
         if (exchange_folders && exchange_folders->len > 0) {
-		int i;
-		const char *folder_type;
+		gint i;
+		const gchar *folder_type;
 		EFolder *folder;
 		GSList *folders = NULL;
 
@@ -481,15 +481,15 @@ add_sources (ExchangeAccount *account)
 				folders = g_slist_append (folders, folder_info);
 			}
 			else if (!(strcmp (folder_type, "tasks")) ||
-			    	 !(strcmp (folder_type, "tasks/public"))) {
+				 !(strcmp (folder_type, "tasks/public"))) {
 				folder_info->name = e_folder_get_name (folder);
 				folder_info->uri = e_folder_get_physical_uri (folder);
 				folder_info->type = EXCHANGE_TASKS_FOLDER;
 				folders = g_slist_append (folders, folder_info);
 			}
 			else if (!(strcmp (folder_type, "contacts")) ||
-			    	 !(strcmp (folder_type, "contacts/public")) ||
-			    	 !(strcmp (folder_type, "contacts/ldap"))) {
+				 !(strcmp (folder_type, "contacts/public")) ||
+				 !(strcmp (folder_type, "contacts/ldap"))) {
 				folder_info->name = e_folder_get_name (folder);
 				folder_info->uri = e_folder_get_physical_uri (folder);
 				folder_info->type = EXCHANGE_CONTACTS_FOLDER;
@@ -508,7 +508,7 @@ add_sources (ExchangeAccount *account)
 
 static void
 remove_account_esource (ExchangeAccount *account,
-		        FolderType folder_type)
+			FolderType folder_type)
 {
 	ESourceGroup *group;
 	ESource *source = NULL;
@@ -516,7 +516,7 @@ remove_account_esource (ExchangeAccount *account,
 	GSList *sources;
 	GSList *ids, *node_to_be_deleted;
 	gboolean found_group;
-	const char *source_uid;
+	const gchar *source_uid;
 	GConfClient *client;
 	ESourceList *source_list = NULL;
 
@@ -537,7 +537,7 @@ remove_account_esource (ExchangeAccount *account,
 	groups = e_source_list_peek_groups (source_list);
 	found_group = FALSE;
 
-	for ( ; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
 		group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), account->account_name) == 0
@@ -545,7 +545,7 @@ remove_account_esource (ExchangeAccount *account,
                     strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
 			sources = e_source_group_peek_sources (group);
 
-			for( ; sources != NULL; sources = g_slist_next (sources)) {
+			for(; sources != NULL; sources = g_slist_next (sources)) {
 				source = E_SOURCE (sources->data);
 				source_uid = e_source_peek_uid (source);
 
@@ -614,10 +614,10 @@ remove_account_esources (ExchangeAccount *account)
 }
 
 #ifdef HAVE_KRB5
-static char *
+static gchar *
 get_new_exchange_password (ExchangeAccount *account)
 {
-	char *old_password, *new_password;
+	gchar *old_password, *new_password;
 
 	old_password = exchange_account_get_password (account);
 	new_password = exchange_get_new_password (old_password, 0);
@@ -638,7 +638,7 @@ get_new_exchange_password (ExchangeAccount *account)
 static void
 change_passwd_cb (GtkWidget *button, ExchangeAccount *account)
 {
-	char *current_passwd, *new_passwd;
+	gchar *current_passwd, *new_passwd;
 
 	gtk_widget_hide (gtk_widget_get_toplevel(button));
 	current_passwd = exchange_account_get_password (account);
@@ -650,13 +650,13 @@ change_passwd_cb (GtkWidget *button, ExchangeAccount *account)
 #endif
 
 static void
-display_passwd_expiry_message (int max_passwd_age, ExchangeAccount *account)
+display_passwd_expiry_message (gint max_passwd_age, ExchangeAccount *account)
 {
 	GladeXML *xml;
 	GtkWidget *top_widget, *change_passwd_button;
 	GtkResponseType response;
 	GtkLabel *warning_msg_label;
-	char *passwd_expiry_msg =
+	gchar *passwd_expiry_msg =
 		g_strdup_printf (_("Your password will expire in the next %d days"), max_passwd_age);
 
 	xml = glade_xml_new (FILENAME, ROOTNODE, NULL);
@@ -688,13 +688,13 @@ exchange_config_listener_authenticate (ExchangeConfigListener *ex_conf_listener,
 {
 	ExchangeConfigListenerPrivate *priv;
 	ExchangeAccountResult result;
-	char *key, *password, *title, *url_string;
+	gchar *key, *password, *title, *url_string;
 #ifdef HAVE_KRB5
-	char *new_password;
+	gchar *new_password;
 #endif
 	gboolean oldremember, remember = FALSE;
 	CamelURL *camel_url;
-	const char *remember_password;
+	const gchar *remember_password;
 
 	g_return_val_if_fail (EXCHANGE_IS_CONFIG_LISTENER (ex_conf_listener), EXCHANGE_ACCOUNT_CONFIG_ERROR);
 	priv = ex_conf_listener->priv;
@@ -732,7 +732,7 @@ exchange_config_listener_authenticate (ExchangeConfigListener *ex_conf_listener,
 		exchange_account_set_save_password (account, FALSE);
 	}
 
- 	exchange_account_connect (account, password, &result);
+	exchange_account_connect (account, password, &result);
 
 	g_free (password);
 	g_free (key);
@@ -743,7 +743,7 @@ exchange_config_listener_authenticate (ExchangeConfigListener *ex_conf_listener,
 		new_password = get_new_exchange_password (account);
 		if (new_password) {
 			/* try connecting with new password */
- 			exchange_account_connect (account, new_password, &result);
+			exchange_account_connect (account, new_password, &result);
 			g_free (new_password);
 		}
 #endif
@@ -752,7 +752,7 @@ exchange_config_listener_authenticate (ExchangeConfigListener *ex_conf_listener,
 		 result == EXCHANGE_ACCOUNT_QUOTA_SEND_ERROR ||
 		 result == EXCHANGE_ACCOUNT_QUOTA_WARN) {
 		gchar *current_quota_usage = NULL;
-		const char *error_code = NULL;
+		const gchar *error_code = NULL;
 		GtkWidget *widget;
 
 		switch (result) {
@@ -789,7 +789,7 @@ exchange_config_listener_authenticate (ExchangeConfigListener *ex_conf_listener,
 		result = EXCHANGE_ACCOUNT_CONNECT_SUCCESS;
 	}
 	if (result == EXCHANGE_ACCOUNT_CONNECT_SUCCESS) {
-		int max_pwd_age_days;
+		gint max_pwd_age_days;
 		GladeXML *xml;
 		GtkWidget *dialog;
 		GtkResponseType response;
@@ -872,7 +872,7 @@ account_added (EAccountList *account_list, EAccount *account)
 
 	g_signal_emit (config_listener, signals[EXCHANGE_ACCOUNT_CREATED], 0,
 		       exchange_account);
-/*  	add_sources (exchange_account); */
+/*	add_sources (exchange_account); */
 
 	exchange_config_listener_get_offline_status (config_listener, &is_offline);
 
@@ -905,13 +905,13 @@ configured_account_destroyed (gpointer user_data, GObject *where_account_was)
 }
 
 static gboolean
-requires_relogin (char *current_url, char *new_url)
+requires_relogin (gchar *current_url, gchar *new_url)
 {
 	E2kUri *current_uri, *new_uri;
-	const char *current_param_val, *new_param_val;
-	const char *params [] = { "owa_url", "ad_server", "use_ssl" };
-	const int n_params = G_N_ELEMENTS (params);
-	int i;
+	const gchar *current_param_val, *new_param_val;
+	const gchar *params [] = { "owa_url", "ad_server", "use_ssl" };
+	const gint n_params = G_N_ELEMENTS (params);
+	gint i;
 	gboolean relogin = FALSE;
 
 	current_uri = e2k_uri_new (current_url);
@@ -925,7 +925,7 @@ requires_relogin (char *current_url, char *new_url)
 
 	if (current_uri->authmech || new_uri->authmech) {
 		if (current_uri->authmech && new_uri->authmech) {
-	    		if (strcmp (current_uri->authmech, new_uri->authmech)) {
+			if (strcmp (current_uri->authmech, new_uri->authmech)) {
 				/* Auth mechanism has changed */
 				relogin = TRUE;
 				goto end;
@@ -1031,7 +1031,7 @@ account_changed (EAccountList *account_list, EAccount *account)
 		remove_account_esources (priv->exchange_account);
 		exchange_account_forget_password (priv->exchange_account);
 	} else if (strcmp (config_listener->priv->configured_name, account->name)) {
-/* 		remove_account_esources (priv->exchange_account); */
+/*		remove_account_esources (priv->exchange_account); */
 		exchange_config_listener_modify_esource_group_name (config_listener,
 								    config_listener->priv->configured_name,
 								    account->name);
@@ -1176,8 +1176,8 @@ exchange_config_listener_get_accounts (ExchangeConfigListener *config_listener)
  **/
 void
 exchange_config_listener_modify_esource_group_name (ExchangeConfigListener *excl,
-							 const char *old_name,
-							 const char *new_name)
+							 const gchar *old_name,
+							 const gchar *new_name)
 {
 	GConfClient *client;
 	ESourceGroup *group;
@@ -1193,7 +1193,7 @@ exchange_config_listener_modify_esource_group_name (ExchangeConfigListener *excl
 
 	groups = e_source_list_peek_groups (c_source_list);
 
-	for ( ; groups != NULL; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		group = E_SOURCE_GROUP (groups->data);
 		if (!strcmp (e_source_group_peek_name (group), old_name)) {
 			e_source_group_set_name (group, new_name);
@@ -1203,7 +1203,7 @@ exchange_config_listener_modify_esource_group_name (ExchangeConfigListener *excl
 
 	groups = e_source_list_peek_groups (t_source_list);
 
-	for ( ; groups != NULL; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		group = E_SOURCE_GROUP (groups->data);
 		if (!strcmp (e_source_group_peek_name (group), old_name)) {
 			e_source_group_set_name (group, new_name);
@@ -1213,7 +1213,7 @@ exchange_config_listener_modify_esource_group_name (ExchangeConfigListener *excl
 
 	groups = e_source_list_peek_groups (a_source_list);
 
-	for ( ; groups != NULL; groups = g_slist_next (groups)) {
+	for (; groups != NULL; groups = g_slist_next (groups)) {
 		group = E_SOURCE_GROUP (groups->data);
 		if (!strcmp (e_source_group_peek_name (group), old_name)) {
 			e_source_group_set_name (group, new_name);
@@ -1230,7 +1230,7 @@ exchange_config_listener_modify_esource_group_name (ExchangeConfigListener *excl
 	g_object_unref (a_source_list);
 }
 
-#if LDEAD
+#ifdef LDEAD
 /**
  * exchange_add_autocompletion_folders:
  *
@@ -1252,7 +1252,7 @@ exchange_add_autocompletion_folders (GConfClient *gc_client, ExchangeAccount *ac
 	sl = e_source_list_new_for_gconf (gc_client, CONF_KEY_CONTACTS);
 	groups = e_source_list_peek_groups (sl);
 
-	for ( ; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
 		ESourceGroup *group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), account->account_name) == 0
@@ -1260,7 +1260,7 @@ exchange_add_autocompletion_folders (GConfClient *gc_client, ExchangeAccount *ac
 		    strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
 			GSList *sources = e_source_group_peek_sources (group);
 
-			for( ; sources != NULL; sources = g_slist_next (sources)) {
+			for(; sources != NULL; sources = g_slist_next (sources)) {
 				ESource *source = E_SOURCE (sources->data);
 				const gchar *absolute_uri;
 
@@ -1299,22 +1299,22 @@ exchange_camel_urls_is_equal (const gchar *url1, const gchar *url2)
 {
 	CamelURL *curl1, *curl2;
 	gchar *param1, *param2;
-	const char *params[] = {
+	const gchar *params[] = {
 		"auth",
 		"owa_url",
 		"owa_path",
 		"mailbox",
 		"ad_server",
 	};
-	const int n_params = 5;
-	int i;
+	const gint n_params = 5;
+	gint i;
 
 	curl1 = camel_url_new (url1, NULL);
 	curl2 = camel_url_new (url2, NULL);
 
 	for (i = 0; i < n_params; ++i) {
-		param1 = (gchar*) camel_url_get_param (curl1, params[i]);
-		param2 = (gchar*) camel_url_get_param (curl2, params[i]);
+		param1 = (gchar *) camel_url_get_param (curl1, params[i]);
+		param2 = (gchar *) camel_url_get_param (curl2, params[i]);
 		if ((param1 && !param2) || (!param1 && param2) || /* Missing */
 		    (param1 && param2 && strcmp (param1, param2))) { /* Differing */
 			g_free (param1);
@@ -1342,7 +1342,7 @@ exchange_camel_urls_is_equal (const gchar *url1, const gchar *url2)
  * selection list
  **/
 static void
-remove_selected_non_offline_esources (ExchangeAccount *account, const char *gconf_key)
+remove_selected_non_offline_esources (ExchangeAccount *account, const gchar *gconf_key)
 {
 	ESourceGroup *group;
 	ESource *source = NULL;
@@ -1350,11 +1350,11 @@ remove_selected_non_offline_esources (ExchangeAccount *account, const char *gcon
 	GSList *sources;
 	GSList *ids, *node_to_be_deleted;
 	gboolean found_group;
-	const char *source_uid;
+	const gchar *source_uid;
 	GConfClient *client;
 	ESourceList *source_list = NULL;
-	const char *offline_mode=NULL;
-	char *selected_gconf_key;
+	const gchar *offline_mode=NULL;
+	gchar *selected_gconf_key;
 
 
 	if (gconf_key && !strcmp (gconf_key, CONF_KEY_CAL)) {
@@ -1372,7 +1372,7 @@ remove_selected_non_offline_esources (ExchangeAccount *account, const char *gcon
 	groups = e_source_list_peek_groups (source_list);
 	found_group = FALSE;
 
-	for ( ; groups != NULL && !found_group; groups = g_slist_next (groups)) {
+	for (; groups != NULL && !found_group; groups = g_slist_next (groups)) {
 		group = E_SOURCE_GROUP (groups->data);
 
 		if (strcmp (e_source_group_peek_name (group), account->account_name) == 0
@@ -1380,7 +1380,7 @@ remove_selected_non_offline_esources (ExchangeAccount *account, const char *gcon
                     strcmp (e_source_group_peek_base_uri (group), EXCHANGE_URI_PREFIX) == 0) {
 			sources = e_source_group_peek_sources (group);
 
-			for( ; sources != NULL; sources = g_slist_next (sources)) {
+			for(; sources != NULL; sources = g_slist_next (sources)) {
 				source = E_SOURCE (sources->data);
 				source_uid = e_source_peek_uid (source);
 
