@@ -1,21 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- * Praveen Kumar <kpraveen@novell.com>
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Praveen Kumar <kpraveen@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -24,6 +25,7 @@
 #include <e-util/e-config.h>
 #include <calendar/gui/e-cal-config.h>
 #include <libedataserver/e-source.h>
+#include <libedataserver/e-source-list.h>
 #include <libedataserver/e-url.h>
 #include <e-folder.h>
 #include <exchange-account.h>
@@ -65,10 +67,12 @@ e_exchange_contacts_get_contacts (void)
 	GPtrArray *contacts_list;
 	EFolder *folder;
 
-	int i, prefix_len;
+	gint i, prefix_len;
 	gchar *uri_prefix, *ruri;
 
 	account = exchange_operations_get_exchange_account ();
+	if (!account)
+		return NULL;
 
 	uri_prefix = g_strconcat ("exchange://", account->account_filename, "/;", NULL);
 	prefix_len = strlen (uri_prefix);
@@ -80,9 +84,9 @@ e_exchange_contacts_get_contacts (void)
 	for (i=0; i<folder_array->len; ++i) {
 		gchar *type, *tmp;
 		folder = g_ptr_array_index (folder_array, i);
-		type = (gchar*) e_folder_get_type_string (folder);
+		type = (gchar *) e_folder_get_type_string (folder);
 		if (!strcmp (type, "contacts")) {
-			tmp = (gchar*) e_folder_get_physical_uri (folder);
+			tmp = (gchar *) e_folder_get_physical_uri (folder);
 			if (g_str_has_prefix (tmp, uri_prefix)) {
 				ruri = g_strdup (tmp+prefix_len);
 				g_ptr_array_add (contacts_list, ruri);
@@ -107,6 +111,8 @@ e_exchange_contacts_pcontacts_on_change (GtkTreeView *treeview, ESource *source)
 	gchar *ruri;
 
 	account = exchange_operations_get_exchange_account ();
+	if (!account)
+		return;
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
 	gtk_tree_selection_get_selected(selection, &model, &iter);
@@ -130,14 +136,14 @@ e_exchange_contacts_pcontacts (EPlugin *epl, EConfigHookItemFactoryData *data)
 	GPtrArray *conlist;
 	gchar *ruri, *account_name, *uri_text;
 	ExchangeAccount *account;
-	int i;
-	char *folder_size, *abook_name;
-	const char *rel_uri;
-	const char *uid;
+	gint i;
+	gchar *folder_size, *abook_name;
+	const gchar *rel_uri;
+	const gchar *uid;
 	EABConfigTargetSource *t = (EABConfigTargetSource *) data->target;
 	ESource *source = t->source;
 	GtkWidget *lbl_offline_msg, *vb_offline_msg;
-	char *offline_msg;
+	gchar *offline_msg;
 	gint offline_status;
 	gboolean gal_folder = FALSE, is_personal;
 
@@ -206,7 +212,7 @@ e_exchange_contacts_pcontacts (EPlugin *epl, EConfigHookItemFactoryData *data)
 	g_free (uri_text);
 
 	if (contacts_src_exists && is_personal ) {
-		abook_name = (char*)e_source_peek_name (source);
+		abook_name = (gchar *)e_source_peek_name (source);
 		model = exchange_account_folder_size_get_model (account);
 		if (model)
 			folder_size = g_strdup_printf (_("%s KB"), exchange_folder_size_get_val (model, abook_name));
@@ -240,9 +246,12 @@ e_exchange_contacts_pcontacts (EPlugin *epl, EConfigHookItemFactoryData *data)
 
 	conlist = e_exchange_contacts_get_contacts ();
 
-	for (i=0; i<conlist->len; ++i) {
-		ruri = g_ptr_array_index (conlist, i);
-		exchange_operations_cta_add_node_to_tree (ts_pcontacts, NULL, ruri);
+	if (conlist) {
+		for (i = 0; i < conlist->len; i++) {
+			ruri = g_ptr_array_index (conlist, i);
+			exchange_operations_cta_add_node_to_tree (ts_pcontacts, NULL, ruri);
+		}
+		g_ptr_array_free (conlist, TRUE);
 	}
 
 	cr_contacts = gtk_cell_renderer_text_new ();
@@ -266,10 +275,10 @@ e_exchange_contacts_pcontacts (EPlugin *epl, EConfigHookItemFactoryData *data)
 
 	if (contacts_src_exists) {
 		gchar *uri_prefix, *sruri, *tmpruri;
-		int prefix_len;
+		gint prefix_len;
 		GtkTreeSelection *selection;
 
-		tmpruri = (gchar*) rel_uri;
+		tmpruri = (gchar *) rel_uri;
 		uri_prefix = g_strconcat (account->account_filename, "/;", NULL);
 		prefix_len = strlen (uri_prefix);
 
@@ -292,7 +301,6 @@ e_exchange_contacts_pcontacts (EPlugin *epl, EConfigHookItemFactoryData *data)
 		g_free (sruri);
 	}
 
-	g_ptr_array_free (conlist, TRUE);
 	g_object_unref (ts_pcontacts);
 	return vb_pcontacts;
 }
@@ -303,8 +311,8 @@ e_exchange_contacts_check (EPlugin *epl, EConfigHookPageCheckData *data)
 	/* FIXME - check pageid */
 	EABConfigTargetSource *t = (EABConfigTargetSource *) data->target;
 	ESourceGroup *group;
-	const char *base_uri;
-	const char *rel_uri;
+	const gchar *base_uri;
+	const gchar *rel_uri;
 	gint offline_status;
 	ExchangeAccount *account;
 
@@ -328,22 +336,26 @@ e_exchange_contacts_check (EPlugin *epl, EConfigHookPageCheckData *data)
 	}
 
 	account = exchange_operations_get_exchange_account ();
+	if (!account)
+		return FALSE;
 
 	if (!rel_uri) {
 		GConfClient *client;
 		ESourceList *source_list = NULL;
 		ESourceGroup *source_group = NULL;
-		GSList *groups;
 		ESource *source;
+		EAccount *eaccount;
 
 		/* GAL folder */
 		client = gconf_client_get_default ();
 		source_list = e_source_list_new_for_gconf ( client, CONF_KEY_CONTACTS);
 		g_object_unref (client);
-		groups = e_source_list_peek_groups (source_list);
 
-		if ((source_group = e_source_list_peek_group_by_name (source_list,
-                                        account->account_name))) {
+		eaccount = exchange_account_fetch (account);
+		g_return_val_if_fail (eaccount != NULL, FALSE);
+		g_return_val_if_fail (eaccount->uid != NULL, FALSE);
+
+		if ((source_group = e_source_list_peek_group_by_properties (source_list, "account-uid", eaccount->uid, NULL))) {
 			source =  e_source_group_peek_source_by_name (source_group, e_source_peek_name (t->source));
 			if (e_source_group_peek_source_by_name (source_group,
 							e_source_peek_name (t->source))) {
@@ -363,7 +375,7 @@ e_exchange_contacts_check (EPlugin *epl, EConfigHookPageCheckData *data)
 	}
 	else {
 		EUri *euri;
-		int uri_len;
+		gint uri_len;
 		gchar *uri_text, *uri_string, *path, *folder_name;
 		gboolean is_personal;
 
@@ -402,7 +414,7 @@ e_exchange_contacts_commit (EPlugin *epl, EConfigTarget *target)
 	ESource *source = t->source;
 	gchar *uri_text, *gname, *gruri, *ruri = NULL, *path = NULL, *path_prefix, *oldpath=NULL;
 	gchar *username, *windows_domain, *authtype;
-	int prefix_len;
+	gint prefix_len;
 	ExchangeAccount *account;
 	ExchangeAccountFolderResult result;
 	gint offline_status;
@@ -423,7 +435,7 @@ e_exchange_contacts_commit (EPlugin *epl, EConfigTarget *target)
 	}
 
 	account = exchange_operations_get_exchange_account ();
-	if (!is_exchange_personal_folder (account, uri_text))
+	if (!account || !is_exchange_personal_folder (account, uri_text))
 		return;
 
 	windows_domain = exchange_account_get_windows_domain (account);
@@ -439,13 +451,13 @@ e_exchange_contacts_commit (EPlugin *epl, EConfigTarget *target)
 	prefix_len = strlen (path_prefix);
 	g_free (path_prefix);
 
-	gname = (gchar*) e_source_peek_name (source);
-	gruri = (gchar*) e_source_peek_relative_uri (source);
+	gname = (gchar *) e_source_peek_name (source);
+	gruri = (gchar *) e_source_peek_relative_uri (source);
 
 	if (contacts_src_exists) {
 		gchar *tmpruri, *uri_string, *temp_path, *prefix;
 		EUri *euri;
-		int uri_len;
+		gint uri_len;
 
 		euri = e_uri_new (uri_text);
 		uri_string = e_uri_to_string (euri, FALSE);
@@ -491,7 +503,7 @@ e_exchange_contacts_commit (EPlugin *epl, EConfigTarget *target)
 		if (authtype) {
 			e_source_set_property (source, "auth-type", authtype);
 			g_free (authtype);
-			authtype=NULL;			
+			authtype=NULL;
 		}
 		e_source_set_property (source, "auth", "plain/password");
 		if (rename) {
