@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -49,37 +49,35 @@
 #include <string.h>
 
 
-#define EXCHANGE_DELEGATES_USER_SEPARATOR -2
 #define EXCHANGE_DELEGATES_USER_CUSTOM    -3
 /* Can't use E2K_PERMISSIONS_ROLE_CUSTOM, because it's -1, which
- * means "end of list" to e_dialog_option_menu_get/set
+ * means "end of list" to e_dialog_combo_box_get/set
  */
 
-static const int exchange_perm_map[] = {
+static const gint exchange_perm_map[] = {
 	E2K_PERMISSIONS_ROLE_NONE,
 	E2K_PERMISSIONS_ROLE_REVIEWER,
 	E2K_PERMISSIONS_ROLE_AUTHOR,
 	E2K_PERMISSIONS_ROLE_EDITOR,
 
-	EXCHANGE_DELEGATES_USER_SEPARATOR,
 	EXCHANGE_DELEGATES_USER_CUSTOM,
 
 	-1
 };
 
-const char *exchange_delegates_user_folder_names[] = {
+const gchar *exchange_delegates_user_folder_names[] = {
 	"calendar", "tasks", "inbox", "contacts"
 };
 
 /* To translators: The folder names to be displayed in the message being
    sent to the delegatee.
 */
-static const char *folder_names_for_display[] = {
+static const gchar *folder_names_for_display[] = {
 	N_("Calendar"), N_("Tasks"), N_("Inbox"), N_("Contacts")
 };
 
-static const char *widget_names[] = {
-	"calendar_perms", "task_perms", "inbox_perms", "contact_perms",
+static const gchar *widget_names[] = {
+	"calendar_perms_combobox", "task_perms_combobox", "inbox_perms_combobox", "contact_perms_combobox",
 };
 
 
@@ -140,26 +138,14 @@ is_delegate_role (E2kPermissionsRole role)
 }
 
 static void
-set_perms (GtkWidget *omenu, E2kPermissionsRole role)
+set_perms (GtkWidget *combobox, E2kPermissionsRole role)
 {
 	if (!is_delegate_role (role)) {
-		GtkWidget *menu, *item;
-
-		menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (omenu));
-
-		item = gtk_menu_item_new ();
-		gtk_widget_set_sensitive (item, FALSE);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-		item = gtk_menu_item_new_with_label (_("Custom"));
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-		gtk_widget_show_all (menu);
-
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Custom"));
 		role = EXCHANGE_DELEGATES_USER_CUSTOM;
 	}
 
-	e_dialog_option_menu_set (omenu, role, exchange_perm_map);
+	e_dialog_combo_box_set (combobox, role, exchange_perm_map);
 }
 
 static void
@@ -170,10 +156,10 @@ parent_window_destroyed (gpointer dialog, GObject *where_parent_window_was)
 
 /* Maps the role_nam parameter to their corresponding Full role name
 */
-static const char *
+static const gchar *
 map_to_full_role_name (E2kPermissionsRole role_nam)
 {
-	const char *role_name;
+	const gchar *role_name;
 
 	switch (role_nam)
 	{
@@ -201,7 +187,7 @@ map_to_full_role_name (E2kPermissionsRole role_nam)
 
 static void
 em_utils_delegates_done (CamelFolder *folder, CamelMimeMessage *msg, CamelMessageInfo *info,
-		       int queued, const char *appended_uid, void *data)
+		       gint queued, const gchar *appended_uid, gpointer data)
 {
 	camel_message_info_free (info);
 	mail_send ();
@@ -224,9 +210,9 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			     GtkWidget *parent_window)
 {
 	GladeXML *xml;
-	GtkWidget *dialog, *table, *label, *menu, *check, *check_delegate;
-	char *title;
-	int button, i;
+	GtkWidget *dialog, *table, *label, *combobox, *check, *check_delegate;
+	gchar *title;
+	gint button, i;
 	E2kPermissionsRole role;
 	gboolean modified;
 
@@ -257,8 +243,8 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 
 	/* Set up the permissions */
 	for (i = 0; i < EXCHANGE_DELEGATES_LAST; i++) {
-		menu = glade_xml_get_widget (xml, widget_names[i]);
-		set_perms (menu, user->role[i]);
+		combobox = glade_xml_get_widget (xml, widget_names[i]);
+		set_perms (combobox, user->role[i]);
 	}
 	check = glade_xml_get_widget (xml, "see_private_checkbox");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
@@ -285,8 +271,8 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 	/* And update */
 	modified = FALSE;
 	for (i = 0; i < EXCHANGE_DELEGATES_LAST; i++) {
-		menu = glade_xml_get_widget (xml, widget_names[i]);
-		role = e_dialog_option_menu_get (menu, exchange_perm_map);
+		combobox = glade_xml_get_widget (xml, widget_names[i]);
+		role = e_dialog_combo_box_get (combobox, exchange_perm_map);
 
 		if (is_delegate_role (user->role[i]) &&
 		    user->role[i] != role) {
@@ -313,14 +299,15 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			CamelStream *stream;
 			CamelFolder *out_folder;
 			CamelMessageInfo *info;
-			char *self_address, *delegate_mail_subject;
-			char *role_name;
-			char *role_name_final = "";
+			gchar *self_address, *delegate_mail_subject;
+			gchar *role_name;
+			GString *role_name_final;
 
-			const char *recipient_address;
-			const char *delegate_exchange_dn;
-			const char *msg_part1 = NULL, *msg_part2 = NULL;
+			const gchar *recipient_address;
+			const gchar *delegate_exchange_dn;
+			const gchar *msg_part1 = NULL, *msg_part2 = NULL;
 
+			role_name_final = g_string_new ("");
 
 			self_address = g_strdup (exchange_account_get_email_id (account));
 
@@ -341,7 +328,7 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			   summarizing the permissions assigned to him.
 			*/
 			msg_part1 = _("This message was sent automatically by Evolution to inform you that you have been "
-				    	"designated as a delegate. You can now send messages on my behalf.");
+					"designated as a delegate. You can now send messages on my behalf.");
 
 			/* To translators: Another chunk of the same message.
 			*/
@@ -350,14 +337,16 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 			camel_stream_printf (stream,
 				"<html><body><p>%s<br><br>%s</p><table border = 0 width=\"40%%\">", msg_part1, msg_part2);
 			for (i = 0; i < EXCHANGE_DELEGATES_LAST; i++) {
-				menu = glade_xml_get_widget (xml, widget_names[i]);
-				role = e_dialog_option_menu_get (menu, exchange_perm_map);
+				combobox = glade_xml_get_widget (xml, widget_names[i]);
+				role = e_dialog_combo_box_get (combobox, exchange_perm_map);
 				role_name = g_strdup (map_to_full_role_name(role));
-				role_name_final = g_strconcat (role_name_final, "<tr><td>" , folder_names_for_display[i],
-					":</td><td>", role_name, "</td> </tr>", NULL);
+				g_string_append_printf (
+					role_name_final,
+					"<tr><td>%s:</td><td>%s</td></tr>",
+					folder_names_for_display[i], role_name);
 			}
 
-			camel_stream_printf (stream, "%s</table>", role_name_final);
+			camel_stream_printf (stream, "%s</table>", role_name_final->str);
 
 			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)) == TRUE) {
 				/* To translators: This message is included if the delegatee has been given access
@@ -374,7 +363,7 @@ exchange_delegates_user_edit (ExchangeAccount *account,
 							 "to see my private items."));
 			camel_data_wrapper_construct_from_stream (delegate_mail_text, stream);
 			g_free (role_name);
-			g_free (role_name_final);
+			g_string_free (role_name_final, TRUE);
 			camel_object_unref (stream);
 
 			part = camel_mime_part_new ();
@@ -467,10 +456,10 @@ exchange_delegates_user_edit (ExchangeAccount *account,
  * with most of the internal data blank).
  **/
 ExchangeDelegatesUser *
-exchange_delegates_user_new (const char *display_name)
+exchange_delegates_user_new (const gchar *display_name)
 {
 	ExchangeDelegatesUser *user;
-	int i;
+	gint i;
 
 	user = g_object_new (EXCHANGE_TYPE_DELEGATES_USER, NULL);
 	user->display_name = g_strdup (display_name);
@@ -498,8 +487,8 @@ exchange_delegates_user_new (const char *display_name)
  **/
 ExchangeDelegatesUser *
 exchange_delegates_user_new_from_gc (E2kGlobalCatalog *gc,
-				    const char *email,
-		                    GByteArray *creator_entryid)
+				    const gchar *email,
+				    GByteArray *creator_entryid)
 {
 	E2kGlobalCatalogStatus status;
 	E2kGlobalCatalogEntry *entry;
