@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
@@ -30,7 +30,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 void exchange_delegates (ExchangeAccount *account, GtkWidget *parent);
-const char *email_look_up (const char *delegate_legacy, ExchangeAccount *account);
+const gchar *email_look_up (const gchar *delegate_legacy, ExchangeAccount *account);
 
 #ifdef __cplusplus
 }
