@@ -1,21 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Shakti Sen <shprasad@novell.com>
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Shakti Sen <shprasad@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -42,44 +44,44 @@
 #include "addressbook/gui/widgets/eab-popup.h"
 #include "exchange-folder-subscription.h"
 
-void org_gnome_exchange_folder_subscription (EPlugin *ep, EMMenuTargetSelect *target, gchar *fname);
+void org_gnome_exchange_folder_subscription (EPlugin *ep, EMMenuTargetSelect *target, const gchar *fname);
 void org_gnome_exchange_inbox_subscription (EPlugin *ep, EMMenuTargetSelect *target);
 void org_gnome_exchange_addressbook_subscription (EPlugin *ep, EMMenuTargetSelect *target);
 void org_gnome_exchange_calendar_subscription (EPlugin *ep, EMMenuTargetSelect *target);
 void org_gnome_exchange_tasks_subscription (EPlugin *ep, EMMenuTargetSelect *target);
 void org_gnome_exchange_check_subscribed (EPlugin *ep, ECalPopupTargetSource *target);
-void org_gnome_exchange_folder_unsubscribe (EPopup *ep, EPopupItem *p, void *data);
+void org_gnome_exchange_folder_unsubscribe (EPopup *ep, EPopupItem *p, gpointer data);
 void org_gnome_exchange_check_address_book_subscribed (EPlugin *ep, EABPopupTargetSource *target);
-void org_gnome_exchange_folder_ab_unsubscribe (EPopup *ep, EPopupItem *p, void *data);
+void org_gnome_exchange_folder_ab_unsubscribe (EPopup *ep, EPopupItem *p, gpointer data);
 void org_gnome_exchange_check_inbox_subscribed (EPlugin *ep, EMPopupTargetFolder *target);
-void org_gnome_exchange_folder_inbox_unsubscribe (EPopup *ep, EPopupItem *p, void *data);
-void popup_free (EPopup *ep, GSList *items, void *data);
-void popup_inbox_free (EPopup *ep, GSList *items, void *data);
-void popup_ab_free (EPopup *ep, GSList *items, void *data);
-static void exchange_get_folder (char *uri, CamelFolder *folder, void *data);
+void org_gnome_exchange_folder_inbox_unsubscribe (EPopup *ep, EPopupItem *p, gpointer data);
+void popup_free (EPopup *ep, GSList *items, gpointer data);
+void popup_inbox_free (EPopup *ep, GSList *items, gpointer data);
+void popup_ab_free (EPopup *ep, GSList *items, gpointer data);
+static void exchange_get_folder (gchar *uri, CamelFolder *folder, gpointer data);
 
 #define CONF_KEY_SELECTED_CAL_SOURCES "/apps/evolution/calendar/display/selected_calendars"
 
 
 static EPopupItem popup_inbox_items[] = {
-	{ E_POPUP_ITEM, "29.inbox_unsubscribe", N_("Unsubscribe Folder..."), org_gnome_exchange_folder_inbox_unsubscribe, NULL, "folder-new", 0, EM_POPUP_FOLDER_INFERIORS }
+	{ E_POPUP_ITEM, (gchar *) "29.inbox_unsubscribe", (gchar *) N_("Unsubscribe Folder..."), org_gnome_exchange_folder_inbox_unsubscribe, NULL, (gchar *) "folder-new", 0, EM_POPUP_FOLDER_INFERIORS }
 };
 
 void
-popup_inbox_free (EPopup *ep, GSList *items, void *data)
+popup_inbox_free (EPopup *ep, GSList *items, gpointer data)
 {
 	g_slist_free (items);
 }
 
 void
-org_gnome_exchange_folder_inbox_unsubscribe (EPopup *ep, EPopupItem *p, void *data)
+org_gnome_exchange_folder_inbox_unsubscribe (EPopup *ep, EPopupItem *p, gpointer data)
 {
 	ExchangeAccount *account = NULL;
 	EMPopupTargetFolder *target = data;
 	gchar *path = NULL;
 	gchar *stored_path = NULL;
-	const char *inbox_uri = NULL;
-	const char *inbox_physical_uri = NULL;
+	const gchar *inbox_uri = NULL;
+	const gchar *inbox_physical_uri = NULL;
 	gchar *target_uri = NULL;
 	EFolder *inbox;
 	ExchangeAccountFolderResult result;
@@ -145,11 +147,11 @@ org_gnome_exchange_folder_inbox_unsubscribe (EPopup *ep, EPopupItem *p, void *da
 }
 
 static CamelFolderInfo *
-ex_create_folder_info (CamelStore *store, char *name, char *uri,
-                  int unread_count, int flags)
+ex_create_folder_info (CamelStore *store, gchar *name, gchar *uri,
+                  gint unread_count, gint flags)
 {
         CamelFolderInfo *info;
-        const char *path;
+        const gchar *path;
 
         path = strstr (uri, "://");
         if (!path)
@@ -168,7 +170,7 @@ ex_create_folder_info (CamelStore *store, char *name, char *uri,
 }
 
 static void
-exchange_get_folder (char *uri, CamelFolder *folder, void *data)
+exchange_get_folder (gchar *uri, CamelFolder *folder, gpointer data)
 {
 	CamelStore *store;
 	CamelException ex;
@@ -204,7 +206,7 @@ void
 org_gnome_exchange_check_inbox_subscribed (EPlugin *ep, EMPopupTargetFolder *target)
 {
 	GSList *menus = NULL;
-	int i = 0;
+	gint i = 0;
 	ExchangeAccount *account = NULL;
 	gchar *path = NULL;
 	gchar *sub_folder = NULL;
@@ -221,7 +223,7 @@ org_gnome_exchange_check_inbox_subscribed (EPlugin *ep, EMPopupTargetFolder *tar
 
 	g_free (path);
 
-	if (!sub_folder)
+	if (!sub_folder || !g_strrstr(sub_folder, "/"))
 		return;
 
         for (i = 0; i < sizeof (popup_inbox_items) / sizeof (popup_inbox_items[0]); i++)
@@ -231,21 +233,21 @@ org_gnome_exchange_check_inbox_subscribed (EPlugin *ep, EMPopupTargetFolder *tar
 }
 
 static EPopupItem popup_items[] = {
-	{ E_POPUP_ITEM, "29.calendar_unsubscribe", N_("Unsubscribe Folder..."), org_gnome_exchange_folder_unsubscribe, NULL, "folder-new", 0, EM_POPUP_FOLDER_INFERIORS }
+	{ E_POPUP_ITEM, (gchar *) "29.calendar_unsubscribe", (gchar *) N_("Unsubscribe Folder..."), org_gnome_exchange_folder_unsubscribe, NULL, (gchar *) "folder-new", 0, EM_POPUP_FOLDER_INFERIORS }
 };
 
 void
-popup_free (EPopup *ep, GSList *items, void *data)
+popup_free (EPopup *ep, GSList *items, gpointer data)
 {
 	g_slist_free (items);
 }
 
 static EPopupItem popup_ab_items[] = {
-	{ E_POPUP_ITEM, "29.address_book_unsubscribe", N_("Unsubscribe Folder..."), org_gnome_exchange_folder_ab_unsubscribe, NULL, "folder-new", 0, EM_POPUP_FOLDER_INFERIORS }
+	{ E_POPUP_ITEM, (gchar *) "29.address_book_unsubscribe", (gchar *) N_("Unsubscribe Folder..."), org_gnome_exchange_folder_ab_unsubscribe, NULL, (gchar *) "folder-new", 0, EM_POPUP_FOLDER_INFERIORS }
 };
 
 void
-popup_ab_free (EPopup *ep, GSList *items, void *data)
+popup_ab_free (EPopup *ep, GSList *items, gpointer data)
 {
 	g_slist_free (items);
 }
@@ -254,12 +256,12 @@ void
 org_gnome_exchange_check_address_book_subscribed (EPlugin *ep, EABPopupTargetSource *target)
 {
 	GSList *menus = NULL;
-	int i = 0;
+	gint i = 0;
 	ESource *source = NULL;
 	gchar *uri = NULL;
 	gchar *path = NULL;
-	char *sub_folder = NULL;
-	const char *base_uri;
+	gchar *sub_folder = NULL;
+	const gchar *base_uri;
 	ExchangeAccount *account = NULL;
 	ESourceGroup *group;
 
@@ -296,12 +298,12 @@ void
 org_gnome_exchange_check_subscribed (EPlugin *ep, ECalPopupTargetSource *target)
 {
 	GSList *menus = NULL;
-	int i = 0;
+	gint i = 0;
 	ESource *source = NULL;
 	gchar *ruri = NULL;
 	gchar *path = NULL;
-	char *sub_folder = NULL;
-	const char *base_uri;
+	gchar *sub_folder = NULL;
+	const gchar *base_uri;
 	ExchangeAccount *account = NULL;
 	ESourceGroup *group;
 
@@ -333,14 +335,14 @@ org_gnome_exchange_check_subscribed (EPlugin *ep, ECalPopupTargetSource *target)
 }
 
 static void
-unsubscribe_dialog_ab_response (GtkDialog *dialog, int response, gpointer data)
+unsubscribe_dialog_ab_response (GtkDialog *dialog, gint response, gpointer data)
 {
 
 	if (response == GTK_RESPONSE_OK) {
 		ExchangeAccount *account = NULL;
 		gchar *path = NULL;
 		gchar *uri = NULL;
-		const char *source_uid = NULL;
+		const gchar *source_uid = NULL;
 		ESourceGroup *source_group = NULL;
 		ESource *source = NULL;
 		EABPopupTargetSource *target = data;
@@ -369,7 +371,7 @@ unsubscribe_dialog_ab_response (GtkDialog *dialog, int response, gpointer data)
 }
 
 static void
-unsubscribe_dialog_response (GtkDialog *dialog, int response, gpointer data)
+unsubscribe_dialog_response (GtkDialog *dialog, gint response, gpointer data)
 {
 
 	if (response == GTK_RESPONSE_OK) {
@@ -377,7 +379,7 @@ unsubscribe_dialog_response (GtkDialog *dialog, int response, gpointer data)
 		ExchangeAccount *account = NULL;
 		gchar *path = NULL;
 		gchar *ruri = NULL;
-		const char *source_uid = NULL;
+		const gchar *source_uid = NULL;
 		GConfClient *client;
 		ESourceGroup *source_group = NULL;
 		ESource *source = NULL;
@@ -428,7 +430,7 @@ unsubscribe_dialog_response (GtkDialog *dialog, int response, gpointer data)
 }
 
 void
-org_gnome_exchange_folder_ab_unsubscribe (EPopup *ep, EPopupItem *p, void *data)
+org_gnome_exchange_folder_ab_unsubscribe (EPopup *ep, EPopupItem *p, gpointer data)
 {
 	GtkWidget *dialog = NULL;
 	EABPopupTargetSource *target = data;
@@ -483,7 +485,7 @@ org_gnome_exchange_folder_ab_unsubscribe (EPopup *ep, EPopupItem *p, void *data)
 	unsubscribe_dialog_ab_response (GTK_DIALOG (dialog), response, data);
 }
 void
-org_gnome_exchange_folder_unsubscribe (EPopup *ep, EPopupItem *p, void *data)
+org_gnome_exchange_folder_unsubscribe (EPopup *ep, EPopupItem *p, gpointer data)
 {
 	GtkWidget *dialog = NULL;
 	ECalPopupTargetSource *target = data;
@@ -539,7 +541,7 @@ org_gnome_exchange_folder_unsubscribe (EPopup *ep, EPopupItem *p, void *data)
 
 
 void
-org_gnome_exchange_folder_subscription (EPlugin *ep, EMMenuTargetSelect *target, gchar *fname)
+org_gnome_exchange_folder_subscription (EPlugin *ep, EMMenuTargetSelect *target, const gchar *fname)
 {
 	ExchangeAccount *account = NULL;
 	gint mode;
@@ -571,24 +573,27 @@ org_gnome_exchange_folder_subscription (EPlugin *ep, EMMenuTargetSelect *target,
 void
 org_gnome_exchange_calendar_subscription (EPlugin *ep, EMMenuTargetSelect *target)
 {
-	gchar *folder_name = N_("Calendar");
+	const gchar *folder_name = N_("Calendar");
 	org_gnome_exchange_folder_subscription (ep, target, folder_name);
 }
+
 void
 org_gnome_exchange_addressbook_subscription (EPlugin *ep, EMMenuTargetSelect *target)
 {
-	gchar *folder_name = N_("Contacts");
+	const gchar *folder_name = N_("Contacts");
 	org_gnome_exchange_folder_subscription (ep, target, folder_name);
 }
+
 void
 org_gnome_exchange_tasks_subscription (EPlugin *ep, EMMenuTargetSelect *target)
 {
-	gchar *folder_name = N_("Tasks");
+	const gchar *folder_name = N_("Tasks");
 	org_gnome_exchange_folder_subscription (ep, target, folder_name);
 }
+
 void
 org_gnome_exchange_inbox_subscription (EPlugin *ep, EMMenuTargetSelect *target)
 {
-	gchar *folder_name = N_("Inbox");
+	const gchar *folder_name = N_("Inbox");
 	org_gnome_exchange_folder_subscription (ep, target, folder_name);
 }
