@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -68,7 +68,7 @@ struct _ExchangeSendOptionsDialogPrivate {
 	/*Label Widgets*/
 	GtkWidget *importance_label;
 	GtkWidget *sensitivity_label;
-	char *help_section;
+	gchar *help_section;
 };
 
 static void exchange_sendoptions_dialog_class_init (GObjectClass *object_class);
@@ -87,12 +87,12 @@ static guint signals[LAST_SIGNAL] = {0};
 /* exchange_send_options_get_widgets_data(ExchangeSendOptionsDialog *sod)
    Return Value:This function returns a -1 if an error occurs. In case of error-free operation a 1 is returned.
 */
-static int
+static gint
 exchange_send_options_get_widgets_data (ExchangeSendOptionsDialog *sod)
 {
 	ExchangeSendOptionsDialogPrivate *priv;
 	ExchangeSendOptions *options;
-	const char *address, *email, *name;
+	const gchar *address, *email, *name;
 
 	guint count=0;
 	ENameSelectorEntry *name_selector_entry;
@@ -108,7 +108,7 @@ exchange_send_options_get_widgets_data (ExchangeSendOptionsDialog *sod)
 	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->delegate_enabled))) {
 
 		name_selector_entry = e_name_selector_peek_section_entry (priv->proxy_name_selector, "Add User");
-		destination_store = e_name_selector_entry_peek_destination_store (E_NAME_SELECTOR_ENTRY 				                                               (name_selector_entry));
+		destination_store = e_name_selector_entry_peek_destination_store (E_NAME_SELECTOR_ENTRY									       (name_selector_entry));
 		destinations = e_destination_store_list_destinations (destination_store);
 		tmp = destinations;
 
@@ -120,8 +120,8 @@ exchange_send_options_get_widgets_data (ExchangeSendOptionsDialog *sod)
 		   produced ambiguous results. Hence count is used :)
 		*/
 		for (; tmp != NULL; tmp = g_list_next (tmp)) {
-			address = g_strdup ((char *) e_destination_get_address (tmp->data));
-			email = g_strdup ((char *) e_destination_get_email (tmp->data));
+			address = g_strdup ((gchar *) e_destination_get_address (tmp->data));
+			email = g_strdup ((gchar *) e_destination_get_email (tmp->data));
 			name = g_strdup (e_destination_get_name (tmp->data));
 			if (g_str_equal (email, ""))
 				continue;
@@ -268,7 +268,7 @@ GType exchange_sendoptions_dialog_get_type (void)
       sizeof (ExchangeSendOptionsDialog),
      0,      /* n_preallocs */
      (GInstanceInitFunc) exchange_sendoptions_dialog_init,
- 	NULL    /* instance_init */
+	NULL    /* instance_init */
     };
     type = g_type_register_static (G_TYPE_OBJECT,
                                    "ExchangeSendOptionsDialogType",
@@ -279,8 +279,8 @@ GType exchange_sendoptions_dialog_get_type (void)
 
 static void exchange_send_options_cb (GtkDialog *dialog, gint state, gpointer func_data)
 {
-   	ExchangeSendOptionsDialogPrivate *priv;
-   	ExchangeSendOptionsDialog *sod;
+	ExchangeSendOptionsDialogPrivate *priv;
+	ExchangeSendOptionsDialog *sod;
 
 	sod = func_data;
         priv = sod->priv;
@@ -290,15 +290,15 @@ static void exchange_send_options_cb (GtkDialog *dialog, gint state, gpointer fu
 		     if(exchange_send_options_get_widgets_data (sod) < 0)
 			return;
 		case GTK_RESPONSE_CANCEL:
-		    	gtk_widget_hide (priv->main);
-	    	    	gtk_widget_destroy (priv->main);
-	           	g_object_unref (priv->xml);
-	             	break;
+			gtk_widget_hide (priv->main);
+			gtk_widget_destroy (priv->main);
+			g_object_unref (priv->xml);
+			break;
 		case GTK_RESPONSE_HELP:
 			e_display_help (
 				GTK_WINDOW (priv->main),
 				priv->help_section);
-	    	    	break;
+			break;
 	}
 	g_signal_emit (G_OBJECT (func_data), signals[SOD_RESPONSE], 0, state);
 
