@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -60,10 +60,10 @@ typedef struct {
 	gboolean send_as_del_enabled;
 	gboolean delivery_enabled;
 	gboolean read_enabled;
-	const char *delegate_name;
-	const char *delegate_email;
-	const char *delegate_address;
-} ExchangeSendOptions ;
+	const gchar *delegate_name;
+	const gchar *delegate_email;
+	const gchar *delegate_address;
+} ExchangeSendOptions;
 
 struct _ExchangeSendOptionsDialog {
 	GObject object;
