@@ -69,7 +69,7 @@ static GThread *editor_thread;
 void
 ee_editor_command_changed (GtkWidget *textbox)
 {
-	const char *editor;
+	const gchar *editor;
 	GConfClient *gconf;
 
 	editor = gtk_entry_get_text (GTK_ENTRY(textbox));
@@ -101,7 +101,7 @@ e_plugin_lib_get_configure_widget (EPlugin *epl)
 	GtkWidget *vbox, *textbox, *label, *help;
 	GtkWidget *checkbox;
 	GConfClient *gconf;
-	char *editor;
+	gchar *editor;
 	gboolean checked;
 
 	vbox = gtk_vbox_new (FALSE, 10);
@@ -209,8 +209,8 @@ run_error_dialog (gchar *text)
 void
 async_external_editor (EMsgComposer *composer)
 {
-	char *filename = NULL;
-	int status = 0;
+	gchar *filename = NULL;
+	gint status = 0;
 	GConfClient *gconf;
 	gchar *editor_cmd_line = NULL;
 	gint fd;
@@ -226,9 +226,9 @@ async_external_editor (EMsgComposer *composer)
 	} else {
 		g_warning ("Temporary file fd is null");
 		g_idle_add ((GSourceFunc) run_error_dialog,
-			    "org.gnome.evolution.plugins.external-editor:no-temp-file");
+			    (gpointer)"org.gnome.evolution.plugins.external-editor:no-temp-file");
 		g_idle_add ((GSourceFunc) enable_composer, composer);
-		return ;
+		return;
 	}
 
 	gconf = gconf_client_get_default ();
@@ -248,12 +248,12 @@ async_external_editor (EMsgComposer *composer)
 	{
 		g_warning ("Unable to launch %s: ", editor_cmd_line);
 		g_idle_add ((GSourceFunc) run_error_dialog,
-			    "org.gnome.evolution.plugins.external-editor:editor-not-launchable");
+			    (gpointer)"org.gnome.evolution.plugins.external-editor:editor-not-launchable");
 		g_idle_add ((GSourceFunc) enable_composer, composer);
 
 		g_free (filename);
 		g_free (editor_cmd_line);
-		return ;
+		return;
 	}
 	g_free (editor_cmd_line);
 
@@ -264,7 +264,7 @@ async_external_editor (EMsgComposer *composer)
 #endif
 		d(printf ("\n\nsome problem here with external editor\n\n"));
 		g_idle_add ((GSourceFunc) enable_composer, composer);
-		return ;
+		return;
 	} else {
 		gchar *buf;
 
@@ -294,7 +294,7 @@ static void launch_editor (GtkAction *action, EMsgComposer *composer)
 
 	if (editor_running()) {
 		d(printf("not opening editor, because it's still running\n"));
-		return ;
+		return;
 	}
 
 	disable_composer (composer);
