@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -49,16 +49,16 @@
 
 #include "google-contacts-source.h"
 
-#define CALENDAR_LOCATION "://www.google.com/calendar/feeds/"
+#define CALENDAR_LOCATION "http://www.google.com/calendar/feeds/"
 #define CALENDAR_DEFAULT_PATH "/private/full"
-#define URL_GET_SUBSCRIBED_CALENDARS "://www.google.com/calendar/feeds/default/allcalendars/full"
+#define URL_GET_SUBSCRIBED_CALENDARS "http://www.google.com/calendar/feeds/default/allcalendars/full"
 
 #define d(x)
 
 /*****************************************************************************/
 /* prototypes */
-int              e_plugin_lib_enable      (EPluginLib                 *ep,
-					   int                         enable);
+gint              e_plugin_lib_enable      (EPluginLib                 *ep,
+					   gint                         enable);
 
 GtkWidget *      plugin_google               (EPlugin                    *epl,
 					   EConfigHookItemFactoryData *data);
@@ -78,12 +78,12 @@ ensure_google_source_group (void)
 		return;
 	}
 
-	manage_google_group (slist, FALSE);
+	e_source_list_ensure_group (slist, _("Google"), "google://", FALSE);
 	g_object_unref (slist);
 }
 
-int
-e_plugin_lib_enable (EPluginLib *ep, int enable)
+gint
+e_plugin_lib_enable (EPluginLib *ep, gint enable)
 {
 
 	if (enable) {
@@ -99,24 +99,37 @@ e_plugin_lib_enable (EPluginLib *ep, int enable)
 
 
 /********************************************************************************************************************/
+#if 0
+
+FIXME: Not sure why this function is declared but called no where. This needs fixing.
+
+static void
+ssl_changed (GtkToggleButton *button, ESource *source)
+{
+	e_source_set_property(source, "ssl",
+			      gtk_toggle_button_get_active(button) ? "1" : "0");
+}
+
+#endif
+
 
 static gboolean
-is_email (const char *address)
+is_email (const gchar *address)
 {
 	/* This is supposed to check if the address's domain could be
            an FQDN but alas, it's not worth the pain and suffering. */
-	const char *at;
+	const gchar *at;
 
 	at = strchr (address, '@');
-	/* make sure we have an '@' and that it's not the first or last char */
+	/* make sure we have an '@' and that it's not the first or last gchar */
 	if (!at || at == address || *(at + 1) == '\0')
 		return FALSE;
 
 	return TRUE;
 }
 
-static char *
-sanitize_user_mail (const char *user)
+static gchar *
+sanitize_user_mail (const gchar *user)
 {
 	if (!user)
 		return NULL;
@@ -124,8 +137,8 @@ sanitize_user_mail (const char *user)
 	if (!is_email (user)) {
 		return g_strconcat (user, "%40gmail.com", NULL);
 	} else {
-		char *tmp = g_malloc0 (sizeof (char) * (1 + strlen (user) + 2));
-		char *at = strchr (user, '@');
+		gchar *tmp = g_malloc0 (sizeof (gchar) * (1 + strlen (user) + 2));
+		gchar *at = strchr (user, '@');
 
 		strncpy (tmp, user, at - user);
 		strcat (tmp, "%40");
@@ -135,13 +148,13 @@ sanitize_user_mail (const char *user)
 	}
 }
 
-static char *
-construct_default_uri (const char *username, gboolean is_ssl)
+static gchar *
+construct_default_uri (const gchar *username)
 {
-	char *user, *uri;
+	gchar *user, *uri;
 
 	user = sanitize_user_mail (username);
-	uri = g_strconcat (is_ssl ? "https" : "http", CALENDAR_LOCATION, user, CALENDAR_DEFAULT_PATH, NULL);
+	uri = g_strconcat (CALENDAR_LOCATION, user, CALENDAR_DEFAULT_PATH, NULL);
 	g_free (user);
 
 	return uri;
@@ -149,66 +162,62 @@ construct_default_uri (const char *username, gboolean is_ssl)
 
 /* checks whether the given_uri is pointing to the default user's calendar or not */
 static gboolean
-is_default_uri (const char *given_uri, const char *username)
+is_default_uri (const gchar *given_uri, const gchar *username)
 {
-	char *uri, *at;
-	int ats, i;
-	gboolean res = FALSE;
+	gchar *uri, *at;
+	gint ats;
+	gboolean res;
 
 	if (!given_uri)
 		return TRUE;
 
-	for (i = 0; !res && i < 2; i++) {
-		/* try both versions here, with and without ssl */
-		uri = construct_default_uri (username, i == 0);
+	uri = construct_default_uri (username);
 
-		/* count number of '@' in given_uri to know how much memory will be required */
-		ats = 0;
-		for (at = strchr (given_uri, '@'); at; at = strchr (at + 1, '@')) {
-			ats++;
-		}
-
-		if (!ats)
-			res = g_ascii_strcasecmp (given_uri, uri) == 0;
-		else {
-			const char *last;
-			char *tmp = g_malloc0 (sizeof (char) * (1 + strlen (given_uri) + (2 * ats)));
-
-			last = given_uri;
-			for (at = strchr (last, '@'); at; at = strchr (at + 1, '@')) {
-				strncat (tmp, last, at - last);
-				strcat (tmp, "%40");
-				last = at + 1;
-			}
-			strcat (tmp, last);
-
-			res = g_ascii_strcasecmp (tmp, uri) == 0;
-
-			g_free (tmp);
-		}
-
-		g_free (uri);
+	/* count number of '@' in given_uri to know how much memory will be required */
+	ats = 0;
+	for (at = strchr (given_uri, '@'); at; at = strchr (at + 1, '@')) {
+		ats++;
 	}
 
+	if (!ats)
+		res = g_ascii_strcasecmp (given_uri, uri) == 0;
+	else {
+		const gchar *last;
+		gchar *tmp = g_malloc0 (sizeof (gchar) * (1 + strlen (given_uri) + (2 * ats)));
+
+		last = given_uri;
+		for (at = strchr (last, '@'); at; at = strchr (at + 1, '@')) {
+			strncat (tmp, last, at - last);
+			strcat (tmp, "%40");
+			last = at + 1;
+		}
+		strcat (tmp, last);
+
+		res = g_ascii_strcasecmp (tmp, uri) == 0;
+
+		g_free (tmp);
+	}
+
+	g_free (uri);
+
 	return res;
 }
 
-static void init_combo_values (GtkComboBox *combo, const char *deftitle, const char *defuri);
+static void init_combo_values (GtkComboBox *combo, const gchar *deftitle, const gchar *defuri);
 
 static void
 user_changed (GtkEntry *editable, ESource *source)
 {
-	char       *uri;
-	const char *user, *ssl;
+	gchar       *uri;
+	const gchar *user;
 
 	/* two reasons why set readonly to FALSE:
 	   a) the e_source_set_relative_uri does nothing for readonly sources
 	   b) we are going to set default uri, which should be always writeable */
 	e_source_set_readonly (source, FALSE);
 
-	ssl = e_source_get_property (source, "ssl");
 	user = gtk_entry_get_text (GTK_ENTRY (editable));
-	uri = construct_default_uri (user, !ssl || g_str_equal (ssl, "1"));
+	uri = construct_default_uri (user);
 	e_source_set_relative_uri (source, uri);
 	g_free (uri);
 
@@ -223,11 +232,11 @@ user_changed (GtkEntry *editable, ESource *source)
 	init_combo_values (GTK_COMBO_BOX (g_object_get_data (G_OBJECT (editable), "CalendarCombo")), _("Default"), NULL);
 }
 
-static char *
-get_refresh_minutes (GtkWidget *spin, GtkWidget *option)
+static gchar *
+get_refresh_minutes (GtkWidget *spin, GtkWidget *combobox)
 {
-	int setting = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
-	switch (gtk_option_menu_get_history (GTK_OPTION_MENU (option))) {
+	gint setting = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin));
+	switch (gtk_combo_box_get_active (GTK_COMBO_BOX (combobox))) {
 	case 0:
 		/* minutes */
 		break;
@@ -255,34 +264,34 @@ static void
 spin_changed (GtkSpinButton *spin, ECalConfigTargetSource *t)
 {
 	gchar *refresh_str;
-	GtkWidget *option;
+	GtkWidget *combobox;
 
-	option = g_object_get_data (G_OBJECT(spin), "option");
+	combobox = g_object_get_data (G_OBJECT(spin), "combobox");
 
-	refresh_str = get_refresh_minutes ((GtkWidget *)spin, option);
+	refresh_str = get_refresh_minutes ((GtkWidget *)spin, combobox);
 	e_source_set_property (t->source, "refresh", refresh_str);
 	g_free (refresh_str);
 }
 
 static void
-option_changed (GtkSpinButton *option, ECalConfigTargetSource *t)
+combobox_changed (GtkComboBox *combobox, ECalConfigTargetSource *t)
 {
 	gchar *refresh_str;
 	GtkWidget *spin;
 
-	spin = g_object_get_data (G_OBJECT(option), "spin");
+	spin = g_object_get_data (G_OBJECT(combobox), "spin");
 
-	refresh_str = get_refresh_minutes (spin, (GtkWidget *)option);
+	refresh_str = get_refresh_minutes (spin, (GtkWidget *)combobox);
 	e_source_set_property (t->source, "refresh", refresh_str);
 	g_free (refresh_str);
 }
 
 static void
-set_refresh_time (ESource *source, GtkWidget *spin, GtkWidget *option)
+set_refresh_time (ESource *source, GtkWidget *spin, GtkWidget *combobox)
 {
-	int time;
-	int item_num = 0;
-	const char *refresh_str = e_source_get_property (source, "refresh");
+	gint time;
+	gint item_num = 0;
+	const gchar *refresh_str = e_source_get_property (source, "refresh");
 	time = refresh_str ? atoi (refresh_str) : 30;
 
 	if (time  && !(time % 10080)) {
@@ -298,7 +307,7 @@ set_refresh_time (ESource *source, GtkWidget *spin, GtkWidget *option)
 		item_num = 1;
 		time /= 60;
 	}
-	gtk_option_menu_set_history (GTK_OPTION_MENU (option), item_num);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), item_num);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin), time);
 }
 
@@ -311,7 +320,7 @@ enum {
 };
 
 static void
-init_combo_values (GtkComboBox *combo, const char *deftitle, const char *defuri)
+init_combo_values (GtkComboBox *combo, const gchar *deftitle, const gchar *defuri)
 {
 	GtkTreeIter iter;
 	GtkListStore *store;
@@ -346,15 +355,13 @@ cal_combo_changed (GtkComboBox *combo, ESource *source)
 	store = GTK_LIST_STORE (gtk_combo_box_get_model (combo));
 
 	if (gtk_combo_box_get_active_iter (combo, &iter)) {
-		char *uri = NULL, *title = NULL;
+		gchar *uri = NULL, *title = NULL;
 		gboolean readonly = FALSE;
 
 		gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, COL_TITLE, &title, COL_URL_PATH, &uri, COL_READ_ONLY, &readonly, -1);
 
-		if (!uri) {
-			const gchar *ssl = e_source_get_property (source, "ssl");
-			uri = construct_default_uri (e_source_get_property (source, "username"), !ssl || g_str_equal (ssl, "1"));
-		}
+		if (!uri)
+			uri = construct_default_uri (e_source_get_property (source, "username"));
 
 		if (is_default_uri (uri, e_source_get_property (source, "username"))) {
 			/* do not store title when we use default uri */
@@ -376,7 +383,7 @@ cal_combo_changed (GtkComboBox *combo, ESource *source)
 }
 
 static void
-claim_error (GtkWindow *parent, const char *error)
+claim_error (GtkWindow *parent, const gchar *error)
 {
 	GtkWidget *dialog;
 
@@ -396,9 +403,8 @@ retrieve_list_clicked (GtkButton *button, GtkComboBox *combo)
 	ESource *source;
 	GDataGoogleService *service;
 	GDataFeed *feed;
-	char *password, *tmp;
-	const char *username, *ssl;
-	char *get_subscribed_url;
+	gchar *password, *tmp;
+	const gchar *username;
 	GError *error = NULL;
 	GtkWindow *parent;
 
@@ -414,7 +420,7 @@ retrieve_list_clicked (GtkButton *button, GtkComboBox *combo)
 	g_return_if_fail (username != NULL && *username != '\0');
 
 	tmp = g_strdup_printf (_("Enter password for user %s to access list of subscribed calendars."), username);
-	password = e_passwords_ask_password (_("Enter password"), "Calendar", "", tmp, 
+	password = e_passwords_ask_password (_("Enter password"), "Calendar", "", tmp,
 			E_PASSWORDS_REMEMBER_NEVER | E_PASSWORDS_REPROMPT | E_PASSWORDS_SECRET | E_PASSWORDS_DISABLE_REMEMBER,
 			NULL, parent);
 	g_free (tmp);
@@ -428,15 +434,12 @@ retrieve_list_clicked (GtkButton *button, GtkComboBox *combo)
 	memset (password, 0, strlen (password));
 	g_free (password);
 
-	ssl = e_source_get_property (source, "ssl");
-	get_subscribed_url = g_strconcat ((!ssl || g_str_equal (ssl, "1")) ? "https" : "http", URL_GET_SUBSCRIBED_CALENDARS, NULL);
-	feed = gdata_service_get_feed (GDATA_SERVICE (service), get_subscribed_url, &error);
-	g_free (get_subscribed_url);
+	feed = gdata_service_get_feed (GDATA_SERVICE (service), URL_GET_SUBSCRIBED_CALENDARS, &error);
 
 	if (feed) {
 		GSList *l;
-		char *old_selected = NULL;
-		int idx, active = -1, default_idx = -1;
+		gchar *old_selected = NULL;
+		gint idx, active = -1, default_idx = -1;
 		GtkListStore *store = GTK_LIST_STORE (gtk_combo_box_get_model (combo));
 		GtkTreeIter iter;
 
@@ -446,7 +449,7 @@ retrieve_list_clicked (GtkButton *button, GtkComboBox *combo)
 		gtk_list_store_clear (store);
 
 		for (l = gdata_feed_get_entries (feed), idx = 1; l != NULL; l = l->next) {
-			const char *uri, *title, *color, *access;
+			const gchar *uri, *title, *color, *access;
 			GSList *links;
 			GDataEntry *entry = (GDataEntry *) l->data;
 
@@ -541,20 +544,6 @@ retrieve_list_sensitize (GtkEntry *username_entry,
 	gtk_widget_set_sensitive (button, sensitive);
 }
 
-static void
-ssl_toggled (GtkToggleButton *check, ESource *source)
-{
-	g_return_if_fail (check != NULL);
-	g_return_if_fail (source != NULL);
-
-	if (gtk_toggle_button_get_active (check))
-		e_source_set_property (source, "ssl", "1");
-	else
-		e_source_set_property (source, "ssl", "0");
-
-	user_changed (GTK_ENTRY (g_object_get_data (G_OBJECT (check), "username")), source);
-}
-
 GtkWidget *
 plugin_google  (EPlugin                    *epl,
 	     EConfigHookItemFactoryData *data)
@@ -570,17 +559,15 @@ plugin_google  (EPlugin                    *epl,
 	GtkWidget    *user;
 	GtkWidget    *label;
 	GtkWidget    *combo;
-	char         *uri;
-	const char   *username;
-	const char   *ssl_prop;
+	gchar         *uri;
+	const gchar   *username;
+	const gchar   *ssl_prop;
 	gboolean      ssl_enabled;
-	int           row;
+	gint           row;
 	GtkCellRenderer *renderer;
 	GtkListStore *store;
 
-	GtkWidget *option, *spin, *menu, *hbox;
-	GtkWidget *times [4];
-	int i;
+	GtkWidget *combobox, *spin, *hbox;
 
 	source = t->source;
 	group = e_source_peek_group (source);
@@ -598,27 +585,19 @@ plugin_google  (EPlugin                    *epl,
 		return NULL;
 	}
 
-	e_uri_free (euri);
-
 	username = e_source_get_property (source, "username");
+	g_free (euri->user);
+	euri->user = NULL;
+	uri = e_uri_to_string (euri, FALSE);
 
 	ssl_prop = e_source_get_property (source, "ssl");
-	if (!ssl_prop || g_str_equal (ssl_prop, "1")) {
+	if (ssl_prop && ssl_prop[0] == '1') {
 		ssl_enabled = TRUE;
 	} else {
 		ssl_enabled = FALSE;
 	}
 
-	if (!ssl_prop) {
-		e_source_set_property (source, "ssl", "1");
-	} else if (ssl_enabled) {
-		const gchar *rel_uri = e_source_peek_relative_uri (source);
-
-		if (rel_uri && g_str_has_prefix (rel_uri, "http://")) {
-			ssl_enabled = FALSE;
-			e_source_set_property (source, "ssl", "0");
-		}
-	}
+	e_source_set_property (source, "ssl", "1");
 
 	/* Build up the UI */
 	parent = data->parent;
@@ -662,45 +641,36 @@ plugin_google  (EPlugin                    *epl,
 	gtk_widget_show (hbox);
 
 	spin = gtk_spin_button_new_with_range (1, 100, 1);
- 	gtk_label_set_mnemonic_widget (GTK_LABEL(label), spin);
+	gtk_label_set_mnemonic_widget (GTK_LABEL(label), spin);
 	gtk_widget_show (spin);
 	gtk_box_pack_start (GTK_BOX(hbox), spin, FALSE, TRUE, 0);
 
-	option = gtk_option_menu_new ();
-	gtk_widget_show (option);
-	times[0] = gtk_menu_item_new_with_label (_("minutes"));
-	times[1] = gtk_menu_item_new_with_label (_("hours"));
-	times[2] = gtk_menu_item_new_with_label (_("days"));
-	times[3] = gtk_menu_item_new_with_label (_("weeks"));
-
-	menu = gtk_menu_new ();
-	gtk_widget_show (menu);
-	for (i = 0; i < 4; i++) {
-		gtk_widget_show (times[i]);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), times[i]);
-	}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option), menu);
-	set_refresh_time (source, spin, option);
-	gtk_box_pack_start (GTK_BOX (hbox), option, FALSE, TRUE, 0);
-
 	if (!e_source_get_property (source, "refresh"))
 		e_source_set_property (source, "refresh", "30");
 
-	g_object_set_data (G_OBJECT (option), "spin", spin);
-	g_signal_connect (G_OBJECT (option), "changed", G_CALLBACK (option_changed), t);
-	g_object_set_data (G_OBJECT (spin), "option", option);
+	combobox = gtk_combo_box_new_text ();
+	gtk_widget_show (combobox);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("minutes"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("hours"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("days"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("weeks"));
+	set_refresh_time (source, spin, combobox);
+	gtk_box_pack_start (GTK_BOX (hbox), combobox, FALSE, TRUE, 0);
+
+	g_object_set_data (G_OBJECT (combobox), "spin", spin);
+	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (combobox_changed), t);
+	g_object_set_data (G_OBJECT (spin), "combobox", combobox);
 	g_signal_connect (G_OBJECT (spin), "value-changed", G_CALLBACK (spin_changed), t);
 
 	gtk_table_attach (GTK_TABLE (parent), hbox, 1, 2, row + 2, row + 3, GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
-	g_object_set_data (G_OBJECT (cssl), "username", user);
-	g_signal_connect (cssl, "toggled", G_CALLBACK (ssl_toggled), source);
-
 	g_signal_connect (G_OBJECT (user),
 			  "changed",
 			  G_CALLBACK (user_changed),
 			  source);
 
+        g_free (uri);
+
 	label = gtk_label_new_with_mnemonic (_("Cal_endar:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_widget_show (label);
