@@ -1,21 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Author: Vivek Jain <jvivek@novell.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of version 2 of the GNU General Public
- *  License as published by the Free Software Foundation.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Vivek Jain <jvivek@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -25,8 +26,6 @@
 #include <glade/glade.h>
 #include "junk-settings.h"
 #include <gtk/gtk.h>
-#include <libgnomeui/gnome-ui-init.h>
-#include <libgnome/gnome-init.h>
 #include <glib/gi18n.h>
 #include <e-util/e-error.h>
 #include <e-util/e-util-private.h>
@@ -36,7 +35,7 @@
 
 struct _JunkEntry {
 	EGwJunkEntry *entry;
-	int flag;
+	gint flag;
 };
 
 typedef struct _JunkEntry JunkEntry;
@@ -49,7 +48,6 @@ static void free_all(JunkSettings *js);
 static void get_junk_list (JunkSettings *js);
 static void disable_clicked (GtkRadioButton *button, JunkSettings *js);
 static void enable_clicked (GtkRadioButton *button, JunkSettings *js);
-GType junk_settings_get_type (void);
 
 static GtkVBoxClass *parent_class = NULL;
 
@@ -144,11 +142,11 @@ find_node(GList *list, gchar *match)
 	JunkEntry *one_entry = NULL;
 	EGwJunkEntry *ent = NULL;
 	GList *tmp;
-	gint i ;
+	gint i;
 
 	if(list){
 		tmp = g_list_first(list);
-		for(i=0; tmp  ; i++)
+		for(i=0; tmp; i++)
 		{
 			one_entry = tmp->data;
 			ent = one_entry->entry;
@@ -177,9 +175,9 @@ static void
 get_junk_list (JunkSettings *js)
 {
 	GList *list = NULL;
-	char *entry;
-	char *msg;
-	int use_junk, use_block, use_pab, persistence;
+	gchar *entry;
+	gchar *msg;
+	gint use_junk, use_block, use_pab, persistence;
 
 	if (E_IS_GW_CONNECTION (js->cnc)) {
 		if (e_gw_connection_get_junk_settings (js->cnc, &use_junk, &use_block, &use_pab, &persistence) == E_GW_CONNECTION_STATUS_OK) {
@@ -229,7 +227,7 @@ commit_changes (JunkSettings *js)
 	GList *node = NULL;
 	JunkEntry *junk_entry = NULL;
 	EGwJunkEntry *entry;
-	int use_junk, use_pab, use_block, persistence;
+	gint use_junk, use_pab, use_block, persistence;
 
 	for (node = js->junk_list; node; node = node->next)
 	{
@@ -244,24 +242,32 @@ commit_changes (JunkSettings *js)
 	if (E_IS_GW_CONNECTION (js->cnc)) {
 		if(js->flag_for_ok == 2 && js->enabled){  /* just turn off the bits*/
 			use_junk = use_pab = use_block = persistence = 0;
-			if (e_gw_connection_modify_junk_settings (js->cnc, use_junk, use_pab, use_block, persistence) == E_GW_CONNECTION_STATUS_OK);
+			if (e_gw_connection_modify_junk_settings (js->cnc, use_junk, use_pab, use_block, persistence) == E_GW_CONNECTION_STATUS_OK) {
+				;
+			}
 
 		}
 		if (js->flag_for_ok == 0 && !js->enabled) {
 			use_block = use_pab =0;
 			use_junk = 1;
 			persistence = 14; /* We are setting the default persistence*/
-			if (e_gw_connection_modify_junk_settings (js->cnc, use_junk, use_pab, use_block, persistence) == E_GW_CONNECTION_STATUS_OK);
+			if (e_gw_connection_modify_junk_settings (js->cnc, use_junk, use_pab, use_block, persistence) == E_GW_CONNECTION_STATUS_OK) {
+				;
+			}
 		}
 
 		while (new_list) {
 			entry = new_list->data;
-			if (e_gw_connection_create_junk_entry (js->cnc, entry->match, "email", "junk") == E_GW_CONNECTION_STATUS_OK);
+			if (e_gw_connection_create_junk_entry (js->cnc, entry->match, "email", "junk") == E_GW_CONNECTION_STATUS_OK) {
+				;
+			}
 			new_list = new_list->next;
 		}
 		while (remove_list) {
 			entry = remove_list->data;
-			if (e_gw_connection_remove_junk_entry (js->cnc, entry->id) == E_GW_CONNECTION_STATUS_OK);
+			if (e_gw_connection_remove_junk_entry (js->cnc, entry->id) == E_GW_CONNECTION_STATUS_OK) {
+				;
+			}
 			remove_list = remove_list->next;
 		}
 
@@ -295,8 +301,8 @@ disable_clicked (GtkRadioButton *button, JunkSettings *js)
 static void
 add_clicked(GtkButton *button, JunkSettings *js)
 {
-	const char *email = NULL;
-	const char *self_email = NULL;
+	const gchar *email = NULL;
+	const gchar *self_email = NULL;
 	JunkEntry *new_entry = NULL;
 	EGwJunkEntry *junk_entry = NULL;
 	gchar *msg = NULL;
@@ -366,7 +372,7 @@ static void
 junk_settings_construct (JunkSettings *js)
 {
 	GladeXML *xml;
-	char *gladefile;
+	gchar *gladefile;
 
 	gladefile = g_build_filename (EVOLUTION_GLADEDIR,
 				      "junk-settings.glade",
