@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -37,7 +37,7 @@
 
 struct _SharedUser {
 	EShUsers *user_node;
-	int flag;
+	gint flag;
 };
 typedef struct _SharedUser SharedUser;
 
@@ -49,7 +49,6 @@ static void free_user_node(EShUsers *user);
 static void free_node(SharedUser *user);
 static void free_all(ShareFolder *sf);
 static SharedUser * find_node(GList *list, gchar *email);
-static void free_all(ShareFolder *sf);
 static void get_container_list (ShareFolder *sf);
 static void user_selected(GtkTreeSelection *selection, ShareFolder *sf);
 static void not_shared_clicked (GtkRadioButton *button, ShareFolder *sf);
@@ -58,7 +57,6 @@ static void add_clicked(GtkButton *button, ShareFolder *sf);
 static void remove_clicked(GtkButton *button, ShareFolder *sf);
 static void not_ok_clicked(GtkButton *button, ShareFolder *sf);
 static void not_cancel_clicked(GtkButton *button, GtkWidget *window);
-static void not_cancel_clicked(GtkButton *button, GtkWidget *window);
 static void share_folder_construct (ShareFolder *sf);
 GType share_folder_get_type (void);
 
@@ -135,7 +133,7 @@ free_user_node(EShUsers *user)
 		g_free(user->email);
 		user->email = NULL;
 	}
-	return ;
+	return;
 }
 
 static void
@@ -146,7 +144,7 @@ free_node(SharedUser *usr)
 		g_free(user->email);
 		user->email = NULL;
 	}
-	return ;
+	return;
 }
 
 static SharedUser *
@@ -155,11 +153,11 @@ find_node(GList *list, gchar *email)
 	SharedUser *user = NULL;
 	EShUsers *usr = NULL;
 	GList *tmp;
-	gint i ;
+	gint i;
 
 	if(list){
 		tmp = g_list_first(list);
-		for(i=0; tmp  ; i++)
+		for(i=0; tmp; i++)
 		{
 			user = tmp->data;
 			usr = user->user_node;
@@ -323,8 +321,8 @@ not_shared_clicked (GtkRadioButton *button, ShareFolder *sf)
 static void
 add_clicked(GtkButton *button, ShareFolder *sf)
 {
-	const char *email = NULL;
-	const char *self_email = NULL;
+	const gchar *email = NULL;
+	const gchar *self_email = NULL;
 	SharedUser *new_user = NULL;
 	EShUsers *usr = NULL;
 	gint rights = 0;
@@ -348,7 +346,7 @@ add_clicked(GtkButton *button, ShareFolder *sf)
 			if (!g_ascii_strcasecmp (email, "" )) {
 				e_error_run (NULL, "org.gnome.evolution.mail_shared_folder:no-user",NULL);
 
-				return ;
+				return;
 			}
 
 
@@ -356,7 +354,7 @@ add_clicked(GtkButton *button, ShareFolder *sf)
 			if (sf->users_list && email){
 				new_user = find_node (sf->users_list, (gchar *)email);
 				if (new_user)
-					return ;
+					return;
 
 			}
 			usr = g_new0 (EShUsers, 1);
@@ -453,18 +451,24 @@ share_folder (ShareFolder *sf)
 
 		} else {
 			if (new_list) {
-				if (e_gw_connection_share_folder (sf->cnc, sf->container_id, new_list, sf->sub, sf->mesg, 0) == E_GW_CONNECTION_STATUS_OK);
+				if (e_gw_connection_share_folder (sf->cnc, sf->container_id, new_list, sf->sub, sf->mesg, 0) == E_GW_CONNECTION_STATUS_OK) {
+					;
+				}
 			}
 
 			if (update_list) {
 				sf->sub = "Shared Folder rights updated";
 
-				if (e_gw_connection_share_folder (sf->cnc, sf->container_id, update_list, sf->sub, sf->mesg, 2) == E_GW_CONNECTION_STATUS_OK);
+				if (e_gw_connection_share_folder (sf->cnc, sf->container_id, update_list, sf->sub, sf->mesg, 2) == E_GW_CONNECTION_STATUS_OK) {
+					;
+				}
 			}
 		}
 		if (remove_list) {
 			sf->sub = "Shared Folder removed";
-			if (e_gw_connection_share_folder (sf->cnc, sf->container_id, remove_list, sf->sub, sf->mesg, 1) == E_GW_CONNECTION_STATUS_OK);
+			if (e_gw_connection_share_folder (sf->cnc, sf->container_id, remove_list, sf->sub, sf->mesg, 1) == E_GW_CONNECTION_STATUS_OK) {
+				;
+			}
 		}
 
 	}
@@ -509,7 +513,7 @@ notification_clicked(GtkButton *button, ShareFolder *sf)
 	GtkButton *not_ok;
 	GtkButton *not_cancel;
 	GtkWidget *vbox;
-	char *gladefile;
+	gchar *gladefile;
 
 	sf->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_type_hint (GTK_WINDOW (sf->window), GDK_WINDOW_TYPE_HINT_DIALOG);
@@ -576,13 +580,13 @@ add_right_clicked (GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 	gboolean right = FALSE;
 	SharedUser *usr = NULL;
 	EShUsers *user = NULL;
-	char *email = NULL;
+	gchar *email = NULL;
 	GtkTreePath *path = NULL;
 
 	path = gtk_tree_path_new_from_string (arg1);
 	if (!gtk_tree_model_get_iter ((GtkTreeModel *) sf->model, &(sf->iter), path)){
 		gtk_tree_path_free (path);
-		return ;
+		return;
 	}
 	gtk_tree_model_get ((GtkTreeModel *) sf->model, &(sf->iter), 0, &email, 1, &right , -1);
 	usr = find_node(sf->users_list, email);
@@ -609,7 +613,7 @@ edit_right_clicked(GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 	gboolean right = FALSE;
 	SharedUser *usr = NULL;
 	EShUsers *user = NULL;
-	char *email = NULL;
+	gchar *email = NULL;
 	GtkTreePath *path = NULL;
 
 	path = gtk_tree_path_new_from_string (arg1);
@@ -643,7 +647,7 @@ delete_right_clicked(GtkCellRenderer *renderer, gchar *arg1, ShareFolder *sf )
 	gboolean right = FALSE;
 	SharedUser *usr = NULL;
 	EShUsers *user = NULL;
-	char *email = NULL;
+	gchar *email = NULL;
 	GtkTreePath *path = NULL;
 
 	path = gtk_tree_path_new_from_string (arg1);
@@ -678,7 +682,7 @@ share_folder_construct (ShareFolder *sf)
 	ENameSelectorModel *name_selector_model;
 	ENameSelectorEntry *name_selector_entry;
 	GtkWidget *box;
-	char *gladefile;
+	gchar *gladefile;
 
 	gladefile = g_build_filename (EVOLUTION_GLADEDIR,
 				      "properties.glade",
