@@ -1,22 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Vivek Jain <jvivek@novell.com>
  *
- *  Copyright 2002-2003 Ximian, Inc. (www.ximian.com)
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *
+ * Authors:
+ *		Vivek Jain <jvivek@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -33,7 +34,7 @@ extern "C" {
 #include <e-gw-connection.h>
 #include <libedataserverui/e-name-selector.h>
 
-#define _SHARE_FOLDER_TYPE    	      (share_folder_get_type ())
+#define _SHARE_FOLDER_TYPE	      (share_folder_get_type ())
 #define SHARE_FOLDER(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), SHARE_FOLDER, ShareFolder))
 #define SHARE_FOLDER_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST ((k), SHARE_FOLDER_TYPE, ShareFolder))
 #define IS_SHARE_FOLDER(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), SHARE_FOLDER_TYPE))
@@ -92,7 +93,7 @@ struct _ShareFolder {
 	gboolean is_shared;
 	EGwConnection *cnc;
 	gchar *container_id;
-	gchar *sub;
+	const gchar *sub;
 	gchar *mesg;
 	GList *container_list;
 	GtkTreeIter iter;
@@ -108,7 +109,7 @@ struct _ShareFolderClass {
 GType share_folderget_type (void);
 struct _ShareFolder * share_folder_new (EGwConnection *ccnc, gchar *id);
 void share_folder(struct _ShareFolder *sf);
-gchar * get_container_id (EGwConnection *cnc, gchar *fname);
+gchar * get_container_id (EGwConnection *cnc, const gchar *fname);
 EGwConnection * get_cnc (CamelStore *store);
 
 #ifdef __cplusplus
