@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -30,9 +30,9 @@
 
 gboolean check_hal (void);
 gboolean ipod_check_status (gboolean silent);
-gboolean try_umount (char *device);
+gboolean try_umount (gchar *device);
 
-char *find_ipod_mount_point (LibHalContext *ctx);
-char *ipod_get_mount (void);
+gchar *find_ipod_mount_point (LibHalContext *ctx);
+gchar *ipod_get_mount (void);
 
 
