@@ -1,21 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Authors: Srinivasa Ragavan <sragavan@novell.com>
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of version 2 of the GNU General Public
- *  License as published by the Free Software Foundation.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * Authors:
+ *		Srinivasa Ragavan <sragavan@novell.com>
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -32,6 +33,7 @@
 #include <glib.h>
 #include <gio/gio.h>
 #include <glib/gi18n.h>
+#include <unistd.h>
 
 #include <libebook/e-book.h>
 #include <libebook/e-contact.h>
@@ -54,7 +56,7 @@ void org_gnome_sync_addressbook (EPlugin *ep, EABPopupTargetSource *target);
 
 
 static void
-display_error_message (GtkWidget *parent, const char *message)
+display_error_message (GtkWidget *parent, const gchar *message)
 {
 	GtkWidget *dialog;
 
@@ -68,7 +70,7 @@ display_error_message (GtkWidget *parent, const char *message)
    It will ask for overwrite if file already exists.
 */
 GOutputStream *
-open_for_writing (GtkWindow *parent, const char *uri, GError **error)
+open_for_writing (GtkWindow *parent, const gchar *uri, GError **error)
 {
 	GFile *file;
 	GFileOutputStream *fostream;
@@ -123,8 +125,8 @@ destination_save_addressbook  (EPlugin *ep, EABPopupTargetSource *target)
 	gchar *uri;
 	GOutputStream *stream;
 	GError *error = NULL;
-	char *dest_uri = NULL;
-	char *mount = ipod_get_mount();
+	gchar *dest_uri = NULL;
+	gchar *mount = ipod_get_mount();
 
 	primary_source = e_source_selector_peek_primary_selection (target->selector);
 
@@ -197,8 +199,8 @@ static void
 destination_save_cal (EPlugin *ep, ECalPopupTargetSource *target, ECalSourceType type)
 {
 	FormatHandler *handler = NULL;
-	char *mount = ipod_get_mount();
-	char *dest_uri = NULL, *path;
+	gchar *mount = ipod_get_mount();
+	gchar *dest_uri = NULL, *path;
 	ESource *primary_source = e_source_selector_peek_primary_selection (target->selector);
 
 	/* The available formathandlers */
@@ -254,7 +256,7 @@ org_gnome_sync_memos (EPlugin *ep, ECalPopupTargetSource *target)
 {
 	if (!ipod_check_status(FALSE))
 		return;
-	
+
 	destination_save_cal (ep, target, E_CAL_SOURCE_TYPE_JOURNAL);
 }
 
