@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -48,11 +48,11 @@
 #include <libnotify/notify.h>
 #endif
 
-#define GCONF_KEY_ROOT		 	"/apps/evolution/eplugin/mail-notification/"
+#define GCONF_KEY_ROOT			"/apps/evolution/eplugin/mail-notification/"
 #define GCONF_KEY_NOTIFY_ONLY_INBOX	GCONF_KEY_ROOT "notify-only-inbox"
-#define GCONF_KEY_ENABLED_DBUS	 	GCONF_KEY_ROOT "dbus-enabled"
-#define GCONF_KEY_ENABLED_STATUS 	GCONF_KEY_ROOT "status-enabled"
-#define GCONF_KEY_ENABLED_SOUND	 	GCONF_KEY_ROOT "sound-enabled"
+#define GCONF_KEY_ENABLED_DBUS		GCONF_KEY_ROOT "dbus-enabled"
+#define GCONF_KEY_ENABLED_STATUS	GCONF_KEY_ROOT "status-enabled"
+#define GCONF_KEY_ENABLED_SOUND		GCONF_KEY_ROOT "sound-enabled"
 
 static gboolean enabled = FALSE;
 static GtkWidget *get_cfg_widget (void);
@@ -66,7 +66,7 @@ static GStaticMutex mlock = G_STATIC_MUTEX_INIT;
  * b) void read_notify_... (EMEventTargetMessage *t)
  *    it is called when read_notify message is sent by Evolution
  *
- * c) void enable_... (int enable)
+ * c) void enable_... (gint enable)
  *    when plugin itself or the part is enabled/disabled
  *
  * d) GtkWidget *get_config_widget_...(void)
@@ -127,7 +127,7 @@ static DBusConnection *bus = NULL;
 static gboolean init_dbus (void);
 
 static void
-send_dbus_message (const char *name, const char *data, guint new)
+send_dbus_message (const gchar *name, const gchar *data, guint new)
 {
 	DBusMessage *message;
 
@@ -145,7 +145,7 @@ send_dbus_message (const char *name, const char *data, guint new)
 				  DBUS_TYPE_INVALID);
 
 	if (new) {
-		char * display_name = em_utils_folder_name_from_uri (data);
+		gchar * display_name = em_utils_folder_name_from_uri (data);
 		dbus_message_append_args (message,
 #if FOUND_DBUS_VERSION >= 310
 					  DBUS_TYPE_STRING, &display_name, DBUS_TYPE_UINT32, &new,
@@ -174,7 +174,7 @@ reinit_dbus (gpointer user_data)
 }
 
 static DBusHandlerResult
-filter_function (DBusConnection *connection, DBusMessage *message, void *user_data)
+filter_function (DBusConnection *connection, DBusMessage *message, gpointer user_data)
 {
 	if (dbus_message_is_signal (message, DBUS_INTERFACE_LOCAL, "Disconnected") &&
 	    strcmp (dbus_message_get_path (message), DBUS_PATH_LOCAL) == 0) {
@@ -237,7 +237,7 @@ read_notify_dbus (EMEventTargetMessage *t)
 }
 
 static void
-enable_dbus (int enable)
+enable_dbus (gint enable)
 {
 	if (enable) {
 		/* we ignore errors here */
@@ -273,7 +273,7 @@ get_config_widget_dbus (void)
 
 static GtkStatusIcon *status_icon = NULL;
 static guint blink_timeout_id = 0;
-static unsigned int status_count = 0;
+static guint status_count = 0;
 
 #ifdef HAVE_LIBNOTIFY
 static gboolean notification_callback (gpointer notify);
@@ -370,7 +370,7 @@ static void
 do_properties (GtkMenuItem *item, gpointer user_data)
 {
 	GtkWidget *cfg, *dialog, *vbox, *label, *hbox;
-	char *text;
+	gchar *text;
 
 	cfg = get_cfg_widget ();
 	if (!cfg)
@@ -398,8 +398,8 @@ do_properties (GtkMenuItem *item, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
 	dialog = gtk_dialog_new_with_buttons (_("Mail Notification Properties"),
-						NULL, 
-						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, 
+						NULL,
+						GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 						NULL);
 
@@ -427,7 +427,7 @@ popup_menu_status (GtkStatusIcon *status_icon, guint button, guint activate_time
 	#endif
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-	
+
 	item = gtk_separator_menu_item_new ();
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
@@ -443,11 +443,11 @@ popup_menu_status (GtkStatusIcon *status_icon, guint button, guint activate_time
 }
 
 #ifdef HAVE_LIBNOTIFY
-static void 
+static void
 notifyActionCallback (NotifyNotification *n, gchar *label, gpointer a)
 {
 	g_static_mutex_lock (&mlock);
-	
+
 	gtk_status_icon_set_visible (status_icon, FALSE);
 	g_object_unref (status_icon);
 
@@ -457,7 +457,7 @@ notifyActionCallback (NotifyNotification *n, gchar *label, gpointer a)
 	}
 
 	status_icon = NULL;
-	status_count = 0;	
+	status_count = 0;
 	g_static_mutex_unlock (&mlock);
 }
 #endif
@@ -465,7 +465,7 @@ notifyActionCallback (NotifyNotification *n, gchar *label, gpointer a)
 static void
 new_notify_status (EMEventTargetFolder *t)
 {
-	char *msg;
+	gchar *msg;
 	gboolean new_icon = !status_icon;
 
 	if (new_icon) {
@@ -541,7 +541,7 @@ read_notify_status (EMEventTargetMessage *t)
 }
 
 static void
-enable_status (int enable)
+enable_status (gint enable)
 {
 	/* this does nothing on enable, it's here just to be
 	   consistent with other parts of this plugin */
@@ -556,9 +556,9 @@ get_config_widget_status (void)
 	vbox = gtk_vbox_new (FALSE, 0);
 	scw = g_malloc0 (sizeof (struct _StatusConfigureWidgets));
 
-	#define create_check(c, key, desc) 							\
-		c = gtk_check_button_new_with_mnemonic (desc); 					\
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (c), is_part_enabled (key)); 	\
+	#define create_check(c, key, desc)							\
+		c = gtk_check_button_new_with_mnemonic (desc);					\
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (c), is_part_enabled (key));	\
 		gtk_box_pack_start (GTK_BOX (parent), c, FALSE, FALSE, 0);			\
 		g_signal_connect (G_OBJECT (c), "toggled", G_CALLBACK (toggled_status_cb), scw);
 
@@ -730,7 +730,7 @@ read_notify_sound (EMEventTargetMessage *t)
 }
 
 static void
-enable_sound (int enable)
+enable_sound (gint enable)
 {
 	if (enable)
 		gnome_sound_init ("localhost");
@@ -833,11 +833,11 @@ get_cfg_widget (void)
 	gtk_widget_show (check);
 	gtk_box_pack_start (GTK_BOX (vbox), check, FALSE, FALSE, 0);
 
-#ifdef HAVE_DBUS	
+#ifdef HAVE_DBUS
 	cfg = get_config_widget_dbus ();
 	if (cfg)
 		gtk_box_pack_start (GTK_BOX (vbox), cfg, FALSE, FALSE, 0);
-#endif 
+#endif
 	cfg = get_config_widget_status ();
 	if (cfg)
 		gtk_box_pack_start (GTK_BOX (vbox), cfg, FALSE, FALSE, 0);
@@ -854,7 +854,7 @@ get_cfg_widget (void)
 void org_gnome_mail_new_notify (EPlugin *ep, EMEventTargetFolder *t);
 void org_gnome_mail_read_notify (EPlugin *ep, EMEventTargetMessage *t);
 
-int e_plugin_lib_enable (EPluginLib *ep, int enable);
+gint e_plugin_lib_enable (EPluginLib *ep, gint enable);
 GtkWidget *e_plugin_lib_get_configure_widget (EPlugin *epl);
 
 
@@ -868,7 +868,7 @@ org_gnome_mail_new_notify (EPlugin *ep, EMEventTargetFolder *t)
 
 	g_static_mutex_lock (&mlock);
 
-#ifdef HAVE_DBUS	
+#ifdef HAVE_DBUS
 	if (is_part_enabled (GCONF_KEY_ENABLED_DBUS))
 		new_notify_dbus (t);
 #endif
@@ -904,11 +904,11 @@ org_gnome_mail_read_notify (EPlugin *ep, EMEventTargetMessage *t)
 	g_static_mutex_unlock (&mlock);
 }
 
-int
-e_plugin_lib_enable (EPluginLib *ep, int enable)
+gint
+e_plugin_lib_enable (EPluginLib *ep, gint enable)
 {
 	if (enable) {
-#ifdef HAVE_DBUS		
+#ifdef HAVE_DBUS
 		if (is_part_enabled (GCONF_KEY_ENABLED_DBUS))
 			enable_dbus (enable);
 #endif
@@ -922,7 +922,7 @@ e_plugin_lib_enable (EPluginLib *ep, int enable)
 	} else {
 #ifdef HAVE_DBUS
 		enable_dbus (enable);
-#endif 
+#endif
 		enable_status (enable);
 		enable_sound (enable);
 
