@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -42,7 +42,7 @@
 	   "only, or in the current folder as well as all subfolders?")
 
 void org_gnome_mark_all_read (EPlugin *ep, EMPopupTargetFolder *target);
-static void mar_got_folder (char *uri, CamelFolder *folder, void *data);
+static void mar_got_folder (gchar *uri, CamelFolder *folder, gpointer data);
 static void mar_all_sub_folders (CamelStore *store, CamelFolderInfo *fi, CamelException *ex);
 
 static void
@@ -204,7 +204,7 @@ static void
 mark_all_as_read (CamelFolder *folder)
 {
 	GPtrArray *uids;
-	int i;
+	gint i;
 
 	uids =  camel_folder_get_uids (folder);
 	camel_folder_freeze(folder);
@@ -215,7 +215,7 @@ mark_all_as_read (CamelFolder *folder)
 }
 
 static void
-mar_got_folder (char *uri, CamelFolder *folder, void *data)
+mar_got_folder (gchar *uri, CamelFolder *folder, gpointer data)
 {
 	CamelFolderInfo *info;
 	CamelStore *store;
@@ -223,19 +223,17 @@ mar_got_folder (char *uri, CamelFolder *folder, void *data)
 	gint response;
 	guint32 flags = CAMEL_STORE_FOLDER_INFO_RECURSIVE | CAMEL_STORE_FOLDER_INFO_FAST;
 
-	camel_exception_init (&ex);
-
 	/* FIXME we have to disable the menu item */
 	if (!folder)
 		return;
 
+	camel_exception_init (&ex);
+
 	store = folder->parent_store;
 	info = camel_store_get_folder_info (store, folder->full_name, flags, &ex);
 
-	if (camel_exception_is_set (&ex)) {
-		camel_exception_clear (&ex);
-		return;
-	}
+	if (camel_exception_is_set (&ex))
+		goto out;
 
 	if (info && (info->child || info->next))
 		response = prompt_user ();
@@ -246,6 +244,8 @@ mar_got_folder (char *uri, CamelFolder *folder, void *data)
 		mark_all_as_read (folder);
 	else if (response == GTK_RESPONSE_YES)
 		mar_all_sub_folders (store, info, &ex);
+out:
+	camel_store_free_folder_info(store, info);
 }
 
 static void
