@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -37,7 +37,7 @@
 static MonoDomain *domain;
 
 /* ********************************************************************** */
-static void *epm_parent_class;
+static gpointer epm_parent_class;
 
 typedef struct _EPluginMonoPrivate {
 	MonoAssembly *assembly;
@@ -48,13 +48,13 @@ typedef struct _EPluginMonoPrivate {
 
 #define epm ((EPluginMono *)ep)
 
-void * load_plugin_type_register_function (void *a, void *b);
+gpointer  load_plugin_type_register_function (gpointer a, gpointer b);
 
-static char *
-get_xml_prop(xmlNodePtr node, const char *id)
+static gchar *
+get_xml_prop(xmlNodePtr node, const gchar *id)
 {
-	char *p = xmlGetProp(node, id);
-	char *out = NULL;
+	gchar *p = xmlGetProp(node, id);
+	gchar *out = NULL;
 
 	if (p) {
 		out = g_strdup(p);
@@ -72,14 +72,14 @@ get_xml_prop(xmlNodePtr node, const char *id)
    All methods take a single (structured) argument.
 */
 
-static void *
-epm_invoke(EPlugin *ep, const char *name, void *data)
+static gpointer
+epm_invoke(EPlugin *ep, const gchar *name, gpointer data)
 {
 	EPluginMonoPrivate *p = epm->priv;
 	MonoMethodDesc *d;
 	MonoMethod *m;
 	MonoObject *x = NULL, *res;
-	void **params;
+	gpointer *params;
 
 	g_print ("\n\a epm_invoke in mono-plugin.c in mono plugin loader is called \n\a");
 
@@ -108,18 +108,18 @@ epm_invoke(EPlugin *ep, const char *name, void *data)
 		if (p->klass) {
 			d(printf("looking up method '%s' in class\n", name));
 			/* class method */
-			
+
 			d = mono_method_desc_new(name, FALSE);
 			/*if (d == NULL) {
 				g_warning("Can't create method descriptor for '%s'", name);
 				return NULL;
 			}*/
-			
+
 			gpointer iter = NULL;
 			MonoMethod* mono_method;
 
 			d(printf ("\n\a About to get methods in klass\n\a"));
-			       
+
 			while ((mono_method = mono_class_get_methods (p->klass, &iter))) {
 				g_print ("\n\a Method name is : <%s>\n\a", mono_method_get_name(mono_method));
 			}
@@ -158,14 +158,14 @@ epm_invoke(EPlugin *ep, const char *name, void *data)
 		mono_print_unhandled_exception(x);
 
 	if (res) {
-		void **p = mono_object_unbox(res);
-		d(printf("mono method returned '%p' %ld\n", *p, (long int)*p));
+		gpointer *p = mono_object_unbox(res);
+		d(printf("mono method returned '%p' %ld\n", *p, (long gint)*p));
 		return *p;
 	} else
 		return NULL;
 }
 
-static int
+static gint
 epm_construct(EPlugin *ep, xmlNodePtr root)
 {
 	if (((EPluginClass *)epm_parent_class)->construct(ep, root) == -1)
@@ -217,8 +217,8 @@ epm_init(GObject *o)
 		(GDestroyNotify) NULL);
 }
 
-void *
-load_plugin_type_register_function (void *a, void *b)
+gpointer
+load_plugin_type_register_function (gpointer a, gpointer b)
 {
 	static GType type = 0;
 
