@@ -1,21 +1,22 @@
 /*
- * Authors: David Trowbridge <trowbrds@cs.colorado.edu>
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		David Trowbridge <trowbrds@cs.colorado.edu>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -32,6 +33,7 @@
 #include <calendar/gui/e-cal-menu.h>
 #include <shell/es-event.h>
 #include <e-util/e-util-private.h>
+#include <e-util/e-dialog-utils.h>
 #include "url-editor-dialog.h"
 #include "publish-format-fb.h"
 #include "publish-format-ical.h"
@@ -42,13 +44,24 @@ static GSList *publish_uris = NULL;
 static GSList *queued_publishes = NULL;
 static gint online = 0;
 
-int          e_plugin_lib_enable (EPlugin *ep, int enable);
+static GSList *error_queue = NULL;
+static GStaticMutex error_queue_lock = G_STATIC_MUTEX_INIT;
+static guint error_queue_show_idle_id = 0;
+static void  error_queue_add (gchar *descriptions, GError *error);
+
+gint          e_plugin_lib_enable (EPlugin *ep, gint enable);
 void         action_publish (EPlugin *ep, ECalMenuTargetSelect *t);
 void         online_state_changed (EPlugin *ep, ESEventTargetState *target);
 void         publish_calendar_context_activate (EPlugin *ep, ECalPopupTargetSource *target);
 GtkWidget   *publish_calendar_locations (EPlugin *epl, EConfigHookItemFactoryData *data);
 static void  update_timestamp (EPublishUri *uri);
-static void publish (EPublishUri *uri);
+static void publish (EPublishUri *uri, gboolean can_report_success);
+
+static void
+publish_no_succ_info (EPublishUri *uri)
+{
+	publish (uri, FALSE);
+}
 
 static void
 publish_uri_async (EPublishUri *uri)
@@ -56,7 +69,7 @@ publish_uri_async (EPublishUri *uri)
 	GThread *thread = NULL;
 	GError *error = NULL;
 
-	thread = g_thread_create ((GThreadFunc) publish, uri, FALSE, &error);
+	thread = g_thread_create ((GThreadFunc) publish_no_succ_info, uri, FALSE, &error);
 	if (!thread) {
 		g_warning (G_STRLOC ": %s", error->message);
 		g_error_free (error);
@@ -64,7 +77,7 @@ publish_uri_async (EPublishUri *uri)
 }
 
 static void
-publish_online (EPublishUri *uri, GFile *file, GError **perror)
+publish_online (EPublishUri *uri, GFile *file, GError **perror, gboolean can_report_success)
 {
 	GOutputStream *stream;
 	GError *error = NULL;
@@ -78,20 +91,20 @@ publish_online (EPublishUri *uri, GFile *file, GError **perror)
 		if (perror) {
 			*perror = error;
 		} else if (error) {
-			g_warning ("Couldn't open %s: %s", uri->location, error->message);
-			g_error_free (error);
+
+			error_queue_add (g_strdup_printf (_("Could not open %s:"), uri->location), error);
 		} else {
-			g_warning ("Couldn't open %s: Unknown error", uri->location);
+			error_queue_add (g_strdup_printf (_("Could not open %s: Unknown error"), uri->location), NULL);
 		}
 		return;
 	}
 
 	switch (uri->publish_format) {
 	case URI_PUBLISH_AS_ICAL:
-		publish_calendar_as_ical (stream, uri);
+		publish_calendar_as_ical (stream, uri, &error);
 		break;
 	case URI_PUBLISH_AS_FB:
-		publish_calendar_as_fb (stream, uri);
+		publish_calendar_as_fb (stream, uri, &error);
 		break;
 	/*
 	case URI_PUBLISH_AS_HTML:
@@ -100,6 +113,11 @@ publish_online (EPublishUri *uri, GFile *file, GError **perror)
 	*/
 	}
 
+	if (error)
+		error_queue_add (g_strdup_printf (_("There was an error while publishing to %s:"), uri->location), error);
+	else if (can_report_success)
+		error_queue_add (g_strdup_printf (_("Publishing to %s finished successfully"), uri->location), NULL);
+
 	update_timestamp (uri);
 
 	g_output_stream_close (stream, NULL, NULL);
@@ -125,6 +143,7 @@ struct mnt_struct {
 	EPublishUri *uri;
 	GFile *file;
 	GMountOperation *mount_op;
+	gboolean can_report_success;
 };
 
 static void
@@ -137,10 +156,9 @@ mount_ready_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
 	g_file_mount_enclosing_volume_finish (G_FILE (source_object), res, &error);
 
 	if (error) {
-		if (error->code != G_IO_ERROR_CANCELLED)
-			g_warning ("Mount of %s failed: %s", ms->uri->location, error->message);
 
-		g_error_free (error);
+		error_queue_add (g_strdup_printf (_("Mount of %s failed:"), ms->uri->location), error);
+
 		if (ms)
 			g_object_unref (ms->mount_op);
 		g_free (ms);
@@ -152,7 +170,7 @@ mount_ready_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
 
 	g_return_if_fail (ms != NULL);
 
-	publish_online (ms->uri, ms->file, NULL);
+	publish_online (ms->uri, ms->file, NULL, ms->can_report_success);
 
 	g_object_unref (ms->mount_op);
 	g_free (ms);
@@ -215,14 +233,14 @@ ask_password (GMountOperation *op, const gchar *message, const gchar *default_us
 }
 
 static void
-ask_question (GMountOperation *op, const char *message, const char *choices[])
+ask_question (GMountOperation *op, const gchar *message, const gchar *choices[])
 {
 	/* this has been stolen from file-chooser */
 	GtkWidget *dialog;
-	int cnt, len;
-	char *primary;
-	const char *secondary = NULL;
-	int res;
+	gint cnt, len;
+	gchar *primary;
+	const gchar *secondary = NULL;
+	gint res;
 
 	primary = strstr (message, "\n");
 	if (primary) {
@@ -240,14 +258,14 @@ ask_question (GMountOperation *op, const char *message, const char *choices[])
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 							  "%s", secondary);
 	}
-	
+
 	if (choices) {
-		/* First count the items in the list then 
+		/* First count the items in the list then
 		 * add the buttons in reverse order */
 		for (len = 0; choices[len] != NULL; len++) {
 			;
 		}
-		
+
 		for (cnt = len - 1; cnt >= 0; cnt--) {
 			gtk_dialog_add_button (GTK_DIALOG (dialog), choices[cnt], cnt);
 		}
@@ -266,22 +284,23 @@ ask_question (GMountOperation *op, const char *message, const char *choices[])
 }
 
 static void
-mount_first (EPublishUri *uri, GFile *file)
+mount_first (EPublishUri *uri, GFile *file, gboolean can_report_success)
 {
 	struct mnt_struct *ms = g_malloc (sizeof (struct mnt_struct));
 
 	ms->uri = uri;
 	ms->file = g_object_ref (file);
 	ms->mount_op = g_mount_operation_new ();
+	ms->can_report_success = can_report_success;
 
 	g_signal_connect (ms->mount_op, "ask-password", G_CALLBACK (ask_password), ms);
-	g_signal_connect (ms->mount_op, "ask-question", G_CALLBACK (ask_question), ms);	
+	g_signal_connect (ms->mount_op, "ask-question", G_CALLBACK (ask_question), ms);
 
 	g_file_mount_enclosing_volume (file, G_MOUNT_MOUNT_NONE, ms->mount_op, NULL, mount_ready_cb, ms);
 }
 
 static void
-publish (EPublishUri *uri)
+publish (EPublishUri *uri, gboolean can_report_success)
 {
 	if (online) {
 		GError *error = NULL;
@@ -297,19 +316,17 @@ publish (EPublishUri *uri)
 
 		g_return_if_fail (file != NULL);
 
-		publish_online (uri, file, &error);
+		publish_online (uri, file, &error, can_report_success);
 
 		if (error && error->domain == G_IO_ERROR && error->code == G_IO_ERROR_NOT_MOUNTED) {
 			g_error_free (error);
 			error = NULL;
 
-			mount_first (uri, file);
+			mount_first (uri, file, can_report_success);
 		}
 
-		if (error) {
-			g_warning ("Couldn't open %s: %s", uri->location, error->message);
-			g_error_free (error);
-		}
+		if (error)
+			error_queue_add (g_strdup_printf (_("Could not open %s:"), uri->location), error);
 
 		g_object_unref (file);
 	} else {
@@ -335,11 +352,11 @@ add_timeout (EPublishUri *uri)
 	/* Set the timeout for now+frequency */
 	switch (uri->publish_frequency) {
 	case URI_PUBLISH_DAILY:
-		id = g_timeout_add (24 * 60 * 60 * 1000, (GSourceFunc) publish, uri);
+		id = g_timeout_add_seconds (24 * 60 * 60, (GSourceFunc) publish, uri);
 		g_hash_table_insert (uri_timeouts, uri, GUINT_TO_POINTER (id));
 		break;
 	case URI_PUBLISH_WEEKLY:
-		id = g_timeout_add (7 * 24 * 60 * 60 * 1000, (GSourceFunc) publish, uri);
+		id = g_timeout_add_seconds (7 * 24 * 60 * 60, (GSourceFunc) publish, uri);
 		g_hash_table_insert (uri_timeouts, uri, GUINT_TO_POINTER (id));
 		break;
 	}
@@ -377,7 +394,7 @@ update_timestamp (EPublishUri *uri)
 
 	if (uri->last_pub_time)
 		g_free (uri->last_pub_time);
-	uri->last_pub_time = g_strdup_printf ("%d", (int) time (NULL));
+	uri->last_pub_time = g_strdup_printf ("%d", (gint) time (NULL));
 
 	uris = g_slist_prepend (uris, e_publish_uri_to_xml (uri));
 
@@ -399,20 +416,20 @@ add_offset_timeout (EPublishUri *uri)
 	switch (uri->publish_frequency) {
 	case URI_PUBLISH_DAILY:
 		if (elapsed > 24 * 60 * 60) {
-			publish (uri);
+			publish (uri, FALSE);
 			add_timeout (uri);
 		} else {
-			id = g_timeout_add (((24 * 60 * 60) - elapsed) * 1000, (GSourceFunc) publish, uri);
+			id = g_timeout_add_seconds (24 * 60 * 60 - elapsed, (GSourceFunc) publish, uri);
 			g_hash_table_insert (uri_timeouts, uri, GUINT_TO_POINTER (id));
 			break;
 		}
 		break;
 	case URI_PUBLISH_WEEKLY:
 		if (elapsed > 7 * 24 * 60 * 60) {
-			publish (uri);
+			publish (uri, FALSE);
 			add_timeout (uri);
 		} else {
-			id = g_timeout_add (((7 * 24 * 60 * 60) - elapsed) * 1000, (GSourceFunc) publish, uri);
+			id = g_timeout_add_seconds (7 * 24 * 60 * 60 - elapsed, (GSourceFunc) publish, uri);
 			g_hash_table_insert (uri_timeouts, uri, GUINT_TO_POINTER (id));
 			break;
 		}
@@ -435,7 +452,7 @@ url_list_changed (PublishUIData *ui)
 	valid = gtk_tree_model_get_iter_first (model, &iter);
 	while (valid) {
 		EPublishUri *url;
-		char *xml;
+		gchar *xml;
 
 		gtk_tree_model_get (model, &iter, URL_LIST_URL_COLUMN, &url, -1);
 
@@ -452,7 +469,7 @@ url_list_changed (PublishUIData *ui)
 
 static void
 url_list_enable_toggled (GtkCellRendererToggle *renderer,
-                         const char            *path_string,
+                         const gchar            *path_string,
 			 PublishUIData         *ui)
 {
 	GtkTreeSelection *selection;
@@ -591,8 +608,8 @@ url_remove_clicked (GtkButton *button, PublishUIData *ui)
 	gtk_tree_model_get (model, &iter, URL_LIST_URL_COLUMN, &url, -1);
 
 	confirm = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-			                  GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-					  _("Are you sure you want to remove this URL?"));
+					  GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
+					  _("Are you sure you want to remove this location?"));
 	gtk_dialog_add_button (GTK_DIALOG (confirm), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
 	gtk_dialog_add_button (GTK_DIALOG (confirm), GTK_STOCK_REMOVE, GTK_RESPONSE_YES);
 	gtk_dialog_set_default_response (GTK_DIALOG (confirm), GTK_RESPONSE_CANCEL);
@@ -601,7 +618,7 @@ url_remove_clicked (GtkButton *button, PublishUIData *ui)
 	gtk_widget_destroy (confirm);
 
 	if (response == GTK_RESPONSE_YES) {
-		int len;
+		gint len;
 		guint id;
 		gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 
@@ -654,7 +671,7 @@ online_state_changed (EPlugin *ep, ESEventTargetState *target)
 	online = target->state;
 	if (online)
 		while (queued_publishes)
-			publish (queued_publishes->data);
+			publish (queued_publishes->data, FALSE);
 }
 
 GtkWidget *
@@ -668,7 +685,7 @@ publish_calendar_locations (EPlugin *epl, EConfigHookItemFactoryData *data)
 	GSList *l;
 	GtkTreeIter iter;
 	GConfClient *client;
-	char *gladefile;
+	gchar *gladefile;
 
 	gladefile = g_build_filename (EVOLUTION_GLADEDIR,
 				      "publish-calendar.glade",
@@ -687,11 +704,11 @@ publish_calendar_locations (EPlugin *epl, EConfigHookItemFactoryData *data)
 	renderer = gtk_cell_renderer_toggle_new ();
 	g_object_set (G_OBJECT (renderer), "activatable", TRUE, NULL);
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (ui->treeview), -1, _("Enabled"),
-			                             renderer, "active", URL_LIST_ENABLED_COLUMN, NULL);
+						     renderer, "active", URL_LIST_ENABLED_COLUMN, NULL);
 	g_signal_connect (G_OBJECT (renderer), "toggled", G_CALLBACK (url_list_enable_toggled), ui);
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (ui->treeview), -1, _("Location"),
-			                             renderer, "text", URL_LIST_LOCATION_COLUMN, NULL);
+						     renderer, "text", URL_LIST_LOCATION_COLUMN, NULL);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (ui->treeview));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 	g_signal_connect (G_OBJECT (selection), "changed", G_CALLBACK (selection_changed), ui);
@@ -742,7 +759,7 @@ publish_urls (gpointer data)
 
 	for (l = publish_uris; l; l = g_slist_next (l)) {
 		EPublishUri *uri = l->data;
-		publish (uri);
+		publish (uri, TRUE);
 	}
 
 	return GINT_TO_POINTER (0);
@@ -755,11 +772,8 @@ action_publish (EPlugin *ep, ECalMenuTargetSelect *t)
 	GError *error = NULL;
 
 	thread = g_thread_create ((GThreadFunc) publish_urls, NULL, FALSE, &error);
-	if (!thread) {
-		g_warning (G_STRLOC ": %s", error->message);
-		g_error_free (error);
-	}
-
+	if (!thread)
+		error_queue_add (g_strdup (_("Could not create publish thread.")), error);
 }
 
 static void
@@ -792,8 +806,8 @@ publish_uris_set_timeout (GSList *uris)
 	g_slist_free (uris);
 }
 
-int
-e_plugin_lib_enable (EPlugin *ep, int enable)
+gint
+e_plugin_lib_enable (EPlugin *ep, gint enable)
 {
 	GSList *uris;
 	GConfClient *client;
@@ -815,3 +829,90 @@ e_plugin_lib_enable (EPlugin *ep, int enable)
 
 	return 0;
 }
+
+struct eq_data {
+	gchar *description;
+	GError *error;
+};
+
+static gboolean
+error_queue_show_idle (gpointer user_data)
+{
+	GString *info = NULL;
+	GSList *l;
+	gboolean has_error = FALSE, has_info = FALSE;
+
+	g_static_mutex_lock (&error_queue_lock);
+
+	for (l = error_queue; l; l = l->next) {
+		struct eq_data *data = l->data;
+
+		if (data) {
+			if (data->description) {
+				if (!info) {
+					info = g_string_new (data->description);
+				} else {
+					g_string_append (info, "\n\n");
+					g_string_append (info, data->description);
+				}
+
+				g_free (data->description);
+			}
+
+			if (data->error) {
+				has_error = TRUE;
+				if (!info) {
+					info = g_string_new (data->error->message);
+				} else if (data->description) {
+					g_string_append (info, " ");
+					g_string_append (info, data->error->message);
+				} else {
+					g_string_append (info, "\n\n");
+					g_string_append (info, data->error->message);
+				}
+
+				g_error_free (data->error);
+			} else if (data->description) {
+				has_info = TRUE;
+			}
+
+			g_free (data);
+		}
+	}
+
+	g_slist_free (error_queue);
+
+	error_queue = NULL;
+	error_queue_show_idle_id = 0;
+
+	g_static_mutex_unlock (&error_queue_lock);
+
+	if (info) {
+		e_notice (NULL,
+			  has_error && has_info ? GTK_MESSAGE_WARNING : has_error ? GTK_MESSAGE_ERROR : GTK_MESSAGE_INFO,
+			  "%s", info->str, NULL);
+
+		g_string_free (info, TRUE);
+	}
+
+	return FALSE;
+}
+
+void
+error_queue_add (gchar *description, GError *error)
+{
+	struct eq_data *data;
+
+	if (!error && !description)
+		return;
+
+	data = g_new0 (struct eq_data, 1);
+	data->description = description;
+	data->error = error;
+
+	g_static_mutex_lock (&error_queue_lock);
+	error_queue = g_slist_append (error_queue, data);
+	if (error_queue_show_idle_id == 0)
+		error_queue_show_idle_id = g_idle_add (error_queue_show_idle, NULL);
+	g_static_mutex_unlock (&error_queue_lock);
+}
