@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -58,12 +58,12 @@ static pthread_mutex_t em_junk_sa_report_lock = PTHREAD_MUTEX_INITIALIZER;
 static pthread_mutex_t em_junk_sa_preferred_socket_path_lock = PTHREAD_MUTEX_INITIALIZER;
 static pthread_mutex_t em_junk_sa_spamd_restart_lock = PTHREAD_MUTEX_INITIALIZER;
 
-int e_plugin_lib_enable (EPluginLib *ep, int enable);
+gint e_plugin_lib_enable (EPluginLib *ep, gint enable);
 gboolean em_junk_sa_check_junk (EPlugin *ep, EMJunkHookTarget *target);
 void em_junk_sa_report_junk (EPlugin *ep, EMJunkHookTarget *target);
 void em_junk_sa_report_non_junk (EPlugin *ep, EMJunkHookTarget *target);
 void em_junk_sa_commit_reports (EPlugin *ep);
-void *em_junk_sa_validate_binary (EPlugin *ep);
+gpointer em_junk_sa_validate_binary (EPlugin *ep);
 GtkWidget *org_gnome_sa_use_remote_tests (struct _EPlugin *epl, struct _EConfigHookItemFactoryData *data);
 
 static void em_junk_sa_init (void);
@@ -79,41 +79,41 @@ static gboolean em_junk_sa_system_spamd_available = FALSE;
 static gboolean em_junk_sa_new_daemon_started = FALSE;
 static gboolean em_junk_sa_checked_spamassassin_version = FALSE;
 static guint em_junk_sa_spamassassin_version = 0;
-static char *em_junk_sa_socket_path = NULL;
-static char *em_junk_sa_spamd_pidfile = NULL;
-static char *em_junk_sa_spamc_binary = NULL;
+static gchar *em_junk_sa_socket_path = NULL;
+static gchar *em_junk_sa_spamd_pidfile = NULL;
+static const gchar *em_junk_sa_spamc_binary = NULL;
 static GConfClient *em_junk_sa_gconf = NULL;
 
 /* volatile so not cached between threads */
 static volatile gboolean em_junk_sa_local_only;
 static volatile gboolean em_junk_sa_use_daemon;
-static char * em_junk_sa_preferred_socket_path;
+static gchar * em_junk_sa_preferred_socket_path;
 
-static char *em_junk_sa_spamc_binaries [4] = {"spamc", "/usr/bin/spamc", "/usr/sbin/spamc", NULL};
-static char *em_junk_sa_spamd_binaries [4] = {"spamd", "/usr/bin/spamd", "/usr/sbin/spamd", NULL};
+static const gchar *em_junk_sa_spamc_binaries [4] = {"spamc", "/usr/bin/spamc", "/usr/sbin/spamc", NULL};
+static const gchar *em_junk_sa_spamd_binaries [4] = {"spamd", "/usr/bin/spamd", "/usr/sbin/spamd", NULL};
 
 #define SPAMD_RESTARTS_SIZE 8
 static time_t em_junk_sa_spamd_restarts [SPAMD_RESTARTS_SIZE] = {0, 0, 0, 0, 0, 0, 0, 0};
-static int em_junk_sa_spamd_restarts_count = 0;
+static gint em_junk_sa_spamd_restarts_count = 0;
 
 /* Variables to indicate whether spamd is running with --allow-tell */
-static int no_allow_tell;
+static gint no_allow_tell;
 static gboolean em_junk_sa_allow_tell_tested = FALSE;
 
-char *em_junk_sa_spamc_gconf_binary = NULL;
-char *em_junk_sa_spamd_gconf_binary = NULL;
+gchar *em_junk_sa_spamc_gconf_binary = NULL;
+gchar *em_junk_sa_spamd_gconf_binary = NULL;
 
-static int
-pipe_to_sa_full (CamelMimeMessage *msg, const char *in, char **argv, int rv_err, int wait_for_termination, GByteArray *output_buffer, GError **error)
+static gint
+pipe_to_sa_full (CamelMimeMessage *msg, const gchar *in, const gchar **argv, gint rv_err, gint wait_for_termination, GByteArray *output_buffer, GError **error)
 {
-	int result, status, errnosav, fds[2], out_fds[2];
+	gint result, status, errnosav, fds[2], out_fds[2];
 	CamelStream *stream;
-	char *program;
+	gchar *program;
 	pid_t pid;
 
 
 	if (camel_debug_start ("junk")) {
-		int i;
+		gint i;
 
 		printf ("pipe_to_sa ");
 		for (i = 0; argv[i]; i++)
@@ -150,7 +150,7 @@ pipe_to_sa_full (CamelMimeMessage *msg, const char *in, char **argv, int rv_err,
 
 	if (!(pid = fork ())) {
 		/* child process */
-		int maxfd, fd, nullfd;
+		gint maxfd, fd, nullfd;
 
 		nullfd = open ("/dev/null", O_WRONLY);
 
@@ -169,7 +169,7 @@ pipe_to_sa_full (CamelMimeMessage *msg, const char *in, char **argv, int rv_err,
 		for (fd = 3; fd < maxfd; fd++)
 			fcntl (fd, F_SETFD, FD_CLOEXEC);
 
-		execvp (argv[0], argv);
+		execvp (argv[0], (gchar * const *) argv);
 		_exit (rv_err & 0377);
 	} else if (pid < 0) {
 		errnosav = errno;
@@ -212,13 +212,13 @@ pipe_to_sa_full (CamelMimeMessage *msg, const char *in, char **argv, int rv_err,
 
 		camel_stream_write_to_stream (stream, (CamelStream *) memstream);
 		camel_object_unref (stream);
-		g_byte_array_append (output_buffer, (unsigned char *)"", 1);
+		g_byte_array_append (output_buffer, (guchar *)"", 1);
 
 		d(printf ("child process output: %s len: %d\n", output_buffer->data, output_buffer->len));
 	}
 
 	if (wait_for_termination) {
-		int res;
+		gint res;
 
 		d(printf ("wait for child %d termination\n", pid));
 		result = waitpid (pid, &status, 0);
@@ -253,13 +253,13 @@ pipe_to_sa_full (CamelMimeMessage *msg, const char *in, char **argv, int rv_err,
 		return 0;
 }
 
-static int
-pipe_to_sa (CamelMimeMessage *msg, const char *in, char **argv, GError **error)
+static gint
+pipe_to_sa (CamelMimeMessage *msg, const gchar *in, const gchar **argv, GError **error)
 {
 	return pipe_to_sa_full (msg, in, argv, -1, 1, NULL, error);
 }
 
-static char *
+static gchar *
 em_junk_sa_get_socket_path ()
 {
 	if (em_junk_sa_preferred_socket_path)
@@ -269,10 +269,10 @@ em_junk_sa_get_socket_path ()
 }
 
 static gboolean
-em_junk_sa_test_spamd_running (char *binary, gboolean system)
+em_junk_sa_test_spamd_running (const gchar *binary, gboolean system)
 {
-	char *argv[5];
-	int i = 0;
+	const gchar *argv[5];
+	gint i = 0;
 	gboolean rv;
 
 	pthread_mutex_lock (&em_junk_sa_preferred_socket_path_lock);
@@ -303,11 +303,11 @@ em_junk_sa_test_spamd_running (char *binary, gboolean system)
   One time test to see if spamd is running with --allow-tell.  The call
   to spamc should return 0 if it is.  (Thanks to Karsten Brckelmann
   for the idea).
-*/ 
+*/
 static void
 em_junk_sa_test_allow_tell (void)
 {
-	char *argv [4] = {
+	const gchar *argv [4] = {
 		"spamc",
 		"-L",
 		"forget",
@@ -321,7 +321,7 @@ em_junk_sa_test_allow_tell (void)
 static void
 em_junk_sa_test_spamassassin (void)
 {
-	char *argv [3] = {
+	const gchar *argv [3] = {
 		"spamassassin",
 		"--version",
 		NULL,
@@ -338,10 +338,10 @@ em_junk_sa_test_spamassassin (void)
 #define MAX_SPAMD_PORTS 1
 
 static gboolean
-em_junk_sa_run_spamd (char *binary)
+em_junk_sa_run_spamd (const gchar *binary)
 {
-	char *argv[8];
-	int i;
+	const gchar *argv[8];
+	gint i;
 	gboolean rv = FALSE;
 
 	pthread_mutex_lock (&em_junk_sa_preferred_socket_path_lock);
@@ -395,7 +395,7 @@ em_junk_sa_run_spamd (char *binary)
 static void
 em_junk_sa_start_own_daemon ()
 {
-	int b;
+	gint b;
 
 	em_junk_sa_new_daemon_started = FALSE;
 
@@ -415,7 +415,7 @@ static void
 em_junk_sa_find_spamc ()
 {
 	if (em_junk_sa_use_spamc && em_junk_sa_new_daemon_started) {
-		int b;
+		gint b;
 
 		em_junk_sa_use_spamc = FALSE;
 		for (b = 0; em_junk_sa_spamc_binaries [b]; b ++) {
@@ -431,8 +431,8 @@ em_junk_sa_find_spamc ()
 static void
 em_junk_sa_test_spamd (void)
 {
-	char *argv[4];
-	int i, b;
+	const gchar *argv[4];
+	gint i, b;
 	gboolean try_system_spamd = TRUE;
 
 	if (em_junk_sa_spamc_gconf_binary) {
@@ -444,7 +444,7 @@ em_junk_sa_test_spamd (void)
 		em_junk_sa_spamd_binaries [0] = em_junk_sa_spamd_gconf_binary;
 		em_junk_sa_spamd_binaries [1] = NULL;
 		try_system_spamd = FALSE;
-  	}
+	}
 
 	em_junk_sa_use_spamc = FALSE;
 
@@ -513,7 +513,7 @@ em_junk_sa_is_available (GError **error)
 
 	/* While we're at it, see if spamd is running with --allow-tell */
 	if (!em_junk_sa_allow_tell_tested)
- 	        em_junk_sa_test_allow_tell () ;
+		em_junk_sa_test_allow_tell ();
 
 	pthread_mutex_unlock (&em_junk_sa_init_lock);
 
@@ -577,8 +577,9 @@ gboolean
 em_junk_sa_check_junk(EPlugin *ep, EMJunkHookTarget *target)
 {
 	GByteArray *out = NULL;
-	char *argv[7], *to_free = NULL;
-	int i = 0, socket_i;
+	const gchar *argv[7];
+	gchar *to_free = NULL;
+	gint i = 0, socket_i;
 	gboolean rv;
 	CamelMimeMessage *msg = target->m;
 
@@ -612,7 +613,7 @@ em_junk_sa_check_junk(EPlugin *ep, EMJunkHookTarget *target)
 
 	rv = pipe_to_sa_full (msg, NULL, argv, 0, 1, out, &target->error) != 0;
 
-	if (!rv && out && out->data && !strcmp ((const char *)out->data, "0/0\n")) {
+	if (!rv && out && out->data && !strcmp ((const gchar *)out->data, "0/0\n")) {
 		/* an error occurred */
 		if (em_junk_sa_respawn_spamd ()) {
 			g_byte_array_set_size (out, 0);
@@ -642,9 +643,9 @@ static guint
 get_spamassassin_version ()
 {
 	GByteArray *out = NULL;
-	int i;
+	gint i;
 
-	char * argv[3] = {
+	const gchar *argv[3] = {
 		"sa-learn",
 		"--version",
 		NULL
@@ -680,8 +681,10 @@ get_spamassassin_version ()
 void
 em_junk_sa_report_junk (EPlugin *ep, EMJunkHookTarget *target)
 {
-	char *sync_op = ((get_spamassassin_version () >= 3) ? "--no-sync": "--no-rebuild");
-	char *argv[6] = {
+	const gchar *sync_op =
+		(get_spamassassin_version () >= 3)
+		? "--no-sync": "--no-rebuild";
+	const gchar *argv[6] = {
 		"sa-learn",
 		sync_op,
 		"--spam",
@@ -690,7 +693,7 @@ em_junk_sa_report_junk (EPlugin *ep, EMJunkHookTarget *target)
 		NULL
 	};
 	/* Call setup for spamc */
-	char *argv2[4] = {
+	const gchar *argv2[4] = {
 	  "spamc",
 	  "-L",
 	  "spam",
@@ -708,8 +711,8 @@ em_junk_sa_report_junk (EPlugin *ep, EMJunkHookTarget *target)
 			argv[4] = "--local";
 
 		pthread_mutex_lock (&em_junk_sa_report_lock);
-		pipe_to_sa (msg, NULL, 
-			    (no_allow_tell ? argv : argv2), 
+		pipe_to_sa (msg, NULL,
+			    (no_allow_tell ? argv : argv2),
 			    &target->error);
 		pthread_mutex_unlock (&em_junk_sa_report_lock);
 	}
@@ -718,8 +721,10 @@ em_junk_sa_report_junk (EPlugin *ep, EMJunkHookTarget *target)
 void
 em_junk_sa_report_non_junk (EPlugin *ep, EMJunkHookTarget *target)
 {
-	char *sync_op = ((get_spamassassin_version () >= 3) ? "--no-sync": "--no-rebuild");
-	char *argv[6] = {
+	const gchar *sync_op =
+		(get_spamassassin_version () >= 3)
+		? "--no-sync": "--no-rebuild";
+	const gchar *argv[6] = {
 		"sa-learn",
 		sync_op,
 		"--ham",
@@ -728,7 +733,7 @@ em_junk_sa_report_non_junk (EPlugin *ep, EMJunkHookTarget *target)
 		NULL
 	};
 	/* Setup for spamc */
-	char *argv2[4] = {
+	const gchar *argv2[4] = {
 	  "spamc",
 	  "-L",
 	  "ham",
@@ -743,8 +748,8 @@ em_junk_sa_report_non_junk (EPlugin *ep, EMJunkHookTarget *target)
 		if (no_allow_tell && em_junk_sa_local_only)
 			argv[4] = "--local";
 		pthread_mutex_lock (&em_junk_sa_report_lock);
-		pipe_to_sa (msg, NULL, 
-			    (no_allow_tell ? argv : argv2), 
+		pipe_to_sa (msg, NULL,
+			    (no_allow_tell ? argv : argv2),
 			    &target->error);
 		pthread_mutex_unlock (&em_junk_sa_report_lock);
 	}
@@ -753,8 +758,9 @@ em_junk_sa_report_non_junk (EPlugin *ep, EMJunkHookTarget *target)
 void
 em_junk_sa_commit_reports (EPlugin *ep)
 {
-	char *sync_op = ((get_spamassassin_version () >= 3) ? "--sync": "--rebuild");
-	char *argv[4] = {
+	const gchar *sync_op =
+		(get_spamassassin_version () >= 3) ? "--sync": "--rebuild";
+	const gchar *argv[4] = {
 		"sa-learn",
 		sync_op,
 		NULL,
@@ -777,17 +783,17 @@ em_junk_sa_commit_reports (EPlugin *ep)
 	}
 }
 
-void *
+gpointer
 em_junk_sa_validate_binary (EPlugin *ep)
 {
-	return em_junk_sa_is_available (NULL) ? "1" : NULL;
+	return em_junk_sa_is_available (NULL) ? (gpointer) "1" : NULL;
 }
 
 static void
-em_junk_sa_setting_notify(GConfClient *gconf, guint cnxn_id, GConfEntry *entry, void *data)
+em_junk_sa_setting_notify(GConfClient *gconf, guint cnxn_id, GConfEntry *entry, gpointer data)
 {
 	GConfValue *value;
-	char *tkey;
+	gchar *tkey;
 
 	g_return_if_fail (gconf_entry_get_key (entry) != NULL);
 
@@ -809,8 +815,8 @@ em_junk_sa_setting_notify(GConfClient *gconf, guint cnxn_id, GConfEntry *entry,
 	}
 }
 
-int
-e_plugin_lib_enable (EPluginLib *ep, int enable)
+gint
+e_plugin_lib_enable (EPluginLib *ep, gint enable)
 {
 	em_junk_sa_init();
 
@@ -856,15 +862,15 @@ em_junk_sa_kill_spamd (void)
 	pthread_mutex_unlock (&em_junk_sa_preferred_socket_path_lock);
 
 	if (em_junk_sa_new_daemon_started) {
-		int fd = open (em_junk_sa_spamd_pidfile, O_RDONLY);
+		gint fd = open (em_junk_sa_spamd_pidfile, O_RDONLY);
 
 		if (fd != -1) {
-			char pid_str [16];
-			int bytes;
+			gchar pid_str [16];
+			gint bytes;
 
 			bytes = read (fd, pid_str, 15);
 			if (bytes > 0) {
-				int pid;
+				gint pid;
 
 				pid_str [bytes] = 0;
 				pid = atoi (pid_str);
@@ -894,14 +900,14 @@ static void
 use_remote_tests_cb (GtkWidget *widget, gpointer data)
 {
 	gboolean active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-   	gconf_client_set_bool (em_junk_sa_gconf, data, !active, NULL);
+	gconf_client_set_bool (em_junk_sa_gconf, data, !active, NULL);
 }
 
 GtkWidget *
 org_gnome_sa_use_remote_tests (struct _EPlugin *epl, struct _EConfigHookItemFactoryData *data)
 {
-   	GtkWidget *check, *vbox, *label;
-	char *text = g_strdup_printf ("    <small>%s</small>", _("This will make SpamAssassin more reliable, but slower"));
+	GtkWidget *check, *vbox, *label;
+	gchar *text = g_strdup_printf ("    <small>%s</small>", _("This will make SpamAssassin more reliable, but slower"));
 	guint i = ((GtkTable *)data->parent)->nrows;
 
 	if (data->old)
@@ -916,7 +922,7 @@ org_gnome_sa_use_remote_tests (struct _EPlugin *epl, struct _EConfigHookItemFact
 	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, 0);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), !em_junk_sa_local_only);
-	g_signal_connect (GTK_TOGGLE_BUTTON (check), "toggled", G_CALLBACK (use_remote_tests_cb), "/apps/evolution/mail/junk/sa/local_only");
+	g_signal_connect (GTK_TOGGLE_BUTTON (check), "toggled", G_CALLBACK (use_remote_tests_cb), (gpointer) "/apps/evolution/mail/junk/sa/local_only");
 	gtk_table_attach((GtkTable *)data->parent, vbox, 0, 1, i, i+1, 0, 0, 0, 0);
 	gtk_widget_show_all (vbox);
 	return (GtkWidget *)vbox;
