@@ -1,24 +1,24 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-shell-settings-dialog.h
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+/*
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Ettore Perazzoli <ettore@ximian.com>
  */
 
 #ifndef _E_SHELL_SETTINGS_DIALOG_H_
@@ -56,7 +56,7 @@ struct _EShellSettingsDialogClass {
 GType      e_shell_settings_dialog_get_type  (void);
 GtkWidget *e_shell_settings_dialog_new       (void);
 void       e_shell_settings_dialog_show_type (EShellSettingsDialog *dialog,
-					      const char           *type);
+					      const gchar           *type);
 
 #ifdef __cplusplus
 }
