@@ -10,11 +10,11 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
- *		Ettore Perazzoli <ettore@ximian.com> 
+ *		Ettore Perazzoli <ettore@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
@@ -95,7 +95,7 @@ typedef enum _EShellConstructResult EShellConstructResult;
 
 GType                  e_shell_get_type   (void);
 EShellConstructResult  e_shell_construct  (EShell                *shell,
-					   const char            *iid,
+					   const gchar            *iid,
 					   EShellStartupLineMode  startup_line_mode);
 EShell                *e_shell_new        (EShellStartupLineMode  startup_line_mode,
 					   EShellConstructResult *construct_result_return);
@@ -103,7 +103,7 @@ EShell                *e_shell_new        (EShellStartupLineMode  startup_line_m
 gboolean  e_shell_attempt_upgrade  (EShell     *shell);
 
 EShellWindow *e_shell_create_window         (EShell       *shell,
-					     const char   *component_id,
+					     const gchar   *component_id,
 					     EShellWindow *template_window);
 gboolean      e_shell_request_close_window  (EShell       *shell,
 					     EShellWindow *window);
@@ -119,10 +119,8 @@ gboolean            e_shell_save_settings            (EShell *shell);
 void                e_shell_close_all_windows        (EShell *shell);
 
 EShellLineStatus  e_shell_get_line_status  (EShell       *shell);
-void              e_shell_go_offline       (EShell       *shell,
-					    EShellWindow *action_window, GNOME_Evolution_ShellState shell_state);
-void              e_shell_go_online        (EShell       *shell,
-					    EShellWindow *action_window, GNOME_Evolution_ShellState shell_state);
+void              e_shell_set_line_status  (EShell       *shell,
+                                            GNOME_Evolution_ShellState shell_state);
 
 gboolean	e_shell_get_crash_recovery	(EShell *shell);
 void		e_shell_set_crash_recovery	(EShell *shell,
@@ -131,14 +129,14 @@ void		e_shell_set_crash_recovery	(EShell *shell,
 void  e_shell_send_receive  (EShell *shell);
 
 void  e_shell_show_settings  (EShell       *shell,
-			      const char   *type,
+			      const gchar   *type,
 			      EShellWindow *shell_window);
 
 gboolean e_shell_can_quit (EShell *shell);
 gboolean e_shell_do_quit  (EShell *shell);
 gboolean e_shell_quit     (EShell *shell);
 
-const char *e_shell_construct_result_to_string (EShellConstructResult result);
+const gchar *e_shell_construct_result_to_string (EShellConstructResult result);
 
 typedef gboolean (*EMainShellFunc) (EShell *shell, EShellWindow *window, gpointer user_data);
 void e_shell_foreach_shell_window (EShell *shell, EMainShellFunc func, gpointer user_data);
