@@ -1,23 +1,23 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-sidebar.c
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Ettore Perazzoli <ettore@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,10 +26,9 @@
 
 #include "e-sidebar.h"
 
-#include "e-shell-marshal.h"
+#include "e-util/e-util.h"
 
 #include <gconf/gconf-client.h>
-#include <libgnome/gnome-gconf.h>
 
 typedef struct {
 	GtkWidget *button_widget;
@@ -37,7 +36,7 @@ typedef struct {
 	GtkWidget *icon;
 	GtkWidget *hbox;
 	gchar *default_icon_name;
-	int id;
+	gint id;
 } Button;
 
 struct _ESidebarPrivate {
@@ -61,7 +60,7 @@ enum {
 	NUM_SIGNALS
 };
 
-static unsigned int signals[NUM_SIGNALS] = { 0 };
+static guint signals[NUM_SIGNALS] = { 0 };
 
 G_DEFINE_TYPE (ESidebar, e_sidebar, GTK_TYPE_CONTAINER)
 
@@ -76,7 +75,7 @@ button_new (GtkWidget *button_widget,
 	    GtkWidget *label,
 	    GtkWidget *icon,
 	    GtkWidget *hbox,
-	    int        id)
+	    gint        id)
 {
 	Button *button = g_new (Button, 1);
 	const gchar *icon_name;
@@ -110,7 +109,7 @@ button_free (Button *button)
 }
 
 static void
-update_buttons (ESidebar *sidebar, int new_selected_id)
+update_buttons (ESidebar *sidebar, gint new_selected_id)
 {
 	GSList *p;
 
@@ -135,7 +134,7 @@ static void
 button_toggled_callback (GtkToggleButton *toggle_button,
 			 ESidebar *sidebar)
 {
-	int id = 0;
+	gint id = 0;
 	gboolean is_active = FALSE;
 	GSList *p;
 
@@ -193,7 +192,7 @@ button_query_tooltip (GtkWidget  *widget,
 {
 	/* Show the tooltip only if the label is hidden */
 	if (INTERNAL_MODE (sidebar) == E_SIDEBAR_MODE_ICON) {
-		char *tip;
+		gchar *tip;
 
 		tip = g_object_get_data (G_OBJECT (widget),
 					 "ESidebar:button-tooltip");
@@ -210,20 +209,20 @@ button_query_tooltip (GtkWidget  *widget,
 
 /* Layout. */
 
-static int
+static gint
 layout_buttons (ESidebar *sidebar)
 {
 	GtkAllocation *allocation = & GTK_WIDGET (sidebar)->allocation;
 	ESidebarMode mode;
 	gboolean icons_only;
-	int num_btns = g_slist_length (sidebar->priv->buttons), btns_per_row;
+	gint num_btns = g_slist_length (sidebar->priv->buttons), btns_per_row;
 	GSList **rows, *p;
 	Button *button;
-	int row_number;
-	int max_btn_width = 0, max_btn_height = 0;
-	int row_last;
-	int x, y;
-	int i;
+	gint row_number;
+	gint max_btn_width = 0, max_btn_height = 0;
+	gint row_last;
+	gint x, y;
+	gint i;
 
 	y = allocation->y + allocation->height - V_PADDING - 1;
 
@@ -282,7 +281,7 @@ layout_buttons (ESidebar *sidebar)
 
 	/* Layout the buttons. */
 	for (i = row_last; i >= 0; i --) {
-		int len, extra_width;
+		gint len, extra_width;
 
 		y -= max_btn_height;
 		x = H_PADDING + allocation->x;
@@ -319,7 +318,7 @@ do_layout (ESidebar *sidebar)
 {
 	GtkAllocation *allocation = & GTK_WIDGET (sidebar)->allocation;
 	GtkAllocation child_allocation;
-	int y;
+	gint y;
 
 	if (sidebar->priv->show)
 		y = layout_buttons (sidebar);
@@ -342,7 +341,7 @@ static void
 impl_forall (GtkContainer *container,
 	     gboolean include_internals,
 	     GtkCallback callback,
-	     void *callback_data)
+	     gpointer callback_data)
 {
 	ESidebar *sidebar = E_SIDEBAR (container);
 	GSList *p;
@@ -438,7 +437,7 @@ impl_dispose (GObject *object)
 		priv->style_changed_id = 0;
 	}
 
- 	g_object_unref (gconf_client);
+	g_object_unref (gconf_client);
 
 	(* G_OBJECT_CLASS (e_sidebar_parent_class)->dispose) (object);
 }
@@ -501,7 +500,7 @@ e_sidebar_class_init (ESidebarClass *klass)
 				G_SIGNAL_RUN_LAST,
 				G_STRUCT_OFFSET (ESidebarClass, button_pressed),
 				boolean_handled_accumulator, NULL,
-				e_shell_marshal_NONE__POINTER_INT,
+				e_marshal_NONE__POINTER_INT,
 				G_TYPE_BOOLEAN, 2,
 				G_TYPE_POINTER, G_TYPE_INT);
 }
@@ -545,10 +544,10 @@ e_sidebar_set_selection_widget (ESidebar *sidebar, GtkWidget *widget)
 
 void
 e_sidebar_add_button (ESidebar *sidebar,
-		      const char *label,
-		      const char *tooltips,
-		      const char *icon_name,
-		      int id)
+		      const gchar *label,
+		      const gchar *tooltips,
+		      const gchar *icon_name,
+		      gint id)
 {
 	GtkWidget *button_widget;
 	GtkWidget *hbox;
@@ -559,8 +558,8 @@ e_sidebar_add_button (ESidebar *sidebar,
 	if (sidebar->priv->show)
 		gtk_widget_show (button_widget);
 	g_signal_connect (button_widget, "toggled", G_CALLBACK (button_toggled_callback), sidebar);
- 	g_signal_connect (button_widget, "button_press_event",
- 			  G_CALLBACK (button_pressed_callback), sidebar);
+	g_signal_connect (button_widget, "button_press_event",
+			  G_CALLBACK (button_pressed_callback), sidebar);
 
 	hbox = gtk_hbox_new (FALSE, 3);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);
@@ -614,7 +613,7 @@ e_sidebar_add_button (ESidebar *sidebar,
  * You cannot change icon as in a stack, only one default icon will be stored.
  **/
 void
-e_sidebar_change_button_icon (ESidebar *sidebar, const gchar *icon_name, int button_id)
+e_sidebar_change_button_icon (ESidebar *sidebar, const gchar *icon_name, gint button_id)
 {
 	GSList *p;
 
@@ -640,7 +639,7 @@ e_sidebar_change_button_icon (ESidebar *sidebar, const gchar *icon_name, int but
 }
 
 void
-e_sidebar_select_button (ESidebar *sidebar, int id)
+e_sidebar_select_button (ESidebar *sidebar, gint id)
 {
 	update_buttons (sidebar, id);
 
@@ -660,7 +659,7 @@ static GConfEnumStringPair toolbar_styles[] = {
          { E_SIDEBAR_MODE_BOTH, "both" },
          { E_SIDEBAR_MODE_BOTH, "both-horiz" },
          { E_SIDEBAR_MODE_BOTH, "both_horiz" },
- 	{ -1, NULL }
+	{ -1, NULL }
 };
 
 static void
@@ -713,18 +712,18 @@ set_mode_internal (ESidebar *sidebar, ESidebarMode mode )
 }
 
 static void
-style_changed_notify (GConfClient *gconf, guint id, GConfEntry *entry, void *data)
+style_changed_notify (GConfClient *gconf, guint id, GConfEntry *entry, gpointer data)
 {
 	ESidebar *sidebar = data;
- 	char *val;
- 	int mode;
+	gchar *val;
+	gint mode;
 
 	val = gconf_client_get_string (gconf, "/desktop/gnome/interface/toolbar_style", NULL);
 	if (val == NULL || !gconf_string_to_enum (toolbar_styles, val, &mode))
 		mode = E_SIDEBAR_MODE_BOTH;
 	g_free(val);
 
- 	set_mode_internal (E_SIDEBAR (sidebar), mode);
+	set_mode_internal (E_SIDEBAR (sidebar), mode);
 	sidebar->priv->toolbar_mode = mode;
 
 	gtk_widget_queue_resize (GTK_WIDGET (sidebar));
