@@ -1,22 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+/*
  *
- *  Authors: Michel Zucchi <notzed@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Michel Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -38,13 +39,13 @@ typedef struct _ESMenuClass ESMenuClass;
 /* Current target description */
 /* Types of popup tagets */
 enum _es_menu_target_t {
-	ES_MENU_TARGET_SHELL,
+	ES_MENU_TARGET_SHELL
 };
 
 /* Flags that describe a TARGET_SHELL */
 enum {
 	ES_MENU_SHELL_ONLINE = 1<<0,
-	ES_MENU_SHELL_OFFLINE = 1<<1,
+	ES_MENU_SHELL_OFFLINE = 1<<1
 };
 
 typedef struct _ESMenuTargetShell ESMenuTargetShell;
@@ -70,7 +71,7 @@ struct _ESMenuClass {
 
 GType es_menu_get_type(void);
 
-ESMenu *es_menu_new(const char *menuid);
+ESMenu *es_menu_new(const gchar *menuid);
 
 ESMenuTargetShell *es_menu_target_new_shell(ESMenu *emp, guint32 flags);
 
