@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -31,10 +31,10 @@ extern "C" {
 #endif /* __cplusplus */
 
 typedef struct _EPixmap {
-	const char *path;
-	const char *name;
-	gint       size;
-	char       *pixbuf;
+	const gchar *path;
+	const gchar *name;
+	GtkIconSize size;
+	gchar       *pixbuf;
 } EPixmap;
 
 #define E_PIXMAP(path,name,size)	{ (path), (name), (size), NULL }
@@ -43,7 +43,7 @@ typedef struct _EPixmap {
 /* Takes an array of pixmaps, terminated by E_PIXMAP_END, and loads into uic */
 void e_pixmaps_update (BonoboUIComponent *uic, EPixmap *pixcache);
 
-char *e_get_activation_failure_msg  (CORBA_Environment *ev);
+gchar *e_get_activation_failure_msg  (CORBA_Environment *ev);
 
 #ifdef __cplusplus
 }
