@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -75,8 +75,8 @@ ca_trust_dialog_show (ECert *cert, gboolean importing)
 {
 	CATrustDialogData *ctd_data;
 	GtkWidget *w;
-	char *txt;
-	char *gladefile;
+	gchar *txt;
+	gchar *gladefile;
 
 	ctd_data = g_new0 (CATrustDialogData, 1);
 
