@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -93,7 +93,7 @@ static void add_ca_cert (CertificateManagerData *cfm, ECert *cert);
 
 static void
 handle_selection_changed (GtkTreeSelection *selection,
-			  int cert_column,
+			  gint cert_column,
 			  GtkWidget *view_button,
 			  GtkWidget *edit_button,
 			  GtkWidget *delete_button)
@@ -130,7 +130,6 @@ static void
 import_your (GtkWidget *widget, CertificateManagerData *cfm)
 {
 	GtkWidget *filesel;
-	const char *filename;
 
 	GtkFileFilter* filter;
 
@@ -144,6 +143,7 @@ import_your (GtkWidget *widget, CertificateManagerData *cfm)
 
 	filter = gtk_file_filter_new();
 	gtk_file_filter_set_name (filter, _("All PKCS12 files"));
+	gtk_file_filter_add_mime_type (filter, "application/x-x509-user-cert");
 	gtk_file_filter_add_mime_type (filter, "application/x-pkcs12");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filesel), filter);
 
@@ -153,7 +153,10 @@ import_your (GtkWidget *widget, CertificateManagerData *cfm)
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filesel), filter);
 
 	if (GTK_RESPONSE_OK == gtk_dialog_run (GTK_DIALOG (filesel))) {
-		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
+		gchar *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
+
+		/* destroy dialog to get rid of it in the GUI */
+		gtk_widget_destroy (filesel);
 
 		if (e_cert_db_import_pkcs12_file (e_cert_db_peek (),
 						  filename, NULL /* XXX */)) {
@@ -163,9 +166,10 @@ import_your (GtkWidget *widget, CertificateManagerData *cfm)
 			load_certs (cfm, E_CERT_USER, add_user_cert);
 			gtk_tree_view_expand_all (GTK_TREE_VIEW (cfm->yourcerts_treeview));
 		}
-	}
 
-	gtk_widget_destroy (filesel);
+		g_free (filename);
+	} else
+		gtk_widget_destroy (filesel);
 }
 
 static void
@@ -373,7 +377,6 @@ static void
 import_contact (GtkWidget *widget, CertificateManagerData *cfm)
 {
 	GtkWidget *filesel;
-	const char *filename;
 
 	GtkFileFilter *filter;
 
@@ -388,6 +391,7 @@ import_contact (GtkWidget *widget, CertificateManagerData *cfm)
 	filter = gtk_file_filter_new();
 	gtk_file_filter_set_name (filter, _("All email certificate files"));
 	gtk_file_filter_add_mime_type (filter, "application/x-x509-email-cert");
+	gtk_file_filter_add_mime_type (filter, "application/x-x509-ca-cert");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filesel), filter);
 
 	filter = gtk_file_filter_new ();
@@ -396,7 +400,10 @@ import_contact (GtkWidget *widget, CertificateManagerData *cfm)
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filesel), filter);
 
 	if (GTK_RESPONSE_OK == gtk_dialog_run (GTK_DIALOG (filesel))) {
-		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
+		gchar *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
+
+		/* destroy dialog to get rid of it in the GUI */
+		gtk_widget_destroy (filesel);
 
 		if (e_cert_db_import_certs_from_file (e_cert_db_peek (),
 						      filename,
@@ -409,9 +416,10 @@ import_contact (GtkWidget *widget, CertificateManagerData *cfm)
 			load_certs (cfm, E_CERT_CONTACT, add_contact_cert);
 			gtk_tree_view_expand_all (GTK_TREE_VIEW (cfm->contactcerts_treeview));
 		}
-	}
 
-	gtk_widget_destroy (filesel);
+		g_free (filename);
+	} else
+		gtk_widget_destroy (filesel);
 }
 
 static void
@@ -597,7 +605,6 @@ static void
 import_ca (GtkWidget *widget, CertificateManagerData *cfm)
 {
 	GtkWidget *filesel;
-	const char *filename;
 
 	GtkFileFilter *filter;
 
@@ -620,7 +627,10 @@ import_ca (GtkWidget *widget, CertificateManagerData *cfm)
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filesel), filter);
 
 	if (GTK_RESPONSE_OK == gtk_dialog_run (GTK_DIALOG (filesel))) {
-		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
+		gchar *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
+
+		/* destroy dialog to get rid of it in the GUI */
+		gtk_widget_destroy (filesel);
 
 		if (e_cert_db_import_certs_from_file (e_cert_db_peek (),
 						      filename,
@@ -632,9 +642,10 @@ import_ca (GtkWidget *widget, CertificateManagerData *cfm)
 			unload_certs (cfm, E_CERT_CA);
 			load_certs (cfm, E_CERT_CA, add_ca_cert);
 		}
-	}
 
-	gtk_widget_destroy (filesel);
+		g_free (filename);
+	} else
+		gtk_widget_destroy (filesel);
 }
 
 static void
@@ -728,7 +739,7 @@ add_user_cert (CertificateManagerData *cfm, ECert *cert)
 {
 	GtkTreeIter iter;
 	GtkTreeIter *parent_iter = NULL;
-	const char *organization = e_cert_get_org (cert);
+	const gchar *organization = e_cert_get_org (cert);
 	GtkTreeModel *model = gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT (cfm->yourcerts_streemodel));
 
 	if (organization) {
@@ -772,7 +783,7 @@ add_contact_cert (CertificateManagerData *cfm, ECert *cert)
 {
 	GtkTreeIter iter;
 	GtkTreeIter *parent_iter = NULL;
-	const char *organization = e_cert_get_org (cert);
+	const gchar *organization = e_cert_get_org (cert);
 	GtkTreeModel *model = gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT (cfm->contactcerts_streemodel));
 
 	if (organization) {
@@ -814,7 +825,7 @@ add_ca_cert (CertificateManagerData *cfm, ECert *cert)
 {
 	GtkTreeIter iter;
 	GtkTreeIter *parent_iter = NULL;
-	const char *organization = e_cert_get_org (cert);
+	const gchar *organization = e_cert_get_org (cert);
 	GtkTreeModel *model = gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT (cfm->authoritycerts_streemodel));
 
 	if (organization) {
@@ -952,7 +963,10 @@ load_certs (CertificateManagerData *cfm,
 	     !CERT_LIST_END(node, certList);
 	     node = CERT_LIST_NEXT(node)) {
 		ECert *cert = e_cert_new ((CERTCertificate*)node->cert);
-		if (e_cert_get_cert_type(cert) == type) {
+		ECertType ct = e_cert_get_cert_type (cert);
+
+		/* show everything else in a contact tab */
+		if (ct == type || (type == E_CERT_CONTACT && ct != E_CERT_CA && ct != E_CERT_USER)) {
 			add_cert (cfm, cert);
 		}
 	}
@@ -980,7 +994,7 @@ certificate_manager_config_control_new (void)
 {
 	CertificateManagerData *cfm_data;
 	GtkWidget *control_widget;
-	char *gladefile;
+	gchar *gladefile;
 
 	/* We need to peek the db here to make sure it (and NSS) are fully initialized. */
 	e_cert_db_peek ();
