@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -24,6 +24,7 @@
 #include <config.h>
 #endif
 
+#include <time.h>
 #include <string.h>
 #include <glib/gi18n.h>
 #include <glade/glade.h>
@@ -75,14 +76,6 @@ struct _ETimezoneDialogPrivate {
 	GtkWidget *preview_label;
 };
 
-#ifndef G_OS_WIN32 /* Declared properly in time.h already */
-extern char *tzname[2];
-extern long timezone;
-extern int daylight;
-#endif
-
-static void e_timezone_dialog_class_init	(ETimezoneDialogClass *class);
-static void e_timezone_dialog_init		(ETimezoneDialog      *etd);
 static void e_timezone_dialog_dispose		(GObject	*object);
 static void e_timezone_dialog_finalize		(GObject	*object);
 
@@ -108,10 +101,10 @@ static void	set_map_timezone		(ETimezoneDialog *etd,
 static void	on_combo_changed		(GtkComboBox	*combo,
 						 ETimezoneDialog *etd);
 
-static void timezone_combo_get_active_text 	(GtkComboBox *combo, 
-						 const char **zone_name);
-static gboolean timezone_combo_set_active_text 	(GtkComboBox *combo, 
-						 const char *zone_name);
+static void timezone_combo_get_active_text	(GtkComboBox *combo,
+						 const gchar **zone_name);
+static gboolean timezone_combo_set_active_text	(GtkComboBox *combo,
+						 const gchar *zone_name);
 
 static void	map_destroy_cb			(gpointer data,
 						 GObject *where_object_was);
@@ -205,7 +198,7 @@ e_timezone_dialog_add_timezones (ETimezoneDialog *etd)
 	GtkTreeIter iter;
 	GtkCellRenderer *cell;
 	GHashTable *index;
-	int i;
+	gint i;
 
 	priv = etd->priv;
 
@@ -330,12 +323,12 @@ e_timezone_dialog_construct (ETimezoneDialog *etd)
 }
 
 #if 0
-static int
+static gint
 get_local_offset (void)
 {
 	time_t now = time(NULL), t_gmt, t_local;
 	struct tm gmt, local;
-	int diff;
+	gint diff;
 
 	gmtime_r (&now, &gmt);
 	localtime_r (&now, &local);
@@ -403,11 +396,11 @@ e_timezone_dialog_new (void)
 }
 
 static void
-format_utc_offset			(int		 utc_offset,
-					 char		*buffer)
+format_utc_offset			(gint		 utc_offset,
+					 gchar		*buffer)
 {
-  char *sign = "+";
-  int hours, minutes, seconds;
+  const gchar *sign = "+";
+  gint hours, minutes, seconds;
 
   if (utc_offset < 0) {
     utc_offset = -utc_offset;
@@ -436,14 +429,14 @@ format_utc_offset			(int		 utc_offset,
 }
 
 
-static char *
+static gchar *
 zone_display_name_with_offset (icaltimezone *zone)
 {
-	const char *display_name;
+	const gchar *display_name;
 	struct tm local;
 	struct icaltimetype tt;
-	int offset;
-	char buffer [100];
+	gint offset;
+	gchar buffer [100];
 	time_t now = time(NULL);
 
 	gmtime_r ((const time_t *) &now, &local);
@@ -459,10 +452,10 @@ zone_display_name_with_offset (icaltimezone *zone)
 	return g_strdup_printf("%s (%s)\n", display_name, buffer);;
 }
 
-static const char *
+static const gchar *
 zone_display_name (icaltimezone *zone)
 {
-	const char *display_name;
+	const gchar *display_name;
 
 	display_name = icaltimezone_get_display_name (zone);
 	if (icaltimezone_get_builtin_timezone (display_name))
@@ -486,10 +479,10 @@ on_map_timeout (gpointer data)
 
         if (e_map_point_get_color_rgba (priv->point_selected)
 	    == E_TIMEZONE_DIALOG_MAP_POINT_SELECTED_1_RGBA)
-	        e_map_point_set_color_rgba (priv->map, priv->point_selected,
+		e_map_point_set_color_rgba (priv->map, priv->point_selected,
 					    E_TIMEZONE_DIALOG_MAP_POINT_SELECTED_2_RGBA);
 	else
-	        e_map_point_set_color_rgba (priv->map, priv->point_selected,
+		e_map_point_set_color_rgba (priv->map, priv->point_selected,
 					    E_TIMEZONE_DIALOG_MAP_POINT_SELECTED_1_RGBA);
 
 	return TRUE;
@@ -503,7 +496,7 @@ on_map_motion (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 	ETimezoneDialogPrivate *priv;
 	double longitude, latitude;
 	icaltimezone *new_zone;
-	char *display=NULL;
+	gchar *display=NULL;
 
 	etd = E_TIMEZONE_DIALOG (data);
 	priv = etd->priv;
@@ -512,14 +505,14 @@ on_map_motion (GtkWidget *widget, GdkEventMotion *event, gpointer data)
 			       &longitude, &latitude);
 
 	if (priv->point_hover && priv->point_hover != priv->point_selected)
-	        e_map_point_set_color_rgba (priv->map, priv->point_hover,
+		e_map_point_set_color_rgba (priv->map, priv->point_hover,
 					    E_TIMEZONE_DIALOG_MAP_POINT_NORMAL_RGBA);
 
 	priv->point_hover = e_map_get_closest_point (priv->map, longitude,
 						     latitude, TRUE);
 
 	if (priv->point_hover != priv->point_selected)
-	        e_map_point_set_color_rgba (priv->map, priv->point_hover,
+		e_map_point_set_color_rgba (priv->map, priv->point_hover,
 					    E_TIMEZONE_DIALOG_MAP_POINT_HOVER_RGBA);
 
 	new_zone = get_zone_from_point (etd, priv->point_hover);
@@ -549,7 +542,7 @@ on_map_leave (GtkWidget *widget, GdkEventCrossing *event, gpointer data)
 		return FALSE;
 
 	if (priv->point_hover && priv->point_hover != priv->point_selected)
-	        e_map_point_set_color_rgba (priv->map, priv->point_hover,
+		e_map_point_set_color_rgba (priv->map, priv->point_hover,
 					    E_TIMEZONE_DIALOG_MAP_POINT_NORMAL_RGBA);
 
 	timezone_combo_set_active_text (GTK_COMBO_BOX (priv->timezone_combo),
@@ -603,14 +596,14 @@ on_map_button_pressed (GtkWidget *w, GdkEventButton *event, gpointer data)
 			       &longitude, &latitude);
 
 	if (event->button != 1) {
-	        e_map_zoom_out (priv->map);
+		e_map_zoom_out (priv->map);
 	} else {
 		if (e_map_get_magnification (priv->map) <= 1.0)
-		        e_map_zoom_to_location (priv->map, longitude,
+			e_map_zoom_to_location (priv->map, longitude,
 						latitude);
 
 		if (priv->point_selected)
-		        e_map_point_set_color_rgba (priv->map,
+			e_map_point_set_color_rgba (priv->map,
 						    priv->point_selected,
 						    E_TIMEZONE_DIALOG_MAP_POINT_NORMAL_RGBA);
 		priv->point_selected = priv->point_hover;
@@ -632,7 +625,7 @@ get_zone_from_point (ETimezoneDialog *etd,
 {
 	icalarray *zones;
 	double longitude, latitude;
-	int i;
+	gint i;
 
 	if (point == NULL)
 		return NULL;
@@ -697,11 +690,11 @@ e_timezone_dialog_set_timezone (ETimezoneDialog *etd,
 				icaltimezone    *zone)
 {
 	ETimezoneDialogPrivate *priv;
-	char *display = NULL;
+	gchar *display = NULL;
 
 	g_return_if_fail (E_IS_TIMEZONE_DIALOG (etd));
 
- 	if (!zone) {
+	if (!zone) {
 		zone = (icaltimezone *)get_local_timezone();
 		if (!zone)
 			zone = icaltimezone_get_utc_timezone();
@@ -769,11 +762,11 @@ static void
 on_combo_changed (GtkComboBox *combo_box, ETimezoneDialog *etd)
 {
 	ETimezoneDialogPrivate *priv;
-	const char *new_zone_name;
+	const gchar *new_zone_name;
 	icalarray *zones;
 	icaltimezone *map_zone = NULL;
-	char *location;
-	int i;
+	gchar *location;
+	gint i;
 
 	priv = etd->priv;
 
@@ -800,8 +793,8 @@ on_combo_changed (GtkComboBox *combo_box, ETimezoneDialog *etd)
 	set_map_timezone (etd, map_zone);
 }
 
-static void 
-timezone_combo_get_active_text (GtkComboBox *combo, const char **zone_name)
+static void
+timezone_combo_get_active_text (GtkComboBox *combo, const gchar **zone_name)
 {
 	GtkTreeModel *list_store;
 	GtkTreeIter iter;
@@ -809,14 +802,14 @@ timezone_combo_get_active_text (GtkComboBox *combo, const char **zone_name)
 	list_store = gtk_combo_box_get_model (combo);
 
 	/* Get the active iter in the list */
-	if (gtk_combo_box_get_active_iter (combo, &iter)) 
+	if (gtk_combo_box_get_active_iter (combo, &iter))
 		gtk_tree_model_get (list_store, &iter, 0, zone_name, -1);
-	else 
+	else
 		*zone_name = "";
 }
 
-static gboolean 
-timezone_combo_set_active_text (GtkComboBox *combo, const char *zone_name)
+static gboolean
+timezone_combo_set_active_text (GtkComboBox *combo, const gchar *zone_name)
 {
 	GtkTreeModel *list_store;
 	GHashTable *index;
@@ -825,7 +818,7 @@ timezone_combo_set_active_text (GtkComboBox *combo, const char *zone_name)
 	list_store = gtk_combo_box_get_model (combo);
 	index = (GHashTable *) g_object_get_data (G_OBJECT (list_store), "index");
 
-	if (zone_name && *zone_name) 
+	if (zone_name && *zone_name)
 		id = g_hash_table_lookup (index, zone_name);
 
 	gtk_combo_box_set_active (combo, GPOINTER_TO_INT (id));
