@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -32,8 +32,6 @@
 #include "gal-define-views-model.h"
 #include "gal-view-new-dialog.h"
 
-static void gal_view_new_dialog_init		(GalViewNewDialog		 *card);
-static void gal_view_new_dialog_class_init	(GalViewNewDialogClass	 *klass);
 static void gal_view_new_dialog_set_property	(GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
 static void gal_view_new_dialog_get_property	(GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void gal_view_new_dialog_dispose		(GObject *object);
@@ -134,7 +132,7 @@ static void
 sensitize_ok_response (GalViewNewDialog *dialog)
 {
 	gboolean ok = TRUE;
-	const char *text;
+	const gchar *text;
 
 	text = gtk_entry_get_text (GTK_ENTRY (dialog->entry));
 	if (!text || !text[0])
@@ -208,7 +206,7 @@ gal_view_new_dialog_construct (GalViewNewDialog  *dialog,
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dialog->list), column);
 
 	iterator = dialog->collection->factory_list;
-	for ( ; iterator; iterator = g_list_next(iterator) ) {
+	for (; iterator; iterator = g_list_next(iterator) ) {
 		GalViewFactory *factory = iterator->data;
 		GtkTreeIter iter;
 
