@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
@@ -30,6 +30,7 @@
 #include "e-util/e-util.h"
 #include "e-attachment-dialog.h"
 #include "e-attachment-handler-image.h"
+#include "e-attachment-handler-sendto.h"
 
 enum {
 	UPDATE_ACTIONS,
@@ -38,9 +39,9 @@ enum {
 
 /* Note: Do not use the info field. */
 static GtkTargetEntry target_table[] = {
-	{ "_NETSCAPE_URL",	0, 0 },
-	{ "text/x-vcard",	0, 0 },
-	{ "text/calendar",	0, 0 }
+	{ (gchar *) "_NETSCAPE_URL",	0, 0 },
+	{ (gchar *) "text/x-vcard",	0, 0 },
+	{ (gchar *) "text/calendar",	0, 0 }
 };
 
 static const gchar *ui =
@@ -430,7 +431,7 @@ attachment_view_text_calendar (EAttachmentView *view,
 	gchar *content_type;
 	gint length;
 
-	if (G_UNLIKELY (atom = GDK_NONE))
+	if (G_UNLIKELY (atom == GDK_NONE))
 		atom = gdk_atom_intern_static_string ("text/calendar");
 
 	if (gtk_selection_data_get_target (selection_data) != atom)
@@ -486,7 +487,7 @@ attachment_view_text_x_vcard (EAttachmentView *view,
 	gchar *content_type;
 	gint length;
 
-	if (G_UNLIKELY (atom = GDK_NONE))
+	if (G_UNLIKELY (atom == GDK_NONE))
 		atom = gdk_atom_intern_static_string ("text/x-vcard");
 
 	if (gtk_selection_data_get_target (selection_data) != atom)
@@ -634,15 +635,12 @@ attachment_view_update_actions (EAttachmentView *view)
 		gchar *action_label;
 		gchar *action_name;
 
-		if (!g_app_info_should_show (app_info))
-			continue;
-
 		app_executable = g_app_info_get_executable (app_info);
 		app_icon = g_app_info_get_icon (app_info);
 		app_name = g_app_info_get_name (app_info);
 
 		action_name = g_strdup_printf ("open-in-%s", app_executable);
-		action_label = g_strdup_printf (_("Open in %s..."), app_name);
+		action_label = g_strdup_printf (_("Open with \"%s\""), app_name);
 
 		action_tooltip = g_strdup_printf (
 			_("Open this attachment in %s"), app_name);
@@ -774,6 +772,7 @@ e_attachment_view_get_type (void)
 
 		/* Register known handler types. */
 		e_attachment_handler_image_get_type ();
+		e_attachment_handler_sendto_get_type ();
 	}
 
 	return type;
@@ -1036,6 +1035,12 @@ e_attachment_view_remove_selected (EAttachmentView *view,
 	store = e_attachment_view_get_store (view);
 	model = GTK_TREE_MODEL (store);
 
+	/* Remove attachments in reverse order to avoid invalidating
+	 * tree paths as we iterate over the list.  Note, the list is
+	 * probably already sorted but we sort again just to be safe. */
+	selected = g_list_reverse (g_list_sort (
+		selected, (GCompareFunc) gtk_tree_path_compare));
+
 	for (item = selected; item != NULL; item = item->next) {
 		EAttachment *attachment;
 		GtkTreePath *path = item->data;
