@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  * Authors:
  *		Damon Chaplin <damon@ximian.com>
@@ -36,7 +36,7 @@
 #include <libedataserver/e-data-server-util.h>
 #include <e-util/e-util.h>
 
-static const int e_calendar_item_days_in_month[12] = {
+static const gint e_calendar_item_days_in_month[12] = {
 	31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
 };
 
@@ -60,37 +60,37 @@ static void e_calendar_item_unmap	(GnomeCanvasItem *item);
 static void e_calendar_item_update	(GnomeCanvasItem *item,
 					 double		 *affine,
 					 ArtSVP		 *clip_path,
-					 int		  flags);
+					 gint		  flags);
 static void e_calendar_item_draw	(GnomeCanvasItem *item,
 					 GdkDrawable	 *drawable,
-					 int		  x,
-					 int		  y,
-					 int		  width,
-					 int		  height);
+					 gint		  x,
+					 gint		  y,
+					 gint		  width,
+					 gint		  height);
 static void e_calendar_item_draw_month	(ECalendarItem   *calitem,
 					 GdkDrawable	 *drawable,
-					 int		  x,
-					 int		  y,
-					 int		  width,
-					 int		  height,
-					 int		  row,
-					 int		  col);
+					 gint		  x,
+					 gint		  y,
+					 gint		  width,
+					 gint		  height,
+					 gint		  row,
+					 gint		  col);
 static void e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 					      GdkDrawable	*drawable,
-					      int		 width,
-					      int		 height,
-					      int		 row,
-					      int		 col,
-					      int		 year,
-					      int		 month,
-					      int		 start_weekday,
+					      gint		 width,
+					      gint		 height,
+					      gint		 row,
+					      gint		 col,
+					      gint		 year,
+					      gint		 month,
+					      gint		 start_weekday,
 					      gint		 cells_x,
 					      gint		 cells_y);
 static double e_calendar_item_point	(GnomeCanvasItem *item,
 					 double		  x,
 					 double		  y,
-					 int		  cx,
-					 int		  cy,
+					 gint		  cx,
+					 gint		  cy,
 					 GnomeCanvasItem **actual_item);
 static void e_calendar_item_stop_selecting (ECalendarItem *calitem,
 					    guint32 time);
@@ -891,7 +891,7 @@ static void
 e_calendar_item_update		(GnomeCanvasItem *item,
 				 double		 *affine,
 				 ArtSVP		 *clip_path,
-				 int		  flags)
+				 gint		  flags)
 {
 	ECalendarItem *calitem;
 	GtkStyle *style;
@@ -1024,10 +1024,10 @@ e_calendar_item_update		(GnomeCanvasItem *item,
 static void
 e_calendar_item_draw		(GnomeCanvasItem *canvas_item,
 				 GdkDrawable	 *drawable,
-				 int		  x,
-				 int		  y,
-				 int		  width,
-				 int		  height)
+				 gint		  x,
+				 gint		  y,
+				 gint		  width,
+				 gint		  height)
 {
 	ECalendarItem *calitem;
 	GtkStyle *style;
@@ -1139,7 +1139,7 @@ e_calendar_item_draw		(GnomeCanvasItem *canvas_item,
 
 
 static void
-layout_set_day_text (ECalendarItem *calitem, PangoLayout *layout, int day_index)
+layout_set_day_text (ECalendarItem *calitem, PangoLayout *layout, gint day_index)
 {
 	const gchar *abbr_name;
 
@@ -1151,12 +1151,12 @@ layout_set_day_text (ECalendarItem *calitem, PangoLayout *layout, int day_index)
 static void
 e_calendar_item_draw_month	(ECalendarItem   *calitem,
 				 GdkDrawable	 *drawable,
-				 int		  x,
-				 int		  y,
-				 int		  width,
-				 int		  height,
-				 int		  row,
-				 int		  col)
+				 gint		  x,
+				 gint		  y,
+				 gint		  width,
+				 gint		  height,
+				 gint		  row,
+				 gint		  col)
 {
 	GnomeCanvasItem *item;
 	GtkWidget *widget;
@@ -1364,18 +1364,18 @@ e_calendar_item_draw_month	(ECalendarItem   *calitem,
 	cairo_destroy (cr);
 }
 
-static const char *
+static const gchar *
 get_digit_fomat ()
 {
 
 #ifdef HAVE_GNU_GET_LIBC_VERSION
 #include <gnu/libc-version.h>
 
-	const char *libc_version = gnu_get_libc_version ();
-	char **split = g_strsplit (libc_version, ".", -1);
-	int major = 0;
-	int minor = 0;
-	int revision = 0;
+	const gchar *libc_version = gnu_get_libc_version ();
+	gchar **split = g_strsplit (libc_version, ".", -1);
+	gint major = 0;
+	gint minor = 0;
+	gint revision = 0;
 
 	major = atoi (split [0]);
 	minor = atoi (split [1]);
@@ -1386,22 +1386,22 @@ get_digit_fomat ()
 
 	if (major > 2 || minor > 2 || (minor == 2 && revision > 2)) {
 		return "%Id";
-	} 
+	}
 #endif
-	
+
 	return "%d";
 }
 
 static void
 e_calendar_item_draw_day_numbers (ECalendarItem	*calitem,
 				  GdkDrawable	*drawable,
-				  int		 width,
-				  int		 height,
-				  int		 row,
-				  int		 col,
-				  int		 year,
-				  int		 month,
-				  int		 start_weekday,
+				  gint		 width,
+				  gint		 height,
+				  gint		 row,
+				  gint		 col,
+				  gint		 year,
+				  gint		 month,
+				  gint		 start_weekday,
 				  gint		 cells_x,
 				  gint		 cells_y)
 {
@@ -1716,7 +1716,7 @@ e_calendar_item_get_week_number	(ECalendarItem *calitem,
 {
 	GDate date;
 	guint weekday, yearday;
-	int offset, week_num;
+	gint offset, week_num;
 
 	/* FIXME: check what happens at year boundaries. */
 
@@ -1757,7 +1757,7 @@ e_calendar_item_get_week_number	(ECalendarItem *calitem,
    This is needed so that we get button/motion events. */
 static double
 e_calendar_item_point (GnomeCanvasItem *item, double x, double y,
-			   int cx, int cy,
+			   gint cx, gint cy,
 			   GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
@@ -1983,8 +1983,8 @@ e_calendar_item_recalc_sizes		(ECalendarItem *calitem)
 	max_week_number_digit_width = 0;
 	for (digit = 0; digit < 10; digit++) {
 		gchar locale_digit[5];
-		int locale_digit_len;
-		
+		gint locale_digit_len;
+
 		locale_digit_len = sprintf (locale_digit, get_digit_fomat (), digit);
 
 		pango_layout_set_text (layout, locale_digit, locale_digit_len);
