@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -34,8 +34,6 @@
 #include "e-canvas-utils.h"
 #include "e-canvas-vbox.h"
 
-static void e_canvas_vbox_init		(ECanvasVbox		 *CanvasVbox);
-static void e_canvas_vbox_class_init	(ECanvasVboxClass	 *klass);
 static void e_canvas_vbox_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
 static void e_canvas_vbox_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void e_canvas_vbox_dispose (GObject *object);
@@ -43,7 +41,7 @@ static void e_canvas_vbox_dispose (GObject *object);
 static gint e_canvas_vbox_event   (GnomeCanvasItem *item, GdkEvent *event);
 static void e_canvas_vbox_realize (GnomeCanvasItem *item);
 
-static void e_canvas_vbox_reflow (GnomeCanvasItem *item, int flags);
+static void e_canvas_vbox_reflow (GnomeCanvasItem *item, gint flags);
 
 static void e_canvas_vbox_real_add_item(ECanvasVbox *e_canvas_vbox, GnomeCanvasItem *item);
 static void e_canvas_vbox_real_add_item_start(ECanvasVbox *e_canvas_vbox, GnomeCanvasItem *item);
@@ -297,7 +295,7 @@ e_canvas_vbox_resize_children (GnomeCanvasItem *item)
 }
 
 static void
-e_canvas_vbox_reflow( GnomeCanvasItem *item, int flags )
+e_canvas_vbox_reflow( GnomeCanvasItem *item, gint flags )
 {
 	ECanvasVbox *e_canvas_vbox = E_CANVAS_VBOX(item);
 	if ( GTK_OBJECT_FLAGS( e_canvas_vbox ) & GNOME_CANVAS_ITEM_REALIZED ) {
@@ -332,7 +330,7 @@ e_canvas_vbox_reflow( GnomeCanvasItem *item, int flags )
 				max_width = item_width;
 			list = g_list_next(list);
 
-			for( ; list; list = g_list_next(list)) {
+			for(; list; list = g_list_next(list)) {
 				running_height += e_canvas_vbox->spacing;
 
 				g_object_get (list->data,
