@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  * Authors:
  *		Damon Chaplin <damon@ximian.com>
@@ -153,9 +153,9 @@ static void on_date_popup_date_selected		(ECalendarItem	*calitem,
 						 EDateEdit	*dedit);
 static void hide_date_popup			(EDateEdit	*dedit);
 static void rebuild_time_popup			(EDateEdit	*dedit);
-static gboolean field_set_to_none		(const char	*text);
+static gboolean field_set_to_none		(const gchar	*text);
 static gboolean e_date_edit_parse_date		(EDateEdit	*dedit,
-						 const char	*date_text,
+						 const gchar	*date_text,
 						 struct tm	*date_tm);
 static gboolean e_date_edit_parse_time		(EDateEdit	*dedit,
 						 const gchar	*time_text,
@@ -1247,7 +1247,7 @@ position_date_popup		(EDateEdit	*dedit)
 	x += win_x;
 	y += win_y;
 
-      	screen_width = gdk_screen_width ();
+	screen_width = gdk_screen_width ();
 	screen_height = gdk_screen_height ();
 
 	x = CLAMP (x, 0, MAX (0, screen_width - cal_req.width));
@@ -1326,7 +1326,7 @@ on_date_popup_key_press			(GtkWidget	*widget,
 					 EDateEdit	*dedit)
 {
 	if (event->keyval != GDK_Escape) {
-    	gdk_keyboard_grab (dedit->priv->cal_popup->window, TRUE, GDK_CURRENT_TIME);
+	gdk_keyboard_grab (dedit->priv->cal_popup->window, TRUE, GDK_CURRENT_TIME);
 		return FALSE;
 	}
 
@@ -1403,7 +1403,7 @@ rebuild_time_popup			(EDateEdit	*dedit)
 {
 	EDateEditPrivate *priv;
 	GtkComboBox *combo;
-	char buffer[40];
+	gchar buffer[40];
 	struct tm tmp_tm;
 	gint hour, min;
 
@@ -1471,7 +1471,7 @@ e_date_edit_parse_date (EDateEdit *dedit,
 		if (date_tm->tm_year > today_tm->tm_year)
 			date_tm->tm_year -= 100;
 	}
-	
+
 	return TRUE;
 }
 
@@ -1497,14 +1497,14 @@ e_date_edit_parse_time	(EDateEdit	*dedit,
 /* Returns TRUE if the string is empty or is "None" in the current locale.
    It ignores whitespace. */
 static gboolean
-field_set_to_none (const char *text)
+field_set_to_none (const gchar *text)
 {
-	const char *pos;
-	const char *none_string;
-	int n;
+	const gchar *pos;
+	const gchar *none_string;
+	gint n;
 
 	pos = text;
-	while (n = (int)((unsigned char)*pos), isspace (n))
+	while (n = (gint)((guchar)*pos), isspace (n))
 		pos++;
 
 	none_string = _("None");
@@ -1717,7 +1717,7 @@ static void
 e_date_edit_update_date_entry		(EDateEdit	*dedit)
 {
 	EDateEditPrivate *priv;
-	char buffer[100];
+	gchar buffer[100];
 	struct tm tmp_tm = { 0 };
 
 	priv = dedit->priv;
@@ -1725,10 +1725,10 @@ e_date_edit_update_date_entry		(EDateEdit	*dedit)
 	if (priv->date_set_to_none || !priv->date_is_valid) {
 		gtk_entry_set_text (GTK_ENTRY (priv->date_entry), _("None"));
 	} else {
-		/* This is a strftime() format for a short date. 
+		/* This is a strftime() format for a short date.
 		   %x the preferred date representation for the current locale without the time,
 		   but has forced to use 4 digit year */
-		char *format = e_time_get_d_fmt_with_4digit_year ();
+		gchar *format = e_time_get_d_fmt_with_4digit_year ();
 
 		tmp_tm.tm_year = priv->year;
 		tmp_tm.tm_mon = priv->month;
@@ -1750,7 +1750,7 @@ static void
 e_date_edit_update_time_entry		(EDateEdit	*dedit)
 {
 	EDateEditPrivate *priv;
-	char buffer[40];
+	gchar buffer[40];
 	struct tm tmp_tm = { 0 };
 
 	priv = dedit->priv;
@@ -1761,7 +1761,7 @@ e_date_edit_update_time_entry		(EDateEdit	*dedit)
 	} else {
 		GtkTreeModel *model;
 		GtkTreeIter iter;
-		char *b;
+		gchar *b;
 
 		/* Set these to reasonable values just in case. */
 		tmp_tm.tm_year = 2000;
@@ -1797,11 +1797,11 @@ e_date_edit_update_time_entry		(EDateEdit	*dedit)
 		model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->time_combo));
 		if (gtk_tree_model_get_iter_first (model, &iter)) {
 			do {
-				char *text = NULL;
+				gchar *text = NULL;
 
 				gtk_tree_model_get (model, &iter, 0, &text, -1);
 				if (text) {
-					char *t = text;
+					gchar *t = text;
 
 					/* truncate left spaces */
 					while (*t == ' ')
