@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -56,11 +56,11 @@ extern "C" {
 typedef struct _EFilterBar       EFilterBar;
 typedef struct _EFilterBarClass  EFilterBarClass;
 
-typedef void (*EFilterBarConfigRule)(EFilterBar *, FilterRule *rule, int id, const char *query, void *data);
+typedef void (*EFilterBarConfigRule)(EFilterBar *, FilterRule *rule, gint id, const gchar *query, gpointer data);
 
 struct _EFilterBar {
 	ESearchBar parent;
-	int menu_base, option_base;
+	gint menu_base, option_base;
 	GPtrArray *menu_rules, *option_rules;
 
 	ESearchBarItem *default_items;
@@ -68,14 +68,14 @@ struct _EFilterBar {
 	GtkWidget *save_dialog;    /* current save dialogue (so we dont pop up multiple ones) */
 
 	FilterRule *current_query; /* as it says */
-	int setquery;		   /* true when we're setting a query directly to advanced, so dont popup the dialog */
+	gint setquery;		   /* true when we're setting a query directly to advanced, so dont popup the dialog */
 
 	RuleContext *context;
-	char *systemrules;
-	char *userrules;
+	gchar *systemrules;
+	gchar *userrules;
 
 	EFilterBarConfigRule config;
-	void *config_data;
+	gpointer config_data;
 
 	CamelVeeFolder *all_account_search_vf;
 	CamelVeeFolder *account_search_vf;
@@ -95,23 +95,21 @@ enum {
 
 	/* preset option options */
 	E_FILTERBAR_ADVANCED_ID = -5,
-	E_FILTERBAR_CURRENT_MESSAGE_ID = -6,
 	E_FILTERBAR_CURRENT_FOLDER_ID = -7,
 	E_FILTERBAR_CURRENT_ACCOUNT_ID = -8,
-	E_FILTERBAR_ALL_ACCOUNTS_ID = -9,
+	E_FILTERBAR_ALL_ACCOUNTS_ID = -9
 };
 
-#define E_FILTERBAR_SAVE      { N_("_Save Search..."), E_FILTERBAR_SAVE_ID, 0 }
-#define E_FILTERBAR_EDIT      { N_("_Edit Saved Searches..."), E_FILTERBAR_EDIT_ID, 0 }
-#define E_FILTERBAR_ADVANCED  { N_("_Advanced Search..."), E_FILTERBAR_ADVANCED_ID, 0 }
-#define E_FILTERBAR_ALL_ACCOUNTS { N_("All Accounts"), E_FILTERBAR_ALL_ACCOUNTS_ID, ESB_ITEMTYPE_RADIO }
-#define E_FILTERBAR_CURRENT_ACCOUNT { N_("Current Account"), E_FILTERBAR_CURRENT_ACCOUNT_ID, ESB_ITEMTYPE_RADIO }
-#define E_FILTERBAR_CURRENT_FOLDER { N_("Current Folder"), E_FILTERBAR_CURRENT_FOLDER_ID, ESB_ITEMTYPE_RADIO }
-#define E_FILTERBAR_CURRENT_MESSAGE { N_("Current Message"), E_FILTERBAR_CURRENT_MESSAGE_ID, ESB_ITEMTYPE_RADIO }
+#define E_FILTERBAR_SAVE      { (gchar *) N_("_Save Search..."), E_FILTERBAR_SAVE_ID, 0 }
+#define E_FILTERBAR_EDIT      { (gchar *) N_("_Edit Saved Searches..."), E_FILTERBAR_EDIT_ID, 0 }
+#define E_FILTERBAR_ADVANCED  { (gchar *) N_("_Advanced Search..."), E_FILTERBAR_ADVANCED_ID, 0 }
+#define E_FILTERBAR_ALL_ACCOUNTS { (gchar *) N_("All Accounts"), E_FILTERBAR_ALL_ACCOUNTS_ID, ESB_ITEMTYPE_RADIO }
+#define E_FILTERBAR_CURRENT_ACCOUNT { (gchar *) N_("Current Account"), E_FILTERBAR_CURRENT_ACCOUNT_ID, ESB_ITEMTYPE_RADIO }
+#define E_FILTERBAR_CURRENT_FOLDER { (gchar *) N_("Current Folder"), E_FILTERBAR_CURRENT_FOLDER_ID, ESB_ITEMTYPE_RADIO }
 #define E_FILTERBAR_SEPARATOR { NULL, 0, 0 }
 
 #ifdef JUST_FOR_TRANSLATORS
-const char * strings[] = {
+const gchar * strings[] = {
 	N_("_Save Search..."),
 	N_("_Edit Saved Searches..."),
 	N_("_Advanced Search...")
@@ -122,16 +120,22 @@ const char * strings[] = {
 GType       e_filter_bar_get_type (void);
 
 EFilterBar *e_filter_bar_new      (RuleContext *context,
-				   const char *systemrules,
-				   const char *userrules,
+				   const gchar *systemrules,
+				   const gchar *userrules,
 				   EFilterBarConfigRule config,
-				   void *data);
+				   gpointer data);
+EFilterBar *e_filter_bar_lite_new (RuleContext *context,
+				   const gchar *systemrules,
+				   const gchar *userrules,
+				   EFilterBarConfigRule config,
+				   gpointer data);
+
 void
-e_filter_bar_new_construct 	  (RuleContext *context,
-				   const char *systemrules,
-				   const char *userrules,
+e_filter_bar_new_construct	  (RuleContext *context,
+				   const gchar *systemrules,
+				   const gchar *userrules,
 				   EFilterBarConfigRule config,
-				   void *data ,EFilterBar *bar );
+				   gpointer data ,EFilterBar *bar );
 
 #ifdef __cplusplus
 }
