@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -37,10 +37,10 @@ struct _EImageChooserPrivate {
 	GtkWidget *image;
 	GtkWidget *browse_button;
 
-	char *image_buf;
-	int   image_buf_size;
-	int   image_width;
-	int   image_height;
+	gchar *image_buf;
+	gint   image_buf_size;
+	gint   image_width;
+	gint   image_height;
 
 	gboolean editable;
 };
@@ -85,9 +85,9 @@ enum DndTargetType {
 #define URI_LIST_TYPE "text/uri-list"
 
 static GtkTargetEntry image_drag_types[] = {
-	{ URI_LIST_TYPE, 0, DND_TARGET_TYPE_URI_LIST },
+	{ (gchar *) URI_LIST_TYPE, 0, DND_TARGET_TYPE_URI_LIST },
 };
-static const int num_image_drag_types = sizeof (image_drag_types) / sizeof (image_drag_types[0]);
+static const gint num_image_drag_types = sizeof (image_drag_types) / sizeof (image_drag_types[0]);
 
 GtkWidget *
 e_image_chooser_new (void)
@@ -222,13 +222,13 @@ e_image_chooser_dispose (GObject *object)
 
 static gboolean
 set_image_from_data (EImageChooser *chooser,
-		     char *data, int length)
+		     gchar *data, gint length)
 {
 	gboolean rv = FALSE;
 	GdkPixbufLoader *loader = gdk_pixbuf_loader_new ();
 	GdkPixbuf *pixbuf;
 
-	gdk_pixbuf_loader_write (loader, (unsigned char *)data, length, NULL);
+	gdk_pixbuf_loader_write (loader, (guchar *)data, length, NULL);
 	gdk_pixbuf_loader_close (loader, NULL);
 
 	pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
@@ -241,8 +241,8 @@ set_image_from_data (EImageChooser *chooser,
 		GdkPixbuf *scaled;
 		GdkPixbuf *composite;
 
-		float scale;
-		int new_height, new_width;
+		gfloat scale;
+		gint new_height, new_width;
 
 		new_height = gdk_pixbuf_get_height (pixbuf);
 		new_width = gdk_pixbuf_get_width (pixbuf);
@@ -259,17 +259,17 @@ set_image_from_data (EImageChooser *chooser,
 			/* we need to scale down */
 			printf ("we need to scale down\n");
 			if (new_height > new_width)
-				scale = (float)chooser->priv->image_height / new_height;
+				scale = (gfloat)chooser->priv->image_height / new_height;
 			else
-				scale = (float)chooser->priv->image_width / new_width;
+				scale = (gfloat)chooser->priv->image_width / new_width;
 		}
 		else {
 			/* we need to scale up */
 			printf ("we need to scale up\n");
 			if (new_height > new_width)
-				scale = (float)new_height / chooser->priv->image_height;
+				scale = (gfloat)new_height / chooser->priv->image_height;
 			else
-				scale = (float)new_width / chooser->priv->image_width;
+				scale = (gfloat)new_width / chooser->priv->image_width;
 		}
 
 		printf ("scale = %g\n", scale);
@@ -331,7 +331,7 @@ image_drag_motion_cb (GtkWidget *widget,
 		return FALSE;
 
 	for (p = context->targets; p != NULL; p = p->next) {
-		char *possible_type;
+		gchar *possible_type;
 
 		possible_type = gdk_atom_name (GDK_POINTER_TO_ATOM (p->data));
 		if (!strcmp (possible_type, URI_LIST_TYPE)) {
@@ -372,7 +372,7 @@ image_drag_drop_cb (GtkWidget *widget,
 	}
 
 	for (p = context->targets; p != NULL; p = p->next) {
-		char *possible_type;
+		gchar *possible_type;
 
 		possible_type = gdk_atom_name (GDK_POINTER_TO_ATOM (p->data));
 		if (!strcmp (possible_type, URI_LIST_TYPE)) {
@@ -398,22 +398,22 @@ image_drag_data_received_cb (GtkWidget *widget,
 			     GtkSelectionData *selection_data,
 			     guint info, guint time, EImageChooser *chooser)
 {
-	char *target_type;
+	gchar *target_type;
 	gboolean handled = FALSE;
 
 	target_type = gdk_atom_name (selection_data->target);
 
 	if (!strcmp (target_type, URI_LIST_TYPE)) {
 		GError *error = NULL;
-		char *uri;
-		char *nl = strstr ((char *)selection_data->data, "\r\n");
-		char *buf = NULL;
+		gchar *uri;
+		gchar *nl = strstr ((gchar *)selection_data->data, "\r\n");
+		gchar *buf = NULL;
 		gsize read = 0;
 
 		if (nl)
-			uri = g_strndup ((char *)selection_data->data, nl - (char*)selection_data->data);
+			uri = g_strndup ((gchar *)selection_data->data, nl - (gchar *)selection_data->data);
 		else
-			uri = g_strdup ((char *)selection_data->data);
+			uri = g_strdup ((gchar *)selection_data->data);
 
 		if (e_util_read_file (uri, TRUE, &buf, &read, &error) && read > 0 && buf) {
 			if (set_image_from_data (chooser, buf, read)) {
@@ -436,7 +436,7 @@ image_drag_data_received_cb (GtkWidget *widget,
 
 
 gboolean
-e_image_chooser_set_from_file (EImageChooser *chooser, const char *filename)
+e_image_chooser_set_from_file (EImageChooser *chooser, const gchar *filename)
 {
 	gchar *data;
 	gsize data_length;
@@ -465,7 +465,7 @@ e_image_chooser_set_editable (EImageChooser *chooser, gboolean editable)
 }
 
 gboolean
-e_image_chooser_get_image_data (EImageChooser *chooser, char **data, gsize *data_length)
+e_image_chooser_get_image_data (EImageChooser *chooser, gchar **data, gsize *data_length)
 {
 	g_return_val_if_fail (E_IS_IMAGE_CHOOSER (chooser), FALSE);
 	g_return_val_if_fail (data != NULL, FALSE);
@@ -479,9 +479,9 @@ e_image_chooser_get_image_data (EImageChooser *chooser, char **data, gsize *data
 }
 
 gboolean
-e_image_chooser_set_image_data (EImageChooser *chooser, char *data, gsize data_length)
+e_image_chooser_set_image_data (EImageChooser *chooser, gchar *data, gsize data_length)
 {
-	char *buf;
+	gchar *buf;
 
 	g_return_val_if_fail (E_IS_IMAGE_CHOOSER (chooser), FALSE);
 	g_return_val_if_fail (data != NULL, FALSE);
