@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -28,10 +28,10 @@
 
 G_BEGIN_DECLS
 
-#define E_TYPE_IMAGE_CHOOSER	        (e_image_chooser_get_type ())
-#define E_IMAGE_CHOOSER(obj)	        (G_TYPE_CHECK_INSTANCE_CAST ((obj), E_TYPE_IMAGE_CHOOSER, EImageChooser))
+#define E_TYPE_IMAGE_CHOOSER		(e_image_chooser_get_type ())
+#define E_IMAGE_CHOOSER(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), E_TYPE_IMAGE_CHOOSER, EImageChooser))
 #define E_IMAGE_CHOOSER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), E_TYPE_IMAGE_CHOOSER, EImageChooserClass))
-#define E_IS_IMAGE_CHOOSER(obj)	        (G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_IMAGE_CHOOSER))
+#define E_IS_IMAGE_CHOOSER(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_IMAGE_CHOOSER))
 #define E_IS_IMAGE_CHOOSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((obj), E_TYPE_IMAGE_CHOOSER))
 
 typedef struct _EImageChooser        EImageChooser;
@@ -58,10 +58,10 @@ struct _EImageChooserClass
 GtkWidget *e_image_chooser_new      (void);
 GType      e_image_chooser_get_type (void);
 
-gboolean   e_image_chooser_set_from_file  (EImageChooser *chooser, const char *filename);
-gboolean   e_image_chooser_set_image_data (EImageChooser *chooser, char *data, gsize data_length);
+gboolean   e_image_chooser_set_from_file  (EImageChooser *chooser, const gchar *filename);
+gboolean   e_image_chooser_set_image_data (EImageChooser *chooser, gchar *data, gsize data_length);
 void       e_image_chooser_set_editable   (EImageChooser *chooser, gboolean editable);
 
-gboolean   e_image_chooser_get_image_data (EImageChooser *chooser, char **data, gsize *data_length);
+gboolean   e_image_chooser_get_image_data (EImageChooser *chooser, gchar **data, gsize *data_length);
 
 #endif /* _E_IMAGE_CHOOSER_H_ */
