@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -96,7 +96,7 @@ void e_map_world_to_window (EMap *map,
 
 /* --- Zoom --- */
 
-double e_map_get_magnification (EMap *map);
+gdouble e_map_get_magnification (EMap *map);
 
 /* Pass TRUE if we want the smooth zoom hack */
 void e_map_set_smooth_zoom (EMap *map, gboolean state);
