@@ -1,23 +1,23 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-multi-config-dialog.c
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Ettore Perazzoli <ettore@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,8 +43,8 @@ struct _EMultiConfigDialogPrivate {
 
 	GtkWidget *notebook;
 
-	int set_page_timeout_id;
-	int set_page_timeout_page;
+	gint set_page_timeout_id;
+	gint set_page_timeout_page;
 };
 
 G_DEFINE_TYPE (EMultiConfigDialog, e_multi_config_dialog, GTK_TYPE_DIALOG)
@@ -52,7 +52,7 @@ G_DEFINE_TYPE (EMultiConfigDialog, e_multi_config_dialog, GTK_TYPE_DIALOG)
 
 /* ETable stuff.  */
 
-static char *list_e_table_spec =
+static const gchar *list_e_table_spec =
 	"<ETableSpecification cursor-mode=\"line\""
 	"		      selection-mode=\"browse\""
 	"                     no-headers=\"true\""
@@ -60,11 +60,11 @@ static char *list_e_table_spec =
         "                     horizontal-resize=\"true\""
         ">"
 	"  <ETableColumn model_col=\"0\""
-	"	         expansion=\"1.0\""
+	"		 expansion=\"1.0\""
 	"                cell=\"vbox\""
- 	"                minimum_width=\"32\""
+	"                minimum_width=\"32\""
 	"                resizable=\"true\""
-	"	         _title=\"Category\""
+	"		 _title=\"Category\""
 	"                compare=\"string\"/>"
 	"  <ETableState>"
 	"    <column source=\"0\"/>"
@@ -76,7 +76,7 @@ static char *list_e_table_spec =
 /* Page handling.  */
 
 static GtkWidget *
-create_page_container (const char *description,
+create_page_container (const gchar *description,
 		       GtkWidget *widget)
 {
 	GtkWidget *vbox;
@@ -94,8 +94,8 @@ create_page_container (const char *description,
 /* Timeout for switching pages (so it's more comfortable navigating with the
    keyboard).  */
 
-static int
-set_page_timeout_callback (void *data)
+static gint
+set_page_timeout_callback (gpointer data)
 {
 	EMultiConfigDialog *multi_config_dialog;
 	EMultiConfigDialogPrivate *priv;
@@ -125,8 +125,8 @@ do_close (EMultiConfigDialog *dialog)
 
 static void
 table_cursor_change_callback (ETable *etable,
-			      int row,
-			      void *data)
+			      gint row,
+			      gpointer data)
 {
 	EMultiConfigDialog *dialog;
 	EMultiConfigDialogPrivate *priv;
@@ -168,7 +168,7 @@ impl_finalize (GObject *object)
 /* GtkDialog methods.  */
 
 static void
-impl_response (GtkDialog *dialog, int response_id)
+impl_response (GtkDialog *dialog, gint response_id)
 {
 	EMultiConfigDialog *multi_config_dialog;
 
@@ -315,8 +315,8 @@ e_multi_config_dialog_new (void)
 
 void
 e_multi_config_dialog_add_page (EMultiConfigDialog *dialog,
-				const char *title,
-				const char *description,
+				const gchar *title,
+				const gchar *description,
 				GdkPixbuf *icon,
 				EConfigPage *page_widget)
 {
@@ -359,7 +359,7 @@ e_multi_config_dialog_add_page (EMultiConfigDialog *dialog,
 }
 
 void
-e_multi_config_dialog_show_page (EMultiConfigDialog *dialog, int page)
+e_multi_config_dialog_show_page (EMultiConfigDialog *dialog, gint page)
 {
 	EMultiConfigDialogPrivate *priv;
 
