@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -22,8 +22,6 @@
  */
 #include <config.h>
 
-#include "e-util/e-util-marshal.h"
-
 #include "e-util/e-util.h"
 
 #include "e-reflow-model.h"
@@ -52,7 +50,7 @@ static guint e_reflow_model_signals [LAST_SIGNAL] = { 0, };
  * @width: The new value for the width of each item.
  */
 void
-e_reflow_model_set_width (EReflowModel *e_reflow_model, int width)
+e_reflow_model_set_width (EReflowModel *e_reflow_model, gint width)
 {
 	g_return_if_fail (e_reflow_model != NULL);
 	g_return_if_fail (E_IS_REFLOW_MODEL (e_reflow_model));
@@ -66,7 +64,7 @@ e_reflow_model_set_width (EReflowModel *e_reflow_model, int width)
  *
  * Returns: the number of items in the reflow model.
  */
-int
+gint
 e_reflow_model_count (EReflowModel *e_reflow_model)
 {
 	g_return_val_if_fail (e_reflow_model != NULL, 0);
@@ -83,8 +81,8 @@ e_reflow_model_count (EReflowModel *e_reflow_model)
  *
  * Returns: the height of the nth item.
  */
-int
-e_reflow_model_height (EReflowModel *e_reflow_model, int n, GnomeCanvasGroup *parent)
+gint
+e_reflow_model_height (EReflowModel *e_reflow_model, gint n, GnomeCanvasGroup *parent)
 {
 	g_return_val_if_fail (e_reflow_model != NULL, 0);
 	g_return_val_if_fail (E_IS_REFLOW_MODEL (e_reflow_model), 0);
@@ -103,7 +101,7 @@ e_reflow_model_height (EReflowModel *e_reflow_model, int n, GnomeCanvasGroup *pa
  * Returns: the new GnomeCanvasItem.
  */
 GnomeCanvasItem *
-e_reflow_model_incarnate (EReflowModel *e_reflow_model, int n, GnomeCanvasGroup *parent)
+e_reflow_model_incarnate (EReflowModel *e_reflow_model, gint n, GnomeCanvasGroup *parent)
 {
 	g_return_val_if_fail (e_reflow_model != NULL, NULL);
 	g_return_val_if_fail (E_IS_REFLOW_MODEL (e_reflow_model), NULL);
@@ -121,8 +119,8 @@ e_reflow_model_incarnate (EReflowModel *e_reflow_model, int n, GnomeCanvasGroup
  *
  * Returns: strcmp like semantics for the comparison value.
  */
-int
-e_reflow_model_compare (EReflowModel *e_reflow_model, int n1, int n2)
+gint
+e_reflow_model_compare (EReflowModel *e_reflow_model, gint n1, gint n2)
 {
 #if 0
 	g_return_val_if_fail (e_reflow_model != NULL, 0);
@@ -141,7 +139,7 @@ e_reflow_model_compare (EReflowModel *e_reflow_model, int n1, int n2)
  * Update item to represent the nth piece of data.
  */
 void
-e_reflow_model_reincarnate (EReflowModel *e_reflow_model, int n, GnomeCanvasItem *item)
+e_reflow_model_reincarnate (EReflowModel *e_reflow_model, gint n, GnomeCanvasItem *item)
 {
 	g_return_if_fail (e_reflow_model != NULL);
 	g_return_if_fail (E_IS_REFLOW_MODEL (e_reflow_model));
@@ -178,7 +176,7 @@ e_reflow_model_class_init (EReflowModelClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EReflowModelClass, model_items_inserted),
 			      NULL, NULL,
-			      e_util_marshal_NONE__INT_INT,
+			      e_marshal_NONE__INT_INT,
 			      G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
 
 	e_reflow_model_signals [MODEL_ITEM_CHANGED] =
@@ -221,7 +219,7 @@ e_reflow_model_init (EReflowModel *e_reflow_model)
 static void
 print_tabs (void)
 {
-	int i;
+	gint i;
 	for (i = 0; i < depth; i++)
 		g_print("\t");
 }
@@ -286,7 +284,7 @@ e_reflow_model_comparison_changed (EReflowModel *e_reflow_model)
  * Use this function to notify any views of the reflow model that a number of items have been inserted.
  **/
 void
-e_reflow_model_items_inserted (EReflowModel *e_reflow_model, int position, int count)
+e_reflow_model_items_inserted (EReflowModel *e_reflow_model, gint position, gint count)
 {
 	g_return_if_fail (e_reflow_model != NULL);
 	g_return_if_fail (E_IS_REFLOW_MODEL (e_reflow_model));
@@ -310,7 +308,7 @@ e_reflow_model_items_inserted (EReflowModel *e_reflow_model, int position, int c
  **/
 void
 e_reflow_model_item_removed    (EReflowModel     *e_reflow_model,
-				int               n)
+				gint               n)
 {
 	g_return_if_fail (e_reflow_model != NULL);
 	g_return_if_fail (E_IS_REFLOW_MODEL (e_reflow_model));
@@ -337,7 +335,7 @@ e_reflow_model_item_removed    (EReflowModel     *e_reflow_model,
  * object
  */
 void
-e_reflow_model_item_changed (EReflowModel *e_reflow_model, int n)
+e_reflow_model_item_changed (EReflowModel *e_reflow_model, gint n)
 {
 	g_return_if_fail (e_reflow_model != NULL);
 	g_return_if_fail (E_IS_REFLOW_MODEL (e_reflow_model));
