@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-reflow.h
- * Copyright 2000, 2001, Ximian, Inc.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #ifndef __E_REFLOW_H__
@@ -80,12 +79,12 @@ struct _EReflow
 	guint adjustment_value_changed_id;
 	guint set_scroll_adjustments_id;
 
-	int *heights;
+	gint *heights;
 	GnomeCanvasItem **items;
-	int count;
-	int allocated_count;
+	gint count;
+	gint allocated_count;
 
-	int *columns;
+	gint *columns;
 	gint column_count; /* Number of columnns */
 
 	GnomeCanvasItem *empty_text;
@@ -97,8 +96,8 @@ struct _EReflow
 
 	double column_width;
 
-	int incarnate_idle_id;
-	int do_adjustment_idle_id;
+	gint incarnate_idle_id;
+	gint do_adjustment_idle_id;
 
 	/* These are all for when the column is being dragged. */
 	gdouble start_x;
@@ -106,9 +105,9 @@ struct _EReflow
 	double temp_column_width;
 	double previous_temp_column_width;
 
-	int cursor_row;
+	gint cursor_row;
 
-	int reflow_from_column;
+	gint reflow_from_column;
 
 	guint column_drag : 1;
 
@@ -128,7 +127,7 @@ struct _EReflowClass
 {
 	GnomeCanvasGroupClass parent_class;
 
-	int (*selection_event) (EReflow *reflow, GnomeCanvasItem *item, GdkEvent *event);
+	gint (*selection_event) (EReflow *reflow, GnomeCanvasItem *item, GdkEvent *event);
 	void (*column_width_changed) (EReflow *reflow, double width);
 };
 
