@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -40,7 +40,7 @@ extern "C" {
 
 #ifndef _E_FOREACH_FUNC_H_
 #define _E_FOREACH_FUNC_H_
-typedef void (*EForeachFunc) (int model_row,
+typedef void (*EForeachFunc) (gint model_row,
 			      gpointer closure);
 #endif
 
@@ -59,39 +59,39 @@ typedef struct {
 	GtkSelectionMode mode;
 	ECursorMode cursor_mode;
 
-	int old_selection;
+	gint old_selection;
 } ESelectionModel;
 
 typedef struct {
 	GObjectClass parent_class;
 
 	/* Virtual methods */
-	gboolean (*is_row_selected)       (ESelectionModel *esm, int row);
+	gboolean (*is_row_selected)       (ESelectionModel *esm, gint row);
 	void     (*foreach)               (ESelectionModel *esm, EForeachFunc callback, gpointer closure);
 	void     (*clear)                 (ESelectionModel *esm);
 	gint     (*selected_count)        (ESelectionModel *esm);
 	void     (*select_all)            (ESelectionModel *esm);
 	void     (*invert_selection)      (ESelectionModel *esm);
-	int      (*row_count)             (ESelectionModel *esm);
+	gint      (*row_count)             (ESelectionModel *esm);
 
 	/* Protected virtual methods. */
-	void     (*change_one_row)        (ESelectionModel *esm, int row, gboolean on);
-	void     (*change_cursor)         (ESelectionModel *esm, int row, int col);
-	int      (*cursor_row)            (ESelectionModel *esm);
-	int      (*cursor_col)            (ESelectionModel *esm);
+	void     (*change_one_row)        (ESelectionModel *esm, gint row, gboolean on);
+	void     (*change_cursor)         (ESelectionModel *esm, gint row, gint col);
+	gint      (*cursor_row)            (ESelectionModel *esm);
+	gint      (*cursor_col)            (ESelectionModel *esm);
 
-	void     (*select_single_row)     (ESelectionModel *selection, int row);
-	void     (*toggle_single_row)     (ESelectionModel *selection, int row);
-	void     (*move_selection_end)    (ESelectionModel *selection, int row);
-	void     (*set_selection_end)     (ESelectionModel *selection, int row);
+	void     (*select_single_row)     (ESelectionModel *selection, gint row);
+	void     (*toggle_single_row)     (ESelectionModel *selection, gint row);
+	void     (*move_selection_end)    (ESelectionModel *selection, gint row);
+	void     (*set_selection_end)     (ESelectionModel *selection, gint row);
 
 	/*
 	 * Signals
 	 */
 
-	void     (*cursor_changed)        (ESelectionModel *esm, int row, int col);
-	void     (*cursor_activated)      (ESelectionModel *esm, int row, int col);
-	void     (*selection_row_changed) (ESelectionModel *esm, int row);
+	void     (*cursor_changed)        (ESelectionModel *esm, gint row, gint col);
+	void     (*cursor_activated)      (ESelectionModel *esm, gint row, gint col);
+	void     (*selection_row_changed) (ESelectionModel *esm, gint row);
 	void     (*selection_changed)     (ESelectionModel *esm);
 
 } ESelectionModelClass;
@@ -128,36 +128,36 @@ void      e_selection_model_clear                  (ESelectionModel *esm);
 gint      e_selection_model_selected_count         (ESelectionModel *esm);
 void      e_selection_model_select_all             (ESelectionModel *esm);
 void      e_selection_model_invert_selection       (ESelectionModel *esm);
-int       e_selection_model_row_count              (ESelectionModel *esm);
+gint       e_selection_model_row_count              (ESelectionModel *esm);
 
 
 /* Private virtual Functions */
 void      e_selection_model_change_one_row         (ESelectionModel *esm,
-						    int              row,
+						    gint              row,
 						    gboolean         on);
 void      e_selection_model_change_cursor          (ESelectionModel *esm,
-						    int              row,
-						    int              col);
-int       e_selection_model_cursor_row             (ESelectionModel *esm);
-int       e_selection_model_cursor_col             (ESelectionModel *esm);
+						    gint              row,
+						    gint              col);
+gint       e_selection_model_cursor_row             (ESelectionModel *esm);
+gint       e_selection_model_cursor_col             (ESelectionModel *esm);
 void      e_selection_model_select_single_row      (ESelectionModel *selection,
-						    int              row);
+						    gint              row);
 void      e_selection_model_toggle_single_row      (ESelectionModel *selection,
-						    int              row);
+						    gint              row);
 void      e_selection_model_move_selection_end     (ESelectionModel *selection,
-						    int              row);
+						    gint              row);
 void      e_selection_model_set_selection_end      (ESelectionModel *selection,
-						    int              row);
+						    gint              row);
 
 /* Signals */
 void      e_selection_model_cursor_changed         (ESelectionModel *selection,
-						    int              row,
-						    int              col);
+						    gint              row,
+						    gint              col);
 void      e_selection_model_cursor_activated       (ESelectionModel *selection,
-						    int              row,
-						    int              col);
+						    gint              row,
+						    gint              col);
 void      e_selection_model_selection_row_changed  (ESelectionModel *selection,
-						    int              row);
+						    gint              row);
 void      e_selection_model_selection_changed      (ESelectionModel *selection);
 
 #ifdef __cplusplus
