@@ -66,7 +66,7 @@ struct _ESpinnerClass
 
 #define E_TYPE_SPINNER_CACHE			(e_spinner_cache_get_type())
 #define E_SPINNER_CACHE(object)		(G_TYPE_CHECK_INSTANCE_CAST((object), E_TYPE_SPINNER_CACHE, ESpinnerCache))
-#define E_SPINNER_CACHE_CLASS(klass) 	(G_TYPE_CHECK_CLASS_CAST((klass), E_TYPE_SPINNER_CACHE, ESpinnerCacheClass))
+#define E_SPINNER_CACHE_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), E_TYPE_SPINNER_CACHE, ESpinnerCacheClass))
 #define E_IS_SPINNER_CACHE(object)		(G_TYPE_CHECK_INSTANCE_TYPE((object), E_TYPE_SPINNER_CACHE))
 #define E_IS_SPINNER_CACHE_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), E_TYPE_SPINNER_CACHE))
 #define E_SPINNER_CACHE_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), E_TYPE_SPINNER_CACHE, ESpinnerCacheClass))
@@ -100,8 +100,8 @@ typedef struct
 {
 	guint ref_count;
 	GtkIconSize size;
-	int width;
-	int height;
+	gint width;
+	gint height;
 	GdkPixbuf **animation_pixbufs;
 	guint n_animation_pixbufs;
 } ESpinnerImages;
@@ -208,9 +208,9 @@ e_spinner_cache_data_unload (ESpinnerCacheData *data)
 
 static GdkPixbuf *
 extract_frame (GdkPixbuf *grid_pixbuf,
-	       int x,
-	       int y,
-	       int size)
+	       gint x,
+	       gint y,
+	       gint size)
 {
 	GdkPixbuf *pixbuf;
 
@@ -230,11 +230,11 @@ extract_frame (GdkPixbuf *grid_pixbuf,
 
 static GdkPixbuf *
 scale_to_size (GdkPixbuf *pixbuf,
-	       int dw,
-	       int dh)
+	       gint dw,
+	       gint dh)
 {
 	GdkPixbuf *result;
-	int pw, ph;
+	gint pw, ph;
 
 	g_return_val_if_fail (pixbuf != NULL, NULL);
 
@@ -259,8 +259,8 @@ e_spinner_images_load (GdkScreen *screen,
 	ESpinnerImages *images;
 	GdkPixbuf *icon_pixbuf, *pixbuf;
 	GtkIconInfo *icon_info = NULL;
-	int grid_width, grid_height, x, y, requested_size, size, isw, ish, n;
-	const char *icon;
+	gint grid_width, grid_height, x, y, requested_size, size, isw, ish, n;
+	const gchar *icon;
 	GSList *list = NULL, *l;
 
 	LOG ("ESpinnerCacheData loading for screen %p at size %d", screen, icon_size);
@@ -275,7 +275,7 @@ e_spinner_images_load (GdkScreen *screen,
 	/* Load the animation. The 'rest icon' is the 0th frame */
 	icon_info = gtk_icon_theme_lookup_icon (icon_theme,
 						SPINNER_ICON_NAME,
-					        requested_size, 0);
+						requested_size, 0);
 	if (icon_info == NULL)
 	{
 		g_warning ("Throbber animation not found");
@@ -315,7 +315,7 @@ e_spinner_images_load (GdkScreen *screen,
 	n = 0;
 	for (y = 0; y < grid_height; y += size)
 	{
-		for (x = 0; x < grid_width ; x += size)
+		for (x = 0; x < grid_width; x += size)
 		{
 			pixbuf = extract_frame (icon_pixbuf, x, y, size);
 
@@ -422,7 +422,7 @@ e_spinner_cache_get_images (ESpinnerCache *cache,
 
 	LOG ("Getting animation images for screen %p at size %d", screen, icon_size);
 
-	g_return_val_if_fail (icon_size >= 0 && icon_size < LAST_ICON_SIZE, NULL);
+	g_return_val_if_fail (icon_size < LAST_ICON_SIZE, NULL);
 
 	/* Backward compat: "invalid" meant "native" size which doesn't exist anymore */
 	if (icon_size == GTK_ICON_SIZE_INVALID)
@@ -633,7 +633,7 @@ e_spinner_init (ESpinner *spinner)
 	details->need_load = TRUE;
 }
 
-static int
+static gint
 e_spinner_expose (GtkWidget *widget,
 		     GdkEventExpose *event)
 {
@@ -642,7 +642,7 @@ e_spinner_expose (GtkWidget *widget,
 	ESpinnerImages *images;
 	GdkPixbuf *pixbuf;
 	GdkGC *gc;
-	int x_offset, y_offset, width, height;
+	gint x_offset, y_offset, width, height;
 	GdkRectangle pix_area, dest;
 
 	if (!GTK_WIDGET_DRAWABLE (spinner))
@@ -665,8 +665,8 @@ e_spinner_expose (GtkWidget *widget,
 	/* Otherwise |images| will be NULL anyway */
 	g_return_val_if_fail (images->n_animation_pixbufs > 0, FALSE);
 
-	g_return_val_if_fail (details->current_image >= 0 &&
-		  details->current_image < images->n_animation_pixbufs, FALSE);
+	g_return_val_if_fail (
+		details->current_image < images->n_animation_pixbufs, FALSE);
 
 	pixbuf = images->animation_pixbufs[details->current_image];
 
@@ -741,10 +741,10 @@ e_spinner_start (ESpinner *spinner)
 
 		details->timer_task =
 			g_timeout_add_full (G_PRIORITY_LOW,
-			                    details->timeout,
-				            (GSourceFunc) bump_spinner_frame_cb,
-				            spinner,
-				            NULL);
+					    details->timeout,
+					    (GSourceFunc) bump_spinner_frame_cb,
+					    spinner,
+					    NULL);
 	}
 }
 
@@ -843,7 +843,7 @@ e_spinner_size_request (GtkWidget *widget,
 		gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
 						   details->size,
 						   &requisition->width,
-					           &requisition->height);
+						   &requisition->height);
 		return;
 	}
 
@@ -888,9 +888,10 @@ e_spinner_dispose (GObject *object)
 {
 	ESpinner *spinner = E_SPINNER (object);
 
-	g_signal_handlers_disconnect_by_func
-			(spinner->details->icon_theme,
-		 G_CALLBACK (icon_theme_changed_cb), spinner);
+	if (spinner->details->icon_theme)
+		g_signal_handlers_disconnect_by_func
+				(spinner->details->icon_theme,
+			 G_CALLBACK (icon_theme_changed_cb), spinner);
 
 	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
