@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -186,7 +186,7 @@ entry_changed_cb (GtkEditable *editable, gpointer data)
 {
 	EUrlEntry *url_entry;
 	EUrlEntryPrivate *priv;
-	const char *url;
+	const gchar *url;
 
 	url_entry = E_URL_ENTRY (data);
 	priv = url_entry->priv;
