@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -71,7 +71,7 @@ typedef struct {
 	ECellClass parent_class;
 
 	/* Virtual function for subclasses to override. */
-	gint   	   (*popup)        (ECellPopup *ecp, GdkEvent *event, int row, int view_col);
+	gint	   (*popup)        (ECellPopup *ecp, GdkEvent *event, gint row, gint view_col);
 } ECellPopupClass;
 
 
@@ -94,8 +94,4 @@ void     e_cell_popup_set_shown          (ECellPopup *ecp,
 					  gboolean    shown);
 void     e_cell_popup_queue_cell_redraw  (ECellPopup *ecp);
 
-void     e_cell_popup_set_shown          (ECellPopup *ecp,
-					  gboolean    shown);
-void     e_cell_popup_queue_cell_redraw  (ECellPopup *ecp);
-
 #endif /* _E_CELL_POPUP_H_ */
