@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -30,8 +30,6 @@
 
 #include "e-table-field-chooser-dialog.h"
 
-static void e_table_field_chooser_dialog_init		(ETableFieldChooserDialog		 *card);
-static void e_table_field_chooser_dialog_class_init	(ETableFieldChooserDialogClass	 *klass);
 static void e_table_field_chooser_dialog_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
 static void e_table_field_chooser_dialog_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void e_table_field_chooser_dialog_dispose (GObject *object);
@@ -64,21 +62,21 @@ e_table_field_chooser_dialog_class_init (ETableFieldChooserDialogClass *klass)
 
 	g_object_class_install_property (object_class, PROP_DND_CODE,
 					 g_param_spec_string ("dnd_code",
-							      _("DnD code"),
+							      "DnD code",
 							      /*_( */"XXX blurb" /*)*/,
 							      NULL,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_FULL_HEADER,
 					 g_param_spec_object ("full_header",
-							      _("Full Header"),
+							      "Full Header",
 							      /*_( */"XXX blurb" /*)*/,
 							      E_TABLE_HEADER_TYPE,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_HEADER,
 					 g_param_spec_object ("header",
-							      _("Header"),
+							      "Header",
 							      /*_( */"XXX blurb" /*)*/,
 							      E_TABLE_HEADER_TYPE,
 							      G_PARAM_READWRITE));
@@ -97,7 +95,7 @@ e_table_field_chooser_dialog_init (ETableFieldChooserDialog *e_table_field_choos
 	gtk_dialog_add_button(GTK_DIALOG(e_table_field_chooser_dialog),
 			      GTK_STOCK_CLOSE, GTK_RESPONSE_OK);
 
-	gtk_window_set_policy(GTK_WINDOW(e_table_field_chooser_dialog), FALSE, TRUE, FALSE);
+	gtk_window_set_resizable(GTK_WINDOW(e_table_field_chooser_dialog), TRUE);
 
 	widget = e_table_field_chooser_new();
 	e_table_field_chooser_dialog->etfc = E_TABLE_FIELD_CHOOSER(widget);
@@ -210,7 +208,7 @@ e_table_field_chooser_dialog_get_property (GObject *object, guint prop_id, GValu
 }
 
 static void
-e_table_field_chooser_dialog_response (GtkDialog *dialog, int id)
+e_table_field_chooser_dialog_response (GtkDialog *dialog, gint id)
 {
 	if (id == GTK_RESPONSE_OK)
 		gtk_widget_destroy (GTK_WIDGET (dialog));
