@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-table-field-chooser-item.c
- * Copyright 2000, 2001, Ximian, Inc.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
  *
  * Authors:
- *   Chris Lahey <clahey@ximian.com>
+ *		Chris Lahey <clahey@ximian.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License, version 2, as published by the Free Software Foundation.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -95,8 +94,8 @@ etfci_dispose (GObject *object)
 static gint
 etfci_find_button (ETableFieldChooserItem *etfci, double loc)
 {
-	int i;
-	int count;
+	gint i;
+	gint count;
 	double height = 0;
 
 	count = e_table_header_count(etfci->combined_header);
@@ -116,9 +115,9 @@ etfci_find_button (ETableFieldChooserItem *etfci, double loc)
 static void
 etfci_rebuild_combined (ETableFieldChooserItem *etfci)
 {
-	int count;
+	gint count;
 	GHashTable *hash;
-	int i;
+	gint i;
 
 	if (etfci->combined_header != NULL)
 		g_object_unref (etfci->combined_header);
@@ -152,8 +151,8 @@ etfci_reflow (GnomeCanvasItem *item, gint flags)
 {
 	ETableFieldChooserItem *etfci = E_TABLE_FIELD_CHOOSER_ITEM (item);
 	double old_height;
-	int i;
-	int count;
+	gint i;
+	gint count;
 	double height = 0;
 
 	etfci_rebuild_combined (etfci);
@@ -171,20 +170,20 @@ etfci_reflow (GnomeCanvasItem *item, gint flags)
 	}
 
 	etfci->height = height;
-	
+
 	if (old_height != etfci->height)
 		e_canvas_item_request_parent_reflow(item);
-	
+
 	gnome_canvas_item_request_update(item);
 }
 
 static void
-etfci_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, int flags)
+etfci_update (GnomeCanvasItem *item, double *affine, ArtSVP *clip_path, gint flags)
 {
 	ETableFieldChooserItem *etfci = E_TABLE_FIELD_CHOOSER_ITEM (item);
 	double   i2c [6];
 	ArtPoint c1, c2, i1, i2;
-	
+
 	if (GNOME_CANVAS_ITEM_CLASS (etfci_parent_class)->update)
 		(*GNOME_CANVAS_ITEM_CLASS (etfci_parent_class)->update)(item, affine, clip_path, flags);
 
@@ -230,7 +229,7 @@ static void
 etfci_drop_full_header (ETableFieldChooserItem *etfci)
 {
 	GObject *header;
-	
+
 	if (!etfci->full_header)
 		return;
 
@@ -249,14 +248,14 @@ etfci_drop_full_header (ETableFieldChooserItem *etfci)
 	e_canvas_item_request_reflow(GNOME_CANVAS_ITEM(etfci));
 }
 
-static void 
+static void
 full_header_structure_changed (ETableHeader *header, ETableFieldChooserItem *etfci)
 {
 	e_canvas_item_request_reflow(GNOME_CANVAS_ITEM(etfci));
 }
 
 static void
-full_header_dimension_changed (ETableHeader *header, int col, ETableFieldChooserItem *etfci)
+full_header_dimension_changed (ETableHeader *header, gint col, ETableFieldChooserItem *etfci)
 {
 	e_canvas_item_request_reflow(GNOME_CANVAS_ITEM(etfci));
 }
@@ -280,7 +279,7 @@ static void
 etfci_drop_table_header (ETableFieldChooserItem *etfci)
 {
 	GObject *header;
-	
+
 	if (!etfci->header)
 		return;
 
@@ -299,14 +298,14 @@ etfci_drop_table_header (ETableFieldChooserItem *etfci)
 	e_canvas_item_request_reflow(GNOME_CANVAS_ITEM(etfci));
 }
 
-static void 
+static void
 table_header_structure_changed (ETableHeader *header, ETableFieldChooserItem *etfci)
 {
 	e_canvas_item_request_reflow(GNOME_CANVAS_ITEM(etfci));
 }
 
 static void
-table_header_dimension_changed (ETableHeader *header, int col, ETableFieldChooserItem *etfci)
+table_header_dimension_changed (ETableHeader *header, gint col, ETableFieldChooserItem *etfci)
 {
 	e_canvas_item_request_reflow(GNOME_CANVAS_ITEM(etfci));
 }
@@ -397,14 +396,14 @@ etfci_drag_data_get (GtkWidget          *widget,
 		gtk_selection_data_set(selection_data,
 				       GDK_SELECTION_TYPE_STRING,
 				       sizeof(string[0]),
-				       (unsigned char *)string,
+				       (guchar *)string,
 				       strlen(string));
 		g_free(string);
 	}
 }
 
 static void
-etfci_drag_end (GtkWidget      *canvas, 
+etfci_drag_end (GtkWidget      *canvas,
 		GdkDragContext *context,
 		ETableFieldChooserItem *etfci)
 {
@@ -444,19 +443,19 @@ etfci_unrealize (GnomeCanvasItem *item)
 	etfci->drag_end_id = 0;
 	g_signal_handler_disconnect (item->canvas, etfci->drag_data_get_id);
 	etfci->drag_data_get_id = 0;
-	
+
 	if (GNOME_CANVAS_ITEM_CLASS (etfci_parent_class)->unrealize)
 		(*GNOME_CANVAS_ITEM_CLASS (etfci_parent_class)->unrealize)(item);
 }
 
 static void
-etfci_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int width, int height)
+etfci_draw (GnomeCanvasItem *item, GdkDrawable *drawable, gint x, gint y, gint width, gint height)
 {
 	ETableFieldChooserItem *etfci = E_TABLE_FIELD_CHOOSER_ITEM (item);
 	GnomeCanvas *canvas = item->canvas;
-	int rows;
-	int y1, y2;
-	int row;
+	gint rows;
+	gint y1, y2;
+	gint row;
 	GtkStyle *style;
 	GtkStateType state;
 
@@ -478,7 +477,7 @@ etfci_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int widt
 			continue;
 
 		y2 += e_table_header_compute_height (ecol, GTK_WIDGET (canvas));
-		
+
 		if (y1 > (y + height))
 			break;
 
@@ -496,7 +495,7 @@ etfci_draw (GnomeCanvasItem *item, GdkDrawable *drawable, int x, int y, int widt
 }
 
 static double
-etfci_point (GnomeCanvasItem *item, double x, double y, int cx, int cy,
+etfci_point (GnomeCanvasItem *item, double x, double y, gint cx, gint cy,
 	    GnomeCanvasItem **actual_item)
 {
 	*actual_item = item;
@@ -504,7 +503,7 @@ etfci_point (GnomeCanvasItem *item, double x, double y, int cx, int cy,
 }
 
 static gboolean
-etfci_maybe_start_drag (ETableFieldChooserItem *etfci, int x, int y)
+etfci_maybe_start_drag (ETableFieldChooserItem *etfci, gint x, gint y)
 {
 	if (!etfci->maybe_drag)
 		return FALSE;
@@ -524,11 +523,11 @@ etfci_start_drag (ETableFieldChooserItem *etfci, GdkEvent *event, double x, doub
 	GdkDragContext *context;
 	ETableCol *ecol;
 	GdkPixmap *pixmap;
-	int drag_col;
-	int button_height;
+	gint drag_col;
+	gint button_height;
 
 	GtkTargetEntry  etfci_drag_types [] = {
-		{ TARGET_ETABLE_COL_TYPE, 0, TARGET_ETABLE_COL_HEADER },
+		{ (gchar *) TARGET_ETABLE_COL_TYPE, 0, TARGET_ETABLE_COL_HEADER },
 	};
 
 	if (etfci->combined_header == NULL)
@@ -576,13 +575,13 @@ etfci_start_drag (ETableFieldChooserItem *etfci, GdkEvent *event, double x, doub
 /*
  * Handles the events on the ETableFieldChooserItem
  */
-static int
+static gint
 etfci_event (GnomeCanvasItem *item, GdkEvent *e)
 {
 	ETableFieldChooserItem *etfci = E_TABLE_FIELD_CHOOSER_ITEM (item);
 	GnomeCanvas *canvas = item->canvas;
-	int x, y;
-	
+	gint x, y;
+
 	switch (e->type){
 	case GDK_MOTION_NOTIFY:
 		gnome_canvas_w2c (canvas, e->motion.x, e->motion.y, &x, &y);
@@ -590,22 +589,22 @@ etfci_event (GnomeCanvasItem *item, GdkEvent *e)
 		if (etfci_maybe_start_drag (etfci, x, y))
 			etfci_start_drag (etfci, e, x, y);
 		break;
-		
+
 	case GDK_BUTTON_PRESS:
 		gnome_canvas_w2c (canvas, e->button.x, e->button.y, &x, &y);
-		
+
 		if (e->button.button == 1){
 			etfci->click_x = x;
 			etfci->click_y = y;
 			etfci->maybe_drag = TRUE;
 		}
 		break;
-		
+
 	case GDK_BUTTON_RELEASE: {
 		etfci->maybe_drag = FALSE;
 		break;
 	}
-	
+
 	default:
 		return FALSE;
 	}
@@ -631,35 +630,35 @@ etfci_class_init (ETableFieldChooserItemClass *klass)
 
 	g_object_class_install_property (object_class, PROP_DND_CODE,
 					 g_param_spec_string ("dnd_code",
-							      _("DnD code"),
+							      "DnD code",
 							      /*_( */"XXX blurb" /*)*/,
 							      NULL,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_FULL_HEADER,
 					 g_param_spec_object ("full_header",
-							      _("Full Header"),
+							      "Full Header",
 							      /*_( */"XXX blurb" /*)*/,
 							      E_TABLE_HEADER_TYPE,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_HEADER,
 					 g_param_spec_object ("header",
-							      _("Header"),
+							      "Header",
 							      /*_( */"XXX blurb" /*)*/,
 							      E_TABLE_HEADER_TYPE,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_WIDTH,
 					 g_param_spec_double ("width",
-							      _("Width"),
+							      "Width",
 							      /*_( */"XXX blurb" /*)*/,
 							      0, G_MAXDOUBLE, 0,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_HEIGHT,
 					 g_param_spec_double ("height",
-							      _("Height"),
+							      "Height",
 							      /*_( */"XXX blurb" /*)*/,
 							      0, G_MAXDOUBLE, 0,
 							      G_PARAM_READABLE));
@@ -671,7 +670,7 @@ etfci_init (ETableFieldChooserItem *etfci)
 	etfci->full_header = NULL;
 	etfci->header = NULL;
 	etfci->combined_header = NULL;
-	
+
 	etfci->height = etfci->width = 0;
 
 	etfci->font_desc = NULL;
