@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -48,8 +48,6 @@ struct _ETextModelPrivate {
 	GString *text;
 };
 
-static void e_text_model_class_init (ETextModelClass *class);
-static void e_text_model_init       (ETextModel *model);
 static void e_text_model_dispose    (GObject *object);
 
 static gint         e_text_model_real_validate_position (ETextModel *, gint pos);
@@ -224,10 +222,10 @@ static void
 e_text_model_real_insert_length (ETextModel *model, gint position, const gchar *text, gint length)
 {
 	EReposInsertShift repos;
-	int model_len = e_text_model_real_get_text_length (model);
-	char *offs;
-	const char *p;
-	int byte_length, l;
+	gint model_len = e_text_model_real_get_text_length (model);
+	gchar *offs;
+	const gchar *p;
+	gint byte_length, l;
 
 	if (position > model_len)
 		return;
@@ -236,7 +234,7 @@ e_text_model_real_insert_length (ETextModel *model, gint position, const gchar *
 
 	for (p = text, l = 0;
 	     l < length;
-	     p = g_utf8_next_char (p), l ++) ;
+	     p = g_utf8_next_char (p), l ++);
 
 	byte_length = p - text;
 
@@ -257,16 +255,16 @@ static void
 e_text_model_real_delete (ETextModel *model, gint position, gint length)
 {
 	EReposDeleteShift repos;
-	int byte_position, byte_length;
-	char *offs, *p;
-	int l;
+	gint byte_position, byte_length;
+	gchar *offs, *p;
+	gint l;
 
 	offs = g_utf8_offset_to_pointer (model->priv->text->str, position);
 	byte_position = offs - model->priv->text->str;
 
 	for (p = offs, l = 0;
 	     l < length;
-	     p = g_utf8_next_char (p), l ++) ;
+	     p = g_utf8_next_char (p), l ++);
 
 	byte_length = p - offs;
 
